C
C     ANOMOD - VERSION 1.10.DG1
C
      PROGRAM ANOMOD
C
C---- ANOMOD ----------------------------------------------------------M
C
C           FINITE ELEMENT SURFACE WATER MODELING SYSTEM FOR
C       TWO-DIMENSIONAL FLOW IN THE HORIZONTAL PLANE *FESWMS-2DH*
C
C                      ANALYSIS OF OUTPUT MODULE
C
C                         ----> ANOMOD <----
C
C                            DEVELOPED FOR
C
C                 U.S. DEPARTMENT OF TRANSPORTATION
C                   FEDERAL HIGHWAY ADMINISTRATION
C            OFFICE OF ENGINEERING AND HIGHWAY OPERATIONS
C                      RESEARCH AND DEVELOPMENT
C               6300 GEORGETOWN PIKE, MCLEAN, VA 22101
C
C                                 BY
C
C           U.S. GEOLOGICAL SURVEY, WATER RESOURCES DIVISION
C
C
C  PROGRAMMER: David C. Froehlich      DATE: January 1, 1988
C
C  MODIFICATIONS:
C  NO.  DATE     PROGRAMMER     DESCRIPTION
C  ==== ======== ============== =======================================
C  1.01 01/06/89 D.C. Froehlich 1. Modified sub. CLVPLT to not plot
C                               contour line values if NDECV = -2.
C  1.10 01/18/89 D.C. Froehlich 1. Corrected assignment of GRID and FLOW
C                               data files in sub. ANOFIL.
C                               2. General housecleaning.
C  1.10.DG1
C       06/03/92 KG Thibodeaux  1. Added DG time and date calls.
C                                  IDATE and TIME.
C                               2. All INCLUDE statements in the program
C                                  have been changed to be compatible
C                                  with DG and PC compilers.
C----------------------------------------------------------------------F
C
C---- Declarations (local)
      INTEGER   IER,LENCHR,IMON,IDAY,IYEAR
      REAL      X
      CHARACTER DATE*8,TIMEBUF*8,IDS*10
C
C---- Common blocks
      INCLUDE 'ANOMOD.INC'
C
C---- Data
      DATA IER/0/
C
C---- OUTPUT FORMATS
2000  FORMAT(/' *** ERROR - INPUT DATA FILE "',(A),'" CANNOT BE FOUND.')
2010  FORMAT(' DATE OF RUN IS ',I2,'/',I2,'/',I2,' (MM/DD/YY)')
2020  FORMAT(' TIME OF RUN IS ',A8,' (HH:MM:SS)')
2040  FORMAT(/' *** ERROR - FLOW DATA FILE "',(A),'" CANNOT BE FOUND.')
2050  FORMAT(/
     # ' *** ANOMOD RUN TERMINATED BECAUSE OF ',I4,' ERROR(S)!!!')
2060  FORMAT(/
     # ' *** ANOMOD RUN TERMINATED NORMALLY.')
2070  FORMAT(1H+,79(' ')/
     # 1H+,'ANOMOD run terminated because of ',I4,' error(s)!!!')
2080  FORMAT(1H+,79(' ')/
     # 1H+,'ANOMOD run terminated normally.')
C
C---- Clear the screen
Cx    CALL SETUP
      PTITLE = 
     & '$Id: anomod.f,v 2.6 1995/09/05 19:02:51 rsregan Exp rsregan $'
      Ptitle = '@(#)ANOMOD - Analysis of Output for FESWMS'
      Ptitle = '@(#)ANOMOD - FHWA Report HW031.D, D.C Froehlich'
      Ptitle = '@(#)ANOMOD - Contact: Janice Fulford, jfulford@usgs.gov'
      Ptitle = '@(#)ANOMOD - Version: 1.10.DG1 2.6x 1995/09/05'
C
C---- READ NAMES OF ANOMOD DATA FILES
      CALL ANOFIL
C
C---- OPEN PRINTED OUTPUT FILE
      INQUIRE(FILE=PRNTFILE,EXIST=EXIST)
      IF(EXIST) THEN
        OPEN(IO2,FILE=PRNTFILE)
        CLOSE(IO2,STATUS='DELETE')
      ENDIF
      OPEN(IO2,FILE=PRNTFILE,STATUS='NEW',ACCESS='SEQUENTIAL',
     # FORM='FORMATTED')
C
C---- PRINT DATE AND TIME OF RUN
      CALL FORMFD(IO2)
C      CALL DATER(DATE)
C      WRITE(IO2,2010) DATE(1:LENCHR(DATE))
      CALL IDATE(IMON,IDAY,IYEAR)
      WRITE(IO2,2010)IMON,IDAY,IYEAR
C      CALL TIMER(TIME)
C      WRITE(IO2,2020) TIME(1:LENCHR(TIME))
      CALL TIME(TIMEBUF)
      WRITE(IO2,2020)TIMEBUF
C
C---- OPEN INPUT DATA FILE
      INQUIRE(FILE=DATAFILE,EXIST=EXIST)
      IF(EXIST) THEN
        OPEN(IO1,FILE=DATAFILE,STATUS='OLD',ACCESS='SEQUENTIAL',
     #  FORM='FORMATTED')
      ELSE
        WRITE(IO2,2000) DATAFILE(1:LENCHR(DATAFILE))
        IER=IER+1
      ENDIF
      IF(IER.GT.0) GOTO 999
C
C---- READ INPUT DATA
      CALL INPUT1(IDS,IER)
      IF(IER.GT.0) GOTO 999
C---- OPEN FLOW DATA FILES IF NECESSARY
      IF(IFLOWA.NE.0) THEN
        INQUIRE(FILE=FLOWFILE,EXIST=EXIST)
        IF(EXIST) THEN
          OPEN(IO93,FILE=FLOWFILE,STATUS='OLD',ACCESS='SEQUENTIAL',
     #    FORM='FORMATTED')
          READ(IO93,'(E10.0)',ERR=1) X
          BACKSPACE IO93
          GOTO 2
1         CLOSE(IO93,STATUS='KEEP')
          OPEN(IO93,FILE=FLOWFILE,STATUS='OLD',ACCESS='SEQUENTIAL',
     #    FORM='UNFORMATTED')
2         CONTINUE
        ELSE
          WRITE(IO2,2040) FLOWFILE(1:LENCHR(FLOWFILE))
          IER=IER+1
        ENDIF
      ENDIF
      IF(IFLOWB.NE.0) THEN
        INQUIRE(FILE=FLWBFILE,EXIST=EXIST)
        IF(EXIST) THEN
          OPEN(IO94,FILE=FLWBFILE,STATUS='OLD',ACCESS='SEQUENTIAL',
     #    FORM='FORMATTED')
          READ(IO94,'(E10.0)',ERR=3) X
          BACKSPACE IO94
          GOTO 4
3         CLOSE(IO94,STATUS='KEEP')
          OPEN(IO94,FILE=FLWBFILE,STATUS='OLD',ACCESS='SEQUENTIAL',
     #    FORM='UNFORMATTED')
4         CONTINUE
        ELSE
          WRITE(IO2,2040) FLWBFILE(1:LENCHR(FLWBFILE))
          IER=IER+1
        ENDIF
      ENDIF
      IF(IER.GT.0) GOTO 999
C
C---- PRELIMINARY COMPUTATIONS
      CALL PREPLT(IER)
      IF(IER.GT.0) GOTO 999
C
C---- READ REMAINING DATA SETS UNTIL "LAST" CARD IS FOUND
10    CALL INPUT2(IDS,IER)
      IF(IER.GT.0) GOTO 20
C
C---- INITIALIZE FOR PLOTTING IF IPLINT = 0
      IF(IPLINT.EQ.0) THEN
Crsr    INQUIRE(FILE=PLOTFILE,EXIST=EXIST)
Crsr    IF(EXIST) THEN
Crsr      OPEN(LDEV,FILE=PLOTFILE)
Crsr      CLOSE(LDEV,STATUS='DELETE')
Crsr    ENDIF
Crsr    OPEN(LDEV,FILE=PLOTFILE,STATUS='NEW',ACCESS='SEQUENTIAL',
Crsr #  FORM='FORMATTED')
        CALL PLOTS(0,0,LDEV)
        IPLINT=1
      ENDIF
C
C---- PERFORM OPERATIONS
      IF(IDS.EQ.'LAST') GOTO 20
      IF(IDS.EQ.'GRID') THEN
        CALL GRDPLT
      ELSEIF(IDS.EQ.'VECT') THEN
        CALL VECPLT
      ELSEIF(IDS.EQ.'CONT') THEN
        CALL CONPLT
      ELSEIF(IDS.EQ.'FLUX') THEN
        CALL FLXPLT
      ELSEIF(IDS.EQ.'HIST') THEN
        CALL HSTPLT
      ENDIF
      IDS='    '
      GOTO 10
C
C---- TERMINATE PLOTTING IF IPLINT > -1
20    IF(IPLINT.GT.-1) CALL PLOT(XUP+1.,0.,1000)
      IF(IPLINT.GT.-1) CALL PLOT(XUP+1.,0.,999)
C
C---- All done
999   IF(IER.EQ.0) THEN
        WRITE(IO2,2060)
        IF(SCREEN) WRITE(*,2080)
      ELSE
        WRITE(IO2,2050) IER
        IF(SCREEN) WRITE(*,2070) IER
      ENDIF
      END
C
C
C
      SUBROUTINE ANOFIL
C
C---- ANOFIL ----------------------------------------------------------S
C
C  PURPOSE:
C    READS NAMES OF ANOMOD DATA FILES FROM THE FILE 'ANOMOD.FIL'
C
C----------------------------------------------------------------------F
C
      INCLUDE 'ANOMOD.INC'
      CHARACTER FILENAME*80
C
C-----INPUT FORMATS
1000  FORMAT(A)
C
      INQUIRE(FILE='ANOMOD.FIL',EXIST=EXIST)
      IF(EXIST) THEN
        OPEN(IO1,FILE='ANOMOD.FIL',STATUS='OLD')
        READ(IO1,1000) FILENAME
        IF(FILENAME.NE.' ') DATAFILE=FILENAME
        READ(IO1,1000) FILENAME
        IF(FILENAME.NE.' ') PRNTFILE=FILENAME
        READ(IO1,1000) FILENAME
        IF(FILENAME.NE.' ') THEN
          GRIDFILE=FILENAME
          GRDAFILE=FILENAME
        ENDIF
        READ(IO1,1000) FILENAME
        IF(FILENAME.NE.' ') THEN
          FLOWFILE=FILENAME
          FLWAFILE=FILENAME
        ENDIF
        READ(IO1,1000) FILENAME
        IF(FILENAME.NE.' ') GRDBFILE=FILENAME
        READ(IO1,1000) FILENAME
        IF(FILENAME.NE.' ') FLWBFILE=FILENAME
        READ(IO1,1000) FILENAME
        IF(FILENAME.NE.' ') PLOTFILE=FILENAME
        CLOSE(IO1)
      ENDIF
      RETURN
      END
C
C
C
      SUBROUTINE TBLOCK(WIDE,VERSION,IO2)
C
C---- TBLOCK ---------------------------------------------------------S
C
C  PURPOSE:
C    PRINTS THE TITLE BLOCK.
C
C  INPUT ARGUMENT(S):
C    WIDE    - PRINT OUTPUT FORMAT CONTROL VARIABLE.
C    VERSION - PROGRAM VERSION NUMBER.
C    IO2     - OUTPUT FILE UNIT NUMBER.
C
C---------------------------------------------------------------------F
C
C---- Declarations (arguments)
      INTEGER   IO2
      CHARACTER VERSION*8
      LOGICAL   WIDE
C
C-----OUTPUT FORMATS
2000  FORMAT(/
     # 27X,78('=')/27X,'>>>>',70X,'<<<<'/27X,'>>>>',12X,
     # 'FINITE ELEMENT SURFACE WATER MODELING SYSTEM:',
     # 13X,'<<<<'/27X,'>>>>',6X,
     # 'TWO-DIMENSIONAL FLOW IN THE HORIZONTAL PLANE *FESWMS-2DH*',
     # 7X,'<<<<'/27X,'>>>>',70X,'<<<<'/27X,'>>>>',15X,
     # 'ANALYSIS OF OUTPUT MODULE - VERSION ',A8,11X,'<<<<'/
     # 27X,'>>>>',70X,'<<<<'/27X,'>>>>',28X,'DEVELOPED FOR',29X,'<<<<'/
     # 27X,'>>>>',70X,'<<<<'/27X,'>>>>',18X,
     # 'U.S. DEPARTMENT OF TRANSPORTATION',19X,'<<<<'/27X,'>>>>',20X,
     # 'FEDERAL HIGHWAY ADMINISTRATION',20X,'<<<<'/27X,'>>>>',13X,
     # 'OFFICE OF ENGINEERING AND HIGHWAY OPERATIONS',13X,'<<<<'/
     # 27X,'>>>>',23X,'RESEARCH AND DEVELOPMENT',23X,'<<<<'/
     # 27X,'>>>>',16X,'6300 GEORGETOWN PIKE, MCLEAN, VA 22101',
     # 16X,'<<<<'/27X,'>>>>',70X,'<<<<'/27X,'>>>>',34X,'BY',34X,'<<<<'/
     # 27X,'>>>>',70X,'<<<<'/27X,'>>>>',11X,
     # 'U.S. GEOLOGICAL SURVEY, WATER RESOURCES DIVISION',
     # 11X,'<<<<'/27X,'>>>>',70X,'<<<<'/27X,78('=')/)
2100  FORMAT(/
     # 1X,78('=')/1X,'>>>>',70X,'<<<<'/1X,'>>>>',12X,
     # 'FINITE ELEMENT SURFACE WATER MODELING SYSTEM -',
     # 12X,'<<<<'/1X,'>>>>',6X,
     # 'TWO-DIMENSIONAL FLOW IN THE HORIZONTAL PLANE *FESWMS-2DH*',
     # 7X,'<<<<'/1X,'>>>>',70X,'<<<<'/1X,'>>>>',15X,
     # 'ANALYSIS OF OUTPUT MODULE - VERSION ',A8,11X,'<<<<'/
     # 1X,'>>>>',70X,'<<<<'/1X,'>>>>',28X,'DEVELOPED FOR',29X,'<<<<'/
     # 1X,'>>>>',70X,'<<<<'/1X,'>>>>',18X,
     # 'U.S. DEPARTMENT OF TRANSPORTATION',19X,'<<<<'/1X,'>>>>',20X,
     # 'FEDERAL HIGHWAY ADMINISTRATION',20X,'<<<<'/1X,'>>>>',13X,
     # 'OFFICE OF ENGINEERING AND HIGHWAY OPERATIONS',13X,'<<<<'/
     # 1X,'>>>>',23X,'RESEARCH AND DEVELOPMENT',23X,'<<<<'/
     # 1X,'>>>>',16X,'6300 GEORGETOWN PIKE, MCLEAN, VA 22101',
     # 16X,'<<<<'/1X,'>>>>',70X,'<<<<'/1X,'>>>>',34X,'BY',34X,'<<<<'/
     # 1X,'>>>>',70X,'<<<<'/1X,'>>>>',11X,
     # 'U.S. GEOLOGICAL SURVEY, WATER RESOURCES DIVISION',
     # 11X,'<<<<'/1X,'>>>>',70X,'<<<<'/1X,78('=')/)
C
C-----PRINT TITLE BLOCK
      IF(WIDE) THEN
        WRITE(IO2,2000) VERSION
      ELSE
        WRITE(IO2,2100) VERSION
      ENDIF
      RETURN
      END
C
C
C
      SUBROUTINE INPUT1(IDS,IER)
C
C---- INPUT1 ----------------------------------------------------------S
C
C  PURPOSE:
C    READS PROGRAM CONTROL (SWMS), GEOMETRIC, AND FLOW DATA.
C
C  OUTPUT ARGUMENT(S):
C    IDS - DATA SET IDENTIFICATION CODE.
C    IER - ERROR COUNT; INCREMENTED BY ONE EACH TIME AN ERROR IS FOUND.
C
C----------------------------------------------------------------------F
C
C---- Declarations (arguments)
      INTEGER   IER
      CHARACTER IDS*(*)
C
C---- Declarations (local)
      INTEGER   IGRIDA,IGRIDB,INX,K,L,LENCHR,M,N,NPX,NEX,I
      REAL      X,XIN,XFACT,YFACT,ZFACT,XZERO,YZERO,ZZERO
C
C---- Common blocks
      INCLUDE 'ANOMOD.INC'
C
C---- Dimensions
      DIMENSION XIN(8),INX(16)
C
C---- INPUT FORMATS
1000  FORMAT(8E10.0)
1010  FORMAT(16I5)
1020  FORMAT(A10,7E10.0)
1030  FORMAT(8I10)
1040  FORMAT(I10,7E10.0)
C
C---- OUTPUT FORMATS
2000  FORMAT(/' ===> FESWMS-2DH -- ANOMOD Ver. ',A8,' <==='/)
2001  FORMAT(1H+,79(' ')/1H+,'Reading ',(A),'...')
2010  FORMAT(/
     # 26X,'*** PROGRAM CONTROL DATA ***'//
     # 46X,'PRINT OPTION CODE............:',I4/
     # 46X,'PRIMARY NETWORK DATA FILE....:',I4/
     # 46X,'PRIMARY FLOW DATA FILE.......:',I4/
     # 46X,'SECONDARY NETWORK DATA FILE..:',I4/
     # 46X,'SECONDARY FLOW DATA FILE.....:',I4/
     # 46X,'UNITS CODE (0=U.S., 1=S.I.)..:',I4/
     # 46X,'STARTING PRINT TIME (HRS)....:',F10.2/
     # 46X,'ENDING PRINT TIME (HRS)......:',F10.2)
 2020 FORMAT(//56X,'*** ELEMENT DATA ***'/)
 2030 FORMAT(//53X,'*** NODE DATA (PRIMARY) ***'/
     # /36X,6F10.4/)
 2031 FORMAT(//52X,'*** NODE DATA (SECONDARY) ***'/
     # /36X,6F10.4/)
 2040 FORMAT(/53X,'*** FLOW DATA (PRIMARY) ***'/)
 2041 FORMAT(/52X,'*** FLOW DATA (SECONDARY) ***'/)
 2095 FORMAT(/57X,'*** END OF DATA ***'/)
 2110 FORMAT(/
     # 26X,'*** PROGRAM CONTROL DATA ***'//
     # 20X,'PRINT OPTION CODE............:',I4/
     # 20X,'PRIMARY NETWORK DATA FILE....:',I4/
     # 20X,'PRIMARY FLOW DATA FILE.......:',I4/
     # 20X,'SECONDARY NETWORK DATA FILE..:',I4/
     # 20X,'SECONDARY FLOW DATA FILE.....:',I4/
     # 20X,'UNITS CODE (0=U.S., 1=S.I.)..:',I4/
     # 20X,'STARTING PRINT TIME (HRS)....:',F10.2/
     # 20X,'ENDING PRINT TIME (HRS)......:',F10.2)
 2120 FORMAT(//30X,'*** ELEMENT DATA ***'/)
 2130 FORMAT(//27X,'*** NODE DATA (PRIMARY) ***'/
     # /10X,6F10.4/)
 2131 FORMAT(//26X,'*** NODE DATA (SECONDARY) ***'/
     # /10X,6F10.4/)
 2140 FORMAT(/26X,'*** FLOW DATA (PRIMARY) ***'/)
 2141 FORMAT(/25X,'*** FLOW DATA (SECONDARY) ***'/)
 2195 FORMAT(/31X,'*** END OF DATA ***'/)
 2200 FORMAT(/' ***ERROR - NETWORK DATA FILE ',(A),' CANNOT BE FOUND.')
 2210 FORMAT(/' ***ERROR - SWMS DATA SET NOT FOUND.')
C
C---- INITIALIZE VARIABLES
      SCREEN=.FALSE.
      WIDE=.TRUE.
      IER=0
      NP=0
      NE=0
      DO 20 N=1,MAXP
        DO 10 K=1,3
          XVELA(K,N)=0.0
          XVELB(K,N)=0.0
10      CONTINUE
        CORD(N,1)=0.0
        CORD(N,2)=0.0
        GRNDA(N)=0.0
20    CONTINUE
      DO 40 L=1,MAXE
        DO 30 K=1,9
           NOP(L,K)=0
30      CONTINUE
        LMAT(L)=0
        LSEQ(L)=0
40    CONTINUE
C
C---- READ PROGRAM CONTROL DATA
50    READ(IO1,1020,END=900) IDS,(XIN(K),K=1,7)
      IF(IDS(1:4).NE.ID(1)) GOTO 50
      IF(XIN(1).GT.0.) WIDE=.FALSE.
      IF(XIN(2).GT.0.) SCREEN=.TRUE.
      TFIRST=XIN(6)
      TLAST=XIN(7)
C
C---- SCREEN ACKNOWLEDGEMENT
      IF(SCREEN) THEN
        WRITE(*,2000) VERSION
        WRITE(*,2001) DATAFILE(1:LENCHR(DATAFILE))
      ENDIF
C
C---- PRINT TITLE BLOCK
      CALL TBLOCK(WIDE,VERSION,IO2)
C
C---- SWMS DATA SET
      READ(IO1,1010) IPRNT,IGRIDA,IFLOWA,IGRIDB,IFLOWB,IUNITS
      IF(WIDE) THEN
        WRITE(IO2,2010)IPRNT,IGRIDA,IFLOWA,IGRIDB,IFLOWB,IUNITS,
     #  TFIRST,TLAST
      ELSE
        WRITE(IO2,2110)IPRNT,IGRIDA,IFLOWA,IGRIDB,IFLOWB,IUNITS,
     #  TFIRST,TLAST
      ENDIF
C
C---- READ PRIMARY NETWORK DATA FILE
      IF(IGRIDA.NE.0) THEN
        INQUIRE(FILE=GRIDFILE,EXIST=EXIST)
        IF(EXIST) THEN
          GRDAFILE=GRIDFILE
        ELSE
          INQUIRE(FILE=GRDAFILE,EXIST=EXIST)
          IF(.NOT.EXIST) THEN
            WRITE(IO2,2200) GRDAFILE(1:LENCHR(GRDAFILE))
            IER=IER+1
          ENDIF
        ENDIF
        IF(EXIST) THEN
          IF(SCREEN) WRITE(*,2001) GRDAFILE(1:LENCHR(GRDAFILE))
          OPEN(IO91,FILE=GRDAFILE,STATUS='OLD',ACCESS='SEQUENTIAL',
     #    FORM='FORMATTED')
          READ(IO91,'(2I10)',ERR=60) NP,NE
          READ(IO91,'(I10,3E10.0)') (N,(CORD(N,K),K=1,2),GRNDA(N),
     #    I=1,NP)
          READ(IO91,'(12I5)') (L,(NOP(L,K),K=1,9),LMAT(L),LSEQ(L),
     #    I=1,NE)
          GOTO 70
60        CLOSE(IO91)
          OPEN(IO91,FILE=GRDAFILE,STATUS='OLD',ACCESS='SEQUENTIAL',
     #    FORM='UNFORMATTED')
          READ(IO91) NP,NE
          READ(IO91) ((CORD(N,K),K=1,2),GRNDA(N),X,N=1,NP)
          READ(IO91) ((NOP(L,K),K=1,9),LMAT(L),LSEQ(L),L=1,NE)
70        CLOSE(IO91,STATUS='KEEP')
        ENDIF
      ENDIF
C
C---- READ SECONDARY NETWORK DATA FILE
      IF(IGRIDB.NE.0) THEN
        INQUIRE(FILE=GRDBFILE,EXIST=EXIST)
        IF(.NOT.EXIST) THEN
          WRITE(IO2,2200) GRDBFILE(1:LENCHR(GRDBFILE))
          IER=IER+1
        ENDIF
        IF(EXIST) THEN
          IF(SCREEN) WRITE(*,2001) GRDBFILE(1:LENCHR(GRDAFILE))
          OPEN(IO92,FILE=GRDBFILE,STATUS='OLD',ACCESS='SEQUENTIAL',
     #    FORM='FORMATTED')
          READ(IO92,'(2I10)',ERR=80) NPX,NEX
          READ(IO92,'(I10,3E10.0)') (N,X,X,GRNDB(N),I=1,NPX)
          GOTO 90
80        CLOSE(IO92)
          OPEN(IO92,FILE=GRDBFILE,STATUS='OLD',ACCESS='SEQUENTIAL',
     #    FORM='UNFORMATTED')
          READ(IO92) NPX,NEX
          READ(IO92) (X,X,GRNDB(N),X,N=1,NPX)
90        CLOSE(IO92,STATUS='KEEP')
        ENDIF
      ENDIF
C
C---- READ REMAINING INPUT DATA
      IF(SCREEN) WRITE(*,2001) DATAFILE(1:LENCHR(DATAFILE))
      IF(MOD(IPRNT,2).EQ.1) ECHO=.TRUE.
110   READ(IO1,1020) IDS,(XIN(K),K=1,7)
      DO 112 K=2,12
        IF(IDS(1:4).EQ.ID(K)) GOTO 114
112   CONTINUE
      GOTO 114
114   GOTO (110,120,130,140,140,160,160,160,160,160,160,160),K
C
C---- ELEM DATA SET
120   IF(ECHO) THEN
        IF(WIDE) THEN
          WRITE(IO2,2020)
        ELSE
          WRITE(IO2,2120)
        ENDIF
      ENDIF
121   READ(IO1,1010,END=220) L,(INX(K),K=1,10)
      IF(L.EQ.0) GOTO 110
      IF(ECHO) THEN
        IF(WIDE) THEN
          WRITE(IO2,'(39X,11I5)') L,(INX(K),K=1,11)
        ELSE
          WRITE(IO2,'(13X,11I5)') L,(INX(K),K=1,11)
        ENDIF
      ENDIF
      CALL LCHECK(L,IDS,MAXE,IO2,IER,ERR)
      IF(ERR) GOTO 121
      DO 122 K=1,9
        N=INX(K)
        CALL NCHECK(N,IDS,MAXP,IO2,IER,ERR)
        IF(.NOT.ERR) THEN
          NOP(L,K)=N
          IF(N.GT.NP) NP=N
        ENDIF
122   CONTINUE
      LMAT(L)=INX(10)
      LSEQ(L)=INX(11)
      IF(L.GT.NE) NE=L
      GOTO 121
C
C---- NODE DATA SET
130   IF(ECHO) THEN
        IF(WIDE) THEN
          IF( IDS(1:5).EQ.'NODE ' .OR. IDS(1:5).EQ.'NODEA' ) THEN
            WRITE(IO2,2030) (XIN(K),K=1,6)
          ELSE
            WRITE(IO2,2031) (XIN(K),K=1,6)
          ENDIF
        ELSE
          IF( IDS(1:5).EQ.'NODE ' .OR. IDS(1:5).EQ.'NODEA' ) THEN
            WRITE(IO2,2130) (XIN(K),K=1,6)
          ELSE
            WRITE(IO2,2131) (XIN(K),K=1,6)
          ENDIF
        ENDIF
      ENDIF
      XFACT=XIN(1)
      YFACT=XIN(2)
      ZFACT=XIN(3)
      XZERO=XIN(4)
      YZERO=XIN(5)
      ZZERO=XIN(6)
      ZIP=1.E-08
      IF(XFACT.LT.ZIP) XFACT=1.0
      IF(YFACT.LT.ZIP) YFACT=1.0
      IF(ZFACT.LT.ZIP) ZFACT=1.0
131   READ(IO1,1040,END=220) N,(XIN(K),K=1,4)
      IF(N.EQ.0) GOTO 110
      IF(ECHO) THEN
        IF(WIDE) THEN
          WRITE(IO2,'(41X,I10,4F10.2)') N,(XIN(K),K=1,4)
        ELSE
          WRITE(IO2,'(15X,I10,4F10.2)') N,(XIN(K),K=1,4)
        ENDIF
      ENDIF
      CALL NCHECK(N,IDS,MAXP,IO2,IER,ERR)
      IF(.NOT.ERR) THEN
        IF( IDS(1:5).EQ.'NODE ' .OR. IDS(1:5).EQ.'NODEA' ) THEN
          CORD(N,1)=XIN(1)*XFACT+XZERO
          CORD(N,2)=XIN(2)*YFACT+YZERO
          GRNDA(N)=XIN(3)*ZFACT+ZZERO
        ELSE
          GRNDB(N)=XIN(3)*ZFACT+ZZERO
        ENDIF
        IF(N.GT.NP) NP=N
      ENDIF
      GOTO 131
C
C---- FLOW DATA SET
140   IF(ECHO) THEN
        IF(WIDE) THEN
          IF( IDS(1:5).EQ.'FLOW ' .OR. IDS(1:5).EQ.'FLOWA' ) THEN
            WRITE(IO2,2040)
          ELSE
            WRITE(IO2,2041)
          ENDIF
        ELSE
          IF( IDS(1:5).EQ.'NODE ' .OR. IDS(1:5).EQ.'NODEA' ) THEN
            WRITE(IO2,2140)
          ELSE
            WRITE(IO2,2141)
          ENDIF
        ENDIF
      ENDIF
141   READ(IO1,1040,END=220) N,(XIN(K),K=1,6)
      IF(N.EQ.0) GOTO 110
      IF(ECHO) THEN
        IF(WIDE) THEN
          WRITE(IO2,'(31X,I10,1P6E10.3)') N,(XIN(K),K=1,6)
        ELSE
          WRITE(IO2,'(5X,I10,1P6E10.3)') N,(XIN(K),K=1,6)
        ENDIF
      ENDIF
      CALL NCHECK(N,IDS,MAXP,IO2,IER,ERR)
      IF(.NOT.ERR) THEN
        IF( IDS(1:5).EQ.'FLOW ' .OR. IDS(1:5).EQ.'FLOWA' ) THEN
          DO 142 K=1,3
            XVELA(K,N)=XIN(K)
142       CONTINUE
        ELSE
          DO 143 K=1,3
            XVELB(K,N)=XIN(K)
143       CONTINUE
        ENDIF
      ENDIF
      GOTO 141
C
C---- OPERATIONS DATA SETS
160   BACKSPACE IO1
220   RETURN
C
C---- END OF FILE
900   WRITE(IO2,2210)
      IER=IER+1
      RETURN
      END
C
C
C
      SUBROUTINE INPUT2(IDS,IER)
C
C---- INPUT2 ----------------------------------------------------------S
C
C  PURPOSE:
C    READS OPERATION DATA SETS.
C
C  OUTPUT ARGUMENT(S):
C    IER - ERROR COUNT; INCREMENTED BY ONE EACH TIME AN ERROR IS FOUND.
C
C  SUBROUTINE(S) CALLED:
C    ASPLTP, FLORED NCHECK
C
C----------------------------------------------------------------------F
C
C---- Declarations (arguments)
      INTEGER   IER
      CHARACTER IDS*(*)
C
C---- Decalartions (local)
      INTEGER   INX,K,KHI,KODE,LENCHR,N
      REAL      XIN,AHTYP
C
C---- Common blocks
      INCLUDE 'ANOMOD.INC'
C
C---- Dimensions
      DIMENSION XIN(8),INX(16)
C
C-----OUTPUT FORMATS
2000  FORMAT(1H+,79(' ')/1H+,'Reading ',(A),'...')
2060  FORMAT(/1X,'*** GRID PLOT DATA ***')
2061  FORMAT(/1X,'PLOT TITLE:'/1X,A79)
2062  FORMAT(/
     # 1X,'PLOT CODES FOR:'/
     # 1X,'  NODE VALUES     ',I3/
     # 1X,'  ELEMENT VALUES  ',I3)
2063  FORMAT(/
     # 1X,'CHARACTER HEIGHTS OF:'/
     # 1X,'  TITLE         ',F8.3/
     # 1X,'  NODE VALUES   ',F8.3/
     # 1X,'  ELEMENT VALUES',F8.3)
2064  FORMAT(/
     # 1X,'PLOT TRANSFORMATION DATA:'/
     # 1X,'  LOWER X-COORDINATE ',F10.2/
     # 1X,'  LOWER Y-COORDINATE ',F10.2/
     # 1X,'  X DIRECTION OFFSET ',F10.2/
     # 1X,'  Y DIRECTION OFFSET ',F10.2/
     # 1X,'  X-COORDINATE SCALE ',F10.2/
     # 1X,'  Y-COORDINATE SCALE ',F10.2/
     # 1X,'  ANGLE OF ROTATION  ',F10.2)
2070  FORMAT(/1X,'*** VECTOR PLOT DATA ***')
2071  FORMAT(/1X,'SIMULATION TIME (HOURS) ',F8.3)
2072  FORMAT(/1X,'PLOT TITLE:'/1X,A79)
2073  FORMAT(/
     # 1X,'PLOT CODES FOR'/
     # 1X,'  VECTORS...........:',I3/
     # 1X,'  SCALAR VALUES.....:',I3)
2074  FORMAT(/
     # 1X,'VECTOR PARAMETERS'/
     # 1X,'  VECTOR SCALE......:',F8.3/
     # 1X,'  MINIMUM LENGTH....:',F8.3/
     # 1X,'  VECTOR TYPE CODE..:',F8.3/
     # 1X,'  ARROWHEAD LENGTH..:',F8.3)
2075  FORMAT(/
     # 1X,'CHARACTER HEIGHTS'/
     # 1X,'  PLOT TITLE........:',F8.3/
     # 1X,'  NODE VALUES.......:',F8.3)
2080  FORMAT(/1X,'*** CONTOUR PLOT DATA ***')
2081  FORMAT(/1X,'SIMULATION TIME (HOURS) ',F8.3)
2082  FORMAT(/1X,'PLOT TITLE:'/1X,A79)
2083  FORMAT(/
     # 1X,'PLOT CODES FOR'/
     # 1X,'  PLOT OPTIONS......:',I3/
     # 1X,'  CONTOUR VALUES....:',I3/
     # 1X,'  DECIMAL PLACES....:',I3)
2084  FORMAT(/
     # 1X,'CONTOUR PARAMETERS'/
     # 1X,'  MIN CONTOUR VALUE.:',F8.3/
     # 1X,'  MAX CONTOUR VALUE.:',F8.3/
     # 1X,'  CONTOUR INTERVAL..:',F8.3)
2085  FORMAT(/
     # 1X,'CHARACTER HEIGHTS'/
     # 1X,'  PLOT TITLE........:',F8.3/
     # 1X,'  NODE VALUES.......:',F8.3/
     # 1X,'  CONTOUR VALUES....:',F8.3)
2090  FORMAT(/1X,'*** TIME HISTORY DATA ***')
2091  FORMAT(/
     # 1X,'SIMULATION TIMES (HOURS)'/
     # 1X,'  FIRST.............:',F8.3/
     # 1X,'  LAST..............:',F8.3)
2092  FORMAT(/
     # 1X,'REPORT/PLOT CODES'/
     # 1X,'  REPORT............:',I3/
     # 1X,'  PLOT..............:',I3)
2093  FORMAT(/2X,'NODE',6X,'PLOT'/3X,'NO.',6X,'CODE'/)
2094  FORMAT(1X,I5,I10)
2099  FORMAT(/' ***ERROR - NUMBER OF TIME HISTORY NODES EXCEEDS ',
     # 'MAXIMUM.')
2100  FORMAT(/1X,'*** FLOW CHECK DATA ***')
2101  FORMAT(/1X,'SIMULATION TIME (HOURS) ',F8.3)
2102  FORMAT(/1X,'PLOT TITLE:'/1X,A79)
2103  FORMAT(/
     # 1X,'REPORT/PLOT CODES'/
     # 1X,'  REPORT............:',I3/
     # 1X,'  PLOT..............:',I3/
     # 1X,'  DECIMAL PLACES....:',I3)
2104  FORMAT(/
     # 1X,'CHARACTER HEIGHT (INCHES) OF:'/
     # 1X,'  PLOT TITLE........:',F8.3/
     # 1X,'  FLOW VALUES.......:',F8.3)
2105  FORMAT(/1X,'LINE NO. ',I3)
2109  FORMAT(/' ***ERR0R - MAXIMUM NUMBER OF CONTINUITY LINES',
     # ' HAS BEEN EXCEEDED')
2120  FORMAT(/57X,'*** END OF DATA ***')
2121  FORMAT(/30X,'*** END OF DATA ***')
C
C-----SCREEN ACKNOWLEDGEMENT
      IF(SCREEN) WRITE(*,2000) DATAFILE(1:LENCHR(DATAFILE))
C
C-----SEARCH FOR NEXT DATA SET IDENTIFICATION CARD
100   READ(IO1,'(A10,7E10.0)',END=12) IDS,(XIN(K),K=1,7)
      DO 102 K=4,12
        IF(IDS(1:4).EQ.ID(K)) GOTO 103
102   CONTINUE
      GOTO 100
103   GOTO(100,100,100,100,100,6,7,8,9,10,11,12),K
C
C-----GRID PLOT DATA SET
6     WRITE(IO2,2060)
      IPLINT=IPLINT+1
      NEWPLT=.TRUE.
      IF(XIN(7).GT.0) NEWPLT=.FALSE.
      READ(IO1,'(A)') PTITLE
      WRITE(IO2,2061)PTITLE
      READ(IO1,'(2I5)') IPLTN,IPLTE
      WRITE(IO2,2062)IPLTN,IPLTE
      READ(IO1,'(3E10.0)') HTT,HTN,HTE
      WRITE(IO2,2063) HTT,HTN,HTE
      READ(IO1,'(7E10.0)') (XIN(K),K=1,7)
      CALL ASPLTP(XIN,XL,YL,XOFF,YOFF,XSCALE,YSCALE,AROT)
      IF(ABS(XL).LT.ZIP) XL=XMIN
      IF(ABS(YL).LT.ZIP) YL=YMIN
      IF(ABS(XOFF).LT.ZIP) XOFF=1.0E+6
      IF(ABS(YOFF).LT.ZIP) YOFF=1.0E+6
      WRITE(IO2,2064) XL,YL,XOFF,YOFF,XSCALE,YSCALE,AROT
      GOTO 999
C
C-----VECTOR PLOT DATA SET
7     WRITE(IO2,2070)
      IPLINT=IPLINT+1
      NEWPLT=.TRUE.
      IF(XIN(7).GT.0) NEWPLT=.FALSE.
      STIME=XIN(1)
      WRITE(IO2,2071) STIME
      READ(IO1,'(A)') PTITLE
      WRITE(IO2,2072) PTITLE
      READ(IO1,'(2I5)') IPLTV,IPLTS
      WRITE(IO2,2073)IPLTV,IPLTS
      READ(IO1,'(4E10.0)') VSCALE,VLMIN,AHTYP,AHLEN
      WRITE(IO2,2074)VSCALE,VLMIN,AHTYP,AHLEN
      IARHD=INT(AHTYP)
      READ(IO1,'(2E10.0)') HTT,HTN
      WRITE(IO2,2075)HTT,HTN
      READ(IO1,'(7E10.0)') (XIN(K),K=1,7)
      CALL ASPLTP(XIN,XL,YL,XOFF,YOFF,XSCALE,YSCALE,AROT)
      WRITE(IO2,2064) XL,YL,XOFF,YOFF,XSCALE,YSCALE,AROT
      IF(ABS(XL).LT.ZIP) XL=XMIN
      IF(ABS(YL).LT.ZIP) YL=YMIN
      IF(ABS(XOFF).LT.ZIP) XOFF=1.0E+35
      IF(ABS(YOFF).LT.ZIP) YOFF=1.0E+35
      IF(IFLOWA.NE.0) THEN
        CALL FLORED(FLWAFILE,IO93,STIME,STCURA,XVELA,SCREEN,IO2)
      ENDIF
      GOTO 999
C
C-----CONTOUR PLOT DATA
8     WRITE(IO2,2080)
      IPLINT=IPLINT+1
      NEWPLT=.TRUE.
      IF(XIN(7).GT.0.) NEWPLT=.FALSE.
      STIME=XIN(1)
      WRITE(IO2,2081)
      READ(IO1,'(A)') PTITLE
      WRITE(IO2,2082) PTITLE
      READ(IO1,'(3I5)') IPLTC,ICVAL,NDECV
      WRITE(IO2,2083) IPLTC,ICVAL,NDECV
      READ(IO1,'(3E10.0)') CVMIN,CVMAX,CVINC
      WRITE(IO2,2084) CVMIN,CVMAX,CVINC
      READ(IO1,'(3E10.0)') HTT,HTN,HTC
      WRITE(IO2,2085) HTT,HTN,HTC
      READ(IO1,'(7E10.0)') (XIN(K),K=1,7)
      CALL ASPLTP(XIN,XL,YL,XOFF,YOFF,XSCALE,YSCALE,AROT)
      WRITE(IO2,2064) XL,YL,XOFF,YOFF,XSCALE,YSCALE,AROT
      IF(ABS(XL).LT.ZIP) XL=XMIN
      IF(ABS(YL).LT.ZIP) YL=YMIN
      IF(ABS(XOFF).LT.ZIP) XOFF=1.0E+35
      IF(ABS(YOFF).LT.ZIP) YOFF=1.0E+35
      IF(IFLOWA.NE.0) THEN
        CALL FLORED(FLWAFILE,IO93,STIME,STCURA,XVELA,SCREEN,IO2)
      ENDIF
      IF(ICVAL.LT.0.AND.IFLOWB.NE.0) THEN
        CALL FLORED(FLWBFILE,IO94,STIME,STCURB,XVELB,SCREEN,IO2)
      ENDIF
      GOTO 999
C
C---- TIME HISTORY DATA
9     WRITE(IO2,2090)
      TFIRST=XIN(1)
      TLAST=XIN(2)
      WRITE(IO2,2091) TFIRST,TLAST
      IF(TLAST.LT.TFIRST) TLAST=TFIRST
      NPTH=0
      WRITE(IO2,2093)
190   READ(IO1,'(2I10)') N,KODE
      IF(N.EQ.0) GOTO 999
      WRITE(IO2,2094) N,KODE
      CALL NCHECK(N,IDS,MAXP,IO2,IER,ERR)
      NPTH=NPTH+1
      IF(NPTH.GT.MAXTHP) THEN
        IER=IER+1
        WRITE(IO2,2099) MAXTHP
        GOTO 999
      ENDIF
      NTHP(NPTH)=N
      KTHP(NPTH)=KODE
      IF(MOD(KODE,1000).GT.0) IPLINT=IPLINT+1
      GOTO 190
C
C---- FLUX DATA
10    WRITE(IO2,2100)
      IPLINT=IPLINT+1
      NEWPLT=.TRUE.
      IF(XIN(7).GT.0.) NEWPLT=.FALSE.
      STIME=XIN(1)
      WRITE(IO2,2101) STIME
      READ(IO1,'(A)') PTITLE
      WRITE(IO2,2102) PTITLE
      READ(IO1,'(3I5)') IPRTF,IPLTF,NDECF
      WRITE(IO2,2103) IPRTF,IPLTF,NDECF
      READ(IO1,'(2E10.0)') HTT,HTN
      WRITE(IO2,2104) HTT,HTN
      READ(IO1,'(7E10.0)') (XIN(K),K=1,7)
      WRITE(IO2,2064) (XIN(K),K=1,7)
      CALL ASPLTP(XIN,XL,YL,XOFF,YOFF,XSCALE,YSCALE,AROT)
      IF(IFLOWA.NE.0) THEN
        CALL FLORED(FLWAFILE,IO93,STIME,STCURA,XVELA,SCREEN,IO2)
      ENDIF
      KHI=0
      NCL=0
203   READ(IO1,'(16I5)') (INX(K),K=1,16)
      IF(INX(1).EQ.0) GOTO 999
      IF(KHI.EQ.0) WRITE(IO2,2105) NCL+1
      WRITE(IO2,'(16I5)') (INX(K),K=1,16)
      DO 206 K=1,16
        N=INX(K)
        IF(N.LT.0) THEN
          IF(KHI.EQ.0) GOTO 203
          KHI=KHI+1
          LINE(KHI)=0
          NCL=NCL+1
          GOTO 203
        ELSEIF(N.GT.0) THEN
          KHI=KHI+1
          IF(KHI.GT.MAXLP) THEN
            IER=IER+1
            WRITE(IO2,2109)
            GOTO 100
          ENDIF
          CALL NCHECK(N,IDS,MAXP,IO2,IER,ERR)
          LINE(KHI)=N
        ENDIF
206   CONTINUE
      GOTO 203
11    GOTO 999
C
C---- END OF DATA
12    IF(WIDE) THEN
        WRITE(IO2,2120)
      ELSE
        WRITE(IO2,2121)
      ENDIF
999   RETURN
      END
C
C
C
      SUBROUTINE ASPLTP(XIN,XL,YL,XOFF,YOFF,XSCALE,YSCALE,AROT)
C
C--- ASPLTP -----------------------------------------------------------S
C
C  PURPOSE:
C    ASSIGNS PLOT TRANSFORMATION PARAMETERS.
C
C  INPUT ARGUMENT(S):
C    XIN - AN ARRAY OF INPUT VALUES.
C
C  OUTPUT ARGUMENT(S):
C    XL,YL - COORDINATES OF THE LOWER LEFT CORNER OF THE AREA TO BE
C            PLOTTED BEFORE ROTATION.
C    XOFF,YOFF - X AND Y DIRECTION OFFSETS.
C    XSCALE,YSCALE - X AND Y SCALE FACTORS IN FEET(METERS)/INCH.
C    AROT - ANGLE OF ROTATION (COUNTERCLOCKWISE) IN DEGREES.
C
C----------------------------------------------------------------------F
C
C---- Declarations (arguments)
      REAL      XIN,XL,YL,XOFF,YOFF,XSCALE,YSCALE,AROT
C
C---- Dimensions
      DIMENSION XIN(7)
C
      XL=XIN(1)
      YL=XIN(2)
      XOFF=XIN(3)
      YOFF=XIN(4)
      XSCALE=XIN(5)
      YSCALE=XIN(6)
      AROT=XIN(7)
      RETURN
      END
C
C
C
      SUBROUTINE FLOPRT(NP,XVEL,GRND,WIDE,IUNITS,IO2,PRNTFILE,SCREEN)
C
C---- FLOPRT ----------------------------------------------------------S
C
C  PURPOSE:
C    PRINTS FLOW DATA
C
C  INPUT ARGUMENT(S):
C    NP       - MAXIMUM NODE POINT NUMBER IN THE NETWORK.
C    XVEL     - ARRAY OF FLOW-FIELD VALUES.
C    GRND     - GROUND-SURFACE ELEVATION ARRAY.
C    WIDE     - 132-COLUMN WIDE PRINTOUT IF WIDE IS .TRUE., OTHERWISE,
C               80-COLUMN WIDE PRINTOUT
C    IUNITS   - UNIT CODE. 0 = U.S. CUSTOMARY UNITS, 1 = S.I. UNITS.
C    IO2      - UNIT NUMBER OF PRINTED OUTPUT FILE.
C    PRNTFILE - NAME OF OUTPUT FILE.
C    SCREEN   - SCREEN ACKNOWLEDGMENT CODE.
C
C----------------------------------------------------------------------F
C
C---- Declarations (arguments)
      INTEGER   NP,IUNITS,IO2
      REAL      XVEL,GRND
      LOGICAL   WIDE,SCREEN
      CHARACTER PRNTFILE*(*)
C
C---- Declarations (local)
      INTEGER   J,JINT,N,LENCHR
C
C---- Dimensions
      DIMENSION XVEL(3,*),GRND(*)
C
C-----OUTPUT FORMATS
 2000 FORMAT(1H+,79(' ')/1H+,'Writing ',(A),'...')
 2030 FORMAT(/6X,3(2X,'NODE',3X,'X-VEL',3X,'Y-VEL',4X,'DEPTH',5X,'WSEL')
     # /6X,3(3X,'NO.',2X,'(FT/S)',2X,'(FT/S)',5X,'(FT)',5X,'(FT)'))
 2031 FORMAT(/6X,3(2X,'NODE',3X,'X-VEL',3X,'Y-VEL',4X,'DEPTH',5X,'WSEL')
     # /6X,3(3X,'NO.',3X,'(M/S)',3X,'(M/S)',6X,'(M)',6X,'(M)'))
 2032 FORMAT(6X,3(I6,2F8.3,2F9.3))
 2130 FORMAT(/2(2X,'NODE',3X,'X-VEL',3X,'Y-VEL',4X,'DEPTH',5X,'WSEL')/
     # 2(3X,'NO.',2X,'(FT/S)',2X,'(FT/S)',5X,'(FT)',5X,'(FT)'))
 2131 FORMAT(/2(2X,'NODE',3X,'X-VEL',3X,'Y-VEL',4X,'DEPTH',5X,'WSEL')/
     # 2(3X,'NO.',3X,'(M/S)',3X,'(M/S)',6X,'(M)',6X,'(M)'))
 2132 FORMAT(2(I6,2F8.3,2F9.3))
C
      IF(SCREEN) WRITE(*,2000) PRNTFILE(1:LENCHR(PRNTFILE))
      IF(WIDE) THEN
        IF(IUNITS.EQ.0) THEN
          WRITE(IO2,2030)
        ELSE
          WRITE(IO2,2031)
        ENDIF
        JINT=(NP+2)/3
        DO 20 J=1,JINT
          WRITE(IO2,2032) (N,XVEL(1,N),XVEL(2,N),XVEL(3,N),
     #    XVEL(3,N)+GRND(N),N=J,NP,JINT)
20      CONTINUE
      ELSE
        IF(IUNITS.EQ.0) THEN
          WRITE(IO2,2130)
        ELSE
          WRITE(IO2,2131)
        ENDIF
        JINT=(NP+1)/2
        DO 30 J=1,JINT
          WRITE(IO2,2132) (N,XVEL(1,N),XVEL(2,N),XVEL(3,N),
     #    XVEL(3,N)+GRND(N),N=J,NP,JINT)
30      CONTINUE
      ENDIF
      RETURN
      END
C
C
C
      SUBROUTINE FLORED(FLOWFILE,IUNIT,STIME,STCUR,XVEL,SCREEN,IO2)
C
C---- FLORED ----------------------------------------------------------S
C
C  PURPOSE:
C    READS A FLOW-FIELD FILE.
C
C  INPUT ARGUMENT(S):
C    FLOWFILE - FLOW DATA FILE NAME.
C    IUNIT - UNIT NUMBER OF THE FLOW-FIELD FILE.
C    STIME - SIMULATION TIME FOR WHICH DATA IS TO BE READ.
C    STCUR - SIMULATION TIME OF CURRENT DATA IN MEMORY.
C    XVEL  - FLOW-FIELD DATA ARRAY.
C    IO2   - PRINTED OUTPUT FILE UNIT NUMBER.
C
C----------------------------------------------------------------------F
C
C---- Declarations (arguments)
      INTEGER   IUNIT,IO2
      REAL      STIME,STCUR,XVEL
      CHARACTER FLOWFILE*(*)
      LOGICAL   SCREEN
C
C---- Declarations (local)
      INTEGER   I,K,LENCHR,N,NPX
      REAL      STEPS,TET,X
C
C---- Dimensions
      DIMENSION XVEL(3,*)
C
C-----Data
      DATA STEPS/1.0E-06/
1000  FORMAT(E10.0,I10)
1010  FORMAT(I10,3E10.0)
C
C-----OUTPUT FORMATS
2000  FORMAT(1H+,79(' ')/1H+,'Reading ',(A),'...')
2010  FORMAT(/
     # ' *** ERROR - UNEXPECTED END-OF-FILE ENCOUNTERED:'/
     # '   FLOW DATA FILE:  ',(A)/
     # '   NUMBER OF NODES EXPECTED:  ',I5/
     # '   LAST NODE NUMBER READ...:  ',I5/)
2020  FORMAT(/
     # ' *** ERROR - ERROR READING THE FOLLOWING FLOW DATA FILE:'/
     # '    ',(A)/)
C
C-----SEE IF DESIRED TIME EQUALS CURRENT TIME
      IF(ABS(STIME-STCUR).LT.STEPS) RETURN
C
C---- SCREEN ACKNOWLEDGEMENT
      IF(SCREEN) WRITE(*,2000) FLOWFILE(1:LENCHR(FLOWFILE))
C
C---- IF DESIRED TIME IS LESS THAN CURRENT TIME REWIND FILE
      IF(STIME.LT.STCUR) REWIND IUNIT
C
C---- READ FLOW DATA FILE
      READ(IUNIT,1000,END=910,ERR=20) TET,NPX
      BACKSPACE IUNIT
10    READ(IUNIT,1000,END=910,ERR=920) TET,NPX
      READ(IUNIT,1010,END=910,ERR=920) (N,(XVEL(K,N),K=1,3),I=1,NPX)
      IF(TET.LT.(STIME-STEPS)) GOTO 10
      RETURN
20    BACKSPACE IUNIT
30    READ(IUNIT,END=910,ERR=920) TET,NPX
      READ(IUNIT,END=910,ERR=920) ((XVEL(K,N),K=1,3),X,X,X,N=1,NPX)
      IF(TET.LT.(STIME-STEPS)) GOTO 20
      RETURN
C
C---- Unexpected end-of-file encountered
910   WRITE(IO2,2010) FLOWFILE(1:LENCHR(FLOWFILE)),NPX,N
      RETURN
C
C---- Error reading flow file
920   WRITE(IO2,2020) FLOWFILE(1:LENCHR(FLOWFILE))
      RETURN
      END
C
C
C
      SUBROUTINE PREPLT(IER)
C
C---- PREPLT ----------------------------------------------------------S
C
C  PURPOSE:
C    PERFORMS PRELIMINARY COMPUTATIONS.
C
C  SUBPROGRAM(S) CALLED:
C    LSIZE
C
C----------------------------------------------------------------------F
C
C
C---- Declarations (arguments)
      INTEGER   IER
C
C---- Declarations (loacl)
      INTEGER   I,J,JINT,K,L,N,NCN,NPX
      REAL      STEPS,TET,X,Y
      CHARACTER FORM*11
C
C---- Common blocks
      INCLUDE 'ANOMOD.INC'
C
C-----Data
      DATA STEPS/1.0E-06/
C
C-----Outpt formats
 2000 FORMAT(1H+,79(' ')/1H+,'Computing (preliminaries)...')
 2010 FORMAT(/56X,'*** ELEMENT DATA ***'//
     # 1X,2('ELMT',5X,'NODES (COUNTERCLOCKWISE)',16X,'PROP',
     # 7X,'AREA '))
 2011 FORMAT(1X,2(1X,'NO',3X,'1',4X,'2',4X,'3',4X,'4',4X,'5',4X,'6',
     # 4X,'7',4X,'8',4X,'9',2X,'CODE',6X,'(FT2) ')/)
 2012 FORMAT(1X,2(1X,'NO',3X,'1',4X,'2',4X,'3',4X,'4',4X,'5',4X,'6',
     # 4X,'7',4X,'8',4X,'9',2X,'CODE',7X,'(M2) ')/)
 2013 FORMAT(1X,2(I4,9I5,I4,F12.2))
 2020 FORMAT(/58X,'*** NODE DATA ***'//
     # 3(2X,'NODE',3X,'X-COORD',3X,'Y-COORD',5X,'GRND',5X,'CEIL'))
 2021 FORMAT(3(3X,'NO.',6X,'(FT)',6X,'(FT)',5X,'(FT)',5X,'(FT)'))
 2022 FORMAT(3(3X,'NO.',7X,'(M)',7X,'(M)',6X,'(M)',6X,'(M)'))
 2023 FORMAT(3(I6,2F10.2,2F9.2))
 2030 FORMAT(/53X,'*** FLOW DATA (PRIMARY) ***')
 2031 FORMAT(/52X,'*** FLOW DATA (SECONDARY) ***')
 2032 FORMAT(/47X,'*** SIMULATION TIME: ',F8.3,' HOURS ***')
 2110 FORMAT(/30X,'*** ELEMENT DATA ***'//
     # 7X,'ELMT',5X,'NODES (COUNTERCLOCKWISE)',16X,'PROP',
     # 8X,'AREA')
 2111 FORMAT(9X,'NO',3X,'1',4X,'2',4X,'3',4X,'4',4X,'5',4X,'6',4X,'7',
     # 4X,'8',4X,'9',1X,'CODE',7X,'(FT2)'/)
 2112 FORMAT(9X,'NO',3X,'1',4X,'2',4X,'3',4X,'4',4X,'5',4X,'6',4X,'7',
     # 4X,'8',4X,'9',1X,'CODE',8X,'(M2)'/)
 2113 FORMAT(7X,I4,9I5,I4,F12.2)
 2120 FORMAT(/32X,'*** NODE DATA ***'//
     # 15X,1(2X,'NODE',5X,'X-COORD',5X,'Y-COORD',6X,'GRND',6X,'CEIL'))
 2121 FORMAT(15X,1(3X,'NO.',8X,'(FT)',8X,'(FT)',6X,'(FT)',6X,'(FT)'))
 2122 FORMAT(15X,1(3X,'NO.',9X,'(M)',9X,'(M)',7X,'(M)',7X,'(M)'))
 2123 FORMAT(15X,1(I6,2F12.2,3F10.2))
 2130 FORMAT(/27X,'*** FLOW DATA (PRIMARY) ***')
 2131 FORMAT(/26X,'*** FLOW DATA (SECONDARY) ***')
 2132 FORMAT(/21X,'*** SIMULATION TIME: ',F8.3,' HOURS ***')
C
C-----SCREEN ACKNOWLEDGEMENT
      IF(SCREEN) WRITE(*,2000)
C
C-----PRINT NETWORK DATA IF MOD(IPRNT,4) > 1
      IF(TLAST.LT.TFIRST) TLAST=TFIRST
      IF(MOD(IPRNT,4).GT.1) THEN
C
C-------COMPUTE ELEMENT AREAS
        CALL LSIZE(IER)
C
C-------PRINT ELEMENT DATA
        CALL FORMFD(IO2)
        IF(WIDE) THEN
          WRITE(IO2,2010)
          IF(IUNITS.EQ.0) THEN
            WRITE(IO2,2011)
          ELSE
            WRITE(IO2,2012)
          ENDIF
          JINT=(NE+1)/2
          DO 10 J=1,JINT
            WRITE(IO2,2013) (L,(NOP(L,K),K=1,9),LMAT(L),AREA(L),
     #      L=J,NE,JINT)
10        CONTINUE
        ELSE
          WRITE(IO2,2110)
          IF(IUNITS.EQ.0) THEN
            WRITE(IO2,2111)
          ELSE
            WRITE(IO2,2112)
          ENDIF
          DO 20 L=1,NE
            WRITE(IO2,2113) L,(NOP(L,K),K=1,9),LMAT(L),AREA(L)
20        CONTINUE
        ENDIF
C
C-------PRINT NODE DATA
        CALL FORMFD(IO2)
        IF(WIDE) THEN
          WRITE(IO2,2020)
          IF(IUNITS.EQ.0) THEN
            WRITE(IO2,2021)
          ELSE
            WRITE(IO2,2022)
          ENDIF
          JINT=(NP+2)/3
        ELSE
          WRITE(IO2,2120)
          IF(IUNITS.EQ.0) THEN
            WRITE(IO2,2121)
          ELSE
            WRITE(IO2,2122)
          ENDIF
          JINT=NP
        ENDIF
        DO 30 J=1,JINT
          IF(WIDE) THEN
            WRITE(IO2,2023) (N,(CORD(N,K),K=1,2),GRNDA(N),CEIL(N),
     #      N=J,NP,JINT)
          ELSE
            WRITE(IO2,2123) (N,(CORD(N,K),K=1,2),GRNDA(N),CEIL(N),
     #      N=J,NP,JINT)
          ENDIF
30      CONTINUE
      ENDIF
C
C-----PRINT PRIMARY FLOW DATA FOR REQUESTED TIME-STEPS
      IF(MOD(IPRNT,8).GT.2) THEN
        CALL FORMFD(IO2)
        IF(WIDE) THEN
          WRITE(IO2,2030)
        ELSE
          WRITE(IO2,2130)
        ENDIF
40      IF(IFLOWA.EQ.0) THEN
          TET=TFIRST
          TLAST=TFIRST
        ELSE
          INQUIRE(UNIT=IO93,FORM=FORM)
          IF(FORM.EQ.'FORMATTED') THEN
            READ(IO93,'(E10.0,I10)') TET,NPX
            READ(IO93,'(I10,3E10.0)') (N,(XVELA(K,N),K=1,3),I=1,NPX)
          ELSE
            READ(IO93) TET,NPX
            READ(IO93) ((XVELA(K,N),K=1,3),X,X,X,N=1,NPX)
          ENDIF
          STCURA=TET
        ENDIF
        IF(TET.GT.(TFIRST-STEPS) .AND. TET.LT.(TLAST+STEPS)) THEN
          IF(WIDE) THEN
            WRITE(IO2,2032) TET
          ELSE
            WRITE(IO2,2132) TET
          ENDIF
          CALL FLOPRT(NP,XVELA,GRNDA,WIDE,IUNITS,IO2,PRNTFILE,SCREEN)
        ENDIF
        IF(TET.LT.TLAST) GOTO 40
      ENDIF
C
C-----PRINT SECONDARY FLOW DATA FOR REQUESTED TIME-STEPS
      IF(MOD(IPRNT,16).GT.8) THEN
        CALL FORMFD(IO2)
        IF(WIDE) THEN
          WRITE(IO2,2031)
        ELSE
          WRITE(IO2,2131)
        ENDIF
50      IF(IFLOWB.EQ.0) THEN
          TET=TFIRST
          TLAST=TFIRST
        ELSE
          INQUIRE(UNIT=IO94,FORM=FORM)
          IF(FORM.EQ.'FORMATTED') THEN
            READ(IO94,'(E10.0,I10)') TET,NPX
            READ(IO94,'(I10,3E10.0)') (N,(XVELB(K,N),K=1,3),I=1,NPX)
          ELSE
            READ(IO94) TET,NPX
            READ(IO94) ((XVELB(K,N),K=1,3),X,X,X,N=1,NPX)
          ENDIF
          STCURB=TET
        ENDIF
        IF(TET.GT.(TFIRST-STEPS) .AND. TET.LT.(TLAST+STEPS)) THEN
          IF(WIDE) THEN
            WRITE(IO2,2032) TET
          ELSE
            WRITE(IO2,2132) TET
          ENDIF
          CALL FLOPRT(NP,XVELB,GRNDB,WIDE,IUNITS,IO2,PRNTFILE,SCREEN)
        ENDIF
        IF(TET.LT.TLAST) GOTO 50
      ENDIF
C
C-----MOVE TO TOP OF FORM
      CALL FORMFD(IO2)
C
C-----ASSIGN NODE POINT IDENTIFICATION VALUES
      DO 60 N=1,NP
        NPID(N)=0
60    CONTINUE
      DO 80 L=1,NE
        IF(LMAT(L).NE.0) THEN
          NCN=6
          IF(NOP(L,7).GT.0) NCN=8
          IF(NOP(L,9).GT.0) NCN=9
          DO 70 K=1,NCN
            N=NOP(L,K)
            NPID(N)=NPID(N)+1
70        CONTINUE
        ENDIF
80    CONTINUE
C
C-----FIND MINIMUM AND MAXIMUM COORDINATES
      XMIN=1.0E+35
      YMIN=1.0E+35
      XMAX=-1.0E+35
      YMAX=-1.0E+35
      DO 90 N=1,NP
        IF(NPID(N).NE.0) THEN
          X=CORD(N,1)
          IF(X.GT.XMAX) XMAX=X
          IF(X.LT.XMIN) XMIN=X
          Y=CORD(N,2)
          IF(Y.GT.YMAX) YMAX=Y
          IF(Y.LT.YMIN) YMIN=Y
        ENDIF
90    CONTINUE
999   RETURN
      END
C
C
C
      SUBROUTINE LNODES(L,NCN)
C
C---- LNODES ----------------------------------------------------------S
C
C  PURPOSE:
C    DETERMINES THE TOTAL NUMBER OF NODES IN AN ELEMENT AND FILLS
C    THE ARRAY 'NODE' WITH THE CONNECTIVITY LIST.
C
C  INPUT ARGUMENT(S):
C    L - ELEMENT NUMBER.
C
C  OUTPUT ARGUMENT(S):
C    NCN - NUMBER OF NODES IN CONNECTIVITY LIST.
C
C----------------------------------------------------------------------F
C
C---- Declarations (arguments)
      INTEGER   L,NCN
C
C---- Common blocks
      INCLUDE 'ANOMOD.INC'
C
      NCN=6
      IF(NOP(L,8).NE.0) NCN=8
      IF(NOP(L,9).NE.0) NCN=9
      DO 10 K=1,9
        NODE(K)=0
10    CONTINUE
      DO 20 K=1,NCN
         NODE(K)=NOP(L,K)
20    CONTINUE
      RETURN
      END
C
C
C
      SUBROUTINE LDNOFF
C
C---- LDNOFF ----------------------------------------------------------S
C
C  PURPOSE:
C    TURNS OFF ELEMENTS WITH DRY NODES BY SETTING THE ELEMENT PROPERTY
C    TYPE CODE NEGATIVE.
C
C----------------------------------------------------------------------F
C
C---- Declarations (local)
      INTEGER   L,M,N
C
C---- Common blocks
      INCLUDE 'ANOMOD.INC'
C
      DO 20 L=1,NE
        M=LMAT(L)
        IF(M.LT.1) GOTO 20
        CALL LNODES(L,NCN)
        IF(NCN.EQ.9) NCN=8
        DO 10 K=1,NCN,2
          N=NODE(K)
          IF(XVELA(3,N).LT.ZIP) THEN
            LMAT(L)=-M
            GOTO 20
          ENDIF
10      CONTINUE
20    CONTINUE
      RETURN
      END
C
C
C
      SUBROUTINE LPCPOS
C
C---- LPCPOS ----------------------------------------------------------S
C
C  PURPOSE:
C    MAKES SURE ELEMENT PROPERTY CODES ARE ALL POSITIVE (THAT IS, TURNS
C    ON ELEMENTS THAT WERE PREVIOUSLY TURNED OFF).
C
C----------------------------------------------------------------------F
C
C---- Declarations (local)
      INTEGER   L
C
C---- Common blocks
      INCLUDE 'ANOMOD.INC'
C
      DO 10 L=1,NE
        LMAT(L)=IABS(LMAT(L))
10    CONTINUE
      RETURN
      END
C
C
C
      SUBROUTINE NCHECK(N,IDS,MAXP,IO2,IER,ERR)
C
C---- NCHECK ----------------------------------------------------------S
C
C  PURPOSE:
C    CHECKS FOR A VALID NODE NUMBER.  THE NODE NUMBER MUST BE GREATER
C    THAN ZERO AND LESS THAN OR EQUAL TO THE MAXIMUM NODAL ARRAY
C    DIMENSION, MAXP.  IF AN INVALID NODE NUMBER IS FOUND TO BE
C    OUTSIDE THIS RANGE, THE ERROR COUNT IS INCREMENTED BY ONE AND A
C    MESSAGE IS PRINTED.
C
C  INPUT ARGUMENT(S):
C    N - THE NODE NUMBER TO BE CHECKED
C    IDS - THE DATA SET FROM WHICH THE NODE NUMBER WAS READ
C    MAXP - THE MAXIMUM NODE DIMENSION (NUMBER)
C    IER - THE ERROR COUNT
C    ERR - LOGICAL
C
C  OUTPUT ARGUMENT(S):
C    IER - THE ERROR COUNT; INCREMENTED BY ONE IF AN ERROR IS FOUND.
C
C----------------------------------------------------------------------F
C
C---- Declarations (arguments)
      INTEGER   N,MAXP,IER
      CHARACTER IDS*(*)
      LOGICAL ERR
C
C---- Declarations (local)
      INTEGER   LENCHR
C
C---- Output formats
2000  FORMAT(/' ***ERROR #230 - NODE NUMBER ',I5,' IN THE ',(A),
     # ' DATA SET IS OUT OF RANGE.')
C
      ERR=.FALSE.
      IF(N.LT.1) ERR=.TRUE.
      IF(N.GT.MAXP) ERR=.TRUE.
      IF(ERR) THEN
        IER=IER+1
        WRITE(IO2,2000) N,IDS(1:LENCHR(IDS))
      ENDIF
      RETURN
      END
C
C
C
      SUBROUTINE LCHECK(L,IDS,MAXE,IO2,IER,ERR)
C
C---- LCHECK ----------------------------------------------------------S
C
C  PURPOSE:
C    CHECKS FOR A VALID ELEMENT NUMBER.  THE ELEMENT NUMBER MUST BE
C    GREATER THAN ZERO AND LESS THAN OR EQUAL TO THE MAXIMUM ELEMENT
C    DIMENSION, MAXE.  IF AN ELEMENT NUMBER IS FOUND TO BE OUTSIDE
C    THIS RANGE, THE ERROR COUNT IS INCREMENTED BY ONE AND A MESSAGE .
C    IS PRINTED.
C
C  INPUT ARGUMENT(S):
C    L -    THE ELEMENT NUMBER TO BE CHECKED
C    IDS -  THE DATA SET FROM WHICH THE ELEMENT NUMBER IS READ
C    MAXE - THE MAXIMUM ELEMENT NUMBER (DIMENSION)
C    IER -  THE ERROR COUNT
C    ERR -  LOGICAL ERROR INDICATOR
C
C  OUTPUT ARGUMENT(S):
C    IER - ERROR COUNT; INCREMENTED BY ONE EACH TIME AN ERROR IS FOUND
C
C----------------------------------------------------------------------F
C
      INTEGER   L,MAXE,IER,LENCHR
      CHARACTER IDS*(*)
      LOGICAL   ERR
C
C---- Output formats
2000  FORMAT(/' ***ERROR #220 - ELEMENT NUMBER ',I5,' IN THE ',(A),
     # ' DATA SET IS OUT OF RANGE.')
C
      ERR=.FALSE.
      IF(L.LT.1) ERR=.TRUE.
      IF(L.GT.MAXE) ERR=.TRUE.
      IF(ERR) THEN
        IER=IER+1
        WRITE(IO2,2000) L,IDS(1:LENCHR(IDS))
      ENDIF
      RETURN
      END
C
C
C
      SUBROUTINE GRDPLT
C
C---- GRDPLT ----------------------------------------------------------S
C
C  PURPOSE:
C    PLOTS THE FINITE ELEMENT NETWORK.
C
C  SUBPROGRAM(S) CALLED:
C    LNODES, TRFMXY, FIT, NUMBER, SYMBOL, PLOT
C
C----------------------------------------------------------------------F
C
C---- Declarations (local)
      INTEGER   IPLOTN,IPLOTL,K,L,N,N1,N2,N3
      REAL      SPLOT,X1,X2,X3,Y1,Y2,Y3
C
C---- Common blocks
      INCLUDE 'ANOMOD.INC'
C
C---- Dimensions
      DIMENSION IPLOTN(3),IPLOTL(3),SPLOT(3)
C
C-----OUTPUT FORMATS
2000  FORMAT(1H+,79(' ')/1H+,'Plotting (network)...')
C
C-----SCREEN ACKNOWLEDGEMENT
      IF(SCREEN) WRITE(*,2000)
C
C-----CLEAR ARRAYS AND SET CONSTANTS
      DO 10 N=1,NP
        NPID(N)=0
10    CONTINUE
C
C-----ASSIGN DEFAULT VALUES
      IF(HTN.LT.ZIP) HTN=0.070
      IF(HTE.LT.ZIP) HTE=0.105
      IF(HTT.LT.ZIP) HTT=0.140
C
C-----CHECK ON PLOT BOUNDS
      CALL BOUNDS
C
C-----FILL PLOT ID ARRAYS
      NPLOTN=0
      NPLOTL=0
      DO 15 K=1,3
        KOUNT=2**K
        IF(MOD(IPLTN,KOUNT) .GE. KOUNT/2) THEN
          NPLOTN=NPLOTN+1
          IPLOTN(K)=1
        ELSE
          IPLOTN(K)=0
        ENDIF
        IF(MOD(IPLTE,KOUNT) .GE. KOUNT/2) THEN
          NPLOTL=NPLOTL+1
          IPLOTL(K)=1
        ELSE
          IPLOTL(K)=0
        ENDIF
15    CONTINUE
C
C-----MOVE TO ORIGIN; PLOT TITLE IF NEWPLT = .TRUE.
      IF(NEWPLT) THEN
        IF(IPLINT.GT.1) CALL PLOT(XUP+1.,0.,-3)
        NCHAR=LENCHR(PTITLE)
        CALL SYMBOL(0.3,0.,HTT,PTITLE,0,90.,NCHAR)
      ENDIF
C
C-----LOOP AROUND ELEMENTS
      DO 100 L=1,NE
        IF(LMAT(L).NE.0) THEN
          CALL LNODES(L,NCN)
C
C---------PLOT ELEMENT SIDES
          KHI=NCN
          IF(KHI.GT.8) KHI=8
          DO 20 K=1,KHI,2
            N2=NODE(K+1)
            IF(NPID(N2).EQ.0) THEN
              N1=NODE(K)
              N3=MOD(K+2,KHI)
              N3=NODE(N3)
              NPID(N2)=1
              X1=CORD(N1,1)
              Y1=CORD(N1,2)
              X2=CORD(N2,1)
              Y2=CORD(N2,2)
              X3=CORD(N3,1)
              Y3=CORD(N3,2)
C-------------TRANSFORM TO PLOT COORDINATES
              CALL TRFMXY(X1,Y1,XSCALE,YSCALE,XL,YL,SGN,CSN)
              CALL TRFMXY(X2,Y2,XSCALE,YSCALE,XL,YL,SGN,CSN)
              CALL TRFMXY(X3,Y3,XSCALE,YSCALE,XL,YL,SGN,CSN)
C-------------PLOT SIDE
              X1=X1+XLP
              X2=X2+XLP
              X3=X3+XLP
              Y1=Y1+YLP
              Y2=Y2+YLP
              Y3=Y3+YLP
              CALL FIT(X1,Y1,X2,Y2,X3,Y3,XLP,YLP,XUP,YUP)
            ENDIF
20        CONTINUE
C
C---------PLOT ELEMENT VALUES
          IF(IPLTE.GT.0) THEN
            IF(NCN.LT.9) THEN
              IF(NCN.EQ.6) THEN
                WC=-1./9.
                WM= 4./9.
              ELSE
                WC=-0.25
                WM= 0.50
              ENDIF
              XBAR=0.
              YBAR=0.
              DO 40 K=2,NCN,2
                NC=NODE(K-1)
                NM=NODE(K)
                XBAR=XBAR+WC*CORD(NC,1)+WM*CORD(NM,1)
                YBAR=YBAR+WC*CORD(NC,2)+WM*CORD(NM,2)
40            CONTINUE
            ELSE
              N=NODE(9)
              XBAR=CORD(N,1)
              YBAR=CORD(N,2)
            ENDIF
            CALL TRFMXY(XBAR,YBAR,XSCALE,YSCALE,XL,YL,SGN,CSN)
            IF(XBAR.LT.XUP .AND. YBAR.LT.YUP) THEN
              SPLOT(1)=L
              SPLOT(2)=LMAT(L)
              SPLOT(3)=LSEQ(L)
              Y=YBAR+0.625*HTE*REAL(NPLOTL)
              DO 50 J=1,3
                IF(IPLOTL(J).GT.0) THEN
                  FPN=SPLOT(J)
                  IF(ABS(FPN).GT.0.) THEN
                    NDIG=ALOG10(ABS(FPN))+0.01
                  ELSE
                    NDIG=0
                  ENDIF
                  IF(FPN.LT.0) THEN
                    NDIG=NDIG+2
                  ELSE
                    NDIG=NDIG+1
                  ENDIF
                  IF(NCN.EQ.9) THEN
                    X=XBAR-HTE*REAL(NDIG)
                  ELSE
                    X=XBAR-0.5*HTE*REAL(NDIG)
                  ENDIF
                  Y=Y-1.25*HTE
                  X=X+XLP
                  Y=Y+YLP
                  CALL NUMBER(X,Y,HTE,FPN,0.,-1)
                ENDIF
50            CONTINUE
            ENDIF
          ENDIF
C
C---------PLOT VALUES AT NODE POINTS
          IF(IPLTN.GT.0) THEN
            DO 70 K=1,NCN
              N=NODE(K)
              IF(NPID(N).GT.1) GOTO 70
              NPID(N)=2
              SPLOT(1)=N
              SPLOT(2)=GRNDA(N)
              SPLOT(3)=CEIL(N)
              X=CORD(N,1)
              Y=CORD(N,2)
              CALL TRFMXY(X,Y,XSCALE,YSCALE,XL,YL,SGN,CSN)
              IF(X.LT.XUP .AND. Y.LT.YUP) THEN
                X=X+0.5*HTN
                Y=Y+HTN*(1.25*REAL(NPLOTN)+0.25)
                DO 60 J=1,3
                  IF(IPLOTN(J).GT.0) THEN
                    FPN=SPLOT(J)
                    Y=Y-1.25*HTN
                    NDEC=-1
                    IF(J.GT.1) NDEC=1
                    X=X+XLP
                    Y=Y+YLP
                    CALL NUMBER(X,Y,HTN,FPN,0.,NDEC)
                  ENDIF
60              CONTINUE
              ENDIF
70          CONTINUE
          ENDIF
        ENDIF
100   CONTINUE
C
C-----END PLOT
      CALL PLOT(XUP,YUP,3)
  999 RETURN
      END
C
C
C
      SUBROUTINE BOUNDS
C
C---- BOUNDS ----------------------------------------------------------S
C
C  PURPOSE:
C    COMPUTES PLOT BOUNDS.
C
C----------------------------------------------------------------------F
C
      INCLUDE 'ANOMOD.INC'
C
C-----ASSIGN PLOT SCALES
      IF(ABS(XSCALE).GT.0. .AND. ABS(YSCALE).GT.0.) THEN
        XSCALE=1./XSCALE
        YSCALE=1./YSCALE
      ELSE
        YSCALE=33./(YMAX-YMIN)
        XSCALE=YSCALE
        XL=XMIN
        YL=YMIN
      ENDIF
C
C-----COMPUTE SINE AND COSINE OF ROTATION ANGLE
      IF(ABS(AROT).GT.0.) THEN
        AROT=0.017453293*AROT
        SGN=SIN(AROT)
        CSN=COS(AROT)
      ELSE
        SGN=0.
        CSN=1.
      ENDIF
C
C-----SET PLOT BOUNDS (LEAVE 1/2 INCH BORDER ALONG Y-AXIS)
      XLP=0.5
      YLP=0.0
      XUP=XHIP
      YUP=YHIP
      TEMP=XSCALE*XOFF+XLP
      IF(TEMP.LT.XUP) XUP=TEMP
      TEMP=YSCALE*YOFF+YLP
      IF(TEMP.LT.YUP) YUP=TEMP
      RETURN
      END
C
C
C
      SUBROUTINE FIT(XA,YA,XB,YB,XC,YC,XL,YL,XU,YU)
C
C---- FIT -------------------------------------------------------------S
C
C  PURPOSE:
C    PLOTS ELEMENT SIDES.
C
C  INPUT ARGUMENT(S):
C    XA - X-COORDINATE OF THE FIRST ENDPOINT
C    YA - Y-COORDINATE OF THE FIRST ENDPOINT
C    XB - X-COORDINATE OF THE MIDPOINT
C    YB - Y-COORDINATE OF THE MIDPOINT
C    XC - X-COORDINATE OF THE SECOND ENDPOINT
C    YC - Y-COORDINATE OF THE SECOND ENDPOINT
C
C  SUBPROGRAM(S) CALLED:
C    PCODE
C
C----------------------------------------------------------------------F
C
      EPS=0.01
      S=0.0
      IPEN=3
C
C-----DETERMINE IF SIDE IS STRAIGHT OR CURVED
      XBAR=0.5*(XA+XC)
      YBAR=0.5*(YA+YC)
      IF(ABS(XBAR-XB).LT.EPS.AND.ABS(YBAR-YB).LT.EPS) THEN
        NSEG=1
      ELSE
        NSEG=25
      ENDIF
C
C-----COMPUTE SEGMENT LENGTH
      DS=1./FLOAT(NSEG)
C
C-----PLOT VISIBLE PORTION OF ELEMENT SIDE
      X2=XA
      Y2=YA
      DO 100 J=1,NSEG
        X1=X2
        Y1=Y2
        S=S+DS
        WA=1.-3.*S+2.*S*S
        WB=4.*S*(1.-S)
        WC=S*(2.*S-1.)
        X2=WA*XA+WB*XB+WC*XC
        Y2=WA*YA+WB*YB+WC*YC
C
C-------COMPUTE POINT LOCATION CODES
30      KODE1=PCODE(X1,Y1,XL,YL,XU,YU)
        KODE2=PCODE(X2,Y2,XL,YL,XU,YU)
C
C-------CHECK FOR ENTIRELY VISIBLE LINE SEGMENT
        IF(KODE1.EQ.0.AND.KODE2.EQ.0) THEN
C-------DRAW LINE SEGMENT
          IF(IPEN.EQ.3) CALL PLOT(X1,Y1,IPEN)
          IPEN=2
          CALL PLOT(X2,Y2,IPEN)
        ELSE
C-------CHECK FOR ENTIRELY INVISIBLE LINE SEGMENT
          IF(KODE1/1000.EQ.1.AND.KODE2/1000.EQ.1) GOTO 100
          IF(MOD(KODE1,10).EQ.1.AND.MOD(KODE2,10).EQ.1) GOTO 100
          IF(MOD(KODE1/100,10).EQ.1.AND.MOD(KODE2/100,10).EQ.1)GOTO 100
          IF(MOD(KODE1/10,10).EQ.1.AND.MOD(KODE2/10,10).EQ.1) GOTO 100
C
C---------BEGIN CLIPPING
          KODE=KODE1
          IF(KODE.EQ.0) KODE=KODE2
          IF(MOD(KODE,100).EQ.1) THEN
C---------LINE SEGMENT CROSSES LEFT EDGE
            Y=Y1+(Y2-Y1)*(XL-X1)/(X2-X1)
            X=XL
          ELSE IF(MOD(KODE,100).EQ.10) THEN
C---------LINE SEGMENT CROSSES RIGHT EDGE
            Y=Y1+(Y2-Y1)*(XU-X1)/(X2-X1)
            X=XU
          ELSE IF(KODE/100.EQ.1) THEN
C---------LINE SEGMENT CROSSES BOTTOM EDGE
            X=X1+(X2-X1)*(YL-Y1)/(Y2-Y1)
            Y=YL
          ELSE IF(KODE/100.EQ.10) THEN
C---------LINE SEGMENT CROSSES TOP EDGE
            X=X1+(X2-X1)*(YU-Y1)/(Y2-Y1)
            Y=YU
          ELSE
C---------IF YOU REACH THIS POINT THERE IS AN ERROR
            GOTO 100
          ENDIF
C
C---------SET NEW ENDPOINT VALUES AND REPEAT PROCESS
          IF(KODE.EQ.KODE1) THEN
            X1=X
            Y1=Y
          ELSE IF(KODE.EQ.KODE2) THEN
            X2=X
            Y2=Y
          ENDIF
          GOTO 30
        ENDIF
100   CONTINUE
      RETURN
      END
C
C
C
      FUNCTION PCODE(X,Y,XL,YL,XU,YU)
C
C---- PCODE -----------------------------------------------------------S
C
C  PURPOSE:
C    DETERMINES THE POINT LOCATION CODE AS SHOWN BELOW:
C
C                            |            |
C                    1001    |    1000    |    1010
C                ____________|____________|____________
C                            |            |
C                    0001    |    0000    |    0010
C                ____________|____________|____________
C                            |            |
C                    0101    |    0100    |    0110
C                            |            |
C
C  INPUT ARGUMENT(S):
C    X - X-COORDINATE OF THE POINT IN QUESTION
C    Y - Y-COORDINATE OF THE POINT IN QUESTION
C    XL - LOWER X-COORDINATE OF THE VIEWPORT
C    YL - LOWER Y-COORDINATE OF THE VIEWPORT
C    XU - UPPER X-COORDINATE OF THE VIEWPORT
C    YU - UPPER Y-COORDINATE OF THE VIEWPORT
C
C----------------------------------------------------------------------F
C
      PCODE=0
      IF(X.LT.XL) PCODE=PCODE+1
      IF(X.GT.XU) PCODE=PCODE+10
      IF(Y.LT.YL) PCODE=PCODE+100
      IF(Y.GT.YU) PCODE=PCODE+1000
      RETURN
      END
C
C
C
      SUBROUTINE TRFMXY(X,Y,XSCALE,YSCALE,X0,Y0,SGN,CSN)
C
C---- TRFMXY ----------------------------------------------------------S
C
C  PURPOSE:
C    TRANSFORMS WORLD X-Y COORDINATES TO PLOT COORDINATES
C
C  INPUT ARGUMENT(S):
C    X - X-COORDINATE TO BE TRANSFORMED
C    Y - Y-COORDINATE TO BE TRANSFORMED
C    XSCALE - X-COORDINATE SCALE FACTOR
C    YSCALE - Y-COORDINATE SCALE FACTOR
C    X0 - X-COORDINATE OF ORIGIN
C    Y0 - Y-COORDINATE OF ORIGIN
C    SGN - SINE OF ROTAION ANGLE
C    CSN - COSINE OF ROATION ANGLE
C
C  OUTPUT ARGUMENT(S):
C    X - TRANSFORMED X-COORDINATE
C    Y - TRANSFORMED Y-COORDINATE
C
C----------------------------------------------------------------------F
C
      TEMP=XSCALE*((X-X0)*CSN-(Y-Y0)*SGN)
      Y=YSCALE*((X-X0)*SGN+(Y-Y0)*CSN)
      X=TEMP
      RETURN
      END
C
C
C
      SUBROUTINE VECPLT
C
C---- VECPLT ----------------------------------------------------------S
C
C  PURPOSE:
C    PLOTS VELOCITY VECTORS AND SCALAR QUANTITIES AT NODE POINTS.
C
C  SUBPROGRAM(S) CALLED:
C    BNDPLT, VSQPLT, PLOT, SYMBOL
C
C----------------------------------------------------------------------F
C
      INCLUDE 'ANOMOD.INC'
C
C-----OUTPUT FORMATS
2000  FORMAT(1H+,79(' ')/1H+,'Plotting (vectors)...')
C
C-----SCREEN ACKNOWLEDGEMENT
      IF(SCREEN) WRITE(*,2000)
C
C-----SET DEFAULT VALUES
      IF(ABS(VSCALE).LT.ZIP) VSCALE=-1.0
      IF(IARHD.EQ.0) IARHD=1
      IF(AHLEN.LT.ZIP) AHLEN=0.070
      IF(HTT.LT.ZIP) HTT=0.140
      IF(HTN.LT.ZIP) HTN=0.070
      IF(HTE.LT.ZIP) HTE=0.105
      IF(ABS(VLMIN).LT.ZIP) VLMIN=ZIP
C
C-----TURN OFF ELEMENTS WITH DRY NODES
      CALL LDNOFF
C
C-----COMPUTE VELOCITY SCALE FACTOR
      VMAX=0.
      QMAX=0.
      XPMIN=0.
      YPMIN=0.
      XPMAX=XSCALE*XOFF
      YPMAX=XSCALE*YOFF
      IF(VSCALE.LT.0.) THEN
        DO 30 N=1,NP
          IF(NPID(N).LT.1) GO TO 30
          XP=CORD(N,1)
          YP=CORD(N,2)
          CALL TRFMXY(XP,YP,XSCALE,YSCALE,XL,YL,SGN,CSN)
          IF(XP.LT.XPMIN .OR. XP.GT.XPMAX) GO TO 30
          IF(YP.LT.YPMIN .OR. YP.GT.YPMAX) GO TO 30
          VX=XVELA(1,N)
          VY=XVELA(2,N)
          H=XVELA(3,N)
          V=SQRT(VX*VX+VY*VY)
          Q=V*H
          IF(V.GT.VMAX) VMAX=V
          IF(Q.GT.QMAX) QMAX=Q
30      CONTINUE
        IF(IPLTV.EQ.1) THEN
          VSCALE=ABS(VSCALE)/VMAX
        ELSEIF(IPLTV.EQ.2) THEN
          VSCALE=ABS(VSCALE)/QMAX
        ENDIF
      ELSE
        VSCALE=1.0/VSCALE
      ENDIF
C
C-----COMPUTE PLOT BOUNDS
      CALL BOUNDS
C
C-----MOVE TO ORIGIN
      IF(NEWPLT) THEN
        IF(IPLINT.GT.1) CALL PLOT(XUP+1.,0.,-3)
        NCHAR=LENCHR(PTITLE)
        CALL SYMBOL(0.3,0.,HTT,PTITLE,0,90.,NCHAR)
      ENDIF
C
C-----PLOT NETWORK BOUNDARY
      IF(NEWPLT) CALL BNDPLT
C
C-----PLOT VECTORS AND SCALAR QUANTITIES
      CALL VSQPLT
C
C-----END PLOT
      CALL PLOT(XUP,0.,3)
C
C-----MAKE SURE ALL ELEMENT PROPERTY CODES ARE POSITIVE
      CALL LPCPOS
      RETURN
      END
C
C
C
      SUBROUTINE BNDPLT
C
C---- BNDPLT ----------------------------------------------------------S
C
C  PURPOSE:
C    PLOTS NETWORK BOUNDARY.
C
C  SUBPROGRAMS CALLED:
C    FIT
C
C----------------------------------------------------------------------F
C
      INCLUDE 'ANOMOD.INC'
C
C-----OUTPUT FORMATS
2000  FORMAT(/' ***ERROR - MAXIMUM NUMBER OF ',
     # 'ELEMENT SIDES EXCEEDED.  INCREASE MAXS.')
2010  FORMAT(/' ***ERROR - CHECK ELEMENT SIDE LIST.')
C
C-----SET NPID ARRAY
      DO 5 N=1,NP
        NPID(N)=0
5     CONTINUE
      DO 20 L=1,NE
        IF(LMAT(L).GT.0) THEN
          CALL LNODES(L,NCN)
          DO 10 K=1,NCN
            N=NODE(K)
            NPID(N)=NPID(N)+1
10        CONTINUE
        ENDIF
20    CONTINUE
C
C-----DEVELOP LIST OF ELEMENT BOUNDARY SIDES
      NBS=0
      DO 40 L=1,NE
        IF(LMAT(L).LT.1) GOTO 40
        CALL LNODES(L,NCN)
        IF(NCN.EQ.9) NCN=8
        DO 30 K=1,NCN,2
          N2=NODE(K+1)
          IF(NPID(N2).EQ.1) THEN
            N1=NOP(L,K)
            N3=K+2
            IF(N3.GT.NCN) N3=1
            N3=NOP(L,N3)
            NBS=NBS+1
            IF(NBS.GT.MAXS) THEN
              IER=IER+1
              WRITE(IO2,2000)
              GOTO 999
            ENDIF
            IBS(NBS,1)=N1
            IBS(NBS,2)=N2
            IBS(NBS,3)=N3
            NPID(N2)=-NPID(N2)
          ENDIF
30      CONTINUE
40    CONTINUE
C
C-----PRINT BOUNDARY SIDE LIST
C
C-----PLOT BOUNDARY SIDES IN SEQUENTIAL ORDER
      NSBS=0
      LS=1
      GOTO 70
C-----SEARCH BOUNDARY SIDE LIST FOR ADJACENT SIDE
45    DO 50 J=2,NBS
        IF(IBS(J,1).EQ.NN) THEN
          LS=J
          GOTO 70
        ENDIF
50    CONTINUE
C-----FIND NEXT UNPLOTTED SIDE
      DO 60 J=2,NBS
        IF(IBS(J,1).GT.1) THEN
          LS=J
          GOTO 70
        ENDIF
60    CONTINUE
C-----THERE IS AN ERROR IF YOU ARE HERE
      WRITE(IO2,2010)
      GOTO 999
C-----DETERMINE NODE POINT COORDINATES
70    N1=IBS(LS,1)
      N2=IBS(LS,2)
      N3=IBS(LS,3)
      X1=CORD(N1,1)
      Y1=CORD(N1,2)
      X2=CORD(N2,1)
      Y2=CORD(N2,2)
      X3=CORD(N3,1)
      Y3=CORD(N3,2)
C-----CONVERT TO PLOT COORDINATES
      CALL TRFMXY(X1,Y1,XSCALE,YSCALE,XL,YL,SGN,CSN)
      CALL TRFMXY(X2,Y2,XSCALE,YSCALE,XL,YL,SGN,CSN)
      CALL TRFMXY(X3,Y3,XSCALE,YSCALE,XL,YL,SGN,CSN)
C-----PLOT ELEMENT SIDE
      X1=X1+XLP
      X2=X2+XLP
      X3=X3+XLP
      Y1=Y1+YLP
      Y2=Y2+YLP
      Y3=Y3+YLP
      CALL FIT(X1,Y1,X2,Y2,X3,Y3,XLP,YLP,XUP,YUP)
      NSBS=NSBS+1
      NN=IBS(LS,3)
      IBS(LS,1)=-IBS(LS,1)
      IF(NSBS.LT.NBS) GOTO 45
C-----SET NPID ARRAY POSITIVE
      DO 100 N=1,NP
        NPID(N)=IABS(NPID(N))
100   CONTINUE
999   RETURN
      END
C
C
C
      SUBROUTINE VSQPLT
C
C---- VSQPLT ----------------------------------------------------------S
C
C  PURPOSE:
C    PLOTS VECTORS AND SCALAR QUANTITIES
C
C  SUBPROGRAM(S) CALLED:
C    TRFMXY, ARROW, NUMBER
C
C----------------------------------------------------------------------F
C
      INCLUDE 'ANOMOD.INC'
      DIMENSION IPLOT(3),SPLOT(3)
C
C-----INITIALIZE VARIABLES
      IF(IPLTV.LT.1.AND.IPLTS.LT.1) GO TO 999
      NPLOT=0
      XLT=XLP-0.5
      XUT=XUP+0.5
      YLT=YLP-0.5
      YUT=YUP+0.5
      IPLOT(1)=0
      IPLOT(2)=0
      IPLOT(3)=0
      IF(MOD(IPLTS,2).GT.0) IPLOT(1)=1
      IF(MOD(IPLTS,4).GT.1) IPLOT(2)=1
      IF(MOD(IPLTS,8).GT.2) IPLOT(3)=1
      DO 10 K=1,3
        IF(IPLOT(K).EQ.1) NPLOT=NPLOT+1
10    CONTINUE
C
C-----BEGIN ELEMENT LOOP
      DO 100 L=1,NE
        IF(LMAT(L).LT.1) GO TO 100
        CALL LNODES(L,NCN)
        DO 90 K=1,NCN
          N=NODE(K)
          IF(NPID(N).LT.1) GO TO 90
          XP=CORD(N,1)
          YP=CORD(N,2)
          CALL TRFMXY(XP,YP,XSCALE,YSCALE,XL,YL,SGN,CSN)
          XP=XP+XLP
          YP=YP+YLP
C---------CHECK WINDOW BOUNDS
          IF(XP.LT.XLP.OR.XP.GT.XUP) GO TO 90
          IF(YP.LT.YLP.OR.YP.GT.YUP) GO TO 90
C---------COMPUTE VELOCITY
          VX=XVELA(1,N)
          VY=XVELA(2,N)
          V=SQRT(VX*VX+VY*VY)
C---------COMPUTE VECTOR COMPONENTS AND LENGTH
          IF(IPLTV.EQ.1) THEN
            VX=VX*VSCALE
            VY=VY*VSCALE
            VLEN=V*VSCALE
          ELSE IF(IPLTV.EQ.2) THEN
            H=XVELA(3,N)
            VX=VX*H*VSCALE
            VY=VY*H*VSCALE
            VLEN=V*H*VSCALE
          ELSE
            VLEN=0.
          ENDIF
C---------ROTATE VECTOR IF NECESSARY
          IF(ABS(AROT).GT.0.) THEN
            TEMP=VX*CSN-VY*SGN
            VY=VX*SGN+VY*CSN
            VX=TEMP
          ENDIF
C---------COMPUTE VECTOR TIP COORDINATES
          XT=XP+VX
          YT=YP+VY
C---------PLOT VECTOR AND SCALARS IF TIP IS INSIDE WINDOW
          KODE=PCODE(XT,YT,XLT,YLT,XUT,YUT)
          IF(KODE.EQ.0.AND.VLEN.GT.VLMIN) THEN
            CALL ARROW(XP,YP,XT,YT,AHLEN,IARHD)
            IF(NPLOT.GT.0) THEN
              H=XVELA(3,N)
              Q=H*V
              SPLOT(1)=N
              SPLOT(2)=V
              SPLOT(3)=Q
              X=XP+0.5*HTN
              Y=YP+HTN*(0.75*(NPLOT-1)+1.0)
              DO 60 J=1,3
                IF(IPLOT(J).GT.0) THEN
                  FPN=SPLOT(J)
                  Y=Y-1.5*HTN
                  NDIG=-1
                  IF(J.GT.1) NDIG=2
                  CALL NUMBER(X,Y,HTN,FPN,0.,NDIG)
                ENDIF
60            CONTINUE
            ENDIF
          ENDIF
          NPID(N)=-NPID(N)
90      CONTINUE
100   CONTINUE
C
C-----SET NPID ARRAY POSITIVE
      DO 110 N=1,NP
        NPID(N)=IABS(NPID(N))
110   CONTINUE
999   RETURN
      END
C
C
C
      SUBROUTINE ARROW(XT,YT,XH,YH,AHLEN,ICODE)
C
C---- ARROW -----------------------------------------------------------S
C
C  PURPOSE:
C    PLOTS AN ARROW WITH ONE OF TWO DIFFERENT HEAD TYPES.
C
C  INPUT ARGUMENT(S):
C    XT -  X-COORDINATE OF THE TAIL OF THE ARROW
C    YT -  Y-COORDINATE OF THE TAIL OF THE ARROW
C    XH -  X-COORDINATE OF THE ARROWHEAD TIP
C    YH -  Y-COORDINATE OF THE ARROWHEAD TIP
C    AHLEN -  LENGTH OF THE ARROWHEAD IN INCHES
C    ICODE -  ARROWHEAD TYPE CODE
C
C  SUBPROGRAM(S) CALLED:
C    PLOT, SDOT
C
C----------------------------------------------------------------------F
C
      EPS=0.0001
      BLEN=1.0541*AHLEN
      DELTA=0.32175
      DX=XH-XT
      DY=YH-YT
      IF(ABS(DX).LT.EPS.AND.ABS(DY).LT.EPS) GOTO 999
      THETA=ATAN2(DY,DX)
C
C-----DRAW ARROW SHAFT
      CALL PLOT(XT,YT,3)
      CALL PLOT(XH,YH,2)
C
C-----DRAW ARROWHEAD OR DOT AT BASE OF SHAFT
      IF(ICODE.EQ.2 .OR. ICODE.EQ.-2) THEN
        X1=XH-BLEN*COS(THETA+DELTA)
        Y1=YH-BLEN*SIN(THETA+DELTA)
        CALL PLOT(X1,Y1,2)
        DIA=0.5*AHLEN
        IF(ICODE.EQ.-1) CALL SDOT(XT,YT,DIA)
      ELSEIF(ICODE.EQ.1 .OR. ICODE.EQ.-1) THEN
        X1=XH-BLEN*COS(THETA+DELTA)
        Y1=YH-BLEN*SIN(THETA+DELTA)
        CALL PLOT(X1,Y1,2)
        X2=XH-BLEN*COS(THETA-DELTA)
        Y2=YH-BLEN*SIN(THETA-DELTA)
        CALL PLOT(X2,Y2,2)
        CALL PLOT(XH,YH,2)
        DIA=0.5*AHLEN
        IF(ICODE.EQ.-2) CALL SDOT(XT,YT,DIA)
      ELSEIF(ICODE.EQ.3) THEN
        CALL SDOT(XT,YT,AHLEN)
      ENDIF
999   RETURN
      END
C
C
C
      SUBROUTINE CONPLT
C
C---- CONPLT ----------------------------------------------------------S
C
C  PURPOSE:
C    PLOTS WATER-SURFACE AND GROUND-SURFACE ELEVATION CONTOURS.
C
C  SUBPROGRAM(S) CALLED:
C    BNDPLT, CLVPLT, PLOTS, PLOT, SYMBOL, ACVINC
C
C----------------------------------------------------------------------F
C
      INCLUDE 'ANOMOD.INC'
C
C---- OUTPUT FORMATS
2000  FORMAT(1H+,79(' ')/1H+,'Plotting (contours)...')
C
C---- SCREEN ACKNOWLEDGEMENT
      IF(SCREEN) WRITE(*,2000)
C
C---- SET DEFAULT VALUES
      IF(CVMAX-CVMIN.LT.ZIP) THEN
        CVMAX=1.0E+35
        CVMIN=-CVMAX
      ENDIF
      IF(CVINC.LT.ZIP) CALL ACVINC
      IF(HTT.LT.ZIP) HTT=0.140
      IF(HTN.LT.ZIP) HTN=0.070
      IF(HTC.LT.ZIP) HTC=0.105
C
C---- TURN OFF ELEMENTS WITH DRY NODES
      CALL LDNOFF
C
C---- COMPUTE PLOT BOUNDS
      CALL BOUNDS
C
C---- MOVE TO PLOT ORIGIN
      IF(NEWPLT) THEN
        IF(IPLINT.GT.1) THEN
          X=XUP+1.
          CALL PLOT(X,0.,-3)
        ENDIF
        NCHAR=LENCHR(PTITLE)
        CALL SYMBOL(0.3,0.,HTT,PTITLE,0,90.,NCHAR)
      ENDIF
C
C---- PLOT NETWORK BOUNDARY
      IF(NEWPLT) CALL BNDPLT
C
C---- PLOT CONTOUR LINES AND VALUES
      CALL CLVPLT
C
C---- END PLOT
      CALL PLOT(XUP,0.,3)
C
C---- MAKE SURE ALL ELEMENT PROPERTY CODES ARE POSITIVE
      CALL LPCPOS
C
C---- END RUN
      RETURN
      END
C
C
C
      SUBROUTINE ACVINC
C
C---- ACVINC ----------------------------------------------------------S
C
C  PURPOSE:
C    ASSIGNS THE CONTOUR VALUE INTERVAL.  A CONTOUR VALUE INTERVAL THAT
C    PROVIDES ABOUT TEN (10) CONTOUR LINES IS ASSIGNED.
C
C----------------------------------------------------------------------F
C
      INCLUDE 'ANOMOD.INC'
      DIMENSION SAVE(5)
      DATA SAVE/1.,2.,5.,10.,20./,NCVINC/10/
      VMIN=1.0E+35
      VMAX=-VMIN
C
C---- COMPUTE MAXIMUM AND MINIMUM CONTOUR VALUES
      DO 20 L=1,NE
        IF(LMAT(L).EQ.0) GOTO 20
        IF(LMAT(L).LT.1 .AND. ICVAL.NE.0) GOTO 20
        NCN=6
        IF(NOP(L,7).GT.0) NCN=8
        DO 10 K=1,NCN
          N=NOP(L,K)
          IF(ICVAL.EQ.0) THEN
            CV=GRNDA(N)
          ELSE IF(ICVAL.GT.0) THEN
            CV=XVELA(3,N)+GRNDA(N)
          ELSE
            CV=XVELA(3,N)-XVELB(3,N)
          ENDIF
          IF(CV.GT.VMAX) THEN
            VMAX=CV
          ELSEIF(CV.LT.VMIN) THEN
            VMIN=CV
          ENDIF
10      CONTINUE
20    CONTINUE
C
C---- ASSIGN CONTOUR INTERVAL VALUE
      CVINC=(VMAX-VMIN)/REAL(NCVINC)
      I=ALOG10(CVINC)
      P=10.**REAL(I)
      CVINC=CVINC/P-0.001
      DO 30 I=1,5
        IS=I
        IF(SAVE(I).GT.CVINC) GOTO 40
30    CONTINUE
40    CVINC=P*SAVE(IS)
      RETURN
      END
C
C
C
      SUBROUTINE CLVPLT
C
C---- CLVPLT ----------------------------------------------------------S
C
C  PURPOSE:
C    CONTROLS CONTOUR PLOTTING.  FOR EACH ELEMENT, EITHER SUBROUTINE
C    CNTORT OR CNTORQ IS CALLED TO PLOT CONTOUR LINES WITHIN THE
C    ELEMENT.
C
C  SUBPROGRAM(S) CALLED:
C    CNTORT, CNTORQ, SYMBOL, NUMBER
C
C----------------------------------------------------------------------F
C
      INCLUDE 'ANOMOD.INC'
      DIMENSION XN(8),YN(8),CV(8),IPLOT(2),SPLOT(2),NXID(8)
C
C---- INITIALIZE VARIABLES
      NPLOT=0
      IPLOT(1)=0
      IPLOT(2)=0
      IF(MOD(IPLTC,4).GT.1) THEN
        IPLOT(1)=1
        NPLOT=NPLOT+1
      ENDIF
      IF(MOD(IPLTC,8).GT.2) THEN
        IPLOT(2)=1
        NPLOT=NPLOT+1
      ENDIF
C
C---- COMPUTE NUMBER OF DECIMAL PALCES IN CONTOUR VALUE LABEL
      NDEC=NDECV
C
C---- LOOP AROUND ELEMENTS
      DO 100 L=1,NE
        IF(LMAT(L).EQ.0) GOTO 100
        IF(LMAT(L).LT.1 .AND. ICVAL.NE.0) GOTO 100
        NCN=6
        IF(NOP(L,7).GT.0) NCN=8
C
C-------ASSIGN CONTOUR VALUES
        DO 50 K=1,NCN
          N=NOP(L,K)
          XN(K)=CORD(N,1)
          YN(K)=CORD(N,2)
          NXID(K)=NPID(N)
          IF(ICVAL.EQ.0) THEN
            CV(K)=GRNDA(N)
          ELSEIF(ICVAL.GT.0) THEN
            CV(K)=XVELA(3,N)+GRNDA(N)
          ELSE
            CV(K)=(XVELA(3,N)+GRNDA(N))-(XVELB(3,N)+GRNDB(N))
          ENDIF
50      CONTINUE
C
C-------PLOT CONTOUR LINES
        IF(MOD(IPLTC,2).EQ.1) THEN
          IF(NCN.EQ.6) CALL CNTORT(XN,YN,CV,NXID,NDEC)
          IF(NCN.EQ.8) CALL CNTORQ(XN,YN,CV,NXID,NDEC)
        ENDIF
C
C-------PLOT CONTOUR VALUES
        IF(IPLTC.GT.1) THEN
          DO 80 K=1,NCN
            N=NOP(L,K)
            IF(NPID(N).LT.1) GOTO 80
            SPLOT(1)=N
            SPLOT(2)=CV(K)
C---------- Plot a dot at the node point
            X=XN(K)
            Y=YN(K)
            CALL TRFMXY(X,Y,XSCALE,YSCALE,XL,YL,SGN,CSN)
            X=X+XLP
            Y=Y+YLP
            CALL SYMBOL(XN(K),YN(K),HTN,' ',3,0.,-1)
C---------- Plot the node number and/or contour value near the node
            X=XN(K)+0.5*HTN
            Y=YN(K)+HTN*(0.75*(NPLOT-1)+1.0)
            CALL TRFMXY(X,Y,XSCALE,YSCALE,XL,YL,SGN,CSN)
            X=X+XLP
            Y=Y+YLP
            DO 70 J=1,2
              IF(IPLOT(J).GT.0) THEN
                FPN=SPLOT(J)
                Y=Y-1.5*HTN
                NDIG=-1
                IF(J.GT.1) NDIG=3
                CALL NUMBER(X,Y,HTN,FPN,0.,NDIG)
              ENDIF
70          CONTINUE
            NPID(N)=-NPID(N)
80        CONTINUE
        ENDIF
100   CONTINUE
C
C---- SET NPID ARRAY POSITIVE
      DO 110 N=1,NP
        NPID(N)=IABS(NPID(N))
110   CONTINUE
      RETURN
      END
C
C
C
      SUBROUTINE CNTORT(XN,YN,CVAL,NXID,NDEC)
C
C---- CNTORT ----------------------------------------------------------S
C
C  PURPOSE:
C    PLOTS CONTOUR LINES WITHIN TRIANGULAR ELEMENTS.
C
C  INPUT ARGUMENT(S):
C    XN,YN - COORDINATE ARRAYS OF ELEMENT NODE POINTS.
C    CVAL - ARRAY OF CONTOUR VALUES AT NODE POINTS.
C    NXID - NODE POINT ID ARRAY. SET TO 1 FOR MIDSIDE NODES LOCATED ON
C           THE NETWORK BOUNDARY.
C    NDEC - NUMBER OF DECIMAL PLACES TO BE PLOTTED.
C
C  SUBPROGRAM(S) CALLED:
C    TRFMXY, FIT, CVPLOT
C
C----------------------------------------------------------------------F
C
      INCLUDE 'ANOMOD.INC'
      DIMENSION BETA(4),ZETA(4),XN(8),YN(8),CVAL(8),NXID(8),LSC(3)
      REAL*4 L1,L2,L3
C
C---- ASSIGN CORNER NODE CONTOUR VALUES
      CV1=CVAL(1)
      CV2=CVAL(3)
      CV3=CVAL(5)
C
C---- CHECK FOR POSSIBLE CONTOUR LINE WITHIN ELEMENT
      CVLO=AMIN1(CV1,CV2,CV3)
      IF(CVLO.GT.CVMAX) GOTO 999
      CVHI=AMAX1(CV1,CV2,CV3)
      IF(CVHI.LT.CVMIN) GOTO 999
      IF(CVLO.LT.CVMIN) CVLO=CVMIN
      IF(CVHI.GT.CVMAX) CVHI=CVMAX
C
C---- BEGIN SEARCH FOR CONTOUR POINTS.  SET INITIAL CONTOUR VALUE.
      CV=CVINC*AINT(CVLO/CVINC)-CVINC
C
C---- INCREMENT CONTOUR VALUE
10    CV=CV+CVINC
      LSC(1)=0
      LSC(2)=0
      LSC(3)=0
C
C---- IS CONTOUR VALUE WITHIN ALLOWABLE RANGE?
      IF(CV.LT.CVLO) GOTO 10
      IF(CV.GT.CVHI) GOTO 999
C
C---- SET INITIAL POINT COUNTER FOR CURRENT CONTOUR VALUE
      IP=0
C
C---- CHECK FOR CONTOUR POINT ALONG FIRST SIDE
      IF(CV.LT.AMIN1(CV1,CV2) .OR. CV.GT.AMAX1(CV1,CV2)) GOTO 20
      IF(ABS(CV1-CV2).GT.ZIP) THEN
        IP=IP+1
        BETA(IP)=(CV-CV2)/(CV1-CV2)
        ZETA(IP)=1.0-BETA(IP)
        IF(NXID(2).EQ.1) LSC(IP)=1
      ENDIF
C
C---- CHECK FOR CONTOUR POINT ALONG SECOND SIDE
20    IF(CV.LT.AMIN1(CV2,CV3) .OR. CV.GT.AMAX1(CV2,CV3)) GOTO 30
      IF(ABS(CV2-CV3).GT.ZIP) THEN
        IP=IP+1
        BETA(IP)=0.0
        ZETA(IP)=(CV-CV3)/(CV2-CV3)
        IF(NXID(4).EQ.1) LSC(IP)=1
      ENDIF
C
C---- CHECK FOR CONTOUR POINT ALONG THIRD SIDE
30    IF(CV.LT.AMIN1(CV3,CV1) .OR. CV.GT.AMAX1(CV3,CV1)) GOTO 40
      IF(ABS(CV3-CV1).GT.ZIP) THEN
        IP=IP+1
        BETA(IP)=(CV-CV3)/(CV1-CV3)
        ZETA(IP)=0.0
        IF(NXID(6).EQ.1) LSC(IP)=1
      ENDIF
C
C---- HAVE TWO CONTOUR POINTS BEEN FOUND?  IF NOT, TRY NEXT VALUE.
40    IF(IP.NE.2) GOTO 10
C
C---- CHECK FOR IDENTICAL INTERSECTION POINTS
cx      BDIF=ABS(BETA(1)-BETA(2))
cx      ZDIF=ABS(ZETA(1)-ZETA(2))
cx      IF( BDIF.LT.ZIP .AND. ZDIF.LT.ZIP ) GOTO 10
C
C---- COMPUTE CONTOUR LINE END- AND MID-POINT COORDINATES
      L1=BETA(1)
      L2=ZETA(1)
      L3=1.0-L1-L2
      W1=(2.0*L1-1.0)*L1
      W2=(2.0*L2-1.0)*L2
      W3=(2.0*L3-1.0)*L3
      W4=4.0*L1*L2
      W5=4.0*L2*L3
      W6=4.0*L3*L1
      XA=W1*XN(1)+W2*XN(3)+W3*XN(5)+W4*XN(2)+W5*XN(4)+W6*XN(6)
      YA=W1*YN(1)+W2*YN(3)+W3*YN(5)+W4*YN(2)+W5*YN(4)+W6*YN(6)
      L1=0.5*(BETA(1)+BETA(2))
      L2=0.5*(ZETA(1)+ZETA(2))
      L3=1.0-L1-L2
      W1=(2.0*L1-1.0)*L1
      W2=(2.0*L2-1.0)*L2
      W3=(2.0*L3-1.0)*L3
      W4=4.0*L1*L2
      W5=4.0*L2*L3
      W6=4.0*L3*L1
      XB=W1*XN(1)+W2*XN(3)+W3*XN(5)+W4*XN(2)+W5*XN(4)+W6*XN(6)
      YB=W1*YN(1)+W2*YN(3)+W3*YN(5)+W4*YN(2)+W5*YN(4)+W6*YN(6)
      L1=BETA(2)
      L2=ZETA(2)
      L3=1.0-L1-L2
      W1=(2.0*L1-1.0)*L1
      W2=(2.0*L2-1.0)*L2
      W3=(2.0*L3-1.0)*L3
      W4=4.0*L1*L2
      W5=4.0*L2*L3
      W6=4.0*L3*L1
      XC=W1*XN(1)+W2*XN(3)+W3*XN(5)+W4*XN(2)+W5*XN(4)+W6*XN(6)
      YC=W1*YN(1)+W2*YN(3)+W3*YN(5)+W4*YN(2)+W5*YN(4)+W6*YN(6)
C
C---- TRANSFORM TO PLOT COORDINATES
      CALL TRFMXY(XA,YA,XSCALE,YSCALE,XL,YL,SGN,CSN)
      CALL TRFMXY(XB,YB,XSCALE,YSCALE,XL,YL,SGN,CSN)
      CALL TRFMXY(XC,YC,XSCALE,YSCALE,XL,YL,SGN,CSN)
C
C---- PLOT CONTOUR LINE
      XA=XA+XLP
      XB=XB+XLP
      XC=XC+XLP
      YA=YA+YLP
      YB=YB+YLP
      YC=YC+YLP
      CALL FIT(XA,YA,XB,YB,XC,YC,XLP,YLP,XUP,YUP)
C
C---- PLOT CONTOUR VALUE AT BOUNDARY INTERSECTIONS
      CALL CVPLOT(XA,YA,XB,YB,XC,YC,LSC,CV,NDEC,HTC,XLP,YLP,XUP,YUP)
      GOTO 10
999   RETURN
      END
C
C
C
      SUBROUTINE CNTORQ(XQ,YQ,CQ,NQID,NDEC)
C
C---- CNTORQ ----------------------------------------------------------S
C
C  PURPOSE:
C    PLOTS CONTOUR LINES WITHIN QUADRILATERL ELEMENTS.  QUADRILATERAL
C    ELEMENTS ARE DIVIDED INTO FOUR TRIANGULAR ELEMENTS IN ORDER TO
C    DRAW CONTOUR LINES.  FOR EACH OF THE NEWLY DEFINED TRIANGUALR
C    ELEMENTS, SUBROUTINE CNTORT IS CALLED TO PLOT THE CONTOURS.
C
C  INPUT ARGUMENT(S):
C    XQ,YQ - COORDINATE ARRAYS OF ELEMENT NODE POINTS.
C    CQ - ARRAY OF CONTOUR VALUES AT NODE POINTS.
C    NQID - NODE POINT ID ARRAY. SET TO 1 FOR MIDSIDE NODES LOCATED ON
C           THE NETWORK BOUNDARY.
C    NDEC - NUMBER OF DECIMAL PLACES TO BE PLOTTED.
C
C  SUBPROGRAM(S) CALLED:
C    CNTORT
C
C----------------------------------------------------------------------F
C
      DIMENSION XQ(8),YQ(8),CQ(8),XR(8),YR(8),CR(8),NQID(8),NRID(8)
C
C---- ASSIGN CENTER POINT VALUES
      XR(5)=0.5*(XQ(2)+XQ(4)+XQ(6)+XQ(8))-0.25*(XQ(1)+XQ(3)+XQ(5)+XQ(7))
      YR(5)=0.5*(YQ(2)+YQ(4)+YQ(6)+YQ(8))-0.25*(YQ(1)+YQ(3)+YQ(5)+YQ(7))
      CR(5)=0.5*(CQ(2)+CQ(4)+CQ(6)+CQ(8))-0.25*(CQ(1)+CQ(3)+CQ(5)+CQ(7))
      NRID(5)=0
C
C---- FIRST ELEMENT
      DO 10 K=1,3
        XR(K)=XQ(K)
        YR(K)=YQ(K)
        CR(K)=CQ(K)
        NRID(K)=NQID(K)
10    CONTINUE
      XR(4)=0.5*(XR(3)+XR(5))
      YR(4)=0.5*(YR(3)+YR(5))
      CR(4)=0.5*(CR(3)+CR(5))
      NRID(4)=0
      XR(6)=0.5*(XR(5)+XR(1))
      YR(6)=0.5*(YR(5)+YR(1))
      CR(6)=0.5*(CR(5)+CR(1))
      NRID(6)=0
      CALL CNTORT(XR,YR,CR,NRID,NDEC)
C
C---- SECOND ELEMENT
      DO 20 K=1,3
        KK=K+2
        XR(K)=XQ(KK)
        YR(K)=YQ(KK)
        CR(K)=CQ(KK)
        NRID(K)=NQID(KK)
20    CONTINUE
      XR(4)=0.5*(XR(3)+XR(5))
      YR(4)=0.5*(YR(3)+YR(5))
      CR(4)=0.5*(CR(3)+CR(5))
      NRID(4)=0
      XR(6)=0.5*(XR(5)+XR(1))
      YR(6)=0.5*(YR(5)+YR(1))
      CR(6)=0.5*(CR(5)+CR(1))
      NRID(6)=0
      CALL CNTORT(XR,YR,CR,NRID,NDEC)
C
C---- THIRD ELEMENT
      DO 30 K=1,3
        KK=K+4
        XR(K)=XQ(KK)
        YR(K)=YQ(KK)
        CR(K)=CQ(KK)
        NRID(K)=NQID(KK)
30    CONTINUE
      XR(4)=0.5*(XR(3)+XR(5))
      YR(4)=0.5*(YR(3)+YR(5))
      CR(4)=0.5*(CR(3)+CR(5))
      NRID(4)=0
      XR(6)=0.5*(XR(5)+XR(1))
      YR(6)=0.5*(YR(5)+YR(1))
      CR(6)=0.5*(CR(5)+CR(1))
      NRID(6)=0
      CALL CNTORT(XR,YR,CR,NRID,NDEC)
C
C---- FOURTH ELEMENT
      DO 40 K=1,3
        KK=K+6
        IF(K.EQ.3) KK=1
        XR(K)=XQ(KK)
        YR(K)=YQ(KK)
        CR(K)=CQ(KK)
        NRID(K)=NQID(KK)
40    CONTINUE
      XR(4)=0.5*(XR(3)+XR(5))
      YR(4)=0.5*(YR(3)+YR(5))
      CR(4)=0.5*(CR(3)+CR(5))
      NRID(4)=0
      XR(6)=0.5*(XR(5)+XR(1))
      YR(6)=0.5*(YR(5)+YR(1))
      CR(6)=0.5*(CR(5)+CR(1))
      NRID(6)=0
      CALL CNTORT(XR,YR,CR,NRID,NDEC)
      RETURN
      END
C
C
C
      SUBROUTINE CVPLOT(XA,YA,XB,YB,XC,YC,LSC,CV,NDEC,HTC,XLP,YLP,
     # XUP,YUP)
C
C---- CVPLOT ----------------------------------------------------------S
C
C  PURPOSE:
C    PLOTS CONTOUR VALUES AT INTERSECTIONS OF CONTOUR LINES WITH THE
C    BOUNDARY OF THE NETWORK.
C
C  INPUT ARGUMENT(S):
C    XA,YA,XB,YB,XC,YC - COORDINATES OF THE ENDPOINTS AND MIDSIDE POINT
C    OF A CONTOUR LINE.
C    LSC - ELEMENT SIDE CODE ARRAY.
C    CV - CONTOUR VALUE.
C    NDEC - NUMBER OF DECIMAL POINTS IN PLOOTED CONTOUR VALUE.
C    HTC - HEIGHT OF PLOTTED CONTOUR VALUE, IN INCHES.
C    XLP,YLP - COORDINATES OF LOWER-LEFT CORNER OF VIEWPORT.
C    XUP,YUP - COORDINATES OF UPPER-RIGHT CORNER OF VIEWPORT.
C
C  SUBPROGRAM(S) CALLED:
C    NUMBER
C
C----------------------------------------------------------------------F
C
      DIMENSION LSC(3)
      DATA RTOD/57.29578/,ZIP/1.0E-08/
      IF(NDEC.LT.-1) RETURN
      IF( LSC(1).EQ.0 .AND. LSC(2).EQ.0 ) GOTO 999
C
C---- COMPUTE NUMBER OF DIGITS IN CONTOUR VALUE
      NLEFT=1
      J=INT(CV)
      IF(J.GT.0) THEN
        K=1
        DO 10 I=1,4
          K=K*10
          IF(J.GE.K) NLEFT=NLEFT+1
10      CONTINUE
      ENDIF
      NDIG=1+NLEFT+NDEC
C
C---- CHECK FIRST ENDPOINT
      KODE=PCODE(XA,YA,XLP,YLP,XUP,YUP)
      IF(LSC(1).EQ.1 .AND. KODE.EQ.0) THEN
        DXDS=-1.5*XA+2.0*XB-0.5*XC
        DYDS=-1.5*YA+2.0*YB-0.5*YC
        DS=SQRT(DXDS*DXDS+DYDS*DYDS)
        IF(DS.GT.ZIP) THEN
          ANGLE=RTOD*ATAN2(DYDS,DXDS)
          FACT=HTC/DS
        ELSE
          ANGLE=0.
          FACT=0.
        ENDIF
        IF(DXDS.GT.0.) THEN
          DX=FACT*(-REAL(NDIG+1)*DXDS+0.5*DYDS)
          DY=FACT*(-REAL(NDIG+1)*DYDS-0.5*DXDS)
          ANGLE=RTOD*ATAN2(DYDS,DXDS)
        ELSE
          DX=FACT*(-DXDS-0.5*DYDS)
          DY=FACT*(-DYDS+0.5*DXDS)
          IF(DS.GT.ZIP) THEN
            ANGLE=RTOD*ATAN2(-DYDS,-DXDS)
          ELSE
            ANGLE=0.
          ENDIF
        ENDIF
        X=XA+DX
        Y=YA+DY
        CALL NUMBER(X,Y,HTC,CV,ANGLE,NDEC)
      ENDIF
C
C---- CHECK SECOND ENDPOINT
      KODE=PCODE(XB,YB,XLP,YLP,XUP,YUP)
      IF(LSC(2).EQ.1 .AND. KODE.EQ.0) THEN
        DXDS=0.5*XA-2.0*XB+1.5*XC
        DYDS=0.5*YA-2.0*YB+1.5*YC
        DS=SQRT(DXDS*DXDS+DYDS*DYDS)
        IF(DS.GT.ZIP) THEN
          FACT=HTC/DS
        ELSE
          FACT=0.
        ENDIF
        IF(DXDS.GT.0.) THEN
          DX=FACT*(DXDS+0.5*DYDS)
          DY=FACT*(DYDS-0.5*DXDS)
          ANGLE=RTOD*ATAN2(DYDS,DXDS)
        ELSE
          DX=FACT*(REAL(NDIG+1)*DXDS-0.5*DYDS)
          DY=FACT*(REAL(NDIG+1)*DYDS+0.5*DXDS)
          IF(DS.GT.ZIP) THEN
            ANGLE=RTOD*ATAN2(-DYDS,-DXDS)
          ELSE
            ANGLE=0.
          ENDIF
        ENDIF
        X=XC+DX
        Y=YC+DY
        CALL NUMBER(X,Y,HTC,CV,ANGLE,NDEC)
      ENDIF
999   RETURN
      END
C
C
C
      SUBROUTINE FLXPLT
C
C---- FLXPLT ----------------------------------------------------------S
C
C  PURPOSE:
C    COMPUTES AND PLOTS DISCHARGE ACROSS A SPECIFIED SERIES OF ELEMENT
C    SIDES.  THIS FLOW COMPUTATION MAY BE USED TO CHECK ON CONTINUITY
C    OF THE MODEL DURING STEADY-STATE SIMULATIONS.
C
C  SUBPROGRAM(S) CALLED:
C    PLOT, BOUNDS, BNDPLT, TRFMXY, SYMBOL, NUMBER
C
C----------------------------------------------------------------------F
C
C---- Declarations (local)
      INTEGER   I,J,K,KK,KLO,KHI,KODE,LENCHR,N,N1,N2,N3,NCHAR,PCODE
      REAL      X,X1,X2,X3,Y,Y1,Y2,Y3,U,V,H,QX,QY,QTOT,QREF,QPCT,
     #          DX,DY,DXDT,DYDT,RTOD,HEIGHT,ANGLE
C
C---- Common blocks
      INCLUDE 'ANOMOD.INC'
C
C---- Data
      DATA RTOD/57.29578/
C
C-----Output formats
2000  FORMAT(1H+,79(' ')/1H+,'Plotting (flow-check lines)...')
2030  FORMAT(//57X,'*** FLOW CHECKS ***'//
     # 37X,'LINE',10X,'TOTAL',9X,'X-FLOW',9X,'Y-FLOW',3X,'PERCENT')
2031  FORMAT(38X,'NO.',10X,'(CFS)',10X,'(CFS)',10X,'(CFS)'/)
2032  FORMAT(38X,'NO.',10X,'(CMS)',10X,'(CMS)',10X,'(CMS)'/)
2035  FORMAT(36X,I5,1P3E15.3,0PF10.1)
2130  FORMAT(//31X,'*** FLOW CHECKS ***'//
     # 11X,'LINE',10X,'TOTAL',9X,'X-FLOW',9X,'Y-FLOW',3X,'PERCENT')
2131  FORMAT(12X,'NO.',10X,'(CFS)',10X,'(CFS)',10X,'(CFS)'/)
2132  FORMAT(12X,'NO.',10X,'(CMS)',10X,'(CMS)',10X,'(CMS)'/)
2135  FORMAT(10X,I5,1P3E15.3,0PF10.1)
C
      IF(SCREEN) WRITE(*,2000)
      IF(WIDE) THEN
        WRITE(IO2,2030)
        IF(IUNITS.EQ.0) THEN
          WRITE(IO2,2031)
        ELSE
           WRITE(IO2,2032)
        ENDIF
      ELSE
        WRITE(IO2,2130)
        IF(IUNITS.EQ.0) THEN
          WRITE(IO2,2131)
        ELSE
          WRITE(IO2,2132)
        ENDIF
      ENDIF
      KHI=-1
C
C-----TURN OFF ELEMENTS WITH DRY NODES
      CALL LDNOFF
C
C-----COMPUTE PLOT BOUNDS
      CALL BOUNDS
C
C-----MOVE TO PLOT ORIGIN
      IF(NEWPLT) THEN
        IF(IPLINT.GT.1) CALL PLOT(XUP+1.0,0.,-3)
        NCHAR=LENCHR(PTITLE)
        CALL SYMBOL(0.3,0.,HTT,PTITLE,0,90.,NCHAR)
      ENDIF
C
C-----PLOT BOUNDARY IF PLOT IS NEW
      IF(NEWPLT) CALL BNDPLT
C
C-----CHANGE PENS FOR FLUX LINES
      CALL NEWPEN(2)
C
C-----LOOP OVER FLUX LINES
      DO 200 J=1,NCL
        QX=0.
        QY=0.
        KLO=KHI+2
        DO 10 K=KLO,MAXLP
          IF(LINE(K).LE.0) GO TO 20
          KHI=K
10      CONTINUE
C
C-------LOOP OVER ELEMENT SIDES
20      DO 100 KK=KLO,KHI,2
          IF(KHI-KK.LT.2) GO TO 100
          NODE(1)=LINE(KK)
          NODE(2)=LINE(KK+1)
          NODE(3)=LINE(KK+2)
C---------PLOT ELEMENT SIDE IF IPLTF > 0
          IF(IPLTF.GT.0) THEN
            N=NODE(1)
            X1=CORD(N,1)
            Y1=CORD(N,2)
            N=NODE(2)
            X2=CORD(N,1)
            Y2=CORD(N,2)
            N=NODE(3)
            X3=CORD(N,1)
            Y3=CORD(N,2)
            CALL TRFMXY(X1,Y1,XSCALE,YSCALE,XL,YL,SGN,CSN)
            CALL TRFMXY(X2,Y2,XSCALE,YSCALE,XL,YL,SGN,CSN)
            CALL TRFMXY(X3,Y3,XSCALE,YSCALE,XL,YL,SGN,CSN)
            X1=X1+XLP
            X2=X2+XLP
            X3=X3+XLP
            CALL FIT(X1,Y1,X2,Y2,X3,Y3,XLP,YLP,XUP,YUP)
          ENDIF
C---------COMPUTE LOCAL COORDINATES
          N1=NODE(1)
          DO 30 K=2,3
            N=NODE(K)
            XLOC(K)=CORD(N,1)-CORD(N1,1)
            YLOC(K)=CORD(N,2)-CORD(N1,2)
30        CONTINUE
C---------ASSIGN NODAL VARIABLES
          DO 40 K=1,3
            N=NODE(K)
            ULOC(K)=XVELA(1,N)
            VLOC(K)=XVELA(2,N)
            HLOC(K)=XVELA(3,N)
40        CONTINUE
C---------LOOP OVER INTEGRATION POINTS
          DO 90 I=1,4
            DYDT=0.0
            DXDT=0.0
            DO 50 K=2,3
              DYDT=DYDT+DNAL(K,I)*YLOC(K)
              DXDT=DXDT-DNAL(K,I)*XLOC(K)
50          CONTINUE
C-----------COMPUTE U, V, AND H
            U=0.0
            V=0.0
            H=0.0
            DO 60 K=1,3
              U=U+XNL(K,I)*ULOC(K)
              V=V+XNL(K,I)*VLOC(K)
60          CONTINUE
            DO 70 K=1,3,2
              H=H+XML(K,I)*HLOC(K)
70          CONTINUE
C-----------SUM QX AND QY
            QX=QX+WAITL(I)*U*H*DYDT
            QY=QY+WAITL(I)*V*H*DXDT
90        CONTINUE
100     CONTINUE
        QTOT=QX+QY
        IF(J.EQ.1) QREF=QTOT
        IF(ABS(QREF).LT.0.0001) QREF=1.0
        QPCT=100.0*QTOT/QREF
        IF(WIDE) THEN
          WRITE(IO2,2035) J,QTOT,QX,QY,QPCT
        ELSE
          WRITE(IO2,2135) J,QTOT,QX,QY,QPCT
        ENDIF
C
C-------PLOT ASTERISKS AT ENDS OF LINE AND DISCHARGE IF IPLTF > 0
        IF(IPLTF.GT.0) THEN
          HEIGHT=2.*HTN
          N=LINE(KLO)
          X=CORD(N,1)
          Y=CORD(N,2)
          CALL TRFMXY(X,Y,XSCALE,YSCALE,XL,YL,SGN,CSN)
          X=X+XLP-HTN
          Y=Y+YLP-HTN
          KODE=PCODE(X,Y,XLP,YLP,XUP,YUP)
          IF(KODE.EQ.0) CALL SYMBOL(X,Y,HEIGHT,'*',0,0.,1)
          N=LINE(KHI)
          X=CORD(N,1)
          Y=CORD(N,2)
          CALL TRFMXY(X,Y,XSCALE,YSCALE,XL,YL,SGN,CSN)
          X=X+XLP-HTN
          Y=Y+YLP-HTN
          KODE=PCODE(X,Y,XLP,YLP,XUP,YUP)
          IF(KODE.EQ.0) CALL SYMBOL(X,Y,HEIGHT,'*',0,0.,1)
          K=KLO+(KHI-KLO)/2
          IF(MOD(K,2).GT.0) K=K-1
          N1=LINE(K-1)
          N2=LINE(K)
          N3=LINE(K+1)
          X1=CORD(N1,1)
          Y1=CORD(N1,2)
          X2=CORD(N2,1)
          Y2=CORD(N2,2)
          X3=CORD(N3,1)
          Y3=CORD(N3,2)
          CALL TRFMXY(X2,Y2,XSCALE,YSCALE,XL,YL,SGN,CSN)
          X2=X2+XLP
          DY=Y3-Y1
          DX=X3-X1
          IF(ABS(DY).GT.ZIP .OR. ABS(DX).GT.ZIP) THEN
            ANGLE=ATAN2(DY,DX)
          ELSE
            ANGLE=0.
          ENDIF
          X=X2-0.5*HTN*SIN(ANGLE)
          Y=Y2+0.5*HTN*COS(ANGLE)
          ANGLE=RTOD*ANGLE
          CALL NUMBER(X,Y,HTN,QTOT,ANGLE,NDECF)
        ENDIF
200   CONTINUE
C
C-----CHANGE BACK TO ORIGINAL PEN
      CALL NEWPEN(1)
C
C-----END PLOT
      CALL PLOT(XUP,0.,3)
C
C-----MAKE SURE ALL ELEMENT PROPERTY CODES ARE POSITIVE
      CALL LPCPOS
      RETURN
      END
C
C
C
      SUBROUTINE HSTPLT
C
C---- HSTPLT ----------------------------------------------------------S
C
C  PURPOSE:
C    CONTROLS TIME HISTORY PLOTS OF VELOCITY, DISCHARGE, AND STAGE AT
C    NODE POINTS.
C
C  SUBPROGRAM(S) CALLED:
C    SCALE, VELPLT, UNQPLT, STGPLT, PLOT
C
C----------------------------------------------------------------------F
C
C---- Declarations (local)
      INTEGER   I,K,N
      REAL      RTOD,DTOR,U,V,H,Q,QX,QY
      CHARACTER FORM*11
C
C---- Common blocks
      INCLUDE 'ANOMOD.INC'
C
C---- Data
      DATA RTOD/57.29578/,DTOR/0.0174533/
      DATA NPTS/0/
C
C---- Input formats
1000  FORMAT(E10.0,I10)
1010  FORMAT(I10,3E10.0)
C
C---- Output formats
 2000 FORMAT(/
     # 46X,'*** TIME-HISTORY REPORT FOR NODE ',I4,' ***'//
     # 41X,'--- VELOCITY ---',5X,'--- UNIT DISCHARGE ---'/
     # 33X,'TIME',3X,'X-VEL',3X,'Y-VEL',3X,'TOTAL',
     # 1X,'X-UNITQ',1X,'Y-UNITQ',3X,'TOTAL',4X,'DEPTH',5X,'WSEL')
 2001 FORMAT(32X,'(HRS)',2X,'(FT/S)',2X,'(FT/S)',2X,'(FT/S)',
     # 1X,'(FT2/S)',1X,'(FT2/S)',1X,'(FT2/S)',5X,'(FT)',5X,'(FT)'/)
 2002 FORMAT(32X,'(HRS)',3X,'(M/S)',3X,'(M/S)',3X,'(M/S)',
     # 2X,'(M2/S)',2X,'(M2/S)',2X,'(M2/S)',6X,'(M)',6X,'(M)'/)
 2003 FORMAT(29X,7F8.2,2F9.3)
 2101 FORMAT(/
     # 19X,'*** TIME HISTORY REPORT FOR NODE ',I5,' ***'//
     # 6X,' TIME --- VELOCITY (FT/S) --- -- UNIT FLOW (FT2/S) --',
     # '   DEPTH     WSEL'/
     # 6X,'(HRS)       X       Y   TOTAL       X       Y   TOTAL',
     # '    (FT)     (FT)')
 2102 FORMAT(/
     # 19X,'*** TIME HISTORY REPORT FOR NODE ',I5,' ***'//
     # 6X,' TIME --- VELOCITY (M/S) ---- -- UNIT FLOW (M2/S) ---',
     # '   DEPTH     WSEL'/
     # 6X,'(HRS)       X       Y   TOTAL       X       Y   TOTAL',
     # '     (M)      (M)')
 2103 FORMAT(3X,8F8.3,F9.3)
 2050 FORMAT(/
     # ' ***ERROR #??? - FLOW-FIELD DATA MUST BE READ FROM A FILE'/
     # '                 FOR TIME-HISTORY REPORTS AND PLOTS.')
 2500 FORMAT(1H+,79(' ')/1H+,'Plotting (time histories)...')
C
C-----SCREEN ACKNOWLEDGEMENT
      IF(SCREEN) WRITE(*,2500)
C
C-----CHECK FOR FLOW DATA FILE
      IF(IFLOWA.EQ.0) THEN
        WRITE(IO2,2050)
        RETURN
      ENDIF
C
C-----FILL PLOT VALUE ARRAY
      REWIND IO93
      READ(IO93,1000,ERR=5) TET,NP
      FORM='FORMATTED'
      GOTO 6
5     FORM='UNFORMATTED'
6     BACKSPACE IO93
10    IF(FORM.EQ.'FORMATTED') THEN
        READ(IO93,1000) TET,NP
        READ(IO93,1010) (N,(XVELA(K,N),K=1,3),I=1,NP)
      ELSE
        READ(IO93) TET,NP,((XVELA(K,N),K=1,3),X,X,X,N=1,NP)
      ENDIF
      STCURA=TET
      IF(TET.LT.TFIRST) GOTO 10
      NPTS=NPTS+1
      DO 20 K=1,NPTH
        N=NTHP(K)
        XARAY(NPTS)=TET
        VARRAY(NPTS,1,K)=XVELA(1,N)
        VARRAY(NPTS,2,K)=XVELA(2,N)
        VARRAY(NPTS,3,K)=XVELA(3,N)
20    CONTINUE
      IF(TLAST.GT.TET+STEPS) GOTO 10
C
C-----SCALE TIME VALUES
50    CALL SCALE(XARAY,6.0,NPTS)
C
C-----LOOP AROUND TIME HISTORY NODE POINTS
      DO 100 I=1,NPTH
        N=NTHP(I)
        KODE=KTHP(I)
C-------CHECK FOR VELOCITY PLOT
        IF( MOD(KODE,1000)/100 .GT. 0 ) THEN
          DO 60 K=1,NPTS
            VX=VARRAY(K,1,I)
            VY=VARRAY(K,2,I)
            VEL=SQRT(VX*VX+VY*VY)
            YARAY1(K)=VEL
            IF(ABS(VEL).GT.0.) THEN
              YARAY2(K)=RTOD*ATAN2(VY,VX)
            ELSE
              YARAY2(K)=0.
            ENDIF
60        CONTINUE
          CALL SCALE(YARAY1,6.0,NPTS)
          YARAY2(NPTS+1)=-180.
          YARAY2(NPTS+2)=180.
          IF(IPLINT.GT.1) CALL PLOT(XUP+1.,0.,-3)
          IPLINT=IPLINT+1
          LINTYP=(MOD(KODE,1000)/100)-1
          CALL VELPLT(N,NPTS,XARAY,YARAY1,YARAY2,LINTYP,IUNITS)
          XUP=8.5
        ENDIF
C
C-------CHECK FOR UNIT FLOW PLOT
        IF( MOD(KODE,100)/10 .GT. 0 ) THEN
          DO 70 K=1,NPTS
            VX=VARRAY(K,1,I)
            VY=VARRAY(K,2,I)
            H=VARRAY(K,3,I)
            VEL=SQRT(VX*VX+VY*VY)
            Q=VEL*H
            YARAY1(K)=Q
            IF(ABS(VEL).GT.0.) THEN
              YARAY2(K)=RTOD*ATAN2(VY,VX)
            ELSE
              YARAY2(K)=0.
            ENDIF
70        CONTINUE
          CALL SCALE(YARAY1,6.0,NPTS)
          YARAY2(NPTS+1)=-180.
          YARAY2(NPTS+2)=180.
          LINTYP=(MOD(KODE,100)/10)-1
          IF(IPLINT.GT.1) CALL PLOT(XUP+1.,0.,-3)
          IPLINT=IPLINT+1
          CALL UNQPLT(N,NPTS,XARAY,YARAY1,YARAY2,LINTYP,IUNITS)
          XUP=8.5
        ENDIF
C
C-------CHECK FOR STAGE (WATER-SURFACE ELEVATION) PLOT
        IF( MOD(KODE,10) .GT. 0 ) THEN
          DO 80 K=1,NPTS
            WS=VARRAY(K,3,I)+GRNDA(N)
            YARAY1(K)=WS
80        CONTINUE
          CALL SCALE(YARAY1,8.5,NPTS)
          LINTYP=MOD(KODE,10)-1
          IF(IPLINT.GT.1) CALL PLOT(XUP+1.,0.,-3)
          IPLINT=IPLINT+1
          CALL STGPLT(N,NPTS,XARAY,YARAY1,LINTYP,IUNITS)
          XUP=8.5
        ENDIF
C
C-------TIME HISTORY REPORT
        IF( MOD(KODE,10000)/1000 .GT. 0 ) THEN
          CALL FORMFD(IO2)
          IF(WIDE) THEN
            WRITE(IO2,2000) N
            IF(IUNITS.EQ.0) THEN
              WRITE(IO2,2001)
            ELSE
              WRITE(IO2,2002)
            ENDIF
          ELSE
            IF(IUNITS.EQ.0) THEN
              WRITE(IO2,2101) N
            ELSE
              WRITE(IO2,2102) N
            ENDIF
          ENDIF
          DO 90 K=1,NPTS
            VX=VARRAY(K,1,I)
            VY=VARRAY(K,2,I)
            H=VARRAY(K,3,I)
            V=SQRT(VX*VX+VY*VY)
            QX=VX*H
            QY=VY*H
            Q=V*H
            WS=H+GRNDA(N)
            TIME=XARAY(K)
            IF(WIDE) THEN
              WRITE(IO2,2003) TIME,VX,VY,V,QX,QY,Q,H,WS
            ELSE
              WRITE(IO2,2103) TIME,VX,VY,V,QX,QY,Q,H,WS
            ENDIF
90        CONTINUE
        ENDIF
100   CONTINUE
      RETURN
      END
C
C
C
      SUBROUTINE VELPLT(N,NPTS,XARAY,YARAY1,YARAY2,LINTYP,IUNITS)
C
C---- VELPLT ----------------------------------------------------------S
C
C  PURPOSE:
C    PLOTS VELOCITY MAGNITUDE AND ANGLE VERSUS TIME.
C
C  INPUT ARGUMENT(S):
C    N - NODE NUMBER.
C    NPTS - NUMBER OF POINTS TO BE PLOTTED + 2
C    XARAY - ARRAY CONTAINING TIME.
C    YARAY1 - ARRAY CONTAINING VELOCITY MAGNITUDE.
C    YARAY2 - ARRAY CONTAINING VELOCITY ANGLE.
C    LINTYP - LINE TYPE CODE.
C    IUNITS - UNIT CODE.  IF IUNITS = 0, U.S. CUSTUMARY UNITS ARE
C             BEING USED.  IF IUINTS = 1, S.I. UNITS ARE BEING USED.
C
C  SUBPROGRAM(S) CALLED:
C    AXIS, XLINE, R2CHAR
C
C----------------------------------------------------------------------F
C
C---- Declarations (arguments)
      INTEGER   N,NPTS,LINTYP,IUNITS
      REAL      XARAY,YARAY1,YARAY2
C
C---- Declarations (local)
      CHARACTER TITLE*32,NODNUM*20
C
C---- Dimensions
      DIMENSION XARAY(NPTS),YARAY1(NPTS),YARAY2(NPTS)
C
C-----PLOT DIRECTION ANGLE
      TITLE='SIMULATION TIME IN HOURS'
      NCHAR=-LENCHR(TITLE)
      FIRSTV=XARAY(NPTS+1)
      DELTAV=XARAY(NPTS+2)
      CALL AXIS(1.5,1.5,TITLE,NCHAR,6.0,0.,FIRSTV,DELTAV,2)
      TITLE='ANGLE IN DEGREES'
      NCHAR=LENCHR(TITLE)
      CALL AXIS(1.5,1.5,TITLE,NCHAR,2.0,90.,-180.,180.,-1)
      CALL XLINE(XARAY,YARAY2,NPTS,LINTYP,1.5,1.5)
C
C-----PLOT MAGNITUDE
      CALL AXIS(1.5,4.0,' ',-1,6.0,0.,FIRSTV,DELTAV,2)
      IF(IUNITS.EQ.0) THEN
        TITLE='MAGNITUDE IN FEET PER SECOND'
      ELSE
        TITLE='MAGNITUDE IN METERS PER SECOND'
      ENDIF
      NCHAR=LENCHR(TITLE)
      FIRSTV=YARAY1(NPTS+1)
      DELTAV=YARAY1(NPTS+2)
      CALL AXIS(1.5,4.0,TITLE,NCHAR,6.0,90.,FIRSTV,DELTAV,2)
      CALL XLINE(XARAY,YARAY1,NPTS,LINTYP,1.5,4.0)
C
C-----PLOT TITLE
      CALL R2CHAR(REAL(N),-1,NODNUM,NCHAR)
      TITLE(1:17)='VELOCITY AT NODE '
      NCHAR=17+NCHAR
      TITLE(18:NCHAR)=NODNUM
      CALL SYMBOL(1.64,10.14,0.14,TITLE,0,0.,NCHAR)
C
C-----DRAW 8.5" X 11.0" BORDER AROUND GRAPH
      CALL BORDER(0.0,8.5,0.0,11.0)
      RETURN
      END
C
C
C
      SUBROUTINE UNQPLT(N,NPTS,XARAY,YARAY1,YARAY2,LINTYP,IUNITS)
C
C---- UNQPLT ----------------------------------------------------------S
C
C  PURPOSE:
C    PLOTS UNIT DISCHARGE MAGNITUDE AND DIRECTION AT NODE POINTS
C    VERSUS TIME.
C
C  INPUT ARGUMENT(S):
C    N - NODE NUMBER.
C    NPTS - NUMBER OF POINTS TO BE PLOTTED + 2.
C    XARAY - ARRAY CONTAINING TIME.
C    YARAY1 - ARRAY CONTAINING UNIT DISCHARGE MAGNITUDE.
C    YARAY2 - ARRAY CONTAINING UNIT DISCHARGE ANGLE.
C    LINTYP - LINE TYPE CODE (0=NO BOXES, 1=BOXES AROUND DATA POINTS.)
C    IUNITS - UNIT CODE (0=U.S. CUSTOMARY, 1=S.I.)
C
C  SUBPROGRAM(S) CALLED:
C    AXIS, XLINE, R2CHAR
C
C----------------------------------------------------------------------F
C
C---- Declarations (arguments)
      INTEGER   N,NPTS,LINTYP,IUNITS
      REAL      XARAY,YARAY1,YARAY2
      CHARACTER LABEL*40,NODNUM*20
C
C---- Declarations (local)
      INTEGER   LENCHR
      REAL      FIRSTV,DELTAV
C
C---- Dimensions
      DIMENSION XARAY(NPTS),YARAY1(NPTS),YARAY2(NPTS)
C
C-----PLOT DIRECTION ANGLE
      LABEL='SIMULATION TIME IN HOURS'
      NCHAR=-LENCHR(LABEL)
      FIRSTV=XARAY(NPTS+1)
      DELTAV=XARAY(NPTS+2)
      CALL AXIS(1.5,1.5,LABEL,NCHAR,6.0,0.,FIRSTV,DELTAV,2)
      LABEL='ANGLE IN DEGREES'
      NCHAR=LENCHR(LABEL)
      CALL AXIS(1.5,1.5,LABEL,NCHAR,2.0,90.,-180.,180.,-1)
      CALL XLINE(XARAY,YARAY2,NPTS,LINTYP,1.5,1.5)
C
C-----PLOT MAGNITUDE
      CALL AXIS(1.5,4.0,' ',-1,6.0,0.,FIRSTV,DELTAV,2)
      IF(IUNITS.EQ.0) THEN
        LABEL='MAGNITUDE IN CUBIC FEET PER SECOND'
      ELSE
        LABEL='MAGNITUDE IN CUBIC METERS PER SECOND'
      ENDIF
      NCHAR=LENCHR(LABEL)
      FIRSTV=YARAY1(NPTS+1)
      DELTAV=YARAY1(NPTS+2)
      CALL AXIS(1.5,4.0,LABEL,NCHAR,6.0,90.,FIRSTV,DELTAV,2)
      CALL XLINE(XARAY,YARAY1,NPTS,LINTYP,1.5,4.0)
C
C-----PLOT TITLE
      CALL R2CHAR(REAL(N),-1,NODNUM,NCHAR)
      LABEL(1:23)='UNIT DISCHARGE AT NODE '
      NCHAR=23+NCHAR
      LABEL(24:NCHAR)=NODNUM
      CALL SYMBOL(1.64,10.14,0.14,LABEL,0,0.,NCHAR)
C
C-----DRAW 8.5" X 11.0" BORDER AROUND GRAPH
      CALL BORDER(0.0,8.5,0.0,11.0)
      RETURN
      END
C
C
C
      SUBROUTINE STGPLT(N,NPTS,XARAY,YARAY,LINTYP,IUNITS)
C
C---- STGPLT ----------------------------------------------------------S
C
C  PURPOSE:
C    PLOTS WATER-SURFAE ELEVATION (STAGE) AT A NODE POINT VERSUS TIME.
C
C  INPUT ARGUMENT(S):
C    N - NODE NUMBER.
C    NPTS - NUMBER OF POINTS TO BE PLOTTED + 2.
C    XARAY - ARRAY CONTAINING TIME.
C    YARAY - ARRAY CONTAINING VELOCITY MAGNITUDE.
C    LINTYP - LINE TYPE CODE.
C    IUNITS - UNIT CODE (0=U.S. CUSTOMARY, 1=S.I.)
C
C  SUBPROGRAM(S) CALLED:
C    AXIS, XLINE, R2CHAR
C
C----------------------------------------------------------------------F
C
      DIMENSION XARAY(NPTS),YARAY(NPTS)
      CHARACTER LABEL*40,NODNUM*80
C
C-----PLOT GRAPH OF STAGE VERSUS TIME
      LABEL='SIMULATION TIME IN HOURS'
      NCHAR=-LENCHR(LABEL)
      FIRSTV=XARAY(NPTS+1)
      DELTAV=XARAY(NPTS+2)
      CALL AXIS(1.5,1.5,LABEL,NCHAR,6.0,0.,FIRSTV,DELTAV,2)
      IF(IUNITS.EQ.0) THEN
        LABEL='WATER-SURFACE ELEVATION IN FEET'
      ELSE
        LABEL='WATER-SURFACE ELEVATION IN METERS'
      ENDIF
      NCHAR=LENCHR(LABEL)
      FIRSTV=YARAY(NPTS+1)
      DELTAV=YARAY(NPTS+2)
      CALL AXIS(1.5,1.5,LABEL,NCHAR,8.5,90.,FIRSTV,DELTAV,1)
      CALL XLINE(XARAY,YARAY,NPTS,LINTYP,1.5,1.5)
C
C-----PLOT TITLE
      CALL R2CHAR(REAL(N),-1,NODNUM,NCHAR)
      LABEL(1:14)='STAGE AT NODE '
      NCHAR=14+NCHAR
      LABEL(15:NCHAR)=NODNUM
      CALL SYMBOL(1.64,10.14,0.14,LABEL,0,0.,NCHAR)
C
C-----DRAW 8.5" X 11.0" BORDER AROUND GRAPH
      CALL BORDER(0.0,8.5,0.0,11.0)
      RETURN
      END
C
C
C
      SUBROUTINE BORDER(X0,XLEN,Y0,YLEN)
C
C---- BORDER ----------------------------------------------------------S
C
C  PURPOSE:
C    DRAWS A RECTANGULAR BORDER.
C
C  INPUT ARGUMENT(S):
C    X0 - X-COORDINATE, IN INCHES, OF THE LOWER LEFT CORNER.
C    XLEN - LENGTH OF THE SIDES, IN INCHES, IN THE X-DIRECTION.
C    Y0 - Y-COORDINATE, IN INCHES, OF THE LOWER LEFT CORNER.
C    YLEN - LENGTH OF THE SIDES, IN INCHES, IN THE Y-DIRECTION.
C
C  SUBPROGRAM(S) CALLED:
C    PLOT
C
C----------------------------------------------------------------------F
C
C---- Declarations (arguments)
      REAL      X0,XLEN,Y0,YLEN
C
      CALL PLOT(X0,Y0,3)
      CALL PLOT(X0+XLEN,Y0,2)
      CALL PLOT(X0+XLEN,Y0+YLEN,2)
      CALL PLOT(X0,Y0+YLEN,2)
      CALL PLOT(X0,Y0,2)
      RETURN
      END
C
C
C
      SUBROUTINE LSIZE(IER)
C
C---- LSIZE -----------------------------------------------------------S
C
C  PURPOSE:
C    COMPUTES ELEMENT AREAS.
C
C  OUTPUT ARGUMENT(S):
C    IER - ERROR COUNT; INCREMENTED BY ONE EACH TIME AN ERROR IS FOUND.
C
C----------------------------------------------------------------------F
C
C---- Declarations (arguments)
      INTEGER   IER
C
C---- Declarations (local)
      INTEGER   J,K,L,N,NCN,NGP,NR
      REAL      DETJ,J11,J12,J21,J22,WAIT,DA,DB,XLC,YLC
C
C---- Common blocks
      INCLUDE 'ANOMOD.INC'
C
C---- Dimensions
      DIMENSION WAIT(9),DA(9,9),DB(9,9),XLC(9),YLC(9)
C
C---- OUTPUT FORMATS
2000  FORMAT(' ***WARNING #130 - DETERMINANT IS <= 0 AT INTEG POINT ',
     # I2,' IN ELEMENT ',I5)
C
C-----INITIALIZE VARIABLES
      IER=0
C
C-----LOOP AROUND ELEMENT LIST
      DO 100 L=1,NE
        AREA(L)=0.0
        IF(LMAT(L).EQ.0) GO TO 100
C
C-------COPY PROPER WEIGHTING FUNCTIONS
        NCN=6
        IF(NOP(L,8).GT.0) NCN=8
        IF(NOP(L,9).GT.0) NCN=9
        IF(NCN.EQ.6) THEN
C-------TRIANGULAR ELEMENT
          NGP=7
          DO 20 J=1,NGP
            WAIT(J)=WAITT(J)
            DO 10 K=1,NCN
              DA(K,J)=DNAT(K,J)
              DB(K,J)=DNBT(K,J)
10          CONTINUE
20        CONTINUE
        ELSEIF(NCN.EQ.8) THEN
C-------EIGHT-NODE RECTANGULAR ELEMENT
          NGP=9
          DO 50 J=1,NGP
            WAIT(J)=WAITR(J)
            DO 40 K=1,NCN
              DA(K,J)=DNAR8(K,J)
              DB(K,J)=DNBR8(K,J)
40          CONTINUE
50        CONTINUE
        ELSE
C-------NINE-NODE RECTANGULAR ELEMENT
          NGP=9
          DO 59 J=1,NGP
            WAIT(J)=WAITR(J)
            DO 58 K=1,NCN
              DA(K,J)=DNAR9(K,J)
              DB(K,J)=DNBR9(K,J)
58          CONTINUE
59        CONTINUE
        ENDIF
C
C-------COMPUTE REFERENCE COORDINATES
        NR=NOP(L,1)
        DO 70 K=2,NCN
          N=NOP(L,K)
          XLC(K)=CORD(N,1)-CORD(NR,1)
          YLC(K)=CORD(N,2)-CORD(NR,2)
70      CONTINUE
C
C-------COMPUTE ELEMENT AREA
        DO 90 J=1,NGP
          J11=0.0
          J12=0.0
          J21=0.0
          J22=0.0
          DO 80 K=2,NCN
            J11=J11+DA(K,J)*XLC(K)
            J12=J12+DA(K,J)*YLC(K)
            J21=J21+DB(K,J)*XLC(K)
            J22=J22+DB(K,J)*YLC(K)
80        CONTINUE
          DETJ=J11*J22-J12*J21
          IF(DETJ.LE.0.0) WRITE(IO2,2000) J,L
          AREA(L)=AREA(L)+WAIT(J)*DETJ
90      CONTINUE
100   CONTINUE
      RETURN
      END
C
C
C
      BLOCK DATA
C
C---- BLOCK DATA ------------------------------------------------------S
C
C  PURPOSE:
C    THIS SUBROUTINE IS NOT CALLED; ITS PRESENCE SUFFICES TO PROVIDE
C    INITIAL DATA VALUES FOR REFERENCES IN THE MAIN PROGRAM AND SUB-
C    PROGRAMS TO LABELED (NAMED) COMMON BLOCKS.
C
C----------------------------------------------------------------------F
C
      CHARACTER VERSION*8
      CHARACTER*80 PTITLE,STRING
      CHARACTER*64
     # DATAFILE,PRNTFILE,PLOTFILE,GRIDFILE,GRDAFILE,GRDBFILE,
     # FLOWFILE,FLWAFILE,FLWBFILE
      CHARACTER ID*4
C
C---- COMMON BLOCKS
      COMMON /BLKAI/
     # IPLTV,IPLTS,IPRNT,IGEOMA,IGEOMB,IFLOWA,IFLOWB,
     # IPLTF,IPRTF,IPLTN,IPLTE,NPTH,IARHD,
     # IUNITS,NCL,NP,NE,
     # IPLTC,ICVAL,IPLINT,IPRTH,IPLTH,NTHP(20),KTHP(20),
     # NDECV,NDECF,
     # IO1,IO2,IO91,IO92,IO93,IO94,LDEV
C
      COMMON /BLKAR/
     # VSCALE,AHLEN,HTN,HTT,HTE,HTC,
     # XL,YL,XOFF,YOFF,XSCALE,YSCALE,AROT,SGN,CSN,
     # XLOP,YLOP,XHIP,YHIP,XLP,YLP,XUP,YUP,
     # XMIN,YMIN,XMAX,YMAX,CVMIN,CVMAX,CVINC,
     # STIME,TFIRST,TLAST,STCURA,STCURB,VLMIN,ZIP,VERSION
C
      COMMON /BLKAC/
     # PTITLE,ID(12),
     # GRIDFILE,GRDAFILE,GRDBFILE,
     # FLOWFILE,FLWAFILE,FLWBFILE,
     # DATAFILE,PRNTFILE,PLOTFILE
C
      COMMON /BLKW/WAITL(4),XNL(3,4),XML(3,4),DNAL(3,4)
      COMMON /BLKT/WAITT(7),DNAT(6,7),DNBT(6,7)
      COMMON /BLKR/WAITR(9),DNAR8(8,9),DNBR8(8,9),DNAR9(9,9),DNBR9(9,9)
C
C---- DATA STATEMENTS
      DATA VERSION/'1.10.DG1'/
      DATA
     # DATAFILE/'ANOMOD.DAT'/,PRNTFILE/'ANOMOD.PRT'/,
     # GRIDFILE/'GRID.DAT'/,GRDAFILE/'GRID.DAT'/,GRDBFILE/'GRID_B.DAT'/,
     # FLOWFILE/'FLOW.DAT'/,FLWAFILE/'FLOW.DAT'/,FLWBFILE/'FLOW_B.DAT'/,
     # PLOTFILE/'ANOMOD.PLT'/
      DATA XLOP/0./,YLOP/0./,XHIP/96./,YHIP/33./
      DATA XLP/0./,YLP/0./,XUP/-1./,YUP/-1./
      DATA ID/
     # 'SWMS','ELEM','NODE','FLOW','FLOW','GRID','VECT','CONT','HIST',
     # 'FLUX','REPO','LAST'/
      DATA IO1/55/,IO2/8/,IO91/91/,IO92/92/,IO93/93/,IO94/94/,
     # LDEV/7/,IPLINT/-1/
      DATA STCURA/-1./,STCURB/-1./
      DATA ZIP/1.0E-06/
C
C---- LINEAR WEIGHTS AND SHAPE FUNCTIONS
      DATA WAITL/0.17392743,2*0.32607258,0.17392743/
      DATA XML/
     # 0.93056816, 0., 0.06943184,
     # 0.66999052, 0., 0.33000948,
     # 0.33000948, 0., 0.66999052,
     # 0.06943184, 0., 0.93056816/
      DATA XNL/
     # 0.80134603, 0.25844425, -0.05979028,
     # 0.22778408, 0.88441289, -0.11219697,
     #-0.11219697, 0.88441289,  0.22778408,
     #-0.05979028, 0.25844425,  0.80134603/
      DATA DNAL/
     #-2.72227262, 3.44454525, -0.72227262,
     #-1.67996209, 1.35992418,  0.32003791,
     #-0.32003791,-1.35992418,  1.67996209,
     # 0.72227262,-3.44454525,  2.72227262/
C
C---- TRIANGULAR ELEMENT WEIGHTING AND SHAPE FUNCTIONS
      DATA WAITT/0.1125,3*0.066197075,3*0.062969590/
      DATA DNAT/
     # .33333333,1.33333333, .0000000,-1.33333333,-.33333333, .00000000,
     #-.76113653,1.88056824, .0000000,-1.88056824,-.88056824,1.64170477,
     # .88056824, .23886348, .00000000,-.23886348,-.88056824, .00000000,
     # .88056824,1.88056824, .0000000,-1.88056824,.76113653,-1.64170477,
     #2.18970796, .40514604, .00000000,-.40514604,.59485397,-2.78456193,
     #-.59485397,3.18970796, .0000000,-3.18970796, .59485397, .00000000,
     #-.59485397, .40514604, .0000000,-.40514604,-2.18970796,2.78456193/
      DATA DNBT/
     # .00000000,1.33333333, .33333333, .0000000,-.33333333,-1.33333333,
     # .00000000, .23886348, .88056824, .00000000,-.88056824,-.23886348,
     # .0000000,1.88056824,-.76113653,1.64170477,-.88056824,-1.88056824,
     # .00000000,1.88056824,.88056824,-1.64170477,.76113653,-1.88056824,
     # .00000000,3.18970796,-.59485397, .00000000,.59485397,-3.18970796,
     # .00000000,.40514604,2.18970796,-2.78456193, .59485397,-.40514604,
     # .00000000,.40514604,-.59485397,2.78456193,-2.18970796,-.40514604/
C
C---- RECTANGULAR 8-NODE ELEMENT SHAPE FUNCTIONS
      DATA WAITR/
     # 0.308641975,0.493827161,0.308641975,
     # 0.493827161,0.790123457,0.493827161,
     # 0.308641975,0.493827161,0.308641975/
      DATA DNAR8/
     #-.04364916, .17459667,-.13094750, .20000000,-.34364916,1.37459665,
     #-1.03094747,-.20000000,
     # .04364916, .00000000,-.04364916, .20000000, .34364916, .00000000,
     #-.34364916,-.20000000,
     # .13094750,-.17459667, .04364916, .2000000,1.03094747,-1.37459665,
     # .34364916,-.20000000,
     #-.38729833, .77459666,-.38729833, .50000000,-.38729833, .77459666,
     #-.38729833,-.50000000,
     # .00000000, .00000000, .00000000, .50000000, .00000000, .00000000,
     # .00000000,-.50000000,
     # .38729833,-.77459666, .38729833, .50000000, .38729833,-.77459666,
     # .38729833,-.50000000,
     #-1.03094747,1.37459666,-.34364916, .2000000,-.13094750, .17459667,
     #-.04364916,-.20000000,
     #-.34364916, .00000000, .34364916, .20000000,-.04364916, .00000000,
     # .04364916,-.20000000,
     # .34364916,-1.37459665,1.03094747, .2000000, .04364916,-.17459667,
     # .13094750,-.20000000/
      DATA DNBR8/
     # .34364916,-.20000000, .13094750,-.17459667, .04364916, .20000000,
     #1.03094747,-1.37459665,
     # .38729833,-.50000000, .38729833,-.77459666, .38729833, .50000000,
     # .38729833,-.77459666,
     # .13094750,-.20000000, .34364916,-1.37459665,1.03094747, .2000000,
     # .04364916,-.17459667,
     #-.34364916,-.20000000, .04364916, .00000000,-.04364916, .20000000,
     # .34364916, .00000000,
     # .00000000,-.50000000, .00000000, .00000000, .00000000, .50000000,
     # .00000000, .00000000,
     # .04364916,-.20000000,-.34364916, .00000000, .34364916, .20000000,
     #-.04364916, .00000000,
     #-1.03094747,-.2000000,-.04364916, .17459667,-.13094750, .20000000,
     #-.34364916,1.37459665,
     #-.38729833,-.50000000,-.38729833, .77459666,-.38729833, .50000000,
     #-.38729833, .77459666,
     #-.04364916,-.2000000,-1.03094747,1.37459665,-.34364916, .20000000,
     #-.13094750, .17459667/
C
C---- RECTANGULAR 9-NODE ELEMENT SHAPE FUNCTIONS
      DATA DNAR9/
     # 0.11127017,-0.13524200, 0.02397183,-0.10983867,-0.18872983,
     # 1.06475800,-0.87602817,-0.50983867, 0.61967734,
     # 0.04364917, 0.0       ,-0.04364917, 0.20000000, 0.34364917,
     # 0.0       ,-0.34364917,-0.20000000, 0.0,
     #-0.02397183, 0.13524200,-0.11127017, 0.50983867, 0.87602817,
     #-1.06475800, 0.18872983, 0.10983867,-0.61967734,
     # 0.0       , 0.0       , 0.0       ,-0.27459667, 0.0       ,
     # 0.0       , 0.0       ,-1.27459667, 1.54919334,
     # 0.0       , 0.0       , 0.0       , 0.50000000, 0.0       ,
     # 0.0       , 0.0       ,-0.50000000, 0.0       ,
     # 0.0       , 0.0       , 0.0       , 1.27459667, 0.0       ,
     # 0.0       , 0.0       , 0.27459667,-1.54919334,
     #-0.87602817, 1.06475800,-0.18872983,-0.10983867, 0.02397183,
     #-0.13524200, 0.11127017,-0.50983867, 0.61967734,
     #-0.34364917, 0.0       , 0.34364917, 0.20000000,-0.04364917,
     # 0.0       , 0.04364917,-0.20000000, 0.0       ,
     # 0.18872983,-1.06475800, 0.87602817, 0.50983867,-0.11127017,
     # 0.13524200,-0.02397183, 0.10983867,-0.61967734/
      DATA DNBR9/
     # 0.18872983, 0.10983867,-0.02397183, 0.13524200,-0.11127017,
     # 0.50983867, 0.87602817,-1.06475800,-0.61967734,
     # 0.0       , 0.27459667, 0.0       , 0.0       , 0.0       ,
     # 1.27459667, 0.0       , 0.0       ,-1.54919334,
     #-0.02397183, 0.10983867, 0.18872983,-1.06475800, 0.87602817,
     # 0.50983867,-0.11127017, 0.13524200,-0.61967734,
     #-0.34364917,-0.20000000, 0.04364917, 0.0       ,-0.04364917,
     # 0.20000000, 0.34364917, 0.0       , 0.0,
     # 0.0       ,-0.50000000, 0.0       , 0.0       , 0.0       ,
     # 0.50000000, 0.0       , 0.0       , 0.0       ,
     # 0.04364917,-0.20000000,-0.34364917, 0.0       , 0.34364917,
     # 0.20000000,-0.04364917, 0.0       , 0.0       ,
     #-0.87602817,-0.50983867, 0.11127017,-0.13524200, 0.02397183,
     #-0.10983867,-0.18872983, 1.06475800, 0.61967734,
     # 0.0       ,-1.27459667, 0.0       , 0.0       , 0.0       ,
     #-0.27459667, 0.0       , 0.0       , 1.54919334,
     # 0.11127017,-0.50983867,-0.87602817, 1.06475800,-0.18872983,
     #-0.10983867, 0.02397183,-0.13524200, 0.61967734/
      END
