#!/bin/sh
# usr/opt/wrdapp/feswms_1.10/test/test.sh -- run feswms test data sets
#
# Usage: test.sh [start [stop]]
#        test.sh [start [stop] | tee test.out
#
#        where: start = starting test number
#                stop = ending test number (may be same as start)
#
# To use this script for another program in a different directory, globally
# change the program name (be sure to change both upper and lower case
# occurrences) and set the default value for the Stop variable as appropriate.
#
# History: 12/24/91, mblalock, initial coding
#          04/27/92, mygoze, restructuring
#          10/19/93, rsregan, modified for use with feswms
#


#
# Variable definitions
# --------------------
#
  TOPDIR=..
  DATA=$TOPDIR/data
  CHECK=$TOPDIR/test/check.sh
  CLEAN=$TOPDIR/test/clean.sh
  PROG=$TOPDIR/bin/flomod
  INPRG=$TOPDIR/bin/dinmod
  POST=$TOPDIR/bin/anomod
  PROGNM=flomod
  PROG2=dinmod
  PROG3=anomod
  DIVD=========================================
  END=3

#
#
  exec 2>&1                                # stderr shows up in .out file

  Start=${1:-1}                            # by default, start at 1
  Stop=${2:-$END}                             # by default, stop at 1
  if [ $Start -lt 1 ] ; then Start=1 ; fi
  if [ $Stop -lt 1 ] ; then Stop=$END ; fi
  if [ $Start -gt $END -o $Stop -gt $END ]
  then
    echo
    echo "Warning, invalid arguments--test range is 1 - $END for $PROGNM"
    echo "input arguments were $Start - $Stop"
    echo
    if [ $Stop -gt $END ] ; then Stop=$END ; fi
    if [ $Start -gt $END ]
    then
      echo "no $PROGNM tests will be performed"
    else
      echo "Tests $Start - $Stop will be performed"
    fi
    echo
  fi

#
# begin test runs
#
  Test=$Start

  if [ $Test -ge $Start -a $Test -le $Stop ]
  then
    echo
    echo $DIVD$DIVD
    echo "Begin processing $PROGNM test runs $Start to $Stop"
    echo
    date
  fi
#
# remove old output file
#
  $CLEAN

  while [ $Test -ge $Start -a $Test -le $Stop ]
  do
    echo
    echo
    echo $DIVD$DIVD
    echo "Test run number $Test"
    echo
    echo "****WHEN GRAPHICS ARE DISPLAYED, CLICK THE LEFT MOUSE BUTTON TO CONTINUE****"
    echo

    rm -f FLOMOD.FIL ANOMOD.FIL DINMOD.FIL go

    Name=$PROG2$Test
    cp $DATA/$Name.fil DINMOD.FIL
    echo @$DATA/$Name.aide > go
    echo n >> go
    $INPRG < go > $Name.log

    Name=$PROGNM$Test
    cp $DATA/flomod$Test.fil FLOMOD.FIL
    $PROG > $Name.log

    Name=$PROG3$Test
    cp $DATA/$Name.fil ANOMOD.FIL
    echo @$DATA/$Name.aide > go
    echo y >> go
    echo " "  >> go
    echo " "  >> go
    echo " "  >> go
    echo " "  >> go
    echo "q"  >> go
    $POST < go > $Name.log

    Test=`expr $Test + 1`
  done
#
  if [ $Test -ge $Start -a $Test -le $Stop ]
  then
    echo
    echo
    echo $DIVD$DIVD
    echo "Completed $PROGNM test runs $Start to $Stop"
    echo
  fi

# check output against original output in data directory
  $CHECK $PROGNM $PROG2 $PROG3
