C   *******************************************************************
C                              DIGSGKS
C     LAST MODIFIED June 6, 1995 -- RSR
C     MODIFIED May 25, 1993 -- RSR
C     MODIFIED March 4, 1993 -- RSR
C   DIGS-GKS V930601, June 1, 1993
C   -------------------------------------------------------------------
C   FORTRAN 77 collection of graphics routines which can be substituted
C   for regular calcomp calls.  These routines use calls to the GKS
C   ANSI/ISO standard FORTRAN binding, minimum level 0a.  At the moment,
C   16 colors, or 'pen numbers' are supported, but more can be added or
C   current pen color assignments changed.
C
C   Originally modified by ARLEN HARBAUGH, from HOUSTON INSTRUMENTS
C      source, using calls to DISSPLA (originally called DIGSDISSPLA)
C
C   Modified to use GKS July 1990 by Gary Granger, USGS Reston, WRD
C   Modified to use on Data General, with Prior GKS by Steve Regan 9/91
C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C
C   Modified for PC use by Tony Bouret, December 1990.
C
C   * Effort has been made to ensure that all code follows standard
C     FORTRAN 77 conventions, as well as standard GKS calls.
C     This code should compile and run on any computer which has
C     GKS libraries and device drivers installed.  However, some minor
C     modification may be needed when porting to a different type of
C     computer, particularly for the initiation and shutdown of the GKS
C     system in use.
C
C   This has been tested using the Graphics Software Systems GSS*GKS
C   Kernel System (GSS-TOOLKIT and GSS*CGI Device Drivers) Version 2.15
C   for DOS and Microsoft FORTRAN 5.0 on a 80286.  These routines must be
C   compiled,C   (optionally LIBed,) and linked according to the
C   requirements of both the compiler and the GKS system in use.
C
C   No GKS libraries or device drivers are included with these routines.
C   The user must obtain this necessary GKS software in order to use
C   these routines, as well as the necessary device drivers in order
C   to run any executable programs created using these routines.
C
C   Required file:  A .CFG file which is created by these routines
C   if it does not exist.
C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C
C   The following calcomp routines are included:
C
C      SUBROUTINE NUMBER
C      SUBROUTINE PLOT
C      SUBROUTINE NEWPEN
C      SUBROUTINE PLOTS
C      SUBROUTINE SYMBOL
C      SUBROUTINE FACTOR
C  axis, scale, line, where, origin, arohd, hatch are in digssubs.f
C
C   ...where some have been modified to handle special uses.
C   In general, these follow  the behavior described in a CALCOMP
C   manual except where noted.
C
C   The NEWPEN routine simply changes colors.  These routines were
C   modified as little as possible by me (GJG) except for graphics
C   and attribute setting-calls (DISSPLA calls replaced by GKS).
C   Only routines PLOT, NEWPEN, PLOTS, SYMBOL, and FACTOR were
C   modified this way.  Line labels in AXIS were moved away from
C   left margin, which may have introduced some errors or incorrect
C   actions.
C
C   The following routines are used internally to these source files to
C   handle GKS:
C
C      SUBROUTINE clrtbl
C      SUBROUTINE clsdigs
C      SUBROUTINE endplot
C      SUBROUTINE gksetplt
C      SUBROUTINE opndigs
C      SUBROUTINE setmark
C      SUBROUTINE setnrm
C      SUBROUTINE settext
C
C   NOTE: These routines expect GKS to be in a specific state at all
C   times.  This means GKS should be in state GKSCL (GKS closed) before
C   calling the plot initializing routine PLOTS.  Also, the Aspect Source
C   Flags should remain INDIVIDUAL, and the color table should not be
C   changed for any of the primitives used by digsgks.
C
C   Primitives used: Polymarker, Polyline, and Text.
C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C
C   GKS calls made:
C
C      Control Functions:
C
C         Subroutine gacwk (wkid):     Activate workstation.
C                                      Integer wkid:  Workstation identifier.
C
C         Subroutine gclks:            Close GKS.
C
C         Subroutine gclrwk (wkid, cofl):  Clear workstation.
C                                      Integer wkid:  Workstation identifier.
C                                      Integer cofl:  Control flag:
C                                         0 = Conditionally,
C                                         1 = Always.
C
C         Subroutine gclwk (wkid):     Close workstation.
C                                      Integer wkid:  Workstation identifier.
C
C         Subroutine gdawk (wkid):     Deactivate workstation.
C                                      Integer wkid:  Workstation identifier.
C
C         Subroutine gopks (errfil, size):  Open GKS.
C                                      Integer errfil:  Error message file:
C                                         A logical unit number from a
C                                         standard FORTRAN OPEN statement,
C                                         which must be opened prior to
C                                         this call.
C                                      Integer size:  Size of a buffer area
C                                         in words allocated for use by
C                                         workstation-independent
C                                         segment storage.
C
C         Subroutine gopwk (wkid, conid, wtype):  Open workstation.
C                                      Integer wkid:  Workstation identifier.
C                                      Integer conid: Connection identifier
C                                         (not used with GSS*GKS on PCs).
C                                      Integer wtype: Workstation type
C                                         (same as wkid in GSS*GKS;
C                                         defined by the files KERNEL.SYS
C                                         and CGI.CFG).
C
C         Subroutine guwk (wkid, regfl):  Update Workstation
C                                      Integer wkid:  Workstation identifier.
C                                      Integer regfl: Regeneration flag:
C                                         0 = Postpone,
C                                         1 = Perform.
C
C      Output Functions:
C
C         Subroutine gpl (n, px, py):  Polyline.
C                                      Integer n:  Number of points.
C                                      Real px(n), py(n):  Coordinates of
C                                         points in world coordinates (WC).
C
C         Subroutine gpm (n, px, py):  Polymarker.
C                                      Integer n:  Number of points.
C                                      Real px(n), py(n):  Coordinates of
C                                         points in world coordinates (WC).
C
C         Subroutine gtx (px, py, chars):  Text.
C                                      Real px, py:  Alignment point of
C                                         string in world coordinates (WC).
C                                      character*(*) chars:  String.
C
C      Attribute Functions:
C
C         Subroutine gschh (chh):      Set character height.
C                                      Real chh:  Character height in
C                                         world coordinates (WC).
C
C         Subroutine gschup (chux, chuy):  Set character up vector.
C                                      Real chux, chuy:  Character up
C                                         vector in world coordinates (WC).
C
C         Subroutine gscr (wkid, ci, cr, cg, cb):  Set color representation.
C                                      Integer wkid:  Workstation identifier.
C                                      Integer ci:    Color index.
C                                      Real cr, cg, cb:  Red/green/blue
C                                         intensities.
C
C         Subroutine gsln (ltype):     Set linetype.
C                                      Integer ltype:  Linetype.
C
C         Subroutine gsmksc (mszsf):   Set marker size scale factor.
C                                      Real mszsf:  Marker size scale factor.
C
C         Subroutine gsmk (mtype):     Set marker type.
C                                      Integer mtype:  Marker type.
C
C         Subroutine gsplci (coli):    Set polyline color index.
C                                      Integer coli:  Color index.
C
C         Subroutine gspmci (coli):    Set polymarker color index.
C                                      Integer coli:  Color index.
C
C         Subroutine gstxci (coli):    Set text color index.
C                                      Integer coli:  Color index.
C
C         Subroutine gstxfp (font, fnt_prec):  Set text font and precision.
C                                      Integer font:  Text font
C                                         (device-specific).
C                                      Integer fnt_prec:  Text precision:
C                                         0 = String fnt_precision, low
C                                         1 = Character fnt_precision, medium
C                                         2 = Stroke fnt_precision. high
C
C      Transformation Functions:
C
C         Subroutine gselnt (tnr):     Set normalization transformation.
C                                      Integer tnr:  Normalization
C                                         transformation number.
C
C         Subroutine gsclip (clsw):    Set clipping indicator.
C                                      Integer clsw:  Clipping indicator.
C
C         Subroutine gsvp (tnr, xmin, xmax, ymin, ymax):  Set viewport.
C                                      Integer tnr:  Transformation number.
C                                      Real xmin, xmax, ymin, ymax:
C                                         Viewport limits (lower-left,
C                                         upper-right) in normalized device
C                                         coordinate (NDC) units.
C
C         Subroutine gswkwn (wkid, xmin, xmax, ymin, ymax):
C                                      Set workstation window.
C                                      Integer wkid:  Workstation identifier.
C                                      Real xmin, xmax, ymin, ymax:
C                                         Workstation window limits in NDC
C                                         units.
C
C         Subroutine gswn (tnr, xmin, xmax, ymin, ymax):  Set window.
C                                      Integer tnr:  Transformation number.
C                                      Real xmin, xmax, ymin, ymax:
C                                         Window limits in NDC units.
C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C
C   IN SOME CASES YOU MAY WANT TO MODIFY SUBROUTINE PLOTS.  FOR
C   EXAMPLE, YOU MIGHT CHANGE THE DEFAULT PAGE SIZE (AS DESCRIBED
C   ABOVE) TO FIT YOUR PARTICULAR GRAPHICS DEVICE.
C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C
C   PLOTS
C
C   Purpose:  Initializes for plotting.
C
C---- Arguments:
C
C   UNITSPEC is the unit number of the plotter output file, named within
C          the calling main program.  This file is opened and closed
C          for screen output, creating an empty file.  For HPGL output,
C          the HPGL instructions are written to this file.  If this
C          filename is identical to the port assignment of the plotting
C          device (PRN, LPT1, LPT2, LPT3, COM1, or COM2), the plot
C          is plotted directly and no file is created.
C
C   ID1 is used here to differentiate between applications, in order to
C          assign the plot configuration file name (contains assignable
C          DIGS parameters).
C          IF ID1=0, config file = DIGSPLT.CFG, else = DISGPLT(ID1).CFG,
C          e.g. if ID1=1, config file = DIGSPLT1.CFG
C
C   ID2 is unused
C
      SUBROUTINE PLOTS(ID1,ID2,UNITSPEC)
C
      INCLUDE 'digsblk.cmn'
C
C Declarations (arguments):
C
      INTEGER ID1, ID2, UNITSPEC
C
C Declarations (local variables):
C
      INTEGER iframe
      CHARACTER*72 idflag
      SAVE iframe
      DATA iframe/0/
C
C Initialize common variables; also reset in between multiple plots:
C
      idflag = '@(#) digsgks - CalComp/Zeta to GKS graphics library'
      idflag = 
     &       '@(#) digsgks - Contact: R. Steven Regan, rsregan@usgs.gov'
      idflag = '@(#) digsgks - Version: 4.1 1995/06/06'
      idflag = 
     & '$Id: digsgks.f,v 1.1 1995/09/05 19:05:01 rsregan Exp rsregan $'
      Xcur = 0.0
      Ycur = 0.0
      Xorg = 0.0
      Yorg = 0.0
      Isessn = 0
C
C Make calls and initialize common variables
C to be set only before the first plot:
C
      IF (iframe.EQ.0 .OR. Mode.EQ.999) THEN
        iframe = 1
        Isessn = 1
        Otunit = ABS(UNITSPEC)
        IF (Otunit.GT.6) CLOSE (Otunit)
        Cfg = ID1
        Digfact = 1.0
        Gkfact = 1.0
        Gkxorg = 0.0
        Gkyorg = 0.0
        Colordev = .TRUE.
        Errunit = 82
        CALL GKSETPLT()
        CALL OPNDIGS()
        Last_ltype = 0
        Last_color = 1
      ENDIF
C
C Make calls and initialize variables to be set before the first plot
C and also in between multiple plots
C
      CALL NEWPEN(1)
      CALL DSETPEN(2,Linetype,Last_ltype)
      Gkxorg = Xorg + Pxoff
      Gkyorg = Yorg + Pyoff
      Gkfact = Digfact*Pltfact
      CALL PLOT(Gkxorg,Gkyorg,-3)
      RETURN
      END
C
C
C
      SUBROUTINE NUMBER(X,Y,HEIGHT,FPN,ANGLE,NDEC)
C
C     + + + PURPOSE + + +
C     Plot real variables as character strings, rounded to the
C     specified decimal place.
C
C     + + + HISTORY + + +
C       AUTHOR: Steve Regan
C     LANGUAGE: Fortran 77
C      VERSION: June 17, 1993
C
C     + + +  DUMMY ARGUMENTS + + +
      INTEGER NDEC
      REAL X, Y, HEIGHT, FPN, ANGLE
C
C     + + + INPUT ARGUMENT DEFINITIONS + + +
C     X,Y    - The coordinates of the lower left corner of the number.
C     HEIGHT - The height of the number to be plotted.
C     FPN    - The floating point number to be plotted.
C     ANGLE  - The angle in degrees from the x-axis, at which the
C              number is to be plotted.  At ANGLE=0.0, the
C              number is right side up and parallel to the x-axis.
C     NDEC   - The number of digits to the right of the decimal point to
C              be included.
C              If > 0, NDEC is the number of digits to the right of
C                      the decimal point.
C              If = 0, number plotted is an integer plus a decimal point.
C              If = -1, number plotted is an integer with no decimal point.
C              If < -1, ABS(NDEC)-1 digits are truncated from the lower
C                       portion of integer after rounding.  (For example,
C                       if NDEC=-2 for FNUM=127.8 the routine plots 13).
C
C     + + + LOCAL VARIABLES + + +
      CHARACTER string*16, iform*8, cdgt*2
      REAL fnum, pow
      INTEGER nd, nde, i
C
C     + + + LOCAL DEFINITIONS + + +
C     ND       -The number of characters to be plotted.
C     STRING   -The string of characters to be plotted.
C
C     + + + EXTERNALS + + +
      EXTERNAL SYMBOL
C
C     + + + END SPECIFICATIONS + + +
C
C Convert the real number to a string:
      fnum = FPN
C
C ND is the number of digits to right of decimal point to retain --
C always GE 0, NDE is set to -1 if no decimal point.
C
      IF (NDEC.LT.0) THEN
        nd = 0
        nde = -1
        IF (NDEC.LT.-1) THEN
C
C Round to power of 10
C
          pow = 10.**(-NDEC-1)
          fnum = FLOAT(IFIX((fnum+SIGN(.5*pow,fnum))/pow))*pow
        ENDIF
      ELSE
        nd = NDEC
        nde = 0
      ENDIF
C
C Setup format for encoding FNUM
C
      iform = '(F16.02)'
      WRITE (cdgt,'(I2)') nd
      iform(6:7) = cdgt
      WRITE (string,iform) fnum
C
C Scan characters for 1st nonblank digit, ie don't plot leading blanks.
C
      DO 10 i = 1, 16
        IF (string(i:i).NE.' ') THEN
C
C Write the string
C
          nd = 16 + nde
          nde = 17 - i + nde
          CALL SYMBOL(X,Y,HEIGHT,string(i:nd),0,ANGLE,nde)
          RETURN
        ENDIF
   10 CONTINUE
      END
C
C     SYMBOL.FOR
C
      SUBROUTINE SYMBOL(X1,Y1,HEIGHT,STRING,INTEQ,ANGLE,NCHAR)
C
 
C     + + + PURPOSE + + +
C     Plots annotation and special symbols.
C     Called by the main program and routines AXIS, NUMBER, and LINE.
C     There are three calls to subroutine SYMBOL:
C     (1) The call to draw text such as titles and legends.
C     (2) The call to draw a single character referenced by its integer
C         index.
C     (3) The call to draw a plot, with a marker centered at X,Y.
C
C     + + + HISTORY + + +
C       AUTHOR: Steve Regan
C       SYSTEM:
C     LANGUAGE: Fortran 77
C      VERSION: June 17, 1993
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER NCHAR, INTEQ
      REAL X1, Y1, HEIGHT, ANGLE
      CHARACTER*(*) STRING
C
C     + + +INPUT ARGUMENT DEFINITIONS + + +
C     X1,Y1    - If NCHAR > 0, these are the coordinates in inches of the
C                              lower left hand corner (before rotation) of
C                              the first character being plotted.
C              - If NCHAR <= 0, these are the coordinates of the geometric
C                               center of the marker being plotted.
C                To continue annotation from the current X and/or Y position,
C                the corresponding X1 and/or Y1 coordinates should equal 999.
C     HEIGHT   - The height in inches of the character(s) being plotted.
C                The width of the character, including spacing, is normally
C                the same as the height.
C     STRING   - If NCHAR > 0, this contains a string array of NCHAR
C                              character(s) being plotted.
C                If NCHAR <= 0, the integer index of the marker to be plotted
C                               is contained in STRING.
C     INTEQ    - IF NCHAR <= 0, the integer index of the marker to be plotted
C     ANGLE    - The angle, in degrees from the x-axis, at which the
C                character(s) are to be plotted.  At ANGLE=0.0, the
C                character(s) will be plotted right side up and parallel
C                to the x-axis.
C     NCHAR    - If > 0,   NCHAR is the number of charcaters in STRING to be
C                          plotted, imncluding any trailing blanks.
C                If = 0/-1,A marker with integer index contained in
C                          STRING is centered at X1,Y1.
C                If < -1,  A marker is produced, where the move to X1,Y1
C                          is made with the line status the same as if
C                          the absolute value of NCHAR were the IPEN
C                          argument of subroutine PLOT.
C
      INCLUDE 'digsblk.cmn'
C
C     + + + LOCAL VARIABLES + + +
      INTEGER ipen, intgr, nc
      REAL c, s, ra, x, y, px1(1), py1(1), px, py, xm, ym, hgt
      CHARACTER*1 sym
      EQUIVALENCE (px,px1(1)), (py,py1(1))
C
C     + + + INTRINSICS + + +
      INTEGER IABS, ICHAR
      REAL ABS, COS, SIN
      CHARACTER*1 CHAR
      INTRINSIC ABS, IABS, COS, SIN, CHAR, ICHAR
C
C     + + + EXTERNALS + + +
      EXTERNAL PLOT, GMARK1, GMKSTR, GSCHUP, GSCHH, GTX
C
C   GKS calls made:
C
C      Output Functions:
C         Subroutine gtx (px, py, chars):  Text.
C                                      Real px, py:  Alignment point of
C                                         string in world coordinates (WC).
C                                      character*(*) chars:  String.
C      Attribute Functions:
C         Subroutine gschh (chh):      Set character height.
C                                      Real chh:  Character height in
C                                         world coordinates (WC).
C         Subroutine gschup (chux, chuy):  Set character up vector.
C                                      Real chux, chuy:  Character up
C                                         vector in world coordinates (WC).
C
C     + + + END SPECIFICATIONS + + +
C
C X,Y is the current unfactored location:
      IF (ABS(X1-999.).LT.0.0001) THEN
        x = Xcur
      ELSE
        x = X1
      ENDIF
C
      IF (ABS(Y1-999.).LT.0.0001) THEN
        y = Ycur
      ELSE
        y = Y1
      ENDIF
C
C Factor the height:
C
      hgt = HEIGHT*Gkfact
C
C Determine whether or not a line is to be drawn
C
      IF (NCHAR.GT.-2) THEN
        ipen = 3
      ELSE
        ipen = IABS(NCHAR)
      ENDIF
      nc = NCHAR
C
C Move to character location
C
      CALL PLOT(x,y,ipen)
C
C Compute location of symbol:
C
      px = (Gkxorg+x)*Gkfact
      py = (Gkyorg+y)*Gkfact
C
C Set absolute direction for character plotting (convert to radians):
C
      ra = .0174533*ANGLE
      c = COS(ra)
      s = SIN(ra)
C
C GKS Set character up vector (angle):
C
      CALL GSCHUP(-s,c)
C
C GKS Set character height:
C
      CALL GSCHH(hgt)
C
C Plot text string:
C
      IF (nc.EQ.0) THEN
C
C A single right-justified character produced.
C This character may be passed from the calling routine as a single
C character in quotes, or as the "char", the ASCII integer index of
C the character; for example, char(65) is the same as 'A'. (NCHAR is 0):
C
        IF (Mode.EQ.2) THEN
          sym = CHAR(ICHAR(STRING(4:4)))
        ELSE
          sym = STRING(1:1)
        ENDIF
        IF (Font.NE.10) THEN
C GKS Text:
          CALL GTX(px,py,sym)
        ELSE
C DIGS software generated character
          xm = hgt*0.5
          ym = xm*s
          xm = xm*c
          CALL GMARK1(ICHAR(sym),hgt,px-xm,py-ym)
        ENDIF
        xm = hgt*0.5
C
      ELSEIF (nc.GT.0) THEN
C NCHAR is greater than 0 -- use standard characters stored in STRING:
        IF (Font.NE.10) THEN
          CALL GTX(px,py,STRING(1:nc))
        ELSE
          CALL GMKSTR(STRING,nc,hgt,px,py,ANGLE)
        ENDIF
        xm = hgt*nc
      ELSE
C
C Special call to SYMBOL for a centered symbol (NCHAR is less than 0):
C The calling routine should pass the index of the symbol desired
C through STRING as the "char" of the symbol index number desired.
C For example, for symbol number 1 (a dot), pass char(1);
C this is then converted back to the integer 0 here using "ichar".
C (See MARKERS.FOR, a demonstration program of these special symbols.):
C
C Determine marker based on value of mark (reference subroutine setmark):
C
        IF (Mark.NE.0) THEN
          intgr = Mark
        ELSEIF (Mode.EQ.2) THEN
cc        intgr = ICHAR(STRING(4:4))
          intgr = INTEQ
        ELSE
cc        intgr = ICHAR(STRING)
          intgr = INTEQ
        ENDIF
C
        IF (Mark.NE.256) CALL GMARK1(intgr,hgt,px,py)
        xm = hgt*0.5
C
      ENDIF
C
C Calculate the new current location (end of string):
C
      ym = xm*s
      xm = xm*c
      Xcur = x + xm/Gkfact
      Ycur = y + ym/Gkfact
C
      RETURN
      END
C
C
C
      SUBROUTINE NXTPLT()
C
C     + + + PURPOSE + + +
C     Beeps to signal the end of screen plotting, and then waits for a
C     carriage return from the user to continue.  Finally, this routine
C     clears the screen.
C
C     + + + EXTERNALS + + +
      EXTERNAL PLOT, FACTOR
C
C     + + + END SPECIFICATIONS + + +
C
C Clear screen
      CALL PLOT(0.0,0.0,1000)
      CALL FACTOR(1.0)
      RETURN
      END
C
C
C
      SUBROUTINE XLINE(XARRAY,YARRAY,NPTS,LINTYP,X0,Y0)
C
C---- XLINE -----------------------------------------------------------S
C
C  PURPOSE:
C    PLOTS A LINE DEFINED BY TWO COORDINATE ARRAYS.
C
C  INPUT ARGUMENT(S):
C    XARRAY - NAME OF ARRAY CONTAINING ABSCISSA OR X VALUES.
C    YARRAY - NAME OF ARRAY CONTAINING ORDINATE OR Y VALUES.
C    NPTS - NUMBER OF POINTS TO BE PLOTTED + 2.
C    LINTYP - XLINE TYPE CODE.
C    X0,Y0 - COORDINATES OF THE PLOT ORIGIN.
C
C  SUBPROGRAM(S) CALLED:
C    PLOT, BOX
C
C----------------------------------------------------------------------F
C
C---- Declarations (arguments)
      INTEGER NPTS, LINTYP
      REAL XARRAY, YARRAY, X0, Y0
C
C---- Declarations (local)
      INTEGER loc1, locd, i
      REAL firstx, deltax, firsty, deltay, x, y
C
C---- Dimensions
      DIMENSION XARRAY(NPTS), YARRAY(NPTS)
C
C---- Externals
      EXTERNAL PLOT, BOX
C
      loc1 = NPTS + 1
      locd = NPTS + 2
      firstx = XARRAY(loc1)
      deltax = XARRAY(locd)
      firsty = YARRAY(loc1)
      deltay = YARRAY(locd)
      x = X0 + (XARRAY(1)-firstx)/deltax
      y = Y0 + (YARRAY(1)-firsty)/deltay
      CALL PLOT(x,y,3)
      DO 10 i = 2, NPTS
        x = X0 + (XARRAY(i)-firstx)/deltax
        y = Y0 + (YARRAY(i)-firsty)/deltay
        CALL PLOT(x,y,2)
        IF (LINTYP.GT.0) CALL BOX(x,y,0.07)
   10 CONTINUE
C
      RETURN
      END
C
C
C
      SUBROUTINE AXIS(X0,Y0,LABEL,NCHAR,AXLEN,ANGLE,FIRSTV,DELTAV,NDEC)
C
C---- AXIS ------------------------------------------------------------S
C
C  PURPOSE:
C    PLOTS A GRAPH AXIS INCLUDING TIC MARKS, SCALE VALUES, AND LABEL.
C
C  INPUT ARGUMENT(S):
C    X0,Y0 - COORDINATES OF STARTING POINT OF AXIS, IN INCHES
C    LABEL - AXIS TITLE.
C    NCHAR - NUMBER OF CHARACTERS IN TITLE.
C    AXLEN - FLOATING POINT AXIS LENGTH IN INCHES.
C    ANGLE - ANGLE OF AXIS FROM THE X-DIRECTION, IN DEGREES.
C    FIRSTV - SCALE VALUE AT THE FIRST TIC MARK.
C    DELTAV - CHANGE IN SCALE BETWEEN TIC MARKS ONE INCH APART
C    NDEC - NUMBER OF DIGITS TO BE PLOTTED TO RIGHT OF DECIMAL POINT.
C           IF NDEC=-1, ONLY THE INTEGER PORTION IS PLOTTED.
C
C----------------------------------------------------------------------F
C
C---- Declarations (arguments)
      INTEGER NCHAR, NDEC
      REAL X0, Y0, AXLEN, ANGLE, FIRSTV, DELTAV
      CHARACTER LABEL(NCHAR), nbcd*3
C
C---- Declarations (local)
      INTEGER kn, i, nt, ntic
      REAL ex, adx, xval, a, cth, dxb, dyb, sth, xn, xt, yn, yt, z
C
C---- Intrinsics
      REAL ABS, COS, SIN
      INTRINSIC ABS, COS, SIN
C
C---- Externals
      EXTERNAL NUMBER, SYMBOL, PLOT
C
      nbcd = '*10'
      kn = NCHAR
      a = 1.0
      IF (kn.LT.0) THEN
        a = -a
        kn = -kn
      ENDIF
      ex = 0.0
      adx = ABS(DELTAV)
      IF (adx.LT.0. .OR. adx.GT.0.) THEN
   10   IF (adx.GT.999) THEN
          adx = adx/10.
          ex = ex + 1.
          GOTO 10
        ENDIF
   20   IF (adx.LT.0.01) THEN
          adx = adx*10.
          ex = ex - 1.
          GOTO 20
        ENDIF
      ENDIF
      xval = FIRSTV*10.0**(-ex)
      adx = DELTAV*10.0**(-ex)
      sth = ANGLE*0.0174533
      cth = COS(sth)
      sth = SIN(sth)
      dxb = -0.1
      dyb = 0.15*a - 0.05
      xn = X0 + dxb*cth - dyb*sth
      yn = Y0 + dyb*cth + dxb*sth
      ntic = AXLEN + 1.0
      nt = ntic/2
      DO 30 i = 1, ntic
        CALL NUMBER(xn,yn,0.105,xval,ANGLE,NDEC)
        xval = xval + adx
        xn = xn + cth
        yn = yn + sth
        IF (nt.EQ.0) THEN
          z = kn
          IF (ex.LT.0. .OR. ex.GT.0.) z = z + 7.
          dxb = -.07*z + AXLEN*0.5
          dyb = 0.325*a - 0.075
          xt = X0 + dxb*cth - dyb*sth
          yt = Y0 + dyb*cth + dxb*sth
          CALL SYMBOL(xt,yt,0.14,LABEL,0,ANGLE,kn)
          IF (ex.LT.0. .OR. ex.GT.0.) THEN
            z = kn + 2
            xt = xt + z*cth*0.14
            yt = yt + z*sth*0.14
            CALL SYMBOL(xt,yt,0.14,nbcd,0,ANGLE,3)
            xt = xt + (3.0*cth-0.8*sth)*0.14
            yt = yt + (3.0*sth+0.8*cth)*0.14
            CALL NUMBER(xt,yt,0.07,ex,ANGLE,-1)
          ENDIF
        ENDIF
        nt = nt - 1
   30 CONTINUE
      CALL PLOT(X0+AXLEN*cth,Y0+AXLEN*sth,3)
      dxb = -0.07*a*sth
      dyb = +0.07*a*cth
      a = ntic - 1
      xn = X0 + a*cth
      yn = Y0 + a*sth
      DO 40 i = 1, ntic
        CALL PLOT(xn,yn,2)
        CALL PLOT(xn+dxb,yn+dyb,2)
        CALL PLOT(xn,yn,2)
        xn = xn - cth
        yn = yn - sth
   40 CONTINUE
C
      RETURN
      END
C
C
C
      SUBROUTINE SCALE(ARRAY,AXLEN,NPTS)
C
C---- SCALE -----------------------------------------------------------S
C
C  PURPOSE:
C    SCALES VALUES TO BE ALONG AN AXIS.
C
C  INPUT ARGUMENT(S):
C    ARRAY - NAME OF ARRAY CONTAINING VALUES TO BE SCALED.
C    AXLEN - LENGTH IN INCHES OVER WHICH ARRAY IS TO BE SCALED.
C    NPTS - NUMBER OF POINTS TO BE SCALED + 2.
C
C  OUTPUT ARGUMENT(S):
C     ARRAY(NPTS+1) - FIRSTV, THE FIRST VALUE ON THE AXIS.
C     ARRAY(NPTS+2) - DELTAV, THE INCREMENTAL VALUE PER INCH.
C
C----------------------------------------------------------------------F
C
C---- Declarations (arguments)
      INTEGER NPTS
      REAL ARRAY(NPTS), AXLEN
C
C---- Declarations (local)
      REAL deltav, firstv, p, save, t, v, vmax, vmin
      INTEGER i, is
C
C---- Dimensions
      DIMENSION save(6)
C
C---- Intrinsics
      REAL ABS, AMAX1, ALOG10, REAL, AINT
      INTRINSIC ABS, AMAX1, ALOG10, REAL, AINT
C
C---- Data
      DATA save/1., 2., 4., 5., 10., 20./
C
      vmin = ARRAY(1)
      vmax = vmin
      DO 10 i = 1, NPTS
        v = ARRAY(i)
        IF (v.LT.vmin) THEN
          vmin = v
        ELSEIF (v.GT.vmax) THEN
          vmax = v
        ENDIF
   10 CONTINUE
      deltav = (vmax-vmin)/AXLEN
      IF (ABS(deltav).LT.1.0E-08) deltav = AMAX1(0.1*vmin,0.1)
      i = ALOG10(deltav)
      p = 10.**REAL(i)
      deltav = deltav/p - 0.001
      DO 20 i = 1, 6
        is = i
        IF (save(i).GT.deltav) GOTO 30
   20 CONTINUE
   30 deltav = p*save(is)
      firstv = deltav*AINT(vmin/deltav)
      t = firstv + AXLEN*deltav
      IF (t.LT.vmax) THEN
        is = is + 1
        IF (is.LT.7) GOTO 30
      ENDIF
      firstv = firstv - AINT(0.5*(AXLEN-(vmax-firstv)/deltav))*deltav
      ARRAY(NPTS+1) = firstv
      ARRAY(NPTS+2) = deltav
C
      RETURN
      END
C
C
C
      SUBROUTINE BOX(X,Y,SIDE)
C
C---- BOX -------------------------------------------------------------S
C
C  PURPOSE:
C    DRAWS A BOX CENTERED AROUND A POINT.  THE PEN IS ASSUMED TO BE
C    INITIALLY LOCATED AT THE POINT.
C
C  INPUT ARGUMENT(S):
C    X,Y - COORDINATES OF THE POINT, IN INCHES.
C    SIDE - LENGTH OF THE BOX SIDE, IN INCHES.
C
C  SUBPROGRAM(S) CALLED:
C    PLOT
C
C----------------------------------------------------------------------F
C
C---- Declarations (arguments)
      REAL SIDE, X, Y
C
C---- Declarations (local)
      REAL xp, yp
C
C---- Externals
      EXTERNAL PLOT
C
      xp = X + 0.5*SIDE
      yp = Y + 0.5*SIDE
      CALL PLOT(xp,yp,3)
      xp = xp - SIDE
      CALL PLOT(xp,yp,2)
      yp = yp - SIDE
      CALL PLOT(xp,yp,2)
      xp = xp + SIDE
      CALL PLOT(xp,yp,2)
      yp = yp + SIDE
      CALL PLOT(xp,yp,2)
      CALL PLOT(X,Y,3)
      RETURN
      END
C
      SUBROUTINE SDOT(X,Y,D)
C
C---- SDOT ------------------------------------------------------------S
C
C  PURPOSE:
C    DRAWS A SOLID FILLED DOT.
C
C  INPUT ARGUMENT(S);
C    X,Y - COORDINATES OF THE CENTER OF THE DOT, IN INCHES.
C    D   - DOT DIAMETER, IN INCHES.
C
C----------------------------------------------------------------------F
C
C---- Declarations (arguments)
      REAL X, Y, D
C
C---- Declarations (local)
      INTEGER ierr, mtype
      REAL sizmrk, szmrk
C
C---- Externals
      EXTERNAL PLOT, GSMK, GPM, GQMK, GQMKSC, GSMKSC
C
C---- Move pen to dot center
      CALL PLOT(X,Y,3)
C
C---- Draw solid filled dot
      CALL GQMK(ierr,mtype)
      CALL GQMKSC(ierr,szmrk)
      sizmrk = D*10.0
      CALL GSMKSC(sizmrk)
      CALL GSMK(1)
      CALL GPM(1,X,Y)
      CALL GSMK(mtype)
      CALL GSMKSC(szmrk)
C
      RETURN
      END
C
C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C
C   PLOT
C
C   Purpose:  This subroutine is primarily called from a main program,
C             and is also called by subroutines AXIS, LINE, and SYMBOL.
C             This is the fundamental plotting subroutine.
C
C---- Arguments:
C
C   X,Y are the coordinates in inches from the current origin to which
C       the imaginary pixel cursor or pen moves.
C
C   IPEN:  Determines the type of move to be made:
C
C          +2         draws solid line from previous current position.
C                     to X,Y, which becomes the new current position.
C          +3         moves current position to X,Y.
C          +4 thru +9 same as +2, but draws with a special GKS line type
C                     chosen by the user in subroutine gkSETPLT.
C          -2 thru -9 same as +IPEN except that a new origin is set at X,Y.
C          999        terminates plotting and shuts down GKS.
C          1000       clears the workstation in between multiple plots.
C          1001       clears and deactivates workstations in between
C                     multiple plots, and then reactivates workstations.
C
C---- GKS subroutines called:
C
C      Output Functions:
C
C         Subroutine gpl (n, px, py):  Polyline.
C                                      Integer n:  Number of points.
C                                      Real px(n), py(n):  Coordinates of
C                                         points in world coordinates (WC).
C
      SUBROUTINE PLOT(X,Y,IPEN)
C
      INCLUDE 'digsblk.cmn'
C
C Declarations (arguments)
C
      INTEGER IPEN
      REAL X, Y
C
C Declarations (local variables):
C
      INTEGER ip
      REAL px(2), py(2), xnew, ynew
C
C Need to use absolute value of IPEN for plotting:
C
      ip = IABS(IPEN)
C
C Factor the point to be moved to:
C
      xnew = X
      ynew = Y
C
C If a line is to be drawn, the actual movement will be from
C ORG+CUR to ORG+NEW, times the hpfact value chosen by the user
C in subroutine gkSETPLT:
C
      IF (ip.GT.1 .AND. ip.LT.10) THEN
C
        IF (ip.NE.3) THEN
          px(1) = (Gkxorg+Xcur)*Gkfact
          py(1) = (Gkyorg+Ycur)*Gkfact
C
          px(2) = (Gkxorg+xnew)*Gkfact
          py(2) = (Gkyorg+ynew)*Gkfact
C
C Set color chosen by the user in subroutine gksetplt:
C Set linestyle chosen by the user in subroutine gksetplt:
C
          CALL DSETPEN(ip,Linetype,Last_ltype)
C GKS Polyline:
          CALL GPL(2,px,py)
C
        ENDIF
        IF (IPEN.GT.0) THEN
C
C The new point is now the current location:
C
          Xcur = xnew
          Ycur = ynew
        ELSE
C
C Move origin of plot
C
          Xorg = Xorg + xnew
          Yorg = Yorg + ynew
          Gkxorg = Xorg + Pxoff
          Gkyorg = Yorg + Pyoff
          Xcur = 0.
          Ycur = 0.
        ENDIF
C
C Determine and do other actions based on value of IPEN:
C
      ELSEIF (IPEN.EQ.999) THEN
        CALL CLSDIGS()
      ELSEIF (IPEN.EQ.1000) THEN
        CALL UPDATEPLOT()
        CALL NXTPLOT()
C
        CALL PLOTS(Otunit,Cfg,IPEN)
C Delete Segment
        CALL GDSG(1)
C Create Segment
        CALL GCRSG(1)
        CALL GSVIS(1,0)
      ELSEIF (IPEN.EQ.1001) THEN
        CALL ENDPLOT()
        CALL PLOTS(Otunit,Cfg,IPEN)
      ELSE
        CALL CLSDIGS()
        WRITE (*,9005) IPEN
        STOP
      ENDIF
C
      RETURN
 9005 FORMAT (/' Invalid IPEN number: ',i5)
C
      END
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C
C  Name:       FACTOR
C
C  Purpose:    This subroutine can be called form a main program to enable
C              the user to enlarge or reduce the size of the entire plot.
C              It should be called immediately after calling subroutine
C              PLOTS.
C
C  Usage:      FACTOR (F)
C
C  Argument:
C
C     F -- The scale factor used to multiply all plotting dimensions.
C          (Input)
C
C  Remarks:   The DIGFACT variable in common /DIGSBLK/ is initially set to 1.0
C             in subroutine PLOTS.
C             This procedure has a side effect: it changes the values of
C             FACT, XCUR, YCUR, XORG, and YORG, which are passed through
C             common block /DIGSBLK/.
C
C  Keywords:  FACTOR, scaling
C
C-----------------------------------------------------------------------
C
      SUBROUTINE FACTOR(F)
C
      INCLUDE 'digsblk.cmn'
C
C Declaration (argument):
C
      REAL F
C
C Replace the old factor with the new one:
C
      Digfact = F
      Gkfact = Digfact*Pltfact
C
      RETURN
      END
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C
C   NEWPEN
C
C   Purpose:  This subroutine is used to change colors.
C             Color example, 0=background, 1=foreground, 2=red, 3=green, 4=blue
C
C---- Argument:
C
C   color = color index number.
C
C---- GKS subroutines called:
C
C      Attribute Functions:
C
C         Subroutine gsplci (coli):    Set polyline color index.
C                                      Integer coli:  Color index.
C
C         Subroutine gspmci (coli):    Set polymarker color index.
C                                      Integer coli:  Color index.
C
C         Subroutine gstxci (coli):    Set text color index.
C                                      Integer coli:  Color index.
C
      SUBROUTINE NEWPEN(COLOR)
C
C Declaration (argument):
C
      INTEGER COLOR
C
C Declarations (local variables):
C
      INTEGER icolor
      INCLUDE 'digsblk.cmn'
C
C Specifications for intrinsics:
C
      INTEGER IABS
      INTRINSIC IABS
C
C If the user has chosen not to use colors, return:
C
      IF (Colordev) THEN
C
        icolor = IABS(COLOR)
        IF (icolor.GT.9) icolor = 1
        icolor = Linecolor(icolor)
        IF (Last_color.NE.icolor) THEN
C
C Set text color index:
C
          CALL GSTXCI(icolor)
C
C Set polyline color index:
C
          CALL GSPLCI(icolor)
C
C Set polymarker color index:
C
          CALL GSPMCI(icolor)
          Last_color = icolor
        ENDIF
      ENDIF
      RETURN
      END
