C
C     DINMOD - Version 1.10.DG2
C
      PROGRAM DINMOD
C
C---- DINMOD -----------------------------------------------------------M
C
C           FINITE ELEMENT SURFACE WATER MODELING SYSTEM FOR
C       TWO-DIMENSIONAL FLOW IN THE HORIZONTAL PLANE *FESWMS-2DH*
C
C                 DATA INPUT MODULE - VERSION 1.10.DG2
C
C                         ----> DINMOD <----
C
C                            DEVELOPED FOR
C
C                 U.S. DEPARTMENT OF TRANSPORTATION
C                   FEDERAL HIGHWAY ADMINISTRATION
C            OFFICE OF ENGINEERING AND HIGHWAY OPERATIONS
C                      RESEARCH AND DEVELOPMENT
C               6300 GEORGETOWN PIKE, MCLEAN, VA 22101
C
C                                BY
C
C           U.S. GEOLOGICAL SURVEY, WATER RESOURCES DIVISION
C
C  PURPOSE:
C    THE PURPOSE OF THIS PROGRAM IS TO PREPARE A TWO-DIMENSIONAL
C    FINITE ELEMENT GRID FOR INPUT TO OTHER FESWMS PROGRAMS.  INPUT
C    DATA DEFINING THE FINITE ELEMENT NETWORK IS READ, EDITED, AND
C    PROCESSED AND WRITTEN TO A GEOMETRIC DATA FILE IN THE FORM OF
C    NODE POINT AND ELEMENT DATA.  AS SUCH, DINMOD ACTS AS A PRE-
C    PROCESSOR IN THE FINITE ELEMENT SURFACE WATER MODELING SYSTEM.
C
C  PROGRAMMER: DAVID C. FROEHLICH      DATE: January 1, 1988
C
C  MODIFICATIONS:
C
C  NO.  DATE     PROGRAMMER     DESCRIPTION
C  ==== ======== ============== ========================================
C  1.01 02/05/87 D.C. Froehlich 1. Replaced FORTRAN carriage-control
C                               character to advance to top of next page
C                               with call to subroutine FORMFD.
C  1.10 02/24/89 D.C. Froehlich 1. Modified level-structure resequencing
C                               algorithm to correctly account for the
C                               starting element list.
C                               2. General housecleaning.
C  1.10.DG1
C       06/03/92 KG Thibodeaux  1. Added DG time and date calls.
C                                  IDATE and TIME.
C                               2. All INCLUDE statements in the program
C                                  have been changed to be compatible
C                                  with DG and PC compilers.
C  1.10.DG2
C       08/31/92 JM Fulford     1. Corrected subroutine SUBQ8
C----------------------------------------------------------------------F
      INCLUDE 'DINMOD.INC'
C
C---- Declarations
      INTEGER   IER
      INTEGER IMON,IDAY,IYEAR
      LOGICAL   ERR,EXISTS
      CHARACTER DATE*8,TIMEBUF*8
C
C---- Data statements
      DATA ERR/.FALSE./
C
C---- Output formats
2010  FORMAT(' DATE OF RUN IS ',I2,'/',I2,'/',I2,' (MM/DD/YY)')
2020  FORMAT(' TIME OF RUN IS ',A8,' (HH:MM:SS)')
2030  FORMAT(/' *** RUN TERMINATED NORMALLY.'/)
2040  FORMAT(/' *** RUN TERMINATED BECAUSE OF ',I3,' ERRORS!'/)
2100  FORMAT(1H+,79(' ')/1H+,'Run terminated normally.')
2110  FORMAT(1H+,79(' ')/1H+,'Run terminated because of ',I3,' errors!')
C
C---- Set colors and clear the screen
cx    CALL SETUP
      PTITLE = 
     & '$Id: dinmod.f,v 2.5 1995/09/05 19:03:28 rsregan Exp rsregan $'
      Ptitle = '@(#)DINMOD - Data Input Module for FESWMS'
      Ptitle = '@(#)DINMOD - FHWA Report HW031.D, D.C Froehlich'
      Ptitle = '@(#)DINMOD - Contact: Janice Fulford, jfulford@usgs.gov'
      Ptitle = '@(#)DINMOD - Version: 1.10.DG2 2.5x 1995/09/05'
C
C---- READ NAMES OF DINMOD DATA FILES IF DINMOD.FIL EXISTS
      CALL DINFIL
C
C---- OPEN DINMOD PRINT FILE
      IF(EXISTS(PRNTFILE)) THEN
        OPEN(IO2,FILE=PRNTFILE)
        CLOSE(IO2,STATUS='DELETE')
      ENDIF
      OPEN(IO2,FILE=PRNTFILE,STATUS='NEW',ACCESS='SEQUENTIAL',
     # FORM='FORMATTED')
C
C---- PRINT STARTING DATE AND TIME OF RUN
      CALL FORMFD(IO2)
C      CALL DATER(DATE)
C      WRITE(IO2,2010) DATE(1:LENCHR(DATE))
C      CALL TIMER(TIME)
C      WRITE(IO2,2020) TIME(1:LENCHR(TIME))
      CALL IDATE(IMON,IDAY,IYEAR)
      WRITE(IO2,2010)IMON,IDAY,IYEAR
      CALL TIME(TIMEBUF)
      WRITE(IO2,2020)TIMEBUF
C
C---- READ INPUT DATA
      CALL INPUT(IER)
      IF(IER.GT.0) GOTO 999
C
C---- CHECK FOR GEOMETRIC CONSISTENCY AND COMPLETENESS
      IF(ICHEK.GT.0) CALL GEOCHK(IER)
      IF(IER.GT.0) ERR=.TRUE.
C
C---- INTERPOLATE STRAIGHT-LINE COORDINATES
      IF(NXZL.GT.0) CALL INTERP(IER)
      IF(IER.GT.0) ERR=.TRUE.
C
C---- Automatic grid generation
      IF(IAUTO.GT.0) CALL GRDGEN(IER)
      IF(IER.GT.0) ERR=.TRUE.
C
C---- Compute midside node coordinates and ground elevations
      CALL MIDSDE(IER)
      IF(IER.GT.0) ERR=.TRUE.
C
C---- Element refinement
      IF(IREFN.GT.0 .AND. .NOT.ERR) CALL REFINE(IER)
      IF(IER.GT.0) ERR=.TRUE.
C
C---- Element resequencing
      IF(IRESQ.GT.0) CALL RESEQ(IER)
      IF(IER.GT.0) ERR=.TRUE.
C
C---- Print system data
      CALL OUTPUT
C
C---- Plots if IPLOT > 0
      IF(IPLOT.GT.0) THEN
C
C------ Open plot file for output
Crsr    IF(EXISTS(PLOTFILE)) THEN
Crsr      OPEN(LDEV,FILE=PLOTFILE)
Crsr      CLOSE(LDEV,STATUS='DELETE')
Crsr    ENDIF
Crsr    OPEN(LDEV,FILE=PLOTFILE,STATUS='NEW',ACCESS='SEQUENTIAL',
Crsr #  FORM='FORMATTED')
Crsr output plot files opened in PLOTS routine
C
C------ Initialize for plotting
        CALL PLOTS(0,0,LDEV)
C
C------ Compute plot bounds
        CALL PREPLT
C
C------ Plot network if MOD(IPLOT,2) > 0
        IF(MOD(IPLOT,2).GT.0) CALL GRDPLT
C
C------ Plot ground-surface elevation contours if MOD(IPLOT,4) > 1
        IF(MOD(IPLOT,4).GT.1) THEN
          IF(MOD(IPLOT,2).GT.0) CALL PLOT(XUP+1.,0.,-3)
          CALL CONPLT
        ENDIF
C
C------ End of plotting
        CALL PLOT(XUP+1.,0.,1000)
        CALL PLOT(XUP+1.,0.,999)
      ENDIF
C
C---- All done
999   IF(IER.EQ.0) THEN
        WRITE(IO2,2030)
        IF(SCREEN) WRITE(*,2100)
      ELSE
        WRITE(IO2,2040) IER
        IF(SCREEN) WRITE(*,2110) IER
      ENDIF
C
C---- PRINT ENDING DATE AND TIME OF RUN
C      CALL DATER(DATE)
C      WRITE(IO2,2010) DATE(1:LENCHR(DATE))
C      CALL TIMER(TIME)
C      WRITE(IO2,2020) TIME(1:LENCHR(TIME))
      CALL IDATE(IMON,IDAY,IYEAR)
      WRITE(IO2,2010)IMON,IDAY,IYEAR
      CALL TIME(TIMEBUF)
      WRITE(IO2,2020)TIMEBUF
C
C---- Close DINMOD printed output file
      CLOSE(IO2,STATUS='KEEP')
      END
C
C
C
      SUBROUTINE DINFIL
C
C---- DINFIL ----------------------------------------------------------S
C
C  PURPOSE:
C    READS NAMES OF DINMOD DATA FILES FROM THE FILE 'DINMOD.FIL'
C
C----------------------------------------------------------------------F
C
C---- Declarations (local)
      CHARACTER FILENAME*80
      LOGICAL   EXISTS
C
C---- Common blocks
      INCLUDE 'DINMOD.INC'
C
C---- INPUT FORMATS
1000  FORMAT(A)
C
      IF(EXISTS('DINMOD.FIL')) THEN
        OPEN(IO1,FILE='DINMOD.FIL',STATUS='OLD')
        READ(IO1,1000) FILENAME
        IF(FILENAME.NE.' ') DATAFILE=FILENAME
        READ(IO1,1000) FILENAME
        IF(FILENAME.NE.' ') PRNTFILE=FILENAME
        READ(IO1,1000) FILENAME
        IF(FILENAME.NE.' ') GRDAFILE=FILENAME
        READ(IO1,1000) FILENAME
        IF(FILENAME.NE.' ') GRDBFILE=FILENAME
        READ(IO1,1000) FILENAME
        IF(FILENAME.NE.' ') PLOTFILE=FILENAME
        CLOSE(IO1)
      ENDIF
      RETURN
      END
C
C
C
      SUBROUTINE TBLOCK(WIDE,VERSION,IO2)
C
C---- TBLOCK ---------------------------------------------------------S
C
C  PURPOSE:
C    PRINTS THE TITLE BLOCK.
C
C  INPUT ARGUMENT(S):
C    WIDE    - PRINT OUTPUT FORMAT CONTROL VARIABLE.
C    VERSION - PROGRAM VERSION NUMBER.
C    IO2     - OUTPUT FILE UNIT NUMBER.
C
C---------------------------------------------------------------------F
C
C---- Declarations (arguments)
      INTEGER   IO2
      CHARACTER VERSION*8
      LOGICAL   WIDE
C
C---- OUTPUT FORMATS
2000  FORMAT(/
     # 27X,78('=')/27X,'>>>>',70X,'<<<<'/27X,'>>>>',12X,
     # 'FINITE ELEMENT SURFACE WATER MODELING SYSTEM -',
     # 12X,'<<<<'/27X,'>>>>',6X,
     # 'TWO-DIMENSIONAL FLOW IN THE HORIZONTAL PLANE *FESWMS-2DH*',
     # 7X,'<<<<'/27X,'>>>>',70X,'<<<<'/27X,'>>>>',19X,
     # 'DATA INPUT MODULE - VERSION ',A8,15X,'<<<<'/
     # 27X,'>>>>',70X,'<<<<'/27X,'>>>>',28X,'DEVELOPED FOR',29X,'<<<<'/
     # 27X,'>>>>',70X,'<<<<'/27X,'>>>>',18X,
     # 'U.S. DEPARTMENT OF TRANSPORTATION',19X,'<<<<'/27X,'>>>>',20X,
     # 'FEDERAL HIGHWAY ADMINISTRATION',20X,'<<<<'/27X,'>>>>',13X,
     # 'OFFICE OF ENGINEERING AND HIGHWAY OPERATIONS',13X,'<<<<'/
     # 27X,'>>>>',23X,'RESEARCH AND DEVELOPMENT',23X,'<<<<'/
     # 27X,'>>>>',16X,'6300 GEORGETOWN PIKE, MCLEAN, VA 22101',
     # 16X,'<<<<'/27X,'>>>>',70X,'<<<<'/27X,'>>>>',34X,'BY',34X,'<<<<'/
     # 27X,'>>>>',70X,'<<<<'/27X,'>>>>',11X,
     # 'U.S. GEOLOGICAL SURVEY, WATER RESOURCES DIVISION',
     # 11X,'<<<<'/27X,'>>>>',70X,'<<<<'/27X,78('=')/)
2100  FORMAT(/
     # 1X,78('=')/1X,'>>>>',70X,'<<<<'/1X,'>>>>',12X,
     # 'FINITE ELEMENT SURFACE WATER MODELING SYSTEM -',
     # 12X,'<<<<'/1X,'>>>>',6X,
     # 'TWO-DIMENSIONAL FLOW IN THE HORIZONTAL PLANE *FESWMS-2DH*',
     # 7X,'<<<<'/1X,'>>>>',70X,'<<<<'/1X,'>>>>',19X,
     # 'DATA INPUT MODULE - VERSION ',A8,15X,'<<<<'/
     # 1X,'>>>>',70X,'<<<<'/1X,'>>>>',28X,'DEVELOPED FOR',29X,'<<<<'/
     # 1X,'>>>>',70X,'<<<<'/1X,'>>>>',18X,
     # 'U.S. DEPARTMENT OF TRANSPORTATION',19X,'<<<<'/1X,'>>>>',20X,
     # 'FEDERAL HIGHWAY ADMINISTRATION',20X,'<<<<'/1X,'>>>>',13X,
     # 'OFFICE OF ENGINEERING AND HIGHWAY OPERATIONS',13X,'<<<<'/
     # 1X,'>>>>',23X,'RESEARCH AND DEVELOPMENT',23X,'<<<<'/
     # 1X,'>>>>',16X,'6300 GEORGETOWN PIKE, MCLEAN, VA 22101',
     # 16X,'<<<<'/1X,'>>>>',70X,'<<<<'/1X,'>>>>',34X,'BY',34X,'<<<<'/
     # 1X,'>>>>',70X,'<<<<'/1X,'>>>>',11X,
     # 'U.S. GEOLOGICAL SURVEY, WATER RESOURCES DIVISION',
     # 11X,'<<<<'/1X,'>>>>',70X,'<<<<'/1X,78('=')/)
C
C---- PRINT TITLE BLOCK
      IF(WIDE) THEN
        WRITE(IO2,2000) VERSION
      ELSE
        WRITE(IO2,2100) VERSION
      ENDIF
      RETURN
      END
C
C
C
      SUBROUTINE INPUT(IER)
C
C---- INPUT -----------------------------------------------------------S
C
C  PURPOSE:
C    READS ALL INPUT DATA AND PERFORMS PRELIMINARY COMPUTATIONS. DATA
C    ARE READ IN GROUPS OF ONE OR MORE RECORDS WHICH CONTAIN RELATED
C    INFORMATION.  THESE DATA SETS ARE IDENTIFIED BY A RECORD WITH
C    A CHARACTER CODE IN THE FIRST FOUR COLUMNS.  DATA SETS MUST
C    IMMEDIATELY FOLLOW THE IDENTIFICATION CARDS.  IN ADDITION, A
C    GEOMETRIC DATA FILE PREVIOUSLY GENERATED BY DINMOD MAY BE READ.
C    DATA READ FROM CARDS, HOWEVER, WILL OVERRIDE OR ADD TO ANY INFOR-
C    MATION OBTAINED FROM THE GEOMETRIC DATA FILE.
C
C  OUTPUT ARGUMENT(S):
C    IER -  ERROR COUNT.
C
C  SUBPROGRAM(S) CALLED:
C    TBLOCK, LCHECK, NCHECK
C
C----------------------------------------------------------------------F
C
C---- Declarations (arguments)
      INTEGER   IER
C
C---- Declarations (local)
      INTEGER   K,L,LENCHR,N
      LOGICAL   ECHO,ERR,OPENED,EXISTS
      CHARACTER FORM*80,IDS*4
C
C---- Common blocks
      INCLUDE 'DINMOD.INC'
C
C---- Dimensions
      DIMENSION INX(16),XIN(8)
C
C---- Data statements
      DATA VOID/-1.0E+35/
C
C---- Input formats
1000  FORMAT(A4,6X,7E10.0)
1010  FORMAT(8E10.0)
1020  FORMAT(16I5)
1030  FORMAT(A)
C
C---- Output formats
2000  FORMAT(/' ===> FESWMS-2DH -- DINMOD Ver. ',A8,' <==='/)
2500  FORMAT(1H+,79(' ')/1H+,'Reading (',(A),')...')
2010  FORMAT(//50X,'FINITE ELEMENT NETWORK DATA FOR:'//26X,A80)
2001  FORMAT(//52X,'*** PROGRAM CONTROL DATA ***'/)
2002  FORMAT(
     # 46X,'JOB OPTION CODES FOR'/
     # 46X,'   PRINTING..................:',I3/
     # 46X,'   PLOTTING..................:',I3/
     # 46X,'   GEOMETRIC DATA CHECK......:',I3/
     # 46X,'   AUTOMATIC GRID GENERATION.:',I3/
     # 46X,'   ELEMENT REFINEMENT........:',I3/
     # 46X,'   ELEMENT RESEQUENCING......:',I3/
     # 46X,'   GEOMETRIC DATA INPUT FILE.:',I3/
     # 46X,'   GEOMETRIC DATA OUTPUT FILE:',I3/
     # 46X,'   GRAPHIC WORKSTATION TYPE..:',I3)
2005  FORMAT(//54X,'*** PLOT CONTROL DATA ***'/)
2006  FORMAT(23X,'TITLE: ',A80/)
2007  FORMAT(
     # 46X,'PLOT OPTION CODES FOR'/
     # 46X,'   NODE VALUES...............:',I8/
     # 46X,'   ELEMENT VALUES............:',I8/
     # 46X,'PLOT TITLE HEIGHT............:',F8.3/
     # 46X,'HEIGHT OF NUMBERS (IN INCHES) PLOTTED AT  '/
     # 46X,'   NODE POINTS...............:',F8.3/
     # 46X,'   ELEMENT CENTERS...........:',F8.3/
     # 46X,'   CONTOUR LINES.............:',F8.3/
     # 46X,'CONTOUR INTERVAL IN FT(M)....:',F8.3)
2008  FORMAT(
     # 46X,'PLOT BOUNDARY COORDINATES:'/
     # 46X,'   LOWER X COORDINATE........:',F10.1/
     # 46X,'   LOWER Y COORDINATE........:',F10.1/
     # 46X,'   X COORDINATE OFFSET.......:',F10.1/
     # 46X,'   Y COORDINATE OFFSET.......:',F10.1/
     # 46X,'PLOT SCALE FACTORS FOR'/
     # 46X,'   X-COORDINATES.............:',F10.2/
     # 46X,'   Y-COORDINATES.............:',F10.2/
     # 46X,'   ANGLE OF ROTATION (DEG)...:',F10.2)
2015  FORMAT(//56X,'*** ELEMENT DATA ***'//
     # 28X,'ELEMENT',6X,'NODAL CONNECTIVITY (COUNTER-CLOCKWISE)',
     # 16X,'PROP',4X,'FRONT'/29X,'NUMBER',7X,'1',5X,'2',
     # 5X,'3',5X,'4',5X,'5',5X,'6',5X,'7',5X,'8',5X,'9',
     # 4X,'CODE',4X,'ORDER'/)
2020  FORMAT(//58X,'*** NODE DATA ***'//
     # 46X,'CONVERSION FACTORS FOR'/
     # 46X,'   X-COORDINATES.............:',F10.2/
     # 46X,'   Y-COORDINATES.............:',F10.2/
     # 46X,'   ELEVATIONS................:',F10.2/
     # 46X,'BASE VALUES FOR:'/
     # 46X,'   X-COORDINATES.............:',F10.2/
     # 46X,'   Y-COORDINATES.............:',F10.2/
     # 46X,'   ELEVATIONS................:',F10.2//
     # 35X,'NODE',13X,'X-',13X,'Y-',11X,'GRND',11X,'CEIL',/
     # 36X,'NO.',10X,'COORD',10X,'COORD',11X,'ELEV',11X,'ELEV',/)
2025  FORMAT(//53X,'*** INTERPOLATION DATA ***'//
     # 25X,'TYPE - STRAIGHT LINE NODE NUMBERS IN CONSECUTIVE ORDER'/)
2030  FORMAT(//54X,'*** NETWORK SLOPE DATA ***'//
     #200X,'NODE',6X,'SLOPE'/59X,'NUMBER',5X,'(DEG)'/)
2035  FORMAT(//54X,'*** MIDSIDE NODE DATA ***'//26X,'MIDSIDE NODES:'/)
2135  FORMAT(//28X,'*** MIDSIDE NODE DATA ***'//1X,'MIDSIDE NODES:'/)
2037  FORMAT(1X,'***ERROR #100 - NUMBER OF SPECIFIED MIDSIDE NODES',
     # ' EXCEEDS MAXIMUM ALLOWED')
2040  FORMAT(//53X,'*** AUTOMATIC GRID DATA ***'/)
2041  FORMAT(34X,'OMEGA = ',F5.3/)
2042  FORMAT(1X,'NPTS = ',I5,', LMAT = ',I2,', NITSM = ',I2)
2043  FORMAT(1X,'NODES:'/(6X,20I6))
2045  FORMAT(//54X,'*** RESEQUENCING DATA ***'//
     # 28X,'TYPE MAXF - STARTING ELEMENT LIST')
2050  FORMAT(//57X,'*** END OF DATA ***'/)
2060  FORMAT(1X,'***',I5,' ERROR(S) ENCOUNTERED DURING DATA INPUT'/)
2100  FORMAT(//24X,'FINITE ELEMENT NETWORK DATA FOR'//A80)
2101  FORMAT(//26X,'*** PROGRAM CONTROL DATA ***'/)
2102  FORMAT(
     # 20X,'JOB OPTION CODES FOR'/
     # 20X,'   PRINTING..................:',I3/
     # 20X,'   PLOTTING..................:',I3/
     # 20X,'   GEOMETRIC DATA CHECK......:',I3/
     # 20X,'   AUTOMATIC GRID GENERATION.:',I3/
     # 20X,'   ELEMENT REFINEMENT........:',I3/
     # 20X,'   ELEMENT RESEQUENCING......:',I3/
     # 20X,'   GEOMETRIC DATA INPUT FILE.:',I3/
     # 20X,'   GEOMETRIC DATA OUTPUT FILE:',I3/
     # 20X,'   GRAPHIC WORKSTATION TYPE..:',I3)
2105  FORMAT(//28X,'*** PLOT CONTROL DATA ***'/)
2106  FORMAT(23X,'TITLE: ',A80/)
2107  FORMAT(
     # 20X,'PLOT OPTION CODES FOR'/
     # 20X,'   NODE VALUES...............:',I8/
     # 20X,'   ELEMENT VALUES............:',I8/
     # 20X,'PLOT TITLE HEIGHT............:',F8.3/
     # 20X,'HEIGHT OF NUMBERS (IN INCHES) PLOTTED AT  '/
     # 20X,'   NODE POINTS...............:',F8.3/
     # 20X,'   ELEMENT CENTERS...........:',F8.3/
     # 20X,'   CONTOUR LINES.............:',F8.3/
     # 20X,'CONTOUR INTERVAL IN FT(M)....:',F8.3)
2108  FORMAT(
     # 20X,'PLOT BOUNDARY COORDINATES:'/
     # 20X,'   LOWER X-COORDINATE........:',F10.1/
     # 20X,'   LOWER Y-COORDINATE........:',F10.1/
     # 20X,'   X COORDINATE OFFSET.......:',F10.1/
     # 20X,'   Y COORDINATE OFFSET.......:',F10.1/
     # 20X,'PLOT SCALE FACTORS FOR'/
     # 20X,'   X-COORDINATES.............:',F10.2/
     # 20X,'   Y-COORDINATES.............:',F10.2/
     # 20X,'   ANGLE OF ROTATION (DEG)...:',F10.2)
2115  FORMAT(//
     # 30X,'*** ELEMENT DATA ***'//
     # 2X,'ELMT',6X,'NODAL CONNECTIVITY (COUNTER-CLOCKWISE)',
     # 16X,'PROP',4X,'FRONT'/2X,' NO.',7X,'1',5X,'2',
     # 5X,'3',5X,'4',5X,'5',5X,'6',5X,'7',5X,'8',5X,'9',
     # 4X,'CODE',4X,'ORDER'/)
2120  FORMAT(//32X,'*** NODE DATA ***'//
     # 20X,'CONVERSION FACTORS FOR'/
     # 20X,'   X-COORDINATES.............:',F10.2/
     # 20X,'   Y-COORDINATES.............:',F10.2/
     # 20X,'   ELEVATIONS................:',F10.2/
     # 20X,'BASE VALUES FOR:'/
     # 20X,'   X-COORDINATES.............:',F10.2/
     # 20X,'   Y-COORDINATES.............:',F10.2/
     # 20X,'   ELEVATIONS................:',F10.2//
     # 9X,'NODE',13X,'X-',13X,'Y-',11X,'GRND',11X,'CEIL',/
     # 10X,'NO.',10X,'COORD',10X,'COORD',11X,'ELEV',11X,'ELEV',/)
2125  FORMAT(//27X,'*** INTERPOLATION DATA ***'//
     # 2X,'TYPE - STRAIGHT LINE NODE NUMBERS IN CONSECUTIVE ORDER'/)
2130  FORMAT(//28X,'*** NETWORK SLOPE DATA ***'//
     # 34X,'NODE',6X,'SLOPE'/59X,'NUMBER',5X,'(DEG)'/)
2131  FORMAT(33X,I5,5X,F7.2)
2140  FORMAT(//27X,'*** AUTOMATIC GRID DATA ***'/)
2141  FORMAT(60X,'OMEGA = ',F5.3/)
2142  FORMAT(1X,'NPTS = ',I5,', LMAT = ',I2,', NITSM = ',I2)
2143  FORMAT(1X,'NODES:'/(4X,12I6))
2145  FORMAT(//28X,'*** RESEQUENCING DATA ***')
2146  FORMAT(/' TYPE = ',I3,': MAXF = ',I3/' STARTING ELEMENT LIST:'/
     # (16I5))
2150  FORMAT(//31X,'*** END OF DATA ***'/)
2200  FORMAT(' ***ERROR #??? - INPUT DATA FILE ',(A),
     # ' CANNOT BE FOUND.')
2210  FORMAT(' ***ERROR #??? - NETWORK DATA FILE ',(A),
     # ' CANNOT BE FOUND.')
C
C---- Initialize variables
      IER=0
      NP=0
      NE=0
      NGEN=0
      NRSQ=0
      NMSN=0
      NXZL=0
      ECHO=.FALSE.
      WIDE=.TRUE.
      SCREEN=.FALSE.
      DO 1 N=1,MAXP
        CORD(N,1)=VOID
        CORD(N,2)=VOID
        GRND(N)=VOID
        CEIL(N)=VOID
1     CONTINUE
C
C---- OPEN DINMOD INPUT DATA FILE
      IF(EXISTS(DATAFILE)) THEN
        OPEN(IO1,FILE=DATAFILE,STATUS='OLD',ACCESS='SEQUENTIAL',
     #  FORM='FORMATTED')
      ELSE
        WRITE(IO2,2200) DATAFILE(1:LENCHR(DATAFILE))
        IER=IER+1
        GOTO 999
      ENDIF
C
C---- READ PROGRAM CONTROL DATA
10    READ(IO1,1000) IDS,(XIN(K),K=1,7)
      IF(IDS.EQ.ID(1)) GOTO 2
      IF(IDS.NE.ID(10)) GOTO 10
      IER=IER+1
      GOTO 999
C
2     IF(XIN(1).GT.0.) WIDE=.FALSE.
      IF(XIN(2).GT.0.) SCREEN=.TRUE.
      IF(SCREEN) WRITE(*,2000) VERSION
C
C---- PRINT TITLE BLOCK
      CALL TBLOCK(WIDE,VERSION,IO2)
      IF(SCREEN) WRITE(*,2500) DATAFILE(1:LENCHR(DATAFILE))
CARD 1
      READ(IO1,1030) JTITLE
CARD 2
      READ(IO1,1020) IPRNT,IPLOT,ICHEK,IAUTO,IREFN,IRESQ,IGIN,
     # IGOUT,IWSTYP
      IF(MOD(IPRNT,2).EQ.1) ECHO=.TRUE.
      IF(WIDE) THEN
        WRITE(IO2,2010)JTITLE
        WRITE(IO2,2001)
        WRITE(IO2,2002)IPRNT,IPLOT,ICHEK,IAUTO,IREFN,IRESQ,IGIN,
     #  IGOUT,IWSTYP
      ELSE
        WRITE(IO2,2100) JTITLE
        WRITE(IO2,2101)
        WRITE(IO2,2102)IPRNT,IPLOT,ICHEK,IAUTO,IREFN,IRESQ,IGIN,
     #  IGOUT,IWSTYP
      ENDIF
C
C---- READ NETWORK DATA FILE IF SPECIFIED
      IF(IGIN.NE.0) THEN
        WRITE(*,2500) GRDAFILE(1:LENCHR(GRDAFILE))
        IF(.NOT.EXISTS(GRDAFILE)) THEN
          WRITE(IO2,2210) GRDAFILE(1:LENCHR(GRDAFILE))
          IER=IER+1
          GOTO 999
        ENDIF
        OPEN(IO3,FILE=GRDAFILE,STATUS='OLD',ACCESS='SEQUENTIAL',
     #  FORM='FORMATTED')
        READ(IO3,'(2I10)',ERR=3) NP,NE
        READ(IO3,'(I10,4E10.0)') (N,(CORD(N,K),K=1,2),GRND(N),CEIL(N),
     #  I=1,NP)
        READ(IO3,'(12I5)') (L,(NOP(L,K),K=1,9),LMAT(L),LSEQ(L),I=1,NE)
        GOTO 4
3       CLOSE(IO3,STATUS='KEEP')
        OPEN(IO3,FILE=GRDAFILE,STATUS='OLD',ACCESS='SEQUENTIAL',
     #  FORM='UNFORMATTED')
        READ(IO3) NP,NE
        READ(IO3) ((CORD(N,K),K=1,2),GRND(N),CEIL(N),N=1,NP)
        READ(IO3) ((NOP(L,K),K=1,9),LMAT(L),LSEQ(L),L=1,NE)
4       CLOSE(IO3,STATUS='KEEP')
      ENDIF
C
C---- VOID STRAIGHT-SIDE MIDDLE NODE AND CENTER NODE COORDINATES
      EPS=0.001
      DO 15 L=1,NE
        IF(LMAT(L).EQ.0) GOTO 15
        NCN=6
        IF(NOP(L,7).GT.0) NCN=8
        IF(NOP(L,9).GT.0) NCN=9
        NCN1=NCN-1
        DO 14 K=1,NCN1,2
          N1=NOP(L,K)
          N2=NOP(L,K+1)
          N3=MOD(K+2,NCN)
          IF(NCN.EQ.9) N3=MOD(K+2,NCN1)
          N3=NOP(L,N3)
          XBAR=0.5*(CORD(N1,1)+CORD(N3,1))
          YBAR=0.5*(CORD(N1,2)+CORD(N3,2))
          IF(ABS(CORD(N2,1)-XBAR).LT.EPS .AND.
     #    ABS(CORD(N2,2)-YBAR).LT.EPS) THEN
            CORD(N2,1)=VOID
            CORD(N2,2)=VOID
          ENDIF
14      CONTINUE
        IF(NCN.EQ.9) THEN
          N=NOP(L,9)
          CORD(N,1)=VOID
          CORD(N,2)=VOID
        ENDIF
15    CONTINUE
C
C---- READ THE NEXT DATA IDENTIFICATION CARD
      IF(SCREEN) WRITE(*,2500) DATAFILE(1:LENCHR(DATAFILE))
16    READ(IO1,1000,END=100) IDS,(XIN(K),K=1,7)
      DO 17 K=1,10
        IF(IDS.EQ.ID(K)) GOTO 18
17    CONTINUE
      GOTO 16
18    GOTO (10,20,30,40,50,60,70,80,90,100),K
C
C---- READ PLOT DATA
CARD 1
20    READ(IO1,1030) PTITLE
CARD 2
      READ(IO1,1020) IPLTN,IPLTE
CARD 3
      READ(IO1,1010) HTT,HTN,HTE,HTC,CVINC
CARD 4
      READ(IO1,1010) XL,YL,XOFF,YOFF,XSCALE,YSCALE,AROT
      IF(WIDE) THEN
        WRITE(IO2,2005)
        WRITE(IO2,2006)PTITLE
        WRITE(IO2,2007)IPLTN,IPLTE,HTT,HTN,HTE,HTC,CVINC
        WRITE(IO2,2008)XL,YL,XOFF,YOFF,XSCALE,YSCALE,AROT
      ELSE
        WRITE(IO2,2105)
        WRITE(IO2,2106) PTITLE
        WRITE(IO2,2107) IPLTN,IPLTE,HTT,HTN,HTE,HTC,CVINC
        WRITE(IO2,2108) XL,YL,XOFF,YOFF,XSCALE,YSCALE,AROT
      ENDIF
      XU=XL+XOFF
      YU=YL+YOFF
      GOTO 16
C
C---- READ ELEMENT DATA
30    IF(ECHO) THEN
        IF(WIDE) THEN
          WRITE(IO2,2015)
        ELSE
          WRITE(IO2,2115)
        ENDIF
      ENDIF
31    READ(IO1,1020) L,(INX(K),K=1,11)
      IF(L.EQ.0) GOTO 16
      IF(ECHO) THEN
        IF(WIDE) THEN
          WRITE(IO2,'(30X,I5,2X,9I6,5X,I3,4X,I5)') L,(INX(K),K=1,11)
        ELSE
          WRITE(IO2,'(1X,I5,2X,9I6,5X,I3,4X,I5)') L,(INX(K),K=1,11)
        ENDIF
      ENDIF
      CALL LCHECK(L,IDS,MAXE,IO2,IER,ERR)
      IF(.NOT.ERR) THEN
        DO 32 K=1,9
          N=INX(K)
          CALL NCHECK(N,IDS,MAXP,IO2,IER,ERR)
          IF(.NOT.ERR) THEN
            NOP(L,K)=N
            IF(N.GT.NP) NP=N
          ENDIF
32      CONTINUE
      ENDIF
      IF(.NOT.ERR) THEN
        LMAT(L)=INX(10)
        LSEQ(L)=INX(11)
        IF(L.GT.NE) NE=L
      ENDIF
      GOTO 31
C
C---- READ NODE DATA
40    IF(ECHO) THEN
        IF(WIDE) THEN
          WRITE(IO2,2020) (XIN(K),K=1,6)
        ELSE
          WRITE(IO2,2120) (XIN(K),K=1,6)
        ENDIF
      ENDIF
      IF(XIN(1).LT.0.OR.XIN(1).GT.0) THEN
        XFACT=XIN(1)
      ELSE
        XFACT=1.0
      ENDIF
      IF(XIN(2).LT.0.OR.XIN(2).GT.0) THEN
        YFACT=XIN(2)
      ELSE
        YFACT=1.0
      ENDIF
      IF(XIN(3).LT.0.OR.XIN(3).GT.0) THEN
        ZFACT=XIN(3)
      ELSE
        ZFACT=1.0
      ENDIF
      XZERO=XIN(4)
      YZERO=XIN(5)
      ZZERO=XIN(6)
41    READ(IO1,1010) (XIN(K),K=1,5)
      N=INT(XIN(1))
      IF(N.EQ.0) GOTO 16
      IF(ECHO) THEN
        IF(WIDE) THEN
          WRITE(IO2,'(34X,I5,4F15.3)') N,(XIN(K),K=2,5)
        ELSE
          WRITE(IO2,'(8X,I5,4F15.3)') N,(XIN(K),K=2,5)
        ENDIF
      ENDIF
      CALL NCHECK(N,IDS,MAXP,IO2,IER,ERR)
      IF(.NOT.ERR) THEN
        IF(N.GT.NP) NP=N
        CORD(N,1)=XIN(2)*XFACT+XZERO
        CORD(N,2)=XIN(3)*YFACT+YZERO
        GRND(N)=XIN(4)*ZFACT+ZZERO
        CEIL(N)=XIN(5)*ZFACT+ZZERO
      ENDIF
      GOTO 41
C
C---- READ COORDINATE INTERPOLATION DATA
50    IF(ECHO) THEN
        IF(WIDE) THEN
          WRITE(IO2,2025)
        ELSE
          WRITE(IO2,2125)
        ENDIF
      ENDIF
      KHI=0
CARD 1
51    READ(IO1,1020) INTYP
      IF(INTYP.EQ.0) GOTO 16
      KHI=KHI+1
      LINE(KHI)=INTYP
      NREC=0
      NXZL=NXZL+1
CARD 2
52    READ(IO1,1020) (INX(K),K=1,16)
      IF(INX(1).EQ.0) GOTO 16
      NREC=NREC+1
      IF(ECHO .AND. NREC.EQ.1) THEN
        IF(WIDE) THEN
          WRITE(IO2,'(24X,I5,1X,16I5)') INTYP,(INX(K),K=1,16)
        ELSE
          WRITE(IO2,'(1X,I5/(6X,8I5))') INTYP,(INX(K),K=1,16)
        ENDIF
      ENDIF
      IF(ECHO .AND. NREC.GT.1) THEN
        IF(WIDE) THEN
          WRITE(IO2,'(30X,16I5)') (INX(K),K=1,16)
        ELSE
          WRITE(IO2,'(6X,8I5)') (INX(K),K=1,16)
        ENDIF
      ENDIF
      DO 55 K=1,16
        IF(INX(K)) 53,55,54
53      KHI=KHI+1
        LINE(KHI)=-1
        GOTO 51
54      KHI=KHI+1
        N=INX(K)
        CALL NCHECK(N,IDS,MAXP,IO2,IER,ERR)
        LINE(KHI)=N
        IF(N.GT.NP) NP=N
55    CONTINUE
      GOTO 52
C
C---- READ NETWORK SLOPE DATA
60    IF(ECHO) WRITE(IO2,2030)
61    READ(IO1,1010) (XIN(K),K=1,2)
      N=INT(XIN(1))
      IF(N.EQ.0) GOTO 16
      IF(ECHO) WRITE(IO2,'(59X,I5,5X,F7.2)') N,XIN(2)
      CALL NCHECK(N,IDS,MAXP,IO2,IER,ERR)
      IF(ERR) GOTO 61
      GOTO 61
C
C---- READ MIDSIDE NODE DATA
70    IF(ECHO) THEN
        IF(WIDE) THEN
          WRITE(IO2,2035)
        ELSE
          WRITE(IO2,2135)
        ENDIF
      ENDIF
71    READ(IO1,1020) (INX(K),K=1,16)
      IF(INX(1).EQ.0) GOTO 16
      IF(ECHO) THEN
        IF(WIDE) THEN
          WRITE(IO2,'(26X,16I5)') (INX(K),K=1,16)
        ELSE
          WRITE(IO2,'(16I5)') (INX(K),K=1,16)
        ENDIF
      ENDIF
      DO 73 K=1,16
        N=INX(K)
        IF(N.LE.0) GOTO 73
        CALL NCHECK(N,IDS,MAXP,IO2,IER,ERR)
        IF(.NOT.ERR) THEN
          NMSN=NMSN+1
          IF(NMSN.GT.MAXS) THEN
            WRITE(IO2,2037)
            IER=IER+1
          ELSE
            MSN(NMSN)=N
          ENDIF
        ENDIF
73    CONTINUE
      GOTO 71
C
C---- READ AUTOMATIC GRID DATA
80    IF(ECHO) THEN
        IF(WIDE) THEN
          WRITE(IO2,2040)
        ELSE
          WRITE(IO2,2140)
        ENDIF
      ENDIF
      KHI=0
      OMEGA=XIN(1)
      IF(OMEGA.LE.0.) OMEGA=.33
      IF(WIDE) THEN
        WRITE(IO2,2041) OMEGA
      ELSE
        WRITE(IO2,2141) OMEGA
      ENDIF
81    READ(IO1,1020) NPTS,M,NITSM
      IF(NPTS.EQ.0) GOTO 16
      IF(ECHO) THEN
        IF(WIDE) THEN
          WRITE(IO2,2042) NPTS,M,NITSM
        ELSE
          WRITE(IO2,2142) NPTS,M,NITSM
        ENDIF
      ENDIF
      NGEN=NGEN+1
      LNGEN(KHI+1)=NPTS
      LNGEN(KHI+2)=M
      LNGEN(KHI+3)=NITSM
      KLO=KHI+4
      KHI=KHI+NPTS+3
      READ(IO1,1020) (LNGEN(K),K=KLO,KHI)
      IF(ECHO) THEN
        IF(WIDE) THEN
          WRITE(IO2,2043) (LNGEN(K),K=KLO,KHI)
        ELSE
          WRITE(IO2,2143) (LNGEN(K),K=KLO,KHI)
        ENDIF
      ENDIF
      DO 82 K=KLO,KHI
        N=LNGEN(K)
        CALL NCHECK(N,IDS,MAXP,IO2,IER,ERR)
        IF(N.GT.NP) NP=N
82    CONTINUE
      GOTO 81
C
C---- READ RESEQUENCING DATA
90    IF(ECHO) THEN
        IF(WIDE) THEN
          WRITE(IO2,2045)
        ELSE
          WRITE(IO2,2145)
        ENDIF
      ENDIF
CARD 1
91    READ(IO1,1020) INX(1),INX(2)
      IF(INX(1).EQ.0) GOTO 16
      NRSQ=NRSQ+1
      IRSQ(NRSQ)=INX(1)
      MHLD(NRSQ)=INX(2)
      KNT=0
CARD 2
92    READ(IO1,1020) (INX(K),K=1,16)
      IF(INX(1).EQ.0) GOTO 16
      IF(ECHO) THEN
        IF(WIDE) THEN
          IF(KNT.EQ.0) THEN
            WRITE(IO2,'(27X,16I5)') IRSQ(NRSQ),MHLD(NRSQ),(INX(K),
     #      K=1,16)
          ELSE
            WRITE(IO2,'(37X,16I5)') (INX(K),K=1,16)
          ENDIF
        ELSE
          IF(KNT.EQ.0) THEN
            WRITE(IO2,2146) IRSQ(NRSQ),MHLD(NRSQ),(INX(K),K=1,16)
          ELSE
            WRITE(IO2,'(16I5)') (INX(K),K=1,16)
          ENDIF
        ENDIF
      ENDIF
      DO 95 K=1,16
        IF(INX(K).LE.0) GOTO 91
        KNT=KNT+1
        L=INX(K)
        CALL LCHECK(L,IDS,MAXE,IO2,IER,ERR)
        IF(.NOT.ERR) LRSQ(NRSQ,KNT)=L
95    CONTINUE
      GOTO 92
C
C---- END OF DATA
100   IF(WIDE) THEN
        WRITE(IO2,2050)
      ELSE
        WRITE(IO2,2150)
      ENDIF
C
C---- CHECK FOR ERRORS
      IF(IER.GT.0) WRITE(IO2,2060) IER
C
C---- CLOSE DINMOD INPUT DATA FILE
999   INQUIRE(UNIT=IO1,OPENED=OPENED)
      IF(OPENED) CLOSE(IO1,STATUS='KEEP')
      END
C
C
C
      BLOCK DATA
C
C---- BLOCK DATA ------------------------------------------------------S
C
C  PURPOSE:
C    THIS SUBROUTINE IS NOT CALLED, ITS PRESENCE SUFFICES TO PROVIDE
C    INITIAL DATA VALUES FOR REFERENCES IN THE MAIN PROGRAM AND SUB-
C    PROGRAMS TO LABELED (NAMED) COMMON BLOCKS.
C
C----------------------------------------------------------------------F
C
C---- Declarations
      CHARACTER VERSION*8
      CHARACTER JTITLE*80,PTITLE*80,ID*4
      CHARACTER*63 DATAFILE,GRDAFILE,GRDBFILE,PRNTFILE,PLOTFILE
      LOGICAL   WIDE,SCREEN
C
C---- Common blocks
      COMMON /BLKA/
     # IPRNT,IPLOT,ICHEK,IAUTO,IRESQ,IGOUT,IWSTYP,
     # NXZL,NRFN,NGEN,
     # NRSQ,IRSQ(10),MHLD(10),LRSQ(10,56),IREFN,
     # NP,NE,NMSN,IO1,IO2,IO3,LDEV,OMEGA,
     # WIDE,SCREEN,VERSION
      COMMON /BLKB/
     # IPLTN,IPLTE,HTT,HTN,HTE,HTC,CVINC,
     # XL,YL,XU,YU,XSCALE,YSCALE,AROT,COSA,SINA,
     # XLOP,YLOP,XHIP,YHIP,XLP,YLP,XUP,YUP,CVMIN,CVMAX
      COMMON /BLKC/
     # JTITLE,PTITLE,ID(10),
     # DATAFILE,GRDAFILE,GRDBFILE,PRNTFILE,PLOTFILE
      COMMON /BLKT/ WAITT(7),DNAT(6,7),DNBT(6,7)
      COMMON /BLKR/ WAITR(9),DNAR(8,9),DNBR(8,9),DNAR9(9,9),DNBR9(9,9)
C
C---- Program version number
      DATA VERSION/'1.10.DG2'/
C
C---- I/O file (device) numbers
      DATA
     # IO1/55/,
     # IO2/8/,
     # IO3/90/,
     # LDEV/7/
C
C---- I/O FILE NAMES
      DATA
     # DATAFILE/'DINMOD.DAT'/,GRDAFILE/'GRID.DAT'/,
     # GRDBFILE/'GRIDOUT.DAT'/PRNTFILE/'DINMOD.PRT'/,
     # PLOTFILE/'DINMOD.PLT'/
C
C---- DATA SET IDENTIFICATION CODES
      DATA
     # ID/'SWMS','PLOT','ELEM','NODE','INTE','NETW','MIDS','AUTO',
     #    'RESE','LAST'/
C
C---- MINIMUM/MAXIMUM PLOT COORDINATES (IN INCHES)
      DATA
     # XLOP/0./,
     # YLOP/0./,
     # XHIP/999./,
     # YHIP/999./
C
C---- TRIANGULAR ELEMENT WEIGHTING AND SHAPE FUNCTIONS
      DATA WAITT/0.1125,3*0.066197075,3*0.062969590/
C
      DATA DNAT/
     # .33333333,1.33333333, .0000000,-1.33333333,-.33333333, .00000000,
     #-.76113653,1.88056824, .0000000,-1.88056824,-.88056824,1.64170477,
     # .88056824, .23886348, .00000000,-.23886348,-.88056824, .00000000,
     # .88056824,1.88056824, .0000000,-1.88056824,.76113653,-1.64170477,
     #2.18970796, .40514604, .00000000,-.40514604,.59485397,-2.78456193,
     #-.59485397,3.18970796, .0000000,-3.18970796, .59485397, .00000000,
     #-.59485397, .40514604, .0000000,-.40514604,-2.18970796,2.78456193/
C
      DATA DNBT/
     # .00000000,1.33333333, .33333333, .0000000,-.33333333,-1.33333333,
     # .00000000, .23886348, .88056824, .00000000,-.88056824,-.23886348,
     # .0000000,1.88056824,-.76113653,1.64170477,-.88056824,-1.88056824,
     # .00000000,1.88056824,.88056824,-1.64170477,.76113653,-1.88056824,
     # .00000000,3.18970796,-.59485397, .00000000,.59485397,-3.18970796,
     # .00000000,.40514604,2.18970796,-2.78456193, .59485397,-.40514604,
     # .00000000,.40514604,-.59485397,2.78456193,-2.18970796,-.40514604/
C
C---- RECTANGULAR 8-NODE ELEMENT SHAPE FUNCTIONS
      DATA WAITR/
     # 0.308641975,0.493827161,0.308641975,
     # 0.493827161,0.790123457,0.493827161,
     # 0.308641975,0.493827161,0.308641975/
      DATA DNAR/
     #-.04364916, .17459667,-.13094750, .20000000,-.34364916,1.37459665,
     #-1.03094747,-.20000000,
     # .04364916, .00000000,-.04364916, .20000000, .34364916, .00000000,
     #-.34364916,-.20000000,
     # .13094750,-.17459667, .04364916, .2000000,1.03094747,-1.37459665,
     # .34364916,-.20000000,
     #-.38729833, .77459666,-.38729833, .50000000,-.38729833, .77459666,
     #-.38729833,-.50000000,
     # .00000000, .00000000, .00000000, .50000000, .00000000, .00000000,
     # .00000000,-.50000000,
     # .38729833,-.77459666, .38729833, .50000000, .38729833,-.77459666,
     # .38729833,-.50000000,
     #-1.03094747,1.37459666,-.34364916, .2000000,-.13094750, .17459667,
     #-.04364916,-.20000000,
     #-.34364916, .00000000, .34364916, .20000000,-.04364916, .00000000,
     # .04364916,-.20000000,
     # .34364916,-1.37459665,1.03094747, .2000000, .04364916,-.17459667,
     # .13094750,-.20000000/
C
      DATA DNBR/
     # .34364916,-.20000000, .13094750,-.17459667, .04364916, .20000000,
     #1.03094747,-1.37459665,
     # .38729833,-.50000000, .38729833,-.77459666, .38729833, .50000000,
     # .38729833,-.77459666,
     # .13094750,-.20000000, .34364916,-1.37459665,1.03094747, .2000000,
     # .04364916,-.17459667,
     #-.34364916,-.20000000, .04364916, .00000000,-.04364916, .20000000,
     # .34364916, .00000000,
     # .00000000,-.50000000, .00000000, .00000000, .00000000, .50000000,
     # .00000000, .00000000,
     # .04364916,-.20000000,-.34364916, .00000000, .34364916, .20000000,
     #-.04364916, .00000000,
     #-1.03094747,-.2000000,-.04364916, .17459667,-.13094750, .20000000,
     #-.34364916,1.37459665,
     #-.38729833,-.50000000,-.38729833, .77459666,-.38729833, .50000000,
     #-.38729833, .77459666,
     #-.04364916,-.2000000,-1.03094747,1.37459665,-.34364916, .20000000,
     #-.13094750, .17459667/
C
C---- RECTANGULAR 9-NODE ELEMENT SHAPE FUNCTIONS
      DATA DNAR9/
     # 0.11127017,-0.13524200, 0.02397183,-0.10983867,-0.18872983,
     # 1.06475800,-0.87602817,-0.50983867, 0.61967734,
     # 0.04364917, 0.0       ,-0.04364917, 0.20000000, 0.34364917,
     # 0.0       ,-0.34364917,-0.20000000, 0.0,
     #-0.02397183, 0.13524200,-0.11127017, 0.50983867, 0.87602817,
     #-1.06475800, 0.18872983, 0.10983867,-0.61967734,
     # 0.0       , 0.0       , 0.0       ,-0.27459667, 0.0       ,
     # 0.0       , 0.0       ,-1.27459667, 1.54919334,
     # 0.0       , 0.0       , 0.0       , 0.50000000, 0.0       ,
     # 0.0       , 0.0       ,-0.50000000, 0.0       ,
     # 0.0       , 0.0       , 0.0       , 1.27459667, 0.0       ,
     # 0.0       , 0.0       , 0.27459667,-1.54919334,
     #-0.87602817, 1.06475800,-0.18872983,-0.10983867, 0.02397183,
     #-0.13524200, 0.11127017,-0.50983867, 0.61967734,
     #-0.34364917, 0.0       , 0.34364917, 0.20000000,-0.04364917,
     # 0.0       , 0.04364917,-0.20000000, 0.0       ,
     # 0.18872983,-1.06475800, 0.87602817, 0.50983867,-0.11127017,
     # 0.13524200,-0.02397183, 0.10983867,-0.61967734/
      DATA DNBR9/
     # 0.18872983, 0.10983867,-0.02397183, 0.13524200,-0.11127017,
     # 0.50983867, 0.87602817,-1.06475800,-0.61967734,
     # 0.0       , 0.27459667, 0.0       , 0.0       , 0.0       ,
     # 1.27459667, 0.0       , 0.0       ,-1.54919334,
     #-0.02397183, 0.10983867, 0.18872983,-1.06475800, 0.87602817,
     # 0.50983867,-0.11127017, 0.13524200,-0.61967734,
     #-0.34364917,-0.20000000, 0.04364917, 0.0       ,-0.04364917,
     # 0.20000000, 0.34364917, 0.0       , 0.0,
     # 0.0       ,-0.50000000, 0.0       , 0.0       , 0.0       ,
     # 0.50000000, 0.0       , 0.0       , 0.0       ,
     # 0.04364917,-0.20000000,-0.34364917, 0.0       , 0.34364917,
     # 0.20000000,-0.04364917, 0.0       , 0.0       ,
     #-0.87602817,-0.50983867, 0.11127017,-0.13524200, 0.02397183,
     #-0.10983867,-0.18872983, 1.06475800, 0.61967734,
     # 0.0       ,-1.27459667, 0.0       , 0.0       , 0.0       ,
     #-0.27459667, 0.0       , 0.0       , 1.54919334,
     # 0.11127017,-0.50983867,-0.87602817, 1.06475800,-0.18872983,
     #-0.10983867, 0.02397183,-0.13524200, 0.61967734/
      END
C
C
C
      SUBROUTINE INTERP(IER)
C
C---- INTERP ----------------------------------------------------------S
C
C  PURPOSE:
C    INTERPOLATES NODE POINT COORDINATES ALONG SPECIFIED STRAIGHT-LINE
C    SEGMENTS OF THE SYSTEM NETWORK.  EITHER X OR Y, OR BOTH X AND Y
C    COORDINATES CAN BE INTERPOLATED.  WHEN BOTH X AND Y COORDINATES
C    ARE COMPUTED, THEY ARE EVENLY SPACED BETWEEN THE TWO LINE-SEGMENT
C    ENDPOINTS.  IF COORDINATES AT AN ENDPOINT HAVE NOT BEEN SPECIFIED,
C    THE ERROR COUNT IS INCREMENTED BY ONE AND A MESSAGE IS PRINTED.
C
C  OUTPUT ARGUMENT(S):
C    IER - ERROR COUNT.
C
C  SUBPROGRAM(S) CALLED:
C    MIDNUM
C
C----------------------------------------------------------------------F
C
C---- Declarations (arguments)
      INTEGER   IER
C
C---- Declarations (local)
      INTEGER   K,KHI,KLO,N,NLINE,N1,N2,N3
      REAL      XA,XB,YA,YB
      LOGICAL   ERR
C
C---- Common block
      INCLUDE 'DINMOD.INC'
C
C---- Data
      DATA VOID/-1.0E+35/,ZIP/1.0E-08/
C
C---- OUTPUT FORMATS
2000  FORMAT(1H+,79(' ')/1H+,'Computing (coordinate interpolation)...')
2005  FORMAT(' ***ERROR #110 - COORDINATES ARE NOT SPECIFIED FOR NODE'
     # ,I5,' IN LINE',I3)
2001  FORMAT(' ***ERROR #120 - X-COORDINATE FOR NODE ',I5,
     # ' IN LINE ',I3,' IS OUT OF RANGE')
2002  FORMAT(' ***ERROR #130 - Y-COORDINATE FOR NODE ',I5,
     # ' IN LINE ',I3,' IS OUT OF RANGE')
2010  FORMAT(' ***',I5,' ERROR(S) ENCOUNTERED DURING COORDINATE ',
     #  'INTERPOLATION'/)
2080  FORMAT(' ***WARNING #140 - THE MIDSIDE NODE BETWEEN CORNER ',
     # 'NODES ',I5,' AND ',I5,' WAS NOT FOUND')
C
      IF(SCREEN) WRITE(*,2000)
C
C---- INITIALIZE VARIABLES
      IER=0
      NLINE=0
      KHI=-1
C
C---- READ NEXT INTERPOLATION LINE
10    KHI=KHI+2
      INTYP=LINE(KHI)
      IF(INTYP.EQ.0) GOTO 100
C
C---- FIND END OF INTERPOLATION LINE
      KLO=KHI+1
      DO 20 K=KLO,MAXLIN
        IF(LINE(K).LT.0) GOTO 30
        KHI=K
20    CONTINUE
      IER=IER+1
      GOTO 100
C
C---- BEGIN COORDINATE INTERPOLATION
30    NLINE=NLINE+1
      ERR=.FALSE.
      NA=LINE(KLO)
      NB=LINE(KHI)
      IF(INTYP.EQ.1) GOTO 40
      IF(INTYP.EQ.2) GOTO 60
      IF(INTYP.EQ.3) GOTO 80
      IER=IER+1
      GOTO 100
C
C---- INTERPOLATE Y-COORDINATES OF CORNER NODES
40    XA=CORD(NA,1)
      IF(ABS(XA-VOID).LT.ZIP) THEN
        ERR=.TRUE.
        IER=IER+1
        WRITE(IO2,2005) NA,NLINE
      ENDIF
      XB=CORD(NB,1)
      IF(ABS(XB-VOID).LT.ZIP) THEN
        ERR=.TRUE.
        IER=IER+1
        WRITE(IO2,2000) NB,NLINE
      ENDIF
      IF(ERR) GOTO 10
      YA=CORD(NA,2)
      YB=CORD(NB,2)
      XMAX=XA
      IF(XB.GT.XMAX) XMAX=XB
      XMIN=XA
      IF(XB.LT.XMIN) XMIN=XB
      RATIO=(YB-YA)/(XB-XA)
      N3=NA
      DO 50 K=KLO+1,KHI
        N1=N3
        N3=LINE(K)
        IF(K.LT.KHI) THEN
          ERR=.FALSE.
          IF(CORD(N3,1).GT.XMAX) ERR=.TRUE.
          IF(CORD(N3,1).LT.XMIN) ERR=.TRUE.
          IF(ERR) THEN
            WRITE(IO2,2001) N3,NLINE
            IER=IER+1
            GOTO 50
          ENDIF
          CORD(N3,2)=YA+RATIO*(CORD(N3,1)-XA)
        ENDIF
C------ COMPUTE COORDINATE OF MIDSIDE NODE BETWEEN CORNER NODES
        CALL MIDNUM(N1,N3,N2)
        IF(N2.EQ.0) THEN
          WRITE(IO2,2080) N1,N3
        ELSE
          CORD(N2,1)=0.5*(CORD(N1,1)+CORD(N3,1))
          CORD(N2,2)=0.5*(CORD(N1,2)+CORD(N3,2))
        ENDIF
50    CONTINUE
      GOTO 10
C
C---- INTERPOLATE X-COORDINATES OF CORNER NODES
60    XA=CORD(NA,1)
      IF(ABS(XA-VOID).LT.ZIP) THEN
        ERR=.TRUE.
        IER=IER+1
        WRITE(IO2,2000) NA,NLINE
      ENDIF
      XB=CORD(NB,1)
      IF(ABS(XB-VOID).LT.ZIP) THEN
        ERR=.TRUE.
        IER=IER+1
        WRITE(IO2,2000) NB,NLINE
      ENDIF
      IF(ERR) GOTO 10
      YA=CORD(NA,2)
      YB=CORD(NB,2)
      YMAX=YA
      IF(YB.GT.YMAX) YMAX=YB
      YMIN=YA
      IF(YB.LT.YMIN) YMIN=YB
      RATIO=(XB-XA)/(YB-YA)
      N3=NA
      DO 70 K=KLO+1,KHI
        N1=N3
        N3=LINE(K)
        IF(K.LT.KHI) THEN
          ERR=.FALSE.
          IF(CORD(N3,2).GT.YMAX) ERR=.TRUE.
          IF(CORD(N3,2).LT.YMIN) ERR=.TRUE.
          IF(ERR) THEN
            WRITE(IO2,2002) N3,NLINE
            IER=IER+1
            GOTO 70
          ENDIF
          CORD(N3,1)=XA+RATIO*(CORD(N3,2)-YA)
        ENDIF
C------ COMPUTE COORDINATE OF MIDSIDE NODE BETWEEN CORNER NODES
        CALL MIDNUM(N1,N3,N2)
        IF(N2.EQ.0) THEN
          WRITE(IO2,2080) N1,N3
        ELSE
          CORD(N2,1)=0.5*(CORD(N1,1)+CORD(N3,1))
          CORD(N2,2)=0.5*(CORD(N1,2)+CORD(N3,2))
        ENDIF
70    CONTINUE
      GOTO 10
C
C---- COMPUTE X- AND Y-COORDINATES OF EQUALLY SPACED CORNER NODES
80    XA=CORD(NA,1)
      IF(ABS(XA-VOID).LT.ZIP) THEN
        ERR=.TRUE.
        IER=IER+1
        WRITE(IO2,2000) NA,NLINE
      ENDIF
      XB=CORD(NB,1)
      IF(ABS(XB-VOID).LT.ZIP) THEN
        ERR=.TRUE.
        IER=IER+1
        WRITE(IO2,2000) NB,NLINE
      ENDIF
      IF(ERR) GOTO 10
      YA=CORD(NA,2)
      YB=CORD(NB,2)
      DX=(XB-XA)/FLOAT(KHI-KLO)
      DY=(YB-YA)/FLOAT(KHI-KLO)
      N3=NA
      DO 90 K=KLO+1,KHI
        N1=N3
        N3=LINE(K)
        IF(K.LT.KHI) THEN
          CORD(N3,1)=XA+FLOAT(K)*DX
          CORD(N3,2)=YA+FLOAT(K)*DY
        ENDIF
C------ COMPUTE COORDINATE OF MIDSIDE NODE BETWEEN CORNER NODES
        CALL MIDNUM(N1,N3,N2)
        IF(N2.EQ.0) THEN
          WRITE(IO2,2080) N1,N3
        ELSE
          CORD(N2,1)=0.5*(CORD(N1,1)+CORD(N3,1))
          CORD(N2,2)=0.5*(CORD(N1,2)+CORD(N3,2))
        ENDIF
90    CONTINUE
      GOTO 10
C
C---- CHECK FOR ERRORS THEN RETURN
100   IF(IER.GT.0) WRITE(IO2,2010) IER
      RETURN
      END
C
C
C
      SUBROUTINE LCHECK(L,IDS,MAXE,IO2,IER,ERR)
C
C---- LCHECK ----------------------------------------------------------S
C
C  PURPOSE:
C    CHECKS FOR A VALID ELEMENT NUMBER.  THE ELEMENT NUMBER MUST BE
C    GREATER THAN ZERO AND LESS THAN OR EQUAL TO THE MAXIMUM ELEMENT
C    DIMENSION, MAXE.  IF AN ELEMENT NUMBER IS FOUND TO BE OUTSIDE
C    THIS RANGE, THE ERROR COUNT IS INCREMENTED BY ONE AND A MESSAGE
C    IS PRINTED.
C
C  INPUT ARGUMENT(S):
C    L -    THE ELEMENT NUMBER TO BE CHECKED
C    IDS -  THE DATA SET FROM WHICH THE ELEMENT NUMBER IS READ
C    MAXE - THE MAXIMUM ELEMENT NUMBER (DIMENSION)
C    IER -  THE ERROR COUNT
C    ERR -  LOGICAL ERROR INDICATOR
C
C  OUTPUT ARGUMENT(S):
C    IER -  ERROR COUNT.
C
C----------------------------------------------------------------------F
C
C---- Declarations (arguments)
      INTEGER L,MAXE,IO2,IER
      CHARACTER IDS*(*)
      LOGICAL ERR
C
C---- Declarations (local)
      INTEGER   LENCHR
C
C---- Output formats
2000  FORMAT(' ***ERROR #220 - ELEMENT NUMBER ',I5,' IN THE ',(A),
     # ' DATA SET IS OUT OF RANGE.')
C
      ERR=.FALSE.
      IF(L.LT.0) ERR=.TRUE.
      IF(L.GT.MAXE) ERR=.TRUE.
      IF(ERR) THEN
        IER=IER+1
        WRITE(IO2,2000) L,IDS(1:LENCHR(IDS))
      END IF
      RETURN
      END
C
C
C
      SUBROUTINE NCHECK(N,IDS,MAXP,IO2,IER,ERR)
C
C---- NCHECK ----------------------------------------------------------S
C
C  PURPOSE:
C    CHECKS FOR A VALID NODE NUMBER.  THE NODE NUMBER MUST BE GREATER
C    THAN ZERO AND LESS THAN OR EQUAL TO THE MAXIMUM NODE DIMENSION,
C    MAXP.  IF AN INVALID NODE NUMBER IS FOUND TO BE OUTSIDE THIS
C    RANGE, THE ERROR COUNT IS INCREMENTED BY ONE AND A MESSAGE IS
C    PRINTED.
C
C  INPUT ARGUMENT(S):
C    N -    THE NODE NUMBER TO BE CHECKED
C    IDS -  THE DAT SET FROM WHICH THE NODE NUMBER WAS READ
C    MAXP - THE MAXIMUM NODE DIMENSION (NUMBER)
C    IER -  THE ERROR COUNT
C    ERR -  LOGICAL
C
C  OUTPUT ARGUMENT(S):
C    IER -  THE ERROR COUNT.
C
C----------------------------------------------------------------------F
C
C---- Declarations
      INTEGER N,MAXP,IER,LENCHR
      CHARACTER IDS*(*)
      LOGICAL ERR
C
C---- Output formats
2000  FORMAT(' ***ERROR #230 - NODE NUMBER ',I5,' IN THE ',(A),
     # ' DATA SET IS OUT OF RANGE.')
C
      ERR=.FALSE.
      IF(N.LT.0) ERR=.TRUE.
      IF(N.GT.MAXP) ERR=.TRUE.
      IF(ERR) THEN
        IER=IER+1
        WRITE(IO2,2000) N,IDS(1:LENCHR(IDS))
      END IF
      RETURN
      END
C
C
C
      SUBROUTINE LNODES(L,NCN)
C
C---- LNODES ----------------------------------------------------------S
C
C  PURPOSE:
C    DETERMINES THE TOTAL NUMBER OF NODES IN AN ELEMENT AND FILLS
C    THE ARRAY NODE WITH THE CONNECTIVITY LIST.
C
C  INPUT ARGUMENT(S):
C    L - ELEMENT NUMBER.
C
C  OUTPUT ARGUMENT(S):
C    NCN - NUMBER OF NODES IN CONNECTIVITY LIST.
C
C----------------------------------------------------------------------F
C
C---- Declarations (arguments)
      INTEGER   L,NCN
C
C---- Declarations (local)
      INTEGER   K
C
C---- Common blocks
      INCLUDE 'DINMOD.INC'
C
      NCN=6
      IF(NOP(L,8).NE.0) NCN=8
      IF(NOP(L,9).NE.0) NCN=9
      DO 10 K=1,9
        NODE(K)=0
10    CONTINUE
      DO 20 K=1,NCN
        NODE(K)=NOP(L,K)
20    CONTINUE
      RETURN
      END
C
C
C
      FUNCTION LAREA(L,KODE)
C
C---- LAREA -----------------------------------------------------------S
C
C  PURPOSE:
C    COMPUTES AREA OF ELEMENTS.
C
C  INPUT ARGUMENT(S):
C    L    - ELEMENT NUMBER.
C    KODE - ERROR MESSAGE CODE.
C
C                0, MESSAGES ARE NOT PRINTED
C         KODE =
C                1, MESSAGES ARE PRINTED
C
C----------------------------------------------------------------------F
C
C---- Declarations (arguments)
      INTEGER   L,KODE
C
C---- Declarations (local)
      INTEGER   J,K,N,NCN,NGP
      REAL      LAREA,DETJ,J11,J12,J21,J22
C
C---- Common blocks
      INCLUDE 'DINMOD.INC'
C
C---- Dimensions
      DIMENSION WAIT(9),DA(9,9),DB(9,9),XLC(9),YLC(9)
C
C---- Data
      DATA VOID/-1.0E+35/,VOIDP/-1.0E+34/
C
C---- OUTPUT FORMATS
2000  FORMAT(' ***WARNING #??? - COORDINATES NOT FOUND FOR NODE ',I5,
     # ' IN ELEMENT ',I5)
2010  FORMAT(' ***WARNING #130 - DETERMINANT <= 0 AT INTEG. PT. ',I2,
     # ' IN ELEMENT ',I5)
C
C---- INITIALIZE VARIABLES
      XLC(1)=0.
      YLC(1)=0.
      LAREA=0.0
      IF(LMAT(L).EQ.0) RETURN
      CALL LNODES(L,NCN)
C
C---- CHECK FOR VOID COORDINATES
      DO 5 K=1,NCN
        N=NODE(K)
        IF(CORD(N,1).LT.VOIDP .OR. CORD(N,2).LT.VOIDP) THEN
          IF(KODE.EQ.1) WRITE(IO2,2000) N,L
          LAREA=0.
          RETURN
        ENDIF
5     CONTINUE
C
C---- TRIANGULAR ELEMENT IF NCN = 6
      IF(NCN.EQ.6) THEN
        NGP=7
        DO 20 J=1,NGP
          WAIT(J)=WAITT(J)
          DO 10 K=1,NCN
            DA(K,J)=DNAT(K,J)
            DB(K,J)=DNBT(K,J)
10        CONTINUE
20      CONTINUE
C
C---- EIGHT-NODE RECTANGULAR ELEMENT IF NCN = 8
      ELSEIF(NCN.EQ.8) THEN
        NGP=9
        DO 50 J=1,NGP
          WAIT(J)=WAITR(J)
          DO 40 K=1,NCN
            DA(K,J)=DNAR(K,J)
            DB(K,J)=DNBR(K,J)
40        CONTINUE
50      CONTINUE
C
C---- NINE-NODE RECTANGULAR ELEMENT IF NCN = 9
      ELSE
        NGP=9
        DO 60 J=1,NGP
          WAIT(J)=WAITR(J)
          DO 58 K=1,NCN
            DA(K,J)=DNAR9(K,J)
            DB(K,J)=DNBR9(K,J)
58        CONTINUE
60      CONTINUE
      ENDIF
C
C---- COMPUTE REFERENCE COORDINATES
      N=NODE(1)
      X=CORD(N,1)
      Y=CORD(N,2)
      DO 70 K=2,NCN
        N=NODE(K)
        XLC(K)=CORD(N,1)-X
        YLC(K)=CORD(N,2)-Y
70    CONTINUE
C
C---- COMPUTE ELEMENT AREA
      DO 90 J=1,NGP
        J11=0.0
        J12=0.0
        J21=0.0
        J22=0.0
        DO 80 K=2,NCN
          J11=J11+DA(K,J)*XLC(K)
          J12=J12+DA(K,J)*YLC(K)
          J21=J21+DB(K,J)*XLC(K)
          J22=J22+DB(K,J)*YLC(K)
80      CONTINUE
        DETJ=J11*J22-J12*J21
        IF(DETJ.LT.0.) THEN
          IF(KODE.EQ.1) WRITE(IO2,2010) J,L
          LAREA=0.
          RETURN
        ENDIF
        LAREA=LAREA+WAIT(J)*DETJ
90    CONTINUE
      RETURN
      END
C
C
C
      SUBROUTINE MIDNUM(N1,N3,N2)
C
C---- MIDNUM ----------------------------------------------------------S
C
C  PURPOSE:
C    FINDS THE MIDSIDE NODE ON AN ELEMENT SIDE BETWEEN TWO GIVEN CORNER
C    NODES.  THE ELEMENT CONNECTIVITY LISTS ARE SCANNED FOR THE TWO
C    CONSECUTIVE CORNER NODES, THE MIDSIDE NODE THUS BEING THE NODE
C    APPEARING IN THE LIST BETWEEN THE TWO.
C
C  INPUT ARGUMENT(S):
C    N1 - THE NUMBER OF THE FIRST CORNER NODE POINT.
C    N3 - THE NUMBER OF THE SECOND CORNER NODE POINT.
C
C  OUTPUT ARGUMENT(S):
C    N2 - THE NUMBER OF THE MIDSIDE NODE POINT.
C
C  SUBPROGRAMS CALLED:
C    LNODES
C
C----------------------------------------------------------------------F
C
      INCLUDE 'DINMOD.INC'
C
C---- Declarations
      INTEGER N1,N2,N3,L,K,NA,NB,NC
C
      N2=0
      DO 20 L=1,NE
        CALL LNODES(L,NCN)
        IF(NCN.EQ.9) NCN=8
        DO 10 K=2,NCN,2
          NB=NODE(K)
          NA=NODE(K-1)
          NC=MOD(K+1,NCN)
          NC=NODE(NC)
          IF(N1.EQ.NA) THEN
            IF(N3.EQ.NC) THEN
              N2=NB
              GOTO 30
            ENDIF
          ELSE IF(N1.EQ.NC) THEN
            IF(N3.EQ.NA) THEN
              N2=NB
              GOTO 30
            ENDIF
          ENDIF
10      CONTINUE
20    CONTINUE
30    RETURN
      END
C
C
C
      SUBROUTINE MIDSDE(IER)
C
C---- MIDSDE ----------------------------------------------------------S
C
C  PURPOSE:
C    CHECKS CORNER NODES FOR UNSPECIFIED VALUES, CHECKS ASSIGNED
C    MIDSIDE NODE COORDINATES FOR COMPLIANCE WITH THE MIDDLE-THIRD
C    RULE, AND COMPUTES UNASSIGNED MIDSIDE AND CENTER NODE COORDINATES
C    AND GROUND ELEVATIONS.
C
C  OUTPUT ARGUMENTS:
C    IER - ERROR COUNT.
C
C  SUBPROGRAM(S) CALLED:
C    LNODES
C
C----------------------------------------------------------------------F
C
C---- Declarations (arguments)
      INTEGER IER
C
C---- Declarations (local)
      REAL    LAREA
      LOGICAL ERR
C
      INCLUDE 'DINMOD.INC'
C
C---- Data statements
      DATA DTOR/0.01745329/,RTOD/57.295780/
      DATA VOID/-1.0E+35/,VOIDP/-1.0E+34/
C
C---- OUTPUT FORMATS
2000  FORMAT(1H+,79(' ')/1H+,'Computing (midside node values)...')
2002  FORMAT(' ***WARNING #100 - MIDSIDE NODE ',I5,' WAS NOT FOUND ',
     # 'IN ELEMENT CONNECTIVITY LISTS')
2003  FORMAT(' ***ERROR #170 - COORDINATES HAVE NOT BEEN SPECIFIED ',
     # 'FOR CORNER NODE ',I5)
2004  FORMAT(' ***ERROR #180 - COORDINATES OF CORNER NODES ARE THE ',
     # ' SAME AT SIDE ',I5,',',I5,',',I5,' IN ELEMENT ',I5)
2005  FORMAT(' ***ERROR #190 - NETWORK SLOPE IS NOT SPECIFIED AT ',
     # 'NODE ',I5,' FOR MIDSIDE NODE ',I5)
2010  FORMAT(' ***ERROR #200 - CORNER NODE SLOPES ARE NOT COMPATIBLE',
     # ' AT SIDE ',I5,',',I5,',',I5,' IN ELEMENT ',I5)
2015  FORMAT(' ***WARNING #110 - NODE ',I5,' VIOLATES MIDDLE-THIRD ',
     # 'RULE IN ELEMENT ',I5,'.')
2020  FORMAT(' ***',I5,' ERROR(S) ENCOUNTERED DURING MIDSIDE NODE ',
     # 'PROCESSING'/)
2060  FORMAT(' ***ERROR #210 - INDETERMINANT BOUNDARY ANGLE AT ',
     # 'NODE ',I5)
C
C---- INITIALIZE VARIABLES AND ARRAYS
      IF(SCREEN) WRITE(*,2000)
      IER=0
      DO 10 N=1,NP
        NPID(N)=0
10    CONTINUE
C
C---- ASSIGN VALUES TO NODAL IDENTIFICATION ARRAY
      DO 50 L=1,NE
        IF(LMAT(L).NE.0) THEN
          CALL LNODES(L,NCN)
          DO 40 K=1,NCN
            N=NODE(K)
            NPID(N)=NPID(N)+1
40        CONTINUE
        ENDIF
50    CONTINUE
C
C---- CHECK CORNER NODE COORDINATES FOR VOIDS
      DO 80 L=1,NE
        IF(LMAT(L).NE.0) THEN
          CALL LNODES(L,NCN)
          NCN1=NCN-1
          DO 70 K=1,NCN1,2
            N=NODE(K)
            IF(NPID(N).GT.0) THEN
              NPID(N)=-NPID(N)
              IF(CORD(N,1).LT.VOIDP) THEN
                ERR=.TRUE.
                IER=IER+1
                WRITE(IO2,2003) N
              ENDIF
            ENDIF
70        CONTINUE
        ENDIF
80    CONTINUE
C
C---- SET NODE POINT IDENTIFICATION ARRAY POSITIVE
      DO 85 N=1,NP
        NPID(N)=IABS(NPID(N))
85    CONTINUE
C
C---- CHECK ASSIGNED AND COMPUTE UNASSIGNED NODE VALUES
      DO 120 L=1,NE
        IF(LMAT(L).EQ.0) GOTO 120
        CALL LNODES(L,NCN)
        KHI=NCN
        IF(NCN.EQ.9) KHI=8
        DO 100 K=2,KHI,2
          N2=NODE(K)
          IF(NPID(N2).GT.0) THEN
            NPID(N2)=-NPID(N2)
            N1=NODE(K-1)
            N3=MOD(K+1,KHI)
            N3=NODE(N3)
C
C-----------COMPUTE ELEVATIONS
            GRND(N2)=0.5*(GRND(N1)+GRND(N3))
            CEIL(N2)=0.5*(CEIL(N1)+CEIL(N3))
C
C-----------COMPUTE UNASSIGNED COORDINATES
            IF(CORD(N2,1).LT.VOIDP) THEN
              CORD(N2,1)=0.5*(CORD(N1,1)+CORD(N3,1))
              CORD(N2,2)=0.5*(CORD(N1,2)+CORD(N3,2))
            ELSE
C
C-----------CHECK ASSIGNED NODES FOR VIOLATION OF MIDDLE-THIRD RULE
              ERR=.FALSE.
              DX1=CORD(N3,1)-CORD(N1,1)
              DY1=CORD(N3,2)-CORD(N1,2)
              DX2=CORD(N2,1)-CORD(N1,1)
              DY2=CORD(N2,2)-CORD(N1,2)
              AN1=ATAN2(DY1,DX1)
              AN2=ATAN2(DY2,DX2)
              AN3=AN2-AN1
              H1=SQRT(DY1*DY1+DX1*DX1)
              H2=SQRT(DY2*DY2+DX2*DX2)
              XMSN=ABS(H2*COS(AN3))
              IF(XMSN.LT.0.333*H1) ERR=.TRUE.
              IF(XMSN.GT.0.667*H1) ERR=.TRUE.
              IF(ERR) WRITE(IO2,2015) N2,L
            ENDIF
          ENDIF
100     CONTINUE
C
C-------COMPUTE CENTER NODE COORDINATE AND GROUND-SURFACE ELEVATION
        IF(NCN.EQ.9) THEN
          N=NODE(9)
          X=0.
          Y=0.
          G=0.
          C=0.
          DO 110 K=1,7,2
            NC=NODE(K)
            NM=NODE(K+1)
            X=X-0.25*CORD(NC,1)+0.5*CORD(NM,1)
            Y=Y-0.25*CORD(NC,2)+0.5*CORD(NM,2)
            G=G+0.25*GRND(NC)
            C=C+0.25*CEIL(NC)
110       CONTINUE
          IF(GRND(N).LT.VOIDP) GRND(N)=G
          IF(CEIL(N).LT.VOIDP) CEIL(N)=C
          IF(CORD(N,1).LT.VOIDP) THEN
            CORD(N,1)=X
            CORD(N,2)=Y
          ENDIF
        ENDIF
C
C---- Check for negative determinants
      AREA=LAREA(L,1)
120   CONTINUE
      IF(IER.GT.0) WRITE(IO2,2020) IER
C
C---- SET NPID ARRAY POSITIVE
      DO 130 N=1,NP
        NPID(N)=IABS(NPID(N))
130   CONTINUE
      RETURN
      END
C
C
C
      SUBROUTINE OUTPUT
C
C---- OUTPUT ----------------------------------------------------------S
C
C  PURPOSE:
C    PRINTS PROCESSED NETWORK DATA INCLUDING ELEMENT CONNECTIVITY
C    LISTS, PROPERTY TYPE CODES, SEQUENCING, AND COMPUTED AREAS.
C    NODE POINT COORDINATES, AND GROUND SURFACE ELEVATIONS.
C
C  SUBPROGRAM(S) CALLED:
C     TBLOCK
C
C----------------------------------------------------------------------F
C
C---- Declarations (local)
      INTEGER   J,K,L,N
      REAL      LAREA
      LOGICAL   EXISTS
C
C---- Common blocks
      INCLUDE 'DINMOD.INC'
C
C---- Data
      DATA VOID/-1.0E+35/,VDX/-1.0E+30/
C
C---- OUTPUT FORMATS
2000  FORMAT(1H+,79(' ')/1H+,'Writing (',(A),')...')
2001  FORMAT(//50X,'FINITE ELEMENT NETWORK DATA FOR'//26X,A80)
2010  FORMAT(//56X,'*** ELEMENT DATA ***'//
     # 2(1X,'ELMT',12X,'NODES (COUNTERCLOCKWISE)',9X,'PROP',
     # 8X,'AREA')/
     # 2(2X,'NO.',3X,'1',4X,'2',4X,'3',4X,'4',4X,'5',4X,'6',4X,'7',
     # 4X,'8',4X,'9',1X,'CODE',5X,'FT2(M2)')/)
2012  FORMAT(2(1X,I4,9I5,I4,F12.2))
2020  FORMAT(//58X,'*** NODE DATA ***'//
     # 1X,3(1X,'NODE',3X,'X-COORD',3X,'Y-COORD',2X,'GRND EL',
     # 2X,'CEIL EL')/
     # 1X,3(2X,'NO.',5X,'FT(M)',5X,'FT(M)',4X,'FT(M)',4X,'FT(M)')/)
2021  FORMAT(1X,3(I5,2F10.2,2F9.2))
2101  FORMAT(//24X,'FINITE ELEMENT NETWORK DATA FOR'//A80)
2110  FORMAT(//30X,'*** ELEMENT DATA ***'//
     # 7X,1(1X,'ELMT',12X,'NODES (COUNTERCLOCKWISE)',9X,'PROP',
     # 8X,'AREA')/
     # 7X,1(2X,'NO.',3X,'1',4X,'2',4X,'3',4X,'4',4X,'5',4X,'6',4X,'7',
     # 4X,'8',4X,'9',1X,'CODE',5X,'FT2(M2)')/)
2112  FORMAT(7X,1(I5,9I5,I4,F12.2))
2120  FORMAT(//32X,'*** NODE DATA ***'//
     # 12X,1(3X,'NODE',5X,'X-COORD',5X,'Y-COORD',5X,'GRND EL',
     # 5X,'CEIL EL')/
     # 12X,1(4X,'NO.',7X,'FT(M)',7X,'FT(M)',7X,'FT(M)',7X,'FT(M)')/)
2121  FORMAT(12X,1(I7,4F12.2))
C
      IF(SCREEN) WRITE(*,2000) PRNTFILE(1:LENCHR(PRNTFILE))
C
C---- CHANGE VOIDS TO ZEROS
      DO 5 N=1,NP
        IF(CORD(N,1).LT.VDX) CORD(N,1)=0.
        IF(CORD(N,2).LT.VDX) CORD(N,2)=0.
        IF(GRND(N).LT.VDX) GRND(N)=0.
        IF(CEIL(N).LT.VDX) CEIL(N)=0.
5     CONTINUE
      IF(MOD(IPRNT,4).LT.2) GOTO 35
C
C---- ADVANCE TO TOP OF PAGE
      CALL FORMFD(IO2)
C
C---- PRINT NETWORK TITLE
      IF(WIDE) THEN
        WRITE(IO2,2001) JTITLE
      ELSE
        WRITE(IO2,2101) JTITLE
      ENDIF
C
C---- PRINT ELEMENT DATA
      IF(WIDE) THEN
        WRITE(IO2,2010)
        JINT=(NE+1)/2
        DO 10 J=1,JINT
          WRITE(IO2,2012) (L,(NOP(L,K),K=1,9),LMAT(L),LAREA(L,0),
     #    L=J,NE,JINT)
10      CONTINUE
      ELSE
        WRITE(IO2,2110)
        DO 15 L=1,NE
          WRITE(IO2,2112) L,(NOP(L,K),K=1,9),LMAT(L),LAREA(L,0)
15      CONTINUE
      ENDIF
C
C---- PRINT NODE DATA
      IF(WIDE) THEN
        WRITE(IO2,2020)
        JINT=(NP+2)/3
        DO 20 J=1,JINT
          WRITE(IO2,2021) (N,(CORD(N,K),K=1,2),GRND(N),CEIL(N),
     #    N=J,NP,JINT)
20      CONTINUE
      ELSE
        WRITE(IO2,2120)
        DO 25 N=1,NP
          WRITE(IO2,2121) N,(CORD(N,K),K=1,2),GRND(N),CEIL(N)
25      CONTINUE
      ENDIF
C
C---- WRITE NETWORK DATA TO OUTPUT FILE
35    IF(IGOUT.NE.0) THEN
        IF(SCREEN) WRITE(*,2000) GRDBFILE(1:LENCHR(GRDBFILE))
        IF(EXISTS(GRDBFILE)) THEN
          OPEN(IO3,FILE=GRDBFILE)
          CLOSE(IO3,STATUS='DELETE')
        ENDIF
        IF(IGOUT.GT.0) THEN
          OPEN(IO3,FILE=GRDBFILE,STATUS='NEW',ACCESS='SEQUENTIAL',
     #    FORM='FORMATTED')
          WRITE(IO3,'(2I10)') NP,NE
          WRITE(IO3,'(I10,4F10.2)') (N,(CORD(N,K),K=1,2),GRND(N),
     #    CEIL(N),N=1,NP)
          WRITE(IO3,'(12I5)') (L,(NOP(L,K), K=1,9),LMAT(L),LSEQ(L),
     #    L=1,NE)
        ELSE
          OPEN(IO3,FILE=GRDBFILE,STATUS='NEW',ACCESS='SEQUENTIAL',
     #    FORM='UNFORMATTED')
          WRITE(IO3) NP,NE
          WRITE(IO3) ((CORD(N,K),K=1,2),GRND(N),CEIL(N),N=1,NP)
          WRITE(IO3) ((NOP(L,K),K=1,9),LMAT(L),LSEQ(L),L=1,NE)
        ENDIF
        CLOSE(IO3,STATUS='KEEP')
      ENDIF
      RETURN
      END
C
C
C
      SUBROUTINE PREPLT
C
C---- PREPLT ----------------------------------------------------------S
C
C  PURPOSE:
C    CHECKS ON PLOT SCALE AND SETS BOUNDARIES.
C
C  SUBPROGRAM(S) CALLED:
C    LNODES
C
C----------------------------------------------------------------------F
C
      INCLUDE 'DINMOD.INC'
C
C
C---- OUTPUT FORMATS
2000  FORMAT(1H+,79(' ')/1H+,'Plotting...')
C
      IF(SCREEN) WRITE(*,2000)
C
C---- ASSIGN INITIAL VALUES AND CONSTANTS
      DO 10 N=1,NP
        NPID(N)=0
10    CONTINUE
      ZIP=1.0E-08
C
C---- ASSIGN VALUES TO NODE POINT IDENTIFICATION ARRAY
      DO 20 L=1,NE
        IF(LMAT(L).NE.0) THEN
          CALL LNODES(L,NCN)
          DO 15 K=1,NCN
            N=NODE(K)
            NPID(N)=NPID(N)+1
15        CONTINUE
        ENDIF
20    CONTINUE
C
C---- FIND MINIMUM AND MAXIMUM COORDINATES
      XMIN= 1.0E+35
      YMIN= 1.0E+35
      XMAX=-1.0E+35
      YMAX=-1.0E+35
      DO 25 N=1,NP
        IF(NPID(N).GT.0) THEN
          X=CORD(N,1)
          IF(X.GT.XMAX) XMAX=X
          IF(X.LT.XMIN) XMIN=X
          Y=CORD(N,2)
          IF(Y.GT.YMAX) YMAX=Y
          IF(Y.LT.YMIN) YMIN=Y
        ENDIF
25    CONTINUE
C
C---- SET DEFAULT WINDOW BOUNDS
      IF(ABS(XL).LT.ZIP) XL=XMIN
      IF(ABS(YL).LT.ZIP) YL=YMIN
      IF(ABS(XU).LT.ZIP) XU=XMAX
      IF(ABS(YU).LT.ZIP) YU=YMAX
C
C---- ASSIGN PLOT SCALES
      IF(ABS(XSCALE).GT.0..AND.ABS(YSCALE).GT.0.) THEN
        XSCALE=1./XSCALE
        YSCALE=1./YSCALE
      ELSE
        YSCALE=33./(YMAX-YMIN)
        XSCALE=YSCALE
        XL=XMIN
        YL=YMIN
        XU=XMAX
        YU=YMAX
      ENDIF
C
C---- COMPUTE SINE AND COSINE OF ROTATION ANGLE
      IF(ABS(AROT).GT.0.) THEN
        AROT=0.017453293*AROT
        SINA=SIN(AROT)
        COSA=COS(AROT)
      ELSE
        SINA=0.
        COSA=1.
      ENDIF
C
C---- CHECK ON PLOT BOUNDS (LEAVE 1/2 INCH BORDER ALONG Y-AXIS)
      XLP=0.5
      YLP=0.0
      XUP=XHIP
      YUP=YHIP
      TEMP=XSCALE*((XU-XL)*COSA-(YU-YL)*SINA)+0.5
      IF(TEMP.LT.XUP) XUP=TEMP
      TEMP=YSCALE*((XU-XL)*SINA+(YU-YL)*COSA)
      IF(TEMP.LT.YUP) YUP=TEMP
      RETURN
      END
C
C
C
      SUBROUTINE REFINE(IER)
C
C---- REFINE ----------------------------------------------------------S
C
C  PURPOSE:
C    REFINES EITHER TRIANGULAR OR RECTANGULAR ELEMENTS BY DIVIDING
C    THEM INTO FOUR SIMILAR ELEMENTS. ALL ELEMENTS IN THE NETWORK
C    ARE REFINED WHEN THIS SUBROUTINE IS CALLED.
C
C  INPUT ARGUMENT(S):
C    IER - ERROR COUNT.
C
C  SUBPROGRAM(S) CALLED:
C    LNODES, SUBT6, SUBQ8, SUBQ9
C
C----------------------------------------------------------------------F
C
      INCLUDE 'DINMOD.INC'
C
C---- Declarations
      INTEGER IER,L,LHI,NCN
C
C---- OUTPUT FORMATS
2000  FORMAT(1H+,79(' ')/1H+,'Computing (network refinement)...')
C
      IF(SCREEN) WRITE(*,2000)
      LHI=NE
      DO 100 L=1,LHI
        IF(LMAT(L).EQ.0) GOTO 100
        CALL LNODES(L,NCN)
        IF(NCN.EQ.6) THEN
          CALL SUBT6(L,IER)
        ELSEIF(NCN.EQ.8) THEN
          CALL SUBQ8(L,IER)
        ELSEIF(NCN.EQ.9) THEN
          CALL SUBQ9(L,IER)
        ENDIF
        IF(IER.GT.0) GOTO 999
100   CONTINUE
999   RETURN
      END
C
C
C
      SUBROUTINE SUBT6(L,IER)
C
C---- SUBT6 -----------------------------------------------------------S
C
C  PURPOSE:
C    SUBDIVIDES A TRIANGULAR ELEMENT INTO FOUR SIMILAR ELEMENTS BY
C    CONNECTING THE MIDSIDE POINTS OF THE ELEMENT.  THE NUMBER OF
C    ELEMENTS AND NODE POINTS IN THE SYSTEM ARE INCREASED ACCORDINGLY
C    AS EACH NEW ELEMENT IS FORMED.
C
C  INPUT ARGUMENT(S):
C    L - NUMBER OF THE TRIANGULAR ELEMENT TO BE SUBDIVIDED.
C
C  SUBPROGRAM(S) CALLED:
C    MIDNUM
C
C----------------------------------------------------------------------F
C
      INCLUDE 'DINMOD.INC'
C
C---- Declarations
      INTEGER L,IER
C
C---- Dimensions
      DIMENSION KNODE(6)
C
C-----OUTPUT FORMATS
 2010 FORMAT(/1X,'***ERROR #??? - NP TO EXCEED MAXP WITH THE ',
     # 'SUBDIVISION OF ELEMENT ',I5,'.')
 2020 FORMAT(/1X,'***ERROR #??? - NE TO EXCEED MAXE WITH THE ',
     # 'SUBDIVISION OF ELEMENT ',I5,'.')
C
C-----INITIALIZE VALUES
      DO 10 K=1,6
        KNODE(K)=NODE(K)
10    CONTINUE
C
C-----CHECK ON ARRAY DIMENSIONS
      IF(NP+9.GT.MAXP) THEN
        IER=IER+1
        WRITE(IO2,2010) L
      ENDIF
      IF(NE+3.GT.MAXE) THEN
        IER=IER+1
        WRITE(IO2,2020) L
      ENDIF
      IF(IER.GT.0) GOTO 999
C
C-----FIRST (CENTER) ELEMENT
      N1=KNODE(2)
      N2=NP+1
      N3=KNODE(4)
      N4=NP+2
      N5=KNODE(6)
      N6=NP+3
      NP=N6
      NOP(L,1)=N1
      NOP(L,2)=N2
      NOP(L,3)=N3
      NOP(L,4)=N4
      NOP(L,5)=N5
      NOP(L,6)=N6
      CORD(N2,1)=(-CORD(KNODE(1),1)+4.*CORD(KNODE(2),1)+
     # 4.*CORD(KNODE(4),1)-CORD(KNODE(5),1)+2.*CORD(KNODE(6),1))/8.
      CORD(N2,2)=(-CORD(KNODE(1),2)+4.*CORD(KNODE(2),2)+
     # 4.*CORD(KNODE(4),2)-CORD(KNODE(5),2)+2.*CORD(KNODE(6),2))/8.
      GRND(N2)=(GRND(KNODE(1))+2.*GRND(KNODE(3))+GRND(KNODE(5)))/4.
      CEIL(N2)=(CEIL(KNODE(1))+2.*CEIL(KNODE(3))+CEIL(KNODE(5)))/4.
      CORD(N4,1)=(-CORD(KNODE(1),1)+2.*CORD(KNODE(2),1)-
     # CORD(KNODE(3),1)+4.*CORD(KNODE(4),1)+4.*CORD(KNODE(6),1))/8.
      CORD(N4,2)=(-CORD(KNODE(1),2)+2.*CORD(KNODE(2),2)-
     # CORD(KNODE(3),2)+4.*CORD(KNODE(4),2)+4.*CORD(KNODE(6),2))/8.
      GRND(N4)=(GRND(KNODE(1))+GRND(KNODE(3))+2.*GRND(KNODE(5)))/4.
      CEIL(N4)=(CEIL(KNODE(1))+CEIL(KNODE(3))+2.*CEIL(KNODE(5)))/4.
      CORD(N6,1)=(4.*CORD(KNODE(2),1)-CORD(KNODE(3),1)+
     # 2.*CORD(KNODE(4),1)-CORD(KNODE(5),1)+4.*CORD(KNODE(6),1))/8.
      CORD(N6,2)=(4.*CORD(KNODE(2),2)-CORD(KNODE(3),2)+
     # 2.*CORD(KNODE(4),2)-CORD(KNODE(5),2)+4.*CORD(KNODE(6),2))/8.
      GRND(N6)=(2.*GRND(KNODE(1))+GRND(KNODE(3))+GRND(KNODE(5)))/4.
      CEIL(N6)=(2.*CEIL(KNODE(1))+CEIL(KNODE(3))+CEIL(KNODE(5)))/4.
C
C-----SECOND ELEMENT
      N1=KNODE(1)
      N3=KNODE(2)
      N4=NOP(L,6)
      N5=KNODE(6)
      CALL MIDNUM(N1,N3,N2)
      IF(N2.EQ.0) THEN
        NP=NP+1
        N2=NP
        CORD(N2,1)=0.5*(CORD(KNODE(1),1)+CORD(KNODE(2),1))
        CORD(N2,2)=0.5*(CORD(KNODE(1),2)+CORD(KNODE(2),2))
        GRND(N2)=0.5*(GRND(KNODE(1))+GRND(KNODE(2)))
        CEIL(N2)=0.5*(CEIL(KNODE(1))+CEIL(KNODE(2)))
      ENDIF
      CALL MIDNUM(N5,N1,N6)
      IF(N6.EQ.0) THEN
        NP=NP+1
        N6=NP
        CORD(N6,1)=0.5*(CORD(KNODE(6),1)+CORD(KNODE(1),1))
        CORD(N6,2)=0.5*(CORD(KNODE(6),2)+CORD(KNODE(1),2))
        GRND(N6)=0.5*(GRND(KNODE(6))+GRND(KNODE(1)))
        CEIL(N6)=0.5*(CEIL(KNODE(6))+CEIL(KNODE(6)))
      ENDIF
      NE=NE+1
      NOP(NE,1)=N1
      NOP(NE,2)=N2
      NOP(NE,3)=N3
      NOP(NE,4)=N4
      NOP(NE,5)=N5
      NOP(NE,6)=N6
      LMAT(NE)=LMAT(L)
C
C-----THIRD ELEMENT
      N1=KNODE(3)
      N3=KNODE(4)
      N4=NOP(L,2)
      N5=KNODE(2)
      CALL MIDNUM(N1,N3,N2)
      IF(N2.EQ.0) THEN
        NP=NP+1
        N2=NP
        CORD(N2,1)=0.5*(CORD(KNODE(3),1)+CORD(KNODE(4),1))
        CORD(N2,2)=0.5*(CORD(KNODE(3),2)+CORD(KNODE(4),2))
        GRND(N2)=0.5*(GRND(KNODE(3))+GRND(KNODE(4)))
        CEIL(N2)=0.5*(CEIL(KNODE(3))+CEIL(KNODE(4)))
      ENDIF
      CALL MIDNUM(N5,N1,N6)
      IF(N6.EQ.0) THEN
        NP=NP+1
        N6=NP
        CORD(N6,1)=0.5*(CORD(KNODE(2),1)+CORD(KNODE(3),1))
        CORD(N6,2)=0.5*(CORD(KNODE(2),2)+CORD(KNODE(3),2))
        GRND(N6)=0.5*(GRND(KNODE(2))+GRND(KNODE(3)))
        CEIL(N6)=0.5*(CEIL(KNODE(2))+CEIL(KNODE(3)))
      ENDIF
      NE=NE+1
      NOP(NE,1)=N1
      NOP(NE,2)=N2
      NOP(NE,3)=N3
      NOP(NE,4)=N4
      NOP(NE,5)=N5
      NOP(NE,6)=N6
      LMAT(NE)=LMAT(L)
C
C-----FOURTH ELEMENT
      N1=KNODE(5)
      N3=KNODE(6)
      N4=NOP(L,4)
      N5=KNODE(4)
      CALL MIDNUM(N1,N3,N2)
      IF(N2.EQ.0) THEN
        NP=NP+1
        N2=NP
        CORD(N2,1)=0.5*(CORD(KNODE(5),1)+CORD(KNODE(6),1))
        CORD(N2,2)=0.5*(CORD(KNODE(5),2)+CORD(KNODE(6),2))
        GRND(N2)=0.5*(GRND(KNODE(5))+GRND(KNODE(6)))
        CEIL(N2)=0.5*(CEIL(KNODE(5))+CEIL(KNODE(6)))
      ENDIF
      CALL MIDNUM(N5,N1,N6)
      IF(N6.EQ.0) THEN
        NP=NP+1
        N6=NP
        CORD(N6,1)=0.5*(CORD(KNODE(4),1)+CORD(KNODE(5),1))
        CORD(N6,2)=0.5*(CORD(KNODE(4),2)+CORD(KNODE(5),2))
        GRND(N6)=0.5*(GRND(KNODE(4))+GRND(KNODE(5)))
        CEIL(N6)=0.5*(CEIL(KNODE(4))+CEIL(KNODE(5)))
      ENDIF
      NE=NE+1
      NOP(NE,1)=N1
      NOP(NE,2)=N2
      NOP(NE,3)=N3
      NOP(NE,4)=N4
      NOP(NE,5)=N5
      NOP(NE,6)=N6
      LMAT(NE)=LMAT(L)
  999 RETURN
      END
C
C
C
      SUBROUTINE SUBQ8(L,IER)
C
C---- SUBQ8 -----------------------------------------------------------S
C
C  PURPOSE:
C    SUBDIVIDES AN EIGHT-NODE QUADRILATERAL ELEMENT INTO FOUR SIMILAR
C    ELEMENTS BY CONNECTING THE MIDSIDE POINTS OF THE ELEMENT.  THE
C    NUMBER OF ELEMENTS AND NODE POINTS IN THE SYSTEM ARE INCREASED
C    ACCORDINGLY AS EACH NEW ELEMENT IS FORMED.
C
C  INPUT ARGUMENT(S):
C    L - NUMBER OF THE TRIANGULAR ELEMENT TO BE SUBDIVIDED.
C
C  SUBPROGRAM(S) CALLED:
C    MIDNUM
C    8-92: subroutine fixed by jmfulford 
C
C----------------------------------------------------------------------F
C
      INCLUDE 'DINMOD.INC'
C
C---- Declarations
      INTEGER L,IER
C
C---- Dimensions
      DIMENSION KNODE(8)
C
C-----OUTPUT FORMATS
2010  FORMAT(/1X,'***ERROR #??? - NP TO EXCEED MAXP WITH THE ',
     # 'SUBDIVISION OF ELEMENT ',I5,'.')
2020  FORMAT(/1X,'***ERROR #??? - NE TO EXCEED MAXE WITH THE ',
     # 'SUBDIVISION OF ELEMENT ',I5,'.')
C
C-----CHECK ON ARRAY DIMENSIONS
      IF(NP+13.GT.MAXP) THEN
        IER=IER+1
        WRITE(IO2,2010) L
      ENDIF
      IF(NE+3.GT.MAXE) THEN
        IER=IER+1
        WRITE(IO2,2020) L
      ENDIF
C
C-----SAVE INITIAL ELEMENT NODE NUMBERS
      DO 10 K=1,8
        KNODE(K)=NODE(K)
10    CONTINUE
C
C-----FIRST ELEMENT
      N1=KNODE(1)
      N3=KNODE(2)
      N7=KNODE(8)
      NP=NP+1
      N5=NP
      CORD(N5,1)=0.5*(CORD(KNODE(2),1)+CORD(KNODE(4),1)+
     # CORD(KNODE(6),1)+CORD(KNODE(8),1))-0.25*(CORD(KNODE(1),1)+
     # CORD(KNODE(3),1)+CORD(KNODE(5),1)+CORD(KNODE(7),1))
      CORD(N5,2)=0.5*(CORD(KNODE(2),2)+CORD(KNODE(4),2)+
     # CORD(KNODE(6),2)+CORD(KNODE(8),2))-0.25*(CORD(KNODE(1),2)+
     # CORD(KNODE(3),2)+CORD(KNODE(5),2)+CORD(KNODE(7),2))
      GRND(N5)=0.25*(GRND(KNODE(1))+GRND(KNODE(3))+
     # GRND(KNODE(5))+GRND(KNODE(6)))
      CEIL(N5)=0.25*(CEIL(KNODE(1))+CEIL(KNODE(3))+
     # CEIL(KNODE(5))+CEIL(KNODE(6)))
      CALL MIDNUM(N1,N3,N2)
      IF(N2.EQ.0) THEN
        NP=NP+1
        N2=NP
        CORD(N2,1)=0.125*(3.*CORD(KNODE(1),1)+6.*CORD(KNODE(2),1)-
     #  CORD(KNODE(3),1))
        CORD(N2,2)=0.125*(3.*CORD(KNODE(1),2)+6.*CORD(KNODE(2),2)-
     #  CORD(KNODE(3),2))
        GRND(N2)=0.5*(GRND(N1)+GRND(N3))
        CEIL(N2)=0.5*(CEIL(N1)+CEIL(N3))
      ENDIF
      NP=NP+1
      N4=NP
      CORD(N4,1)=(12.*CORD(KNODE(2),1)+6.*CORD(KNODE(4),1)+
     # 4.*CORD(KNODE(6),1)+6.*CORD(KNODE(8),1)-3.*(CORD(KNODE(1),1)+
     # CORD(KNODE(3),1)+CORD(KNODE(5),1)+CORD(KNODE(7),1)))/16.
      CORD(N4,2)=(12.*CORD(KNODE(2),2)+6.*CORD(KNODE(4),2)+
     # 4.*CORD(KNODE(6),2)+6.*CORD(KNODE(8),2)-3.*(CORD(KNODE(1),2)+
     # CORD(KNODE(3),2)+CORD(KNODE(5),2)+CORD(KNODE(7),2)))/16.
      GRND(N4)=0.5*(GRND(N3)+GRND(N5))
      CEIL(N4)=0.5*(CEIL(N3)+CEIL(N5))
      NP=NP+1
      N6=NP
      CORD(N6,1)=(12.*CORD(KNODE(8),1)+6.*CORD(KNODE(2),1)+
     # 4.*CORD(KNODE(4),1)+6.*CORD(KNODE(6),1)-3.*(CORD(KNODE(1),1)+
     # CORD(KNODE(3),1)+CORD(KNODE(5),1)+CORD(KNODE(7),1)))/16.
      CORD(N6,2)=(12.*CORD(KNODE(8),2)+6.*CORD(KNODE(2),2)+
     # 4.*CORD(KNODE(4),2)+6.*CORD(KNODE(6),2)-3.*(CORD(KNODE(1),2)+
     # CORD(KNODE(3),2)+CORD(KNODE(5),2)+CORD(KNODE(7),2)))/16.
      GRND(N6)=0.5*(GRND(N5)+GRND(N7))
      CEIL(N6)=0.5*(CEIL(N5)+CEIL(N7))
      CALL MIDNUM(N7,N1,N8)
      IF(N8.EQ.0) THEN
        NP=NP+1
        N8=NP
        CORD(N8,1)=0.125*(3.*CORD(KNODE(1),1)+6.*CORD(KNODE(8),1)-
     #  CORD(KNODE(7),1))
        CORD(N8,2)=0.125*(3.*CORD(KNODE(1),2)+6.*CORD(KNODE(8),2)-
     #  CORD(KNODE(7),2))
        GRND(N8)=0.5*(GRND(N7)+GRND(N1))
        CEIL(N8)=0.5*(CEIL(N7)+CEIL(N1))
      ENDIF
      NOP(L,1)=N1
      NOP(L,2)=N2
      NOP(L,3)=N3
      NOP(L,4)=N4
      NOP(L,5)=N5
      NOP(L,6)=N6
      NOP(L,7)=N7
      NOP(L,8)=N8
C
C-----SECOND ELEMENT
      N1=KNODE(3)
      N3=KNODE(4)
      N5=NOP(L,5)
      N6=NOP(L,4)
      N7=NOP(L,3)
      CALL MIDNUM(N1,N3,N2)
      IF(N2.EQ.0) THEN
        NP=NP+1
        N2=NP
        CORD(N2,1)=0.125*(3.*CORD(KNODE(3),1)+6.*CORD(KNODE(4),1)-
     #  CORD(KNODE(5),1))
        CORD(N2,2)=0.125*(3.*CORD(KNODE(3),2)+6.*CORD(KNODE(4),2)-
     #  CORD(KNODE(5),2))
        GRND(N2)=0.5*(GRND(N1)+GRND(N3))
        CEIL(N2)=0.5*(CEIL(N1)+CEIL(N3))
      ENDIF
      NP=NP+1
      N4=NP
      CORD(N4,1)=(12.*CORD(KNODE(4),1)+6.*CORD(KNODE(6),1)+
     # 4.*CORD(KNODE(8),1)+6.*CORD(KNODE(2),1)-3.*(CORD(KNODE(1),1)+
     # CORD(KNODE(3),1)+CORD(KNODE(5),1)+CORD(KNODE(7),1)))/16.
      CORD(N4,2)=(12.*CORD(KNODE(4),2)+6.*CORD(KNODE(6),2)+
     # 4.*CORD(KNODE(8),2)+6.*CORD(KNODE(2),2)-3.*(CORD(KNODE(1),2)+
     # CORD(KNODE(3),2)+CORD(KNODE(5),2)+CORD(KNODE(7),2)))/16.
      GRND(N4)=0.5*(GRND(N3)+GRND(N5))
      CEIL(N4)=0.5*(CEIL(N3)+CEIL(N5))
      CALL MIDNUM(N7,N1,N8)
      IF(N8.EQ.0) THEN
        NP=NP+1
        N8=NP
        CORD(N8,1)=0.125*(3.*CORD(KNODE(3),1)+6.*CORD(KNODE(2),1)-
     #  CORD(KNODE(1),1))
        CORD(N8,2)=0.125*(3.*CORD(KNODE(3),2)+6.*CORD(KNODE(2),2)-
     #  CORD(KNODE(1),2))
        GRND(N8)=0.5*(GRND(N7)+GRND(N1))
        CEIL(N8)=0.5*(CEIL(N7)+CEIL(N1))
      ENDIF
      NE=NE+1
      NOP(NE,1)=N1
      NOP(NE,2)=N2
      NOP(NE,3)=N3
      NOP(NE,4)=N4
      NOP(NE,5)=N5
      NOP(NE,6)=N6
      NOP(NE,7)=N7
      NOP(NE,8)=N8
      LMAT(NE)=LMAT(L)
C
C-----THIRD ELEMENT
      N1=KNODE(5)
      N3=KNODE(6)
      N5=NOP(NE,5)
      N6=NOP(NE,4)
      N7=KNODE(4)
      CALL MIDNUM(N1,N3,N2)
      IF(N2.EQ.0) THEN
        NP=NP+1
        N2=NP
        CORD(N2,1)=0.125*(3.*CORD(KNODE(5),1)+6.*CORD(KNODE(6),1)-
     #  CORD(KNODE(7),1))
        CORD(N2,2)=0.125*(3.*CORD(KNODE(5),2)+6.*CORD(KNODE(6),2)-
     #  CORD(KNODE(7),2))
        GRND(N2)=0.5*(GRND(N1)+GRND(N3))
        CEIL(N2)=0.5*(CEIL(N1)+CEIL(N3))
      ENDIF
      NP=NP+1
      N4=NP
      CORD(N4,1)=(12.*CORD(KNODE(6),1)+6.*CORD(KNODE(8),1)+
     # 4.*CORD(KNODE(2),1)+6.*CORD(KNODE(4),1)-3.*(CORD(KNODE(1),1)+
     # CORD(KNODE(3),1)+CORD(KNODE(5),1)+CORD(KNODE(7),1)))/16.
      CORD(N4,2)=(12.*CORD(KNODE(6),2)+6.*CORD(KNODE(8),2)+
     # 4.*CORD(KNODE(2),2)+6.*CORD(KNODE(4),2)-3.*(CORD(KNODE(1),2)+
     # CORD(KNODE(3),2)+CORD(KNODE(5),2)+CORD(KNODE(7),2)))/16.
      GRND(N4)=0.5*(GRND(N3)+GRND(N5))
      CEIL(N4)=0.5*(CEIL(N3)+CEIL(N5))
      CALL MIDNUM(N7,N1,N8)
      IF(N8.EQ.0) THEN
        NP=NP+1
        N8=NP
        CORD(N8,1)=0.125*(3.*CORD(KNODE(5),1)+6.*CORD(KNODE(4),1)-
     #  CORD(KNODE(3),1))
        CORD(N8,2)=0.125*(3.*CORD(KNODE(5),2)+6.*CORD(KNODE(4),2)-
     #  CORD(KNODE(3),2))
        GRND(N8)=0.5*(GRND(N7)+GRND(N1))
        CEIL(N8)=0.5*(CEIL(N7)+CEIL(N1))
      ENDIF
      NE=NE+1
      NOP(NE,1)=N1
      NOP(NE,2)=N2
      NOP(NE,3)=N3
      NOP(NE,4)=N4
      NOP(NE,5)=N5
      NOP(NE,6)=N6
      NOP(NE,7)=N7
      NOP(NE,8)=N8
      LMAT(NE)=LMAT(L)
C
C-----FOURTH ELEMENT
      N1=KNODE(7)
      N3=KNODE(8)
      N4=NOP(L,6)
      N5=NOP(NE,5)
      N6=NOP(NE,4)
      N7=NOP(NE,3)
      CALL MIDNUM(N1,N3,N2)
      IF(N2.EQ.0) THEN
        NP=NP+1
        N2=NP
        CORD(N2,1)=0.125*(3.*CORD(KNODE(7),1)+6.*CORD(KNODE(8),1)-
     #  CORD(KNODE(1),1))
        CORD(N2,2)=0.125*(3.*CORD(KNODE(7),2)+6.*CORD(KNODE(8),2)-
     #  CORD(KNODE(1),2))
        GRND(N2)=0.5*(GRND(N1)+GRND(N3))
        CEIL(N2)=0.5*(CEIL(N1)+CEIL(N3))
      ENDIF
      CALL MIDNUM(N7,N1,N8)
      IF(N8.EQ.0) THEN
        NP=NP+1
        N8=NP
        CORD(N8,1)=0.125*(3.*CORD(KNODE(7),1)+6.*CORD(KNODE(6),1)-
     #  CORD(KNODE(5),1))
        CORD(N8,2)=0.125*(3.*CORD(KNODE(7),2)+6.*CORD(KNODE(6),2)-
     #  CORD(KNODE(5),2))
        GRND(N8)=0.5*(GRND(N7)+GRND(N1))
        CEIL(N8)=0.5*(CEIL(N7)+CEIL(N1))
      ENDIF
      NE=NE+1
      NOP(NE,1)=N1
      NOP(NE,2)=N2
      NOP(NE,3)=N3
      NOP(NE,4)=N4
      NOP(NE,5)=N5
      NOP(NE,6)=N6
      NOP(NE,7)=N7
      NOP(NE,8)=N8
      LMAT(NE)=LMAT(L)
      RETURN
      END
C
C
C
      SUBROUTINE SUBQ9(L,IER)
C
C---- SUBQ9 -----------------------------------------------------------S
C
C  PURPOSE:
C    SUBDIVIDES AN NINE-NODE QUADRILATERAL ELEMENT INTO FOUR SIMILAR
C    ELEMENTS BY CONNECTING THE MIDSIDE POINTS OF THE ELEMENT.  THE
C    NUMBER OF ELEMENTS AND NODE POINTS IN THE SYSTEM ARE INCREASED
C    ACCORDINGLY AS EACH NEW ELEMENT IS FORMED.
C
C  INPUT ARGUMENT(S):
C    L - NUMBER OF THE TRIANGULAR ELEMENT TO BE SUBDIVIDED.
C    IER - ERROR COUNT.
C
C  SUBPROGRAM(S) CALLED:
C    MIDNUM
C
C----------------------------------------------------------------------F
C
      INCLUDE 'DINMOD.INC'
C
C---- Declarations
      INTEGER L,IER
C
C---- Dimensions
      DIMENSION KNODE(9)
C
C---- OUTPUT FORMATS
2010  FORMAT(/1X,'***ERROR #??? - NP TO EXCEED MAXP WITH THE ',
     # 'SUBDIVISION OF ELEMENT ',I5,'.')
2020  FORMAT(/1X,'***ERROR #??? - NE TO EXCEED MAXE WITH THE ',
     # 'SUBDIVISION OF ELEMENT ',I5,'.')
C
C---- CHECK ON ARRAY DIMENSIONS
      IF(NP+16.GT.MAXP) THEN
        IER=IER+1
        WRITE(IO2,2010) L
      ENDIF
      IF(NE+3.GT.MAXE) THEN
        IER=IER+1
        WRITE(IO2,2020) L
      ENDIF
C
C---- SAVE INITIAL ELEMENT NODE NUMBERS
      DO 10 K=1,9
        KNODE(K)=NODE(K)
10    CONTINUE
C
C---- FIRST ELEMENT
      N1=KNODE(1)
      N3=KNODE(2)
      N5=KNODE(9)
      N7=KNODE(8)
      CALL MIDNUM(N1,N3,N2)
      IF(N2.EQ.0) THEN
        NP=NP+1
        N2=NP
        CORD(N2,1)=0.125*(3.*CORD(KNODE(1),1)+6.*CORD(KNODE(2),1)-
     #  CORD(KNODE(3),1))
        CORD(N2,2)=0.125*(3.*CORD(KNODE(1),2)+6.*CORD(KNODE(2),2)-
     #  CORD(KNODE(3),2))
        GRND(N2)=0.5*(GRND(N1)+GRND(N3))
        CEIL(N2)=0.5*(CEIL(N1)+CEIL(N3))
      ENDIF
      NP=NP+1
      N4=NP
      CORD(N4,1)=0.125*(3.*CORD(KNODE(2),1)+6.*CORD(KNODE(9),1)-
     # CORD(KNODE(6),1))
      CORD(N4,2)=0.125*(3.*CORD(KNODE(2),2)+6.*CORD(KNODE(9),2)-
     # CORD(KNODE(6),2))
      GRND(N4)=0.5*(GRND(N3)+GRND(N5))
      CEIL(N4)=0.5*(CEIL(N3)+CEIL(N5))
      NP=NP+1
      N6=NP
      CORD(N6,1)=0.125*(3.*CORD(KNODE(8),1)+6.*CORD(KNODE(9),1)-
     # CORD(KNODE(4),1))
      CORD(N6,2)=0.125*(3.*CORD(KNODE(8),2)+6.*CORD(KNODE(9),2)-
     # CORD(KNODE(4),2))
      GRND(N6)=0.5*(GRND(N5)+GRND(N7))
      CEIL(N6)=0.5*(CEIL(N5)+CEIL(N7))
      CALL MIDNUM(N7,N1,N8)
      IF(N8.EQ.0) THEN
        NP=NP+1
        N8=NP
        CORD(N8,1)=0.125*(3.*CORD(KNODE(1),1)+6.*CORD(KNODE(8),1)-
     #  CORD(KNODE(7),1))
        CORD(N8,2)=0.125*(3.*CORD(KNODE(1),2)+6.*CORD(KNODE(8),2)-
     #  CORD(KNODE(7),2))
        GRND(N8)=0.5*(GRND(N7)+GRND(N1))
        CEIL(N8)=0.5*(CEIL(N7)+CEIL(N1))
      ENDIF
      NP=NP+1
      N9=NP
      CORD(N9,1)=0.5*(CORD(N2,1)+CORD(N4,1)+CORD(N6,1)+CORD(N8,1))-
     # 0.25*(CORD(N1,1)+CORD(N3,1)+CORD(N5,1)+CORD(N7,1))
      CORD(N9,2)=0.5*(CORD(N2,2)+CORD(N4,2)+CORD(N6,2)+CORD(N8,2))-
     # 0.25*(CORD(N1,2)+CORD(N3,2)+CORD(N5,2)+CORD(N7,2))
      GRND(N9)=0.25*(GRND(N1)+GRND(N3)+GRND(N5)+GRND(N7))
      CEIL(N9)=0.25*(CEIL(N1)+CEIL(N3)+CEIL(N5)+CEIL(N7))
      NOP(L,1)=N1
      NOP(L,2)=N2
      NOP(L,3)=N3
      NOP(L,4)=N4
      NOP(L,5)=N5
      NOP(L,6)=N6
      NOP(L,7)=N7
      NOP(L,8)=N8
      NOP(L,9)=N9
C
C---- SECOND ELEMENT
      N1=KNODE(3)
      N3=KNODE(4)
      N5=NOP(L,5)
      N6=NOP(L,4)
      N7=NOP(L,3)
      CALL MIDNUM(N1,N3,N2)
      IF(N2.EQ.0) THEN
        NP=NP+1
        N2=NP
        CORD(N2,1)=0.125*(3.*CORD(KNODE(3),1)+6.*CORD(KNODE(4),1)-
     #  CORD(KNODE(5),1))
        CORD(N2,2)=0.125*(3.*CORD(KNODE(3),2)+6.*CORD(KNODE(4),2)-
     #  CORD(KNODE(5),2))
        GRND(N2)=0.5*(GRND(N1)+GRND(N3))
        CEIL(N2)=0.5*(CEIL(N1)+CEIL(N3))
      ENDIF
      NP=NP+1
      N4=NP
      CORD(N4,1)=0.125*(3.*CORD(KNODE(4),1)+6.*CORD(KNODE(9),1)-
     # CORD(KNODE(8),1))
      CORD(N4,2)=0.125*(3.*CORD(KNODE(4),2)+6.*CORD(KNODE(9),2)-
     # CORD(KNODE(8),2))
      GRND(N4)=0.5*(GRND(N3)+GRND(N5))
      CEIL(N4)=0.5*(CEIL(N3)+CEIL(N5))
      CALL MIDNUM(N7,N1,N8)
      IF(N8.EQ.0) THEN
        NP=NP+1
        N8=NP
        CORD(N8,1)=0.125*(3.*CORD(KNODE(3),1)+6.*CORD(KNODE(2),1)-
     #  CORD(KNODE(1),1))
        CORD(N8,2)=0.125*(3.*CORD(KNODE(3),2)+6.*CORD(KNODE(2),2)-
     #  CORD(KNODE(1),2))
        GRND(N8)=0.5*(GRND(N7)+GRND(N1))
        CEIL(N8)=0.5*(CEIL(N7)+CEIL(N1))
      ENDIF
      NP=NP+1
      N9=NP
      CORD(N9,1)=0.5*(CORD(N2,1)+CORD(N4,1)+CORD(N6,1)+CORD(N8,1))-
     # 0.25*(CORD(N1,1)+CORD(N3,1)+CORD(N5,1)+CORD(N7,1))
      CORD(N9,2)=0.5*(CORD(N2,2)+CORD(N4,2)+CORD(N6,2)+CORD(N8,2))-
     # 0.25*(CORD(N1,2)+CORD(N3,2)+CORD(N5,2)+CORD(N7,2))
      GRND(N9)=0.25*(GRND(N1)+GRND(N3)+GRND(N5)+GRND(N7))
      CEIL(N9)=0.25*(CEIL(N1)+CEIL(N3)+CEIL(N5)+CEIL(N7))
      NE=NE+1
      NOP(NE,1)=N1
      NOP(NE,2)=N2
      NOP(NE,3)=N3
      NOP(NE,4)=N4
      NOP(NE,5)=N5
      NOP(NE,6)=N6
      NOP(NE,7)=N7
      NOP(NE,8)=N8
      NOP(NE,9)=N9
      LMAT(NE)=LMAT(L)
C
C---- THIRD ELEMENT
      N1=KNODE(5)
      N3=KNODE(6)
      N5=NOP(NE,5)
      N6=NOP(NE,4)
      N7=NOP(NE,3)
      CALL MIDNUM(N1,N3,N2)
      IF(N2.EQ.0) THEN
        NP=NP+1
        N2=NP
        CORD(N2,1)=0.125*(3.*CORD(KNODE(5),1)+6.*CORD(KNODE(6),1)-
     #  CORD(KNODE(7),1))
        CORD(N2,2)=0.125*(3.*CORD(KNODE(5),2)+6.*CORD(KNODE(6),2)-
     #  CORD(KNODE(7),2))
        GRND(N2)=0.5*(GRND(N1)+GRND(N3))
        CEIL(N2)=0.5*(CEIL(N1)+CEIL(N3))
      ENDIF
      NP=NP+1
      N4=NP
      CORD(N4,1)=0.125*(3.*CORD(KNODE(6),1)+6.*CORD(KNODE(9),1)-
     # CORD(KNODE(2),1))
      CORD(N4,2)=0.125*(3.*CORD(KNODE(6),2)+6.*CORD(KNODE(9),2)-
     # CORD(KNODE(2),2))
      GRND(N4)=0.5*(GRND(N3)+GRND(N5))
      CEIL(N4)=0.5*(CEIL(N3)+CEIL(N5))
      CALL MIDNUM(N7,N1,N8)
      IF(N8.EQ.0) THEN
        NP=NP+1
        N8=NP
        CORD(N8,1)=0.125*(3.*CORD(KNODE(5),1)+6.*CORD(KNODE(4),1)-
     #  CORD(KNODE(3),1))
        CORD(N8,2)=0.125*(3.*CORD(KNODE(5),2)+6.*CORD(KNODE(4),2)-
     #  CORD(KNODE(3),2))
        GRND(N8)=0.5*(GRND(N7)+GRND(N1))
        CEIL(N8)=0.5*(CEIL(N7)+CEIL(N1))
      ENDIF
      NP=NP+1
      N9=NP
      CORD(N9,1)=0.5*(CORD(N2,1)+CORD(N4,1)+CORD(N6,1)+CORD(N8,1))-
     # 0.25*(CORD(N1,1)+CORD(N3,1)+CORD(N5,1)+CORD(N7,1))
      CORD(N9,2)=0.5*(CORD(N2,2)+CORD(N4,2)+CORD(N6,2)+CORD(N8,2))-
     # 0.25*(CORD(N1,2)+CORD(N3,2)+CORD(N5,2)+CORD(N7,2))
      GRND(N9)=0.25*(GRND(N1)+GRND(N3)+GRND(N5)+GRND(N7))
      CEIL(N9)=0.25*(CEIL(N1)+CEIL(N3)+CEIL(N5)+CEIL(N7))
      NE=NE+1
      NOP(NE,1)=N1
      NOP(NE,2)=N2
      NOP(NE,3)=N3
      NOP(NE,4)=N4
      NOP(NE,5)=N5
      NOP(NE,6)=N6
      NOP(NE,7)=N7
      NOP(NE,8)=N8
      NOP(NE,9)=N9
      LMAT(NE)=LMAT(L)
C
C---- FOURTH ELEMENT
      N1=KNODE(7)
      N3=KNODE(8)
      N4=NOP(L,6)
      N5=NOP(NE,5)
      N6=NOP(NE,4)
      N7=NOP(NE,3)
      CALL MIDNUM(N1,N3,N2)
      IF(N2.EQ.0) THEN
        NP=NP+1
        N2=NP
        CORD(N2,1)=0.125*(3.*CORD(KNODE(7),1)+6.*CORD(KNODE(8),1)-
     #  CORD(KNODE(1),1))
        CORD(N2,2)=0.125*(3.*CORD(KNODE(7),2)+6.*CORD(KNODE(8),2)-
     #  CORD(KNODE(1),2))
        GRND(N2)=0.5*(GRND(N1)+GRND(N3))
        CEIL(N2)=0.5*(CEIL(N1)+CEIL(N3))
      ENDIF
      CALL MIDNUM(N7,N1,N8)
      IF(N8.EQ.0) THEN
        NP=NP+1
        N8=NP
        CORD(N8,1)=0.125*(3.*CORD(KNODE(7),1)+6.*CORD(KNODE(6),1)-
     #  CORD(KNODE(5),1))
        CORD(N8,2)=0.125*(3.*CORD(KNODE(7),2)+6.*CORD(KNODE(6),2)-
     #  CORD(KNODE(5),2))
        GRND(N8)=0.5*(GRND(N7)+GRND(N1))
        CEIL(N8)=0.5*(CEIL(N7)+CEIL(N1))
      ENDIF
      NP=NP+1
      N9=NP
      CORD(N9,1)=0.5*(CORD(N2,1)+CORD(N4,1)+CORD(N6,1)+CORD(N8,1))-
     # 0.25*(CORD(N1,1)+CORD(N3,1)+CORD(N5,1)+CORD(N7,1))
      CORD(N9,2)=0.5*(CORD(N2,2)+CORD(N4,2)+CORD(N6,2)+CORD(N8,2))-
     # 0.25*(CORD(N1,2)+CORD(N3,2)+CORD(N5,2)+CORD(N7,2))
      GRND(N9)=0.25*(GRND(N1)+GRND(N3)+GRND(N5)+GRND(N7))
      CEIL(N9)=0.25*(CEIL(N1)+CEIL(N3)+CEIL(N5)+CEIL(N7))
      NE=NE+1
      NOP(NE,1)=N1
      NOP(NE,2)=N2
      NOP(NE,3)=N3
      NOP(NE,4)=N4
      NOP(NE,5)=N5
      NOP(NE,6)=N6
      NOP(NE,7)=N7
      NOP(NE,8)=N8
      NOP(NE,9)=N9
      LMAT(NE)=LMAT(L)
      RETURN
      END
C
C
C
      SUBROUTINE SMOOTH(NLO,NHI,LLO,LHI,NITSM)
C
C---- SMOOTH ----------------------------------------------------------S
C
C  PURPOSE:
C    SMOOTHS PORTIONS OF THE NETWORK GENERATED IN SUBROUTINE GRDGEN
C    USING AN ITERATIVE PROCEDURE BASED ON THE LAPLACIAN SCHEME.
C
C  INPUT ARGUMENT(S):
C    NLO - LOWEST GENERATED NODE NUMBER.
C    NHI - HIGHEST GENERATED NODE NUMBER (NP).
C    LLO - LOWEST GENERATED ELEMENT NUMBER.
C    LHI - HIGHEST GENERATED ELEMENT NUMBER (NE).
C    NITSM - NUMBER OF SMOOTHING ITERATIONS TO BE PERFORMED.
C
C----------------------------------------------------------------------F
C
      INCLUDE 'DINMOD.INC'
C
C---- OUTPUT FORMATS
2010  FORMAT(/1X,'*** MAXIMUM CHANGE AT SMOOTHING ITERATION NO.',I3,/
     # 1X,'X-COORDINATE - ',F10.2,' AT NODE ',I5/
     # 1X,'Y-COORDINATE - ',F10.2,' AT NODE ',I5)
C
C---- BEGIN SMOOTHING ITERATIONS
      DO 100 IT=1,NITSM
        DXMAX=0.
        DYMAX=0.
        DO 90 N=NLO,NHI
          XSUM=0.
          YSUM=0.
          KSUM=0
          DO 20 NN=1,NP
            NPID(NN)=0
20        CONTINUE
          NPID(N)=1
          DO 60 L=LLO,LHI
            NCN=6
            DO 30 K=1,NCN,2
              IF(N.EQ.NOP(L,K)) GOTO 40
30          CONTINUE
            GOTO 60
40          KSUM=KSUM+1
            DO 50 K=1,NCN,2
              NN=NOP(L,K)
              IF(NPID(NN).LE.0) THEN
                NPID(NN)=1
                XSUM=XSUM+CORD(NN,1)
                YSUM=YSUM+CORD(NN,2)
              ENDIF
50          CONTINUE
60        CONTINUE
          IF(KSUM.NE.0) THEN
            X=XSUM/REAL(KSUM)
            Y=YSUM/REAL(KSUM)
            DX=X-CORD(N,1)
            DY=Y-CORD(N,2)
            IF(ABS(DX).GT.ABS(DXMAX)) THEN
              DXMAX=DX
              NXMAX=N
            END IF
            IF(ABS(DY).GT.ABS(DYMAX)) THEN
              DYMAX=DY
              NYMAX=N
            END IF
            CORD(N,1)=X
            CORD(N,2)=Y
          ENDIF
90      CONTINUE
        WRITE(IO2,2010) IT,DXMAX,NXMAX,DYMAX,NYMAX
100   CONTINUE
999   RETURN
      END
C
C
C
      SUBROUTINE RESEQ(IER)
C
C---- RESEQ -----------------------------------------------------------S
C
C  PURPOSE:
C    CONTROLS ELEMENT RESEQUENCING.  LISTS OF ELEMENTS ADJACENT TO
C    NODES AND ELEMENTS ADJACENT TO OTHER ELEMENTS ARE COMPUTED FIRST.
C    THEN THE MAXIMUM FRONTWIDTH AND THE SEQUENCE SUM FOR THE INITIAL
C    ELEMENT SEQUENCE ARE FOUND.  EACH RESEQUENCING IS THEN PERFORMED
C    AND THE FRONTWIDTH AND SEQUENCE SUM ARE COMPARED WITH THE CURRENT
C    VALUES.  IF AN IMPROVEMENT IS FOUND, THE ELEMENT SEQUENCE ARRAYS
C    ARE UPDATED.  TWO TECHNIQUES ARE AVAILABLE FOR RESEQUENCING -
C    THE LEVEL STRUCTURE METHOD AND THE MINIMUM FRONTGROWTH METHOD.
C
C  OUTPUT ARGUMENT(S):
C    IER - ERROR COUNT.
C
C  MAJOR VARIABLE(S):
C    NWMAX - MAXIMUM FRONTWIDTH FOR A POSSIBLE ELEMENT SEQUENCE.
C    NWSSQ - SEQUENCE SUM FOR A POSSIBLE ELEMENT SEQUENCE.
C    NWMAX1 - MAXIMUM FRONTWIDTH FOR THE CURRENT ELEMENT SEQUENCE.
C    NWSSQ1 - SEQUENCE SUM FOR THE CURRENT ELEMENT SEQUENCE.
C    LRSQ - NUMBER OF ELEMENTS IN THE SEQUENCE.
C    ITYP - CODE FOR TYPE OF RESEQUENCING TO BE PERFORMED
C    MXHLD - MAXIMUM LENGTH OF WAVEFRONT STAY FOR MFG METHOD.
C    LNEW(L) - NEW SEQUENCE OF ELEMENT NUMBER L.
C    LOLD(L) - OLD NUMBER OF ELEMENT SEQUENCE L.
C
C  SUBPROGRAM(S) CALLED:
C    ADJEL, BGNSEQ, MFGSEQ, LEVSEQ
C
C---------------------------------------------------------------------F-F
C
      INCLUDE 'DINMOD.INC'
C
C-----OUTPUT FORMATS
 2000 FORMAT(1X,'***',I5,' ERROR(S) ENCOUNTERED DURING ELEMENT ',
     # 'RESEQUENCING'/)
 2001 FORMAT(/51X,'FOR INITIAL ELEMENT SEQUENCE:'//
     # 53X,'MAXIMUM FRONTWIDTH =',I6/
     # 53X,'SEQUENCE SUM =',I12)
 2002 FORMAT(/51X,'FOR ELEMENT SEQUENCE NO. ',I3,':'//
     # 53X,'MAXIMUM FRONTWIDTH =',I6/
     # 53X,'SEQUENCE SUM =',I12)
 2010 FORMAT(/1X,'ELEMENT SEQUENCE:'/
     # 6X,'MAXIMUM FRONTWIDTH = ',I5/
     # 6X,'SEQUENCE SUM = ',I11/
     # 6X,'SEQUENCE(NUMBER):'/
     # (1X,10(2X,I4,'(',I4,')')))
 2020 FORMAT(/1X,'STARTING ELEMENT SEQUENCE'/1X,19I5/(16X,16I5))
 2030 FORMAT(1X,'***ERROR #240 - PROPERTY TYPE CODE IS ZERO ',
     # 'FOR ELEMENT ',I5,' IN SEQUENCE ',I3)
 2101 FORMAT(/25X,'FOR INITIAL ELEMENT SEQUENCE:'//
     # 27X,'MAXIMUM FRONTWIDTH =',I6/
     # 27X,'SEQUENCE SUM =',I12)
 2102 FORMAT(/25X,'FOR ELEMENT SEQUENCE NO. ',I3,':'//
     # 27X,'MAXIMUM FRONTWIDTH =',I6/
     # 27X,'SEQUENCE SUM =',I12)
 2110 FORMAT(/1X,'ELEMENT SEQUENCE:'/
     # 6X,'MAXIMUM FRONTWIDTH = ',I5/
     # 6X,'SEQUENCE SUM = ',I11/
     # 6X,'SEQUENCE(NUMBER):'/
     # (1X,7(1X,I4,'(',I4,')')))
 2120 FORMAT(/1X,'STARTING ELEMENT SEQUENCE'/1X,15I5/(16X,12I5))
 2500 FORMAT(1H+,79(' ')/1H+,'Computing (element resequencing)...')
C
C-----INITIALIZE VARIABLES
      IF(SCREEN) WRITE(*,2500)
      IER=0
C
C-----COMPUTE ADJACENT ELEMENT LISTS
      CALL ADJEL(IER)
      IF(IER.GT.0) RETURN
C
C-----COMPUTE INITIAL FRONTWIDTH AND SEQUENCE SUM
      CALL BGNSEQ(LKNT1,NWMAX1,NWSSQ1,IER)
      IF(IER.GT.0) THEN
        WRITE(IO2,2000) IER
        RETURN
      ENDIF
      IF(WIDE) THEN
        WRITE(IO2,2001) NWMAX1,NWSSQ1
      ELSE
        WRITE(IO2,2101) NWMAX1,NWSSQ1
      ENDIF
C
C-----BEGIN ELEMENT RESEQUENCING
      DO 50 K=1,NRSQ
        LKNT=0
        DO 20 J=1,56
          L=LRSQ(K,J)
          IF(L.EQ.0) GOTO 21
          IF(LMAT(L).EQ.0) THEN
            IER=IER+1
            WRITE(IO2,2030) L,K
            GOTO 50
          ENDIF
          LOLD(J)=L
          LKNT=LKNT+1
   20   CONTINUE
   21   IF(LKNT.EQ.0) GOTO 50
        IF(MOD(IPRNT,16).GT.7) THEN
          IF(WIDE) THEN
            WRITE(IO2,2020) IRSQ(K),MHLD(K),LKNT,
     #      (LRSQ(K,J),J=1,LKNT)
          ELSE
            WRITE(IO2,2120) IRSQ(K),MHLD(K),LKNT,
     #      (LRSQ(K,J),J=1,LKNT)
          ENDIF
        ENDIF
C
C-------CALL APPROPRIATE RESEQUENCING SCHEME
        IF(IRSQ(K).EQ.1) THEN
          CALL MFGSEQ(LKNT,LKNT1,MHLD(K),NWMAX,NWSSQ,IER)
        ELSEIF(IRSQ(K).EQ.2) THEN
          CALL LEVSEQ(LKNT,LKNT1,NWMAX,NWSSQ,IER)
        ENDIF
        IF(IER.GT.0) GOTO 40
C
C-------PRINT SEQUENCE PARAMETERS
        IF(WIDE) THEN
          WRITE(IO2,2002) K,NWMAX,NWSSQ
        ELSE
          WRITE(IO2,2102) K,NWMAX,NWSSQ
        ENDIF
C
C-------CHECK FOR SUPERIOR SEQUENCE
        IF(NWMAX-NWMAX1) 24,22,40
   22   IF(NWSSQ-NWSSQ1) 24,40,40
C
C-------UPDATE MAXIMUM FRONTWIDTH AND SEQUENCE SUM
   24   NWMAX1=NWMAX
        NWSSQ1=NWSSQ
C
C-------ASSIGN NEW ELEMENT SEQUENCES
        DO 26 L=1,NE
          LSEQ(L)=LNEW(L)
          ISEQ(L)=LOLD(L)
   26   CONTINUE
C
C-------CHECK FOR ERRORS
   40   IF(IER.GT.0) WRITE(IO2,2000) IER
   50 CONTINUE
C
C-----PRINT FINAL ELEMENT SEQUENCE THEN RETURN TO MAIN PROGRAM
      IF(WIDE) THEN
        WRITE(IO2,2010) NWMAX1,NWSSQ1,(L,ISEQ(L),L=1,LKNT)
      ELSE
        WRITE(IO2,2110) NWMAX1,NWSSQ1,(L,ISEQ(L),L=1,LKNT)
      ENDIF
      RETURN
      END
C
C
C
      SUBROUTINE ADJEL(IER)
C
C---- ADJEL -----------------------------------------------------------S
C
C  PURPOSE:
C    FORMS A LIST OF ELEMENTS ADJACENT TO EACH NODE AND A LIST OF
C    ELEMENTS ADJACENT TO EACH ELEMENT.  IN ADDITION, THE TOTAL NUMBER
C    OF ELEMENTS ADJACENT TO EACH ELEMENT AND THE TOTAL NUMBER OF
C    ELEMENTS ADJACENT TO EACH NODE ARE COMPUTED.
C
C  OUTPUT ARGUMENT(S):
C    IER - ERROR COUNT.
C
C  SUBPROGRAM(S) CALLED:
C    LNODES
C
C----------------------------------------------------------------------F
C
      INCLUDE 'DINMOD.INC'
C
C-----OUTPUT FORMATS
 2004 FORMAT(1X,'***ERROR #270 - NO. OF ELEMENTS ADJACENT TO NODE ',
     # I5,' EXCEEDS 10')
 2005 FORMAT(1X,'***ERROR #280 - NO. OF ELEMENTS ADJACENT TO ELEMENT ',
     # I5,' EXCEEDS 20')
 2010 FORMAT(/2X,'NODE NEIGH  ADJACENT ELEMENTS'//(12I6))
 2020 FORMAT(/2X,'ELMT LNEXT  ADJACENT ELEMENTS'//(22I6))
 2120 FORMAT(/2X,'ELMT LNEXT  ADJACENT ELEMENTS'//(12I6/12X,10I6))
C
C-----INITIALIZE VARAIBLES
      IER=0
      DO 20 N=1,NP
        NEIGH(N)=0
        DO 10 K=1,10
          LADJN(N,K)=0
   10   CONTINUE
   20 CONTINUE
      DO 40 L=1,NE
        LNEXT(L)=0
        DO 30 K=1,20
          LADJL(L,K)=0
   30   CONTINUE
   40 CONTINUE
C
C-----FORM LISTS OF ELEMENTS ADJACENT TO NODES
      DO 100 L=1,NE
        IF(LMAT(L).EQ.0) GOTO 100
        CALL LNODES(L,NCN)
        DO 90 K=1,NCN
          N=NODE(K)
          M=NEIGH(N)
          M=M+1
          NEIGH(N)=M
          IF(M.LT.11) THEN
            LADJN(N,M)=L
          ELSEIF(M.EQ.11) THEN
            IER=IER+1
            WRITE(IO2,2004) N
          ENDIF
   90   CONTINUE
  100 CONTINUE
C
C-----PRINT LIST OF ADJACENT ELEMENTS
      IF(MOD(IPRNT,16).GT.7) THEN
        WRITE(IO2,2010)(N,NEIGH(N),(LADJN(N,K),K=1,10),N=1,NP)
      ENDIF
C
C-----FORM LISTS OF ELEMENTS ADJACENT TO ELEMENTS
      DO 200 L=1,NE
        IF(LMAT(L).EQ.0) GOTO 200
        CALL LNODES(L,NCN)
        DO 190 J=1,NCN
          N=NODE(J)
          NN=NEIGH(N)
          DO 180 K=1,NN
            LL=LADJN(N,K)
            IF(L.EQ.LL) GOTO 180
            LN=LNEXT(L)
            IF(LN.GT.0) THEN
              DO 170 M=1,LN
                IF(LL.EQ.LADJL(L,M)) GOTO 180
  170         CONTINUE
            ENDIF
            LN=LN+1
            LNEXT(L)=LN
            IF(LN.LT.21) THEN
              LADJL(L,LN)=LL
            ELSEIF(LN.EQ.21) THEN
              WRITE(IO2,2005) L
              IER=IER+1
            ENDIF
  180     CONTINUE
  190   CONTINUE
  200 CONTINUE
C
C-----PRINT LIST OF ADJACENT ELEMENTS
      IF(MOD(IPRNT,16).GT.7) THEN
        IF(WIDE) THEN
          WRITE(IO2,2020) (L,LNEXT(L),(LADJL(L,K),K=1,20),L=1,NE)
        ELSE
          WRITE(IO2,2120) (L,LNEXT(L),(LADJL(L,K),K=1,20),L=1,NE)
        ENDIF
      ENDIF
      RETURN
      END
C
C
C
      SUBROUTINE BGNSEQ(LKNT1,NWMAX,NWSSQ,IER)
C
C---- BGNSEG ----------------------------------------------------------S
C
C  PURPOSE:
C    COMPUTES THE FRONTWIDTH AND SEQUENCE SUM FOR THE INITIAL ELEMENT
C    ORDER.  WITH THE ADDITION OF AN ELEMENT TO THE WAVEFRONT, THE
C    FRONTWIDTH IS COMPUTED AS THE SUM OF THE PREVIOUS FRONTWIDTH,
C    PLUS THOSE NODES MAKING THEIR FIRST APPEARANCE WITH THE NEW
C    ELEMENT, MINUS THOSE NODES MAKING THEIR LAST APPEARANCE WITH THE
C    PREVIOUS ELEMENT.  THE SEQUENCE SUM IS THE SUM OF THE ELEMENT
C    FRONTWIDTHS SQUARED.
C
C  INPUT ARGUMENT(S):
C    IER - ERROR COUNT
C
C  OUTPUT ARGUMENT(S):
C    LKNT1 - NUMBER OF ELEMENTS IN THE INITIAL SEQUENCE.
C    NWSSQ - MAXIMUM FRONTWIDTH.
C    NWSSQ - SEQUENCE SUM, SUM OF FRONTWIDTHS SQUARED.
C    IER - ERROR COUNT.
C
C  SUBPROGRAM(S) CALLED:
C    LNODES
C
C----------------------------------------------------------------------F
C
      INCLUDE 'DINMOD.INC'
C
C-----OUTPUT FORMATS
 2001 FORMAT(1X,'***ERROR #245 - ADJACENT ELEMENT LIST FOR NODE ',I5,
     # ' IN ELEMENT ',I5)
 2002 FORMAT(1X,'***ERROR #250 - FRONTWIDTH DOES NOT VANISH WITH LAST ',
     # 'ELEMENT')
 2003 FORMAT(1X,'***ERROR #260 - SEQUENCE ',I4,' FOR ELEMENT ',I4,
     # ' IS TOO LARGE')
 2010 FORMAT(/2X,'SEQUENCE',4X,'NUMBER',5X,'NWAVE',5X,'NFRST',5X,
     # 'NLAST'/)
 2011 FORMAT(5I10)
C
C-----INITIALIZE DATA
      LKNT1=0
      DO 10 N=1,MAXP
        NOLAN(N)=NEIGH(N)
        LFRST(N)=0
   10 CONTINUE
      DO 20 L=1,NE
        ISEQ(L)=0
   20 CONTINUE
      DO 30 L=1,NE
        IF(LMAT(L).NE.0 .AND. LSEQ(L).GT.LKNT1) LKNT1=LSEQ(L)
   30 CONTINUE
      DO 36 L=1,NE
        IF(LMAT(L).EQ.0) GOTO 36
        J=LSEQ(L)
        IF(J.EQ.0) THEN
          LKNT1=LKNT1+1
          J=LKNT1
          LSEQ(L)=J
        ENDIF
        IF(J.GT.MAXE) THEN
          IER=IER+1
          WRITE(IO2,2003) J,L
        ELSE
          ISEQ(J)=L
        ENDIF
   36 CONTINUE
      NWMAX=0
      NWSSQ=0
      NWAVE=0
      NLAST=0
C
C-----PRINT INITIAL SEQUENCE HEADING
      IF(MOD(IPRNT,16).GT.7) WRITE(IO2,2010)
C
C-----SCAN ELEMENTS IN SEQUENCE
      DO 60 J=1,LKNT1
        L=ISEQ(J)
        IF(L.EQ.0) GOTO 60
C
C-------FIND THE NUMBER OF NODES MAKING THEIR FIRST APPEARANCE
        CALL LNODES(L,NCN)
        NFRST=0
        DO 40 K=1,NCN
          N=NODE(K)
          IF(LFRST(N).EQ.0) THEN
            NFRST=NFRST+1
            LFRST(N)=L
          ENDIF
   40   CONTINUE
C
C-------COMPUTE FRONTWIDTH AND SEQUENCE SUM
        NWAVE=NWAVE+NFRST-NLAST
        NWSSQ=NWSSQ+NWAVE*NWAVE
        IF(NWAVE.GT.NWMAX) NWMAX=NWAVE
C
C-------FIND THE NUMBER OF NODES MAKING THEIR LAST APPEARANCE
        NLAST=0
        DO 50 K=1,NCN
          N=NODE(K)
          NOLAN(N)=NOLAN(N)-1
          IF(NOLAN(N).LE.0) THEN
            IF(NOLAN(N).LT.0) THEN
              IER=IER+1
              WRITE(IO2,2001) N,L
            ENDIF
            NOLAN(N)=-L
            NLAST=NLAST+1
          ENDIF
   50   CONTINUE
C
C-------PRINT WAVEFRONT VALUES FOR THE CURRENT ELEMENT
        IF(MOD(IPRNT,16).GT.7) WRITE(IO2,2011) J,ISEQ(J),NWAVE,NFRST,
     #  NLAST
   60 CONTINUE
C
C-----CHECK ON FINAL FRONTWIDTH
      IF(NWAVE.NE.NLAST) THEN
        IER=IER+1
        WRITE(IO2,2002)
      ENDIF
  999 RETURN
      END
C
C
C
      SUBROUTINE LEVSEQ(LKNT,LKNT1,NWMAX,NWSSQ,IER)
C
C---- LEVSEQ ----------------------------------------------------------S
C
C  PURPOSE:
C    RESEQUNCES ELEMENTS BY THE LEVEL STRUCTURE METHOD (OR CUTHILL-MCKEE
C    METHOD) BASED ON ELEMENTS RATHER THAN NODES.
C
C  INPUT ARGUMENT(S):
C    LKNT - NUMBER OF ELEMENTS IN THE STARTING SEQUENCE.
C
C  OUTPUT ARGUMENT(S):
C    LKNT - NUMBER OF RESEQUENCED ELEMENTS.
C    NWMAX - MAXIMUM FRONTWIDTH.
C    NWSSQ - SEQUENCE SUM.
C    IER - ERROR COUNT.
C
C----------------------------------------------------------------------F
C
      INCLUDE 'DINMOD.INC'
C
C-----OUTPUT FORMATS
2001  FORMAT(1X,'***ERROR #245 - ERROR IN ADJACENT ELEMENT LIST FOR ',
     # 'NODE ',I5,' IN ELEMENT ',I5)
2005  FORMAT(1X,'***ERROR #250 - FRONTWIDTH DOES NOT VANISH WITH LAST ',
     # 'ELEMENT')
2020  FORMAT(5I6,4X,18I5/(40X,18I5))
2030  FORMAT(10X,3I10)
2050  FORMAT(1X,'***WARNING #120 - ELEMENT ',I5,' IS UNATTACHED')
C-----INITIALIZE VARIABLES
      IER=0
      DO 10 N=1,NP
         LFRST(N)=0
         NOLAN(N)=NEIGH(N)
10    CONTINUE
      DO 20 L=1,NE
         LNEW(L)=0
20    CONTINUE
      DO 30 J=1,MAXLW
         LWAVE(J)=0
30    CONTINUE
      NWMAX=0
      NWAVE=0
      NLAST=0
      NWSSQ=0
      LW=0
C
C-----SCAN STARTING ELEMENT LIST
      DO 90 J=1,LKNT
        L=LOLD(J)
        LNEW(L)=J
C
C-------FIND THE NUMBER OF NODES MAKING THEIR FIRST APPEARANCE.
        NCN=6
        IF(NOP(L,7).GT.0) NCN=8
        IF(NOP(L,9).GT.0) NCN=9
        NFRST=0
        DO 40 K=1,NCN
          N=NOP(L,K)
          IF(LFRST(N).GT.0) GOTO 40
          NFRST=NFRST+1
          LFRST(N)=L
40      CONTINUE
C
C-------COMPUTE FRONTWIDTH AND SEQUENCE SUM
        NWAVE=NWAVE+NFRST-NLAST
        IF(NWAVE.GT.NWMAX) NWMAX=NWAVE
        NWSSQ=NWSSQ+NWAVE*NWAVE
C
C-------FIND THE NUMBER OF NODES MAKING THEIR LAST APPEARANCE
        NLAST=0
        DO 50 K=1,NCN
          N=NOP(L,K)
          NOLAN(N)=NOLAN(N)-1
CD        IF(MOD(IPRNT,16).GT.7) WRITE(IO2,2030) L,N,NOLAN(N)
          IF(NOLAN(N).LE.0) THEN
            IF(NOLAN(N).LT.0) THEN
              IER=IER+1
              WRITE(IO2,2001) N,L
            ENDIF
            NOLAN(N)=-L
            NLAST=NLAST+1
          ENDIF
50      CONTINUE
C
C-------REMOVE L FROM THE LIST OF ELEMENTS ADJACENT TO THE WAVEFRONT
        IF(J.EQ.1) GOTO 61
        DO 60 K=2,LW
          LWAVE(K-1)=LWAVE(K)
60      CONTINUE
        LW=LW-1
C
C-------ADD NEWLY ACTIVE ELEMENTS TO THE LIST
61      LN=LNEXT(L)
        DO 70 K=1,LN
          LL=LADJL(L,K)
          IF(LNEW(LL).EQ.0) THEN
            LW=LW+1
            LNEW(LL)=-1
            LWAVE(LW)=LL
          ENDIF
70      CONTINUE
C
C-------PRINT WAVEFRONT VALUES FOR THE CURRENT ELEMENT
        IF(MOD(IPRNT,16).GT.7) WRITE(IO2,2020) J,LOLD(J),NWAVE,NFRST,
     #  NLAST
        IF(MOD(IPRNT,16).GT.15) WRITE(IO2,2020) J,LOLD(J),NWAVE,NFRST,
     #  NLAST,(LWAVE(K),K=1,LW)
90    CONTINUE
C
C-----ADD NEXT ELEMENT TO THE WAVEFRONT
100   NEXTL=LWAVE(1)
C
C-----UPDATE VARIABLES.
200   LKNT=LKNT+1
      L=NEXTL
      LNEW(L)=LKNT
      LOLD(LKNT)=L
C
C-----FIND THE NUMBER OF NODES MAKING THEIR FIRST APPEARANCE
      NCN=6
      IF(NOP(L,7).GT.0) NCN=8
      IF(NOP(L,9).GT.0) NCN=9
      NFRST=0
      DO 210 K=1,NCN
        N=NOP(L,K)
        IF(LFRST(N).LE.0) THEN
          NFRST=NFRST+1
          LFRST(N)=L
        ENDIF
210   CONTINUE
C
C-----COMPUTE FRONTWIDTH AND UPDATE RESEQUENCING SUM
      NWAVE=NWAVE+NFRST-NLAST
      IF(NWAVE.GT.NWMAX) NWMAX=NWAVE
      NWSSQ=NWSSQ+NWAVE*NWAVE
C
C-----FIND THE NUMBER OF NODES MAKING THEIR LAST APPEARANCE
      NLAST=0
      DO 220 K=1,NCN
        N=NOP(L,K)
        NOLAN(N)=NOLAN(N)-1
CD      IF(IPRNT.GT.2) WRITE(IO2,2030 L,N,NOLAN(N)
        IF(NOLAN(N).LE.0) THEN
          IF(NOLAN(N).LT.0) THEN
            IER=IER+1
            WRITE(IO2,2001) N,L
          ENDIF
          NOLAN(N)=-L
          NLAST=NLAST+1
        ENDIF
220   CONTINUE
C
C-----REMOVE L FROM THE LIST OF ELEMENTS ADJACENT TO THE WAVEFRONT
      DO 230 K=2,LW
        LWAVE(K-1)=LWAVE(K)
230   CONTINUE
      LW=LW-1
C
C-----ADD NEWLY ACTIVE ELEMENTS TO THE LIST
      LN=LNEXT(L)
      DO 240 K=1,LN
        LL=LADJL(L,K)
        IF(LNEW(LL).EQ.0) THEN
          LW=LW+1
          LNEW(LL)=-1
          LWAVE(LW)=LL
        ENDIF
240   CONTINUE
C
C-----PRINT WAVEFRONT VALUES FOR THE CURRENT ELEMENT
      IF(MOD(IPRNT,16).GT.7) WRITE(IO2,2020)LKNT,LOLD(LKNT),NWAVE,
     # NFRST,NLAST
      IF(MOD(IPRNT,32).GT.15) WRITE(IO2,2020) LKNT,LOLD(LKNT),NWAVE,
     # NFRST,NLAST,(LWAVE(J),J=1,LW)
C
C-----END ELEMENT RESEQUENCING LOOP
      IF(LW.GT.0) GOTO 100
C
C-----CHECK FOR UNATTACHED ELEMENTS
      IF(LKNT.EQ.LKNT1) GOTO 300
      DO 260 L=1,NE
        IF(LMAT(L).EQ.0) GOTO 260
        IF(LNEW(L).GT.0) GOTO 260
        WRITE(IO2,2050) L
        NEXTL=L
        GOTO 200
260   CONTINUE
C
C-----CHECK ON FINAL FRONTWIDTH
300   IF(NWAVE.NE.NLAST) THEN
        WRITE(IO2,2005)
        IER=IER+1
      ENDIF
999   RETURN
      END
C
C
C
      SUBROUTINE MFGSEQ(LKNT,LKNT1,MXHLD,NWMAX,NWSSQ,IER)
C
C---- MFGSEQ ----------------------------------------------------------S
C
C  PURPOSE:
C    COMPUTES AN INTERNAL REORDERING OF THE NETWORK ELEMENTS BY THE
C    MINIMUM FRONTGROWTH METHOD TO OBTAIN THE MOST EFFICIENT FRONTAL
C    SOLUTION POSSIBLE.  THE ALGORITHM SEEKS TO KEEP THE SIZE OF THE
C    WAVEFRONT TO A MINIMUM WITH THE ADDITION OF EACH NEW ELEMENT.
C    EACH ACTIVE ELEMENT THAT HAS NOT BEEN REORDERED IS EXAMINED AND
C    THE ONE THAT INCREASES THE FRONTWIDTH THE LEAST IS ASSEMBLED NEXT.
C    SEVEREL CRITERIA ARE USED TO BREAK TIES BETWEEN ELEMENTS AT EACH
C    SELECTION.
C
C  INPUT ARGUMENT(S):
C    LKNT - NUMBER OF ELEMENTS IN THE STARTING LIST.
C    LKNT1 - NUMBER OF ELEMENTS IN THE INITIAL SEQUENCE.
C    MXHLD - MAXIMUM LENGTH OF STAY IN THE ELEMENT WAVEFRONT.
C    IER - ERROR COUNT.
C
C  OUTPUT ARGUMENT(S):
C    LKNT - NUMBER OF RESEQUENCED ELEMENTS.
C    NWMAX - MAXIMUM FRONTWIDTH.
C    NWSSQ - RESEQUENCING SUM, SUM OF FRONTWIDTHS SQUARED.
C    IER - ERROR COUNT.
C
C  MAJOR VARIABLES:
C    LADJN(N,K) - LIST OF UP TO K ELEMENTS ADJACENT TO NODE N.
C    LADJL(L,K) - LIST OF UP TO K ELEMENTS ADJACENT TO ELEMENT L.
C    NEIGH(N) - NUMBER OF ELEMENTS ADJACENT TO NODE N
C    NOLAN(N) - NUMBER OF UNSEQUENCED ELEMENTS ADJACENT TO NODE N.
C    LFRST(N) - ELEMENT SEQUENCE IN WHICH NODE N FIRST APPEARS.
C    NWAVE - NUMBER OF NODES IN THE WAVEFRONT AT AN ELEMENT.
C    NFRST - NUMBER OF NODES MAKING THEIR FIRST APPEARANCE.
C    NLAST - NUMBER OF NODES MAKING THEIR LAST APPEARANCE.
C    LNEW(L) - NEW SEQUENCE OF ELEMENT NUMBER L.
C    LOLD(L) - OLD NUMBER OF ELEMENT SEQUENCE L.
C    LWAVE(K) - LIST OF UP TO K ACTIVE ELEMENTS IN THE WAVEFRONT.
C
C----------------------------------------------------------------------F
C
      INCLUDE 'DINMOD.INC'
      LOGICAL LFND
C
C-----OUTPUT FORMATS
2001  FORMAT(1X,'***ERROR #245 - ERROR IN ADJACENT ELEMENT LIST FOR ',
     # 'NODE ',I5,' IN ELEMENT ',I5)
2005  FORMAT(1X,'***ERROR #250 - FRONTWIDTH DOES NOT VANISH WITH LAST ',
     # 'ELEMENT')
2020  FORMAT(6I6,4X,18I5/(40X,18I5))
2030  FORMAT(10X,3I10)
2050  FORMAT(1X,'***WARNING #120 - ELEMENT ',I5,' IS UNATTACHED')
C
C-----INITIALIZE VARIABLES
      IER=0
      DO 10 N=1,NP
        LFRST(N)=0
        NOLAN(N)=NEIGH(N)
10    CONTINUE
      DO 20 L=1,NE
        LNEW(L)=0
        NOLAL(L)=LNEXT(L)
20    CONTINUE
      DO 30 J=1,MAXLW
        LWAVE(J)=0
        IHOLD(J)=0
30    CONTINUE
      NWMAX=0
      NWAVE=0
      NLAST=0
      NWSSQ=0
      LW=0
C
C-----SCAN STARTING ELEMENT LIST
      DO 90 J=1,LKNT
        L=LOLD(J)
        LNEW(L)=J
C
C-------FIND THE NUMBER OF NODES MAKING THEIR FIRST APPEARANCE.
        NCN=6
        IF(NOP(L,7).GT.0) NCN=8
        IF(NOP(L,9).GT.0) NCN=9
        NFRST=0
        DO 40 K=1,NCN
          N=NOP(L,K)
          IF(LFRST(N).LE.0) THEN
            NFRST=NFRST+1
            LFRST(N)=L
          ENDIF
40      CONTINUE
C
C-------COMPUTE FRONTWIDTH AND SEQUENCE SUM
        NWAVE=NWAVE+NFRST-NLAST
        IF(NWAVE.GT.NWMAX) NWMAX=NWAVE
        NWSSQ=NWSSQ+NWAVE*NWAVE
C
C-------FIND THE NUMBER OF NODES MAKING THEIR LAST APPEARANCE
        NLAST=0
        DO 50 K=1,NCN
          N=NOP(L,K)
          NOLAN(N)=NOLAN(N)-1
CD        IF(MOD(IPRNT,16).GT.7) WRITE(IO2,2030) L,N,NOLAN(N)
          IF(NOLAN(N).LE.0) THEN
            IF(NOLAN(N).LT.0) THEN
              IER=IER+1
              WRITE(IO2,2001) N,L
            ENDIF
            NOLAN(N)=-L
            NLAST=NLAST+1
          ENDIF
50      CONTINUE
C
C-------REMOVE L FROM THE LIST OF ELEMENTS ADJACENT TO THE WAVEFRONT
        IF(J.GT.1) THEN
          LFND=.FALSE.
          DO 60 K=1,LW
            IF(LFND) THEN
              LWAVE(K-1)=LWAVE(K)
              IHOLD(K-1)=IHOLD(K)
            ELSE
              IF(LWAVE(K).EQ.L) LFND=.TRUE.
            ENDIF
60        CONTINUE
          IF(LFND) LW=LW-1
        ENDIF
C
C-------ADD NEWLY ACTIVE ELEMENTS TO THE LIST
        LN=LNEXT(L)
        DO 70 K=1,LN
          LL=LADJL(L,K)
          IF(LNEW(LL).EQ.0) THEN
            LW=LW+1
            LNEW(LL)=-1
            LWAVE(LW)=LL
            IHOLD(LW)=0
          ENDIF
          NOLAL(LL)=NOLAL(LL)-1
70      CONTINUE
C
C-------UPDATE THE LENGTH OF STAY COUINTER
        DO 80 K=1,LW
          IHOLD(K)=IHOLD(K)+1
80      CONTINUE
C
C-------PRINT WAVEFRONT VALUES FOR THE CURRENT ELEMENT
        IF(MOD(IPRNT,16).GT.7) WRITE(IO2,2020) J,LOLD(J),NWAVE,NFRST,
     #  NLAST,IHOLD(1)
        IF(MOD(IPRNT,32).GT.15) WRITE(IO2,2020) J,LOLD(J),NWAVE,NFRST,
     #  NLAST,IHOLD(1),(LWAVE(K),K=1,LW)
90    CONTINUE
C
C-----BEGIN ELEMENT RESEQUENCING LOOP
100   IF(IHOLD(1).GE.MXHLD) THEN
        NEXTL=LWAVE(1)
        GOTO 200
      ENDIF
C
C-----INITIALIZE VARIABLES
      MININ=NP+1
      MXOUT1=0
      MXOUT2=0
      MAXACT=0
      MINDEG=NE+1
C
C-----SCAN LIST OF ELEMENTS ADJACENT TO THE WAVEFRONT
      DO 190 J=1,LW
        L=LWAVE(J)
C
C-------INITIALIZE COUNTERS FOR CANDIDATE L
        KOUNT1=0
        KOUNT2=0
        KOUNT4=0
        KOUNT5=0
C
C-------UPDATE COUNTERS FOR CANDIDATE L
        NCN=6
        IF(NOP(L,7).GT.0) NCN=8
        IF(NOP(L,9).GT.0) NCN=9
        DO 105 K=1,NCN
          N=NOP(L,K)
C---------FIRST APPEARANCE OF NODE N
          IF(LFRST(N).EQ.0) KOUNT1=KOUNT1+1
C---------LAST APPEARANCE OF NODE AT CURRENT LEVEL
          IF(NOLAN(N).EQ.1) KOUNT2=KOUNT2+1
C---------CURRENTLY ACTIVE NODE
          IF(LFRST(N).GT.0) KOUNT4=KOUNT4+1
C---------POSSIBLE LAST APPEARANCE OF NODE AT NEXT LEVEL
          IF(NOLAN(N).EQ.2) KOUNT5=KOUNT5+1
105     CONTINUE
        KOUNT3=NOLAL(L)
C
C-------TEST ELEMENT SELECTION CRITERIA
        IF(KOUNT1-MININ) 130,110,160
110     IF(KOUNT2-MXOUT1)160,115,135
115     IF(KOUNT3-MINDEG)140,120,160
120     IF(KOUNT4-MAXACT)160,125,145
125     IF(KOUNT5-MXOUT2)160,160,150
130     MININ=KOUNT1
135     MXOUT1=KOUNT2
140     MINDEG=KOUNT3
145     MAXACT=KOUNT4
150     MXOUT2=KOUNT5
        NEXTL=L
160     CONTINUE
190   CONTINUE
C
C-----SELECTION COMPLETED.  UPDATE VARIABLES AND COMPUTE FRONT VALUES.
200   LKNT=LKNT+1
      L=NEXTL
      LNEW(L)=LKNT
      LOLD(LKNT)=L
C
C-----FIND THE NUMBER OF NODES MAKING THEIR FIRST APPEARANCE
      NCN=6
      IF(NOP(L,7).GT.0) NCN=8
      IF(NOP(L,9).GT.0) NCN=9
      NFRST=0
      DO 210 K=1,NCN
        N=NOP(L,K)
        IF(LFRST(N).LE.0) THEN
          NFRST=NFRST+1
          LFRST(N)=L
        ENDIF
210   CONTINUE
C
C-----COMPUTE FRONTWIDTH AND UPDATE RESEQUENCING SUM
      NWAVE=NWAVE+NFRST-NLAST
      IF(NWAVE.GT.NWMAX) NWMAX=NWAVE
      NWSSQ=NWSSQ+NWAVE*NWAVE
C
C-----FIND THE NUMBER OF NODES MAKING THEIR LAST APPEARANCE
      NLAST=0
      DO 220 K=1,NCN
        N=NOP(L,K)
        NOLAN(N)=NOLAN(N)-1
CD      IF(IPRNT.GT.2) WRITE(IO2,2030) L,N,NOLAN(N)
        IF(NOLAN(N).LE.0) THEN
          IF(NOLAN(N).LT.0) THEN
            IER=IER+1
            WRITE(IO2,2001) N,L
          ENDIF
          NOLAN(N)=-L
          NLAST=NLAST+1
        ENDIF
220   CONTINUE
C
C-----REMOVE L FROM THE LIST OF ELEMENTS ADJACENT TO THE WAVEFRONT
      LFND=.FALSE.
      DO 230 K=1,LW
        IF(LFND) THEN
          LWAVE(K-1)=LWAVE(K)
          IHOLD(K-1)=IHOLD(K)
        ELSE
          IF(LWAVE(K).EQ.L) LFND=.TRUE.
        ENDIF
230   CONTINUE
      LW=LW-1
C
C-----ADD NEWLY ACTIVE ELEMENTS TO THE LIST
      LN=LNEXT(L)
      DO 240 K=1,LN
        LL=LADJL(L,K)
        IF(LNEW(LL).EQ.0) THEN
          LW=LW+1
          LNEW(LL)=-1
          LWAVE(LW)=LL
          IHOLD(LW)=0
        ENDIF
        NOLAL(LL)=NOLAL(LL)-1
240   CONTINUE
C
C-----UPDATE THE LENGTH OF STAY COUNTER
      DO 250 K=1,LW
        IHOLD(K)=IHOLD(K)+1
250   CONTINUE
C
C-----PRINT WAVEFRONT VALUES FOR THE CURRENT ELEMENT
      IF(MOD(IPRNT,16).GT.7) WRITE(IO2,2020)LKNT,LOLD(LKNT),NWAVE,NFRST,
     # NLAST,IHOLD(1)
      IF(MOD(IPRNT,32).GT.15) WRITE(IO2,2020) LKNT,LOLD(LKNT),NWAVE,
     # NFRST,NLAST,IHOLD(1),(LWAVE(J),J=1,LW)
C
C-----END ELEMENT RESEQUENCING LOOP
      IF(LW.GT.0) GOTO 100
C
C-----CHECK FOR UNATTACHED ELEMENTS
      IF(LKNT.EQ.LKNT1) GOTO 300
      DO 260 L=1,NE
        IF(LMAT(L).LT.1) GOTO 260
        IF(LNEW(L).GT.0) GOTO 260
        WRITE(IO2,2050) L
260   CONTINUE
C
C-----CHECK ON FINAL FRONTWIDTH
300   IF(NWAVE.NE.NLAST) THEN
        WRITE(IO2,2005)
        IER=IER+1
      ENDIF
999   RETURN
      END
C
C
C
      SUBROUTINE FIT(XA,YA,XB,YB,XC,YC,XL,YL,XU,YU)
C
C---- FIT -------------------------------------------------------------S
C
C  PURPOSE:
C    PLOTS ELEMENT SIDES.
C
C  INPUT ARGUMENT(S):
C    XA - X-COORDINATE OF THE FIRST ENDPOINT
C    YA - Y-COORDINATE OF THE FIRST ENDPOINT
C    XB - X-COORDINATE OF THE MIDPOINT
C    YB - Y-COORDINATE OF THE MIDPOINT
C    XC - X-COORDINATE OF THE SECOND ENDPOINT
C    YC - Y-COORDINATE OF THE SECOND ENDPOINT
C
C  SUBPROGRAM(S) CALLED:
C    PCODE
C
C----------------------------------------------------------------------F
C
      EPS=0.01
      S=0.0
      IPEN=3
C
C---- Determine if side is straight or curved
      XBAR=0.5*(XA+XC)
      YBAR=0.5*(YA+YC)
      IF(ABS(XBAR-XB).LT.EPS.AND.ABS(YBAR-YB).LT.EPS) THEN
        NSEG=1
      ELSE
        NSEG=25
      ENDIF
C
C---- Compute segment length
      DS=1./REAL(NSEG)
C
C---- Plot visible portion of element side
      X2=XA
      Y2=YA
      DO 100 J=1,NSEG
        X1=X2
        Y1=Y2
        S=S+DS
        WA=1.-3.*S+2.*S*S
        WB=4.*S*(1.-S)
        WC=S*(2.*S-1.)
        X2=WA*XA+WB*XB+WC*XC
        Y2=WA*YA+WB*YB+WC*YC
C
C------ Compute point location codes
   30   KODE1=PCODE(X1,Y1,XL,YL,XU,YU)
        KODE2=PCODE(X2,Y2,XL,YL,XU,YU)
C
C------ Check for a line segment that is completely visible
        IF(KODE1.EQ.0.AND.KODE2.EQ.0) THEN
C------ Draw the line segment
          IF(IPEN.EQ.3) CALL PLOT(X1,Y1,IPEN)
          IPEN=2
          CALL PLOT(X2,Y2,IPEN)
        ELSE
C------ Check for a line segment that is completely invisible
          IF(KODE1/1000.EQ.1.AND.KODE2/1000.EQ.1) GOTO 100
          IF(MOD(KODE1,10).EQ.1.AND.MOD(KODE2,10).EQ.1) GOTO 100
          IF(MOD(KODE1/100,10).EQ.1.AND.MOD(KODE2/100,10).EQ.1)GOTO 100
          IF(MOD(KODE1/10,10).EQ.1.AND.MOD(KODE2/10,10).EQ.1) GOTO 100
C
C-------- Begin clipping
          KODE=KODE1
          IF(KODE.EQ.0) KODE=KODE2
          IF(MOD(KODE,100).EQ.1) THEN
C-------- Line segment crosses left edge of the window
            Y=Y1+(Y2-Y1)*(XL-X1)/(X2-X1)
            X=XL
          ELSE IF(MOD(KODE,100).EQ.10) THEN
C-------- Line segment crosses right edge of the window
            Y=Y1+(Y2-Y1)*(XU-X1)/(X2-X1)
            X=XU
          ELSE IF(KODE/100.EQ.1) THEN
C-------- Line segment crosses bottom edge of the window
            X=X1+(X2-X1)*(YL-Y1)/(Y2-Y1)
            Y=YL
          ELSE IF(KODE/100.EQ.10) THEN
C-------- Line segment crosses top edge of the window
            X=X1+(X2-X1)*(YU-Y1)/(Y2-Y1)
            Y=YU
          ELSE
C-------- Error trap
            GOTO 100
          ENDIF
C
C-------- Set new endpoint values and repeat the process
          IF(KODE.EQ.KODE1) THEN
            X1=X
            Y1=Y
          ELSE IF(KODE.EQ.KODE2) THEN
            X2=X
            Y2=Y
          ENDIF
          GOTO 30
        ENDIF
  100 CONTINUE
      RETURN
      END
C
C
C
      SUBROUTINE GRDPLT
C
C---- GRDPLT ----------------------------------------------------------S
C
C  PURPOSE:
C    PLOTS THE FINITE ELEMENT NETWORK.
C
C  SUBPROGRAM(S) CALLED:
C    LNODES, TRFMXY, FIT, NUMBER, SYMBOL, PLOT
C
C----------------------------------------------------------------------F
C
      INCLUDE 'DINMOD.INC'
      DIMENSION IPLOTN(3),IPLOTL(3),SPLOT(3)
C
C-----OUTPUT FORMATS
2000  FORMAT(1H+,79(' ')/1H+,'Plotting (network)...')
C
      IF(SCREEN) WRITE(*,2000)
C
C-----CLEAR ARRAYS AND SET CONSTANTS
      DO 10 N=1,NP
        NPID(N)=0
   10 CONTINUE
C
C-----ASSIGN DEFAULT VALUES
      ZIP=1.0E-08
      IF(HTN.LT.ZIP) HTN=0.070
      IF(HTE.LT.ZIP) HTE=0.105
      IF(HTT.LT.ZIP) HTT=0.140
C
C-----FILL PLOT ID ARRAYS
      NPLOTN=0
      NPLOTL=0
      DO 15 K=1,3
        KOUNT=2**K
        IF(MOD(IPLTN,KOUNT) .GE. KOUNT/2) THEN
          NPLOTN=NPLOTN+1
          IPLOTN(K)=1
        ELSE
          IPLOTN(K)=0
        ENDIF
        IF(MOD(IPLTE,KOUNT) .GE. KOUNT/2) THEN
          NPLOTL=NPLOTL+1
          IPLOTL(K)=1
        ELSE
          IPLOTL(K)=0
        ENDIF
   15 CONTINUE
C
C---- Plot title (leave 1/2-inch border along y-axis for title)
      NCHAR=LENCHR(PTITLE)
      CALL SYMBOL(0.3,0.0,HTT,PTITLE,0,90.0,NCHAR)
C
C---- LOOP AROUND ELEMENTS
      DO 100 L=1,NE
        IF(LMAT(L).NE.0) THEN
          CALL LNODES(L,NCN)
C
C-------- PLOT ELEMENT SIDES
          KHI=NCN
          IF(KHI.GT.8) KHI=8
          DO 20 K=1,KHI,2
            N2=NODE(K+1)
            IF(NPID(N2).EQ.0) THEN
              N1=NODE(K)
              N3=MOD(K+2,KHI)
              N3=NODE(N3)
              NPID(N2)=1
              X1=CORD(N1,1)
              Y1=CORD(N1,2)
              X2=CORD(N2,1)
              Y2=CORD(N2,2)
              X3=CORD(N3,1)
              Y3=CORD(N3,2)
              CALL TRFMXY(X1,Y1,XSCALE,YSCALE,XL,YL,SINA,COSA)
              CALL TRFMXY(X2,Y2,XSCALE,YSCALE,XL,YL,SINA,COSA)
              CALL TRFMXY(X3,Y3,XSCALE,YSCALE,XL,YL,SINA,COSA)
              X1=X1+XLP
              X2=X2+XLP
              X3=X3+XLP
              CALL FIT(X1,Y1,X2,Y2,X3,Y3,XLP,YLP,XUP,YUP)
            ENDIF
   20     CONTINUE
C
C-------- PLOT ELEMENT VALUES
          IF(IPLTE.GT.0) THEN
            IF(NCN.LT.9) THEN
              IF(NCN.EQ.6) THEN
                WC=-1./9.
                WM= 4./9.
              ELSE
                WC=-0.25
                WM= 0.50
              ENDIF
              XBAR=0.
              YBAR=0.
              DO 40 K=2,NCN,2
                NC=NODE(K-1)
                NM=NODE(K)
                XBAR=XBAR+WC*CORD(NC,1)+WM*CORD(NM,1)
                YBAR=YBAR+WC*CORD(NC,2)+WM*CORD(NM,2)
   40         CONTINUE
            ELSE
              N=NODE(9)
              XBAR=CORD(N,1)
              YBAR=CORD(N,2)
            ENDIF
            CALL TRFMXY(XBAR,YBAR,XSCALE,YSCALE,XL,YL,SINA,COSA)
            XBAR=XBAR+XLP
            KODE=PCODE(XBAR,YBAR,XLP,YLP,XUP,YUP)
            IF(KODE.EQ.0) THEN
              SPLOT(1)=L
              SPLOT(2)=LMAT(L)
              SPLOT(3)=LSEQ(L)
              Y=YBAR+0.625*HTE*REAL(NPLOTL)
              DO 50 J=1,3
                IF(IPLOTL(J).GT.0) THEN
                  FPN=SPLOT(J)
                  IF(ABS(FPN).GT.0.) THEN
                    NDIG=ALOG10(ABS(FPN))+0.01
                  ELSE
                    NDIG=0
                  ENDIF
                  IF(FPN.LT.0) THEN
                    NDIG=NDIG+2
                  ELSE
                    NDIG=NDIG+1
                  ENDIF
                  IF(NCN.EQ.9) THEN
                    X=XBAR-HTE*REAL(NDIG)
                  ELSE
                    X=XBAR-0.5*HTE*REAL(NDIG)
                  ENDIF
                  Y=Y-1.25*HTE
                  CALL NUMBER(X,Y,HTE,FPN,0.,-1)
                ENDIF
   50         CONTINUE
            ENDIF
          ENDIF
C
C------- PLOT VALUES AT NODE POINTS
          IF(IPLTN.GT.0) THEN
            DO 70 K=1,NCN
              N=NODE(K)
              IF(NPID(N).GT.1) GOTO 70
              NPID(N)=2
              SPLOT(1)=N
              SPLOT(2)=GRND(N)
              SPLOT(3)=CEIL(N)
              X=CORD(N,1)
              Y=CORD(N,2)
              CALL TRFMXY(X,Y,XSCALE,YSCALE,XL,YL,SINA,COSA)
              X=X+XLP
              KODE=PCODE(X,Y,XLP,YLP,XUP,YUP)
              IF(KODE.EQ.0) THEN
                X=X+0.5*HTN
                Y=Y+HTN*(1.25*REAL(NPLOTN)+0.25)
                DO 60 J=1,3
                  IF(IPLOTN(J).GT.0) THEN
                    FPN=SPLOT(J)
                    Y=Y-1.25*HTN
                    NDEC=-1
                    IF(J.GT.1) NDEC=1
                    CALL NUMBER(X,Y,HTN,FPN,0.,NDEC)
                  ENDIF
   60           CONTINUE
              ENDIF
   70       CONTINUE
          ENDIF
        ENDIF
  100 CONTINUE
      RETURN
      END
C
C
C
      SUBROUTINE TRFMXY(X,Y,XSCALE,YSCALE,X0,Y0,SGN,CSN)
C
C---- TRFMXY ----------------------------------------------------------S
C
C  PURPOSE:
C    TRANSFORMS WORLD X-Y COORDINATES TO PLOT COORDINATES
C
C  INPUT ARGUMENTS:
C    X - X-COORDINATE TO BE TRANSFORMED
C    Y - Y-COORDINATE TO BE TRANSFORMED
C    XSCALE - X-COORDINATE SCALE FACTOR
C    YSCALE - Y-COORDINATE SCALE FACTOR
C    X0 - X-COORDINATE OF ORIGIN
C    Y0 - Y-COORDINATE OF ORIGIN
C    SGN - SINE OF ROTAION ANGLE
C    CSN - COSINE OF ROATION ANGLE
C
C  OUTPUT ARGUMENTS:
C    X - TRANSFORMED X-COORDINATE
C    Y - TRANSFORMED Y-COORDINATE
C
C----------------------------------------------------------------------F
C
      TEMP=XSCALE*((X-X0)*CSN-(Y-Y0)*SGN)
      Y=YSCALE*((X-X0)*SGN+(Y-Y0)*CSN)
      X=TEMP
      RETURN
      END
C
C
C
      SUBROUTINE BNDPLT
C
C---- BNDPLT ----------------------------------------------------------S
C
C  PURPOSE:
C    PLOTS THE NETWORK BOUNDARY.
C
C  SUBPROGRAM(S) CALLED:
C    FIT, TRFMXY, LNODES
C
C----------------------------------------------------------------------F
C
      INCLUDE 'DINMOD.INC'
C
C-----ASSIGN NPID ARRAY VALUES
      DO 5 N=1,NP
        NPID(N)=0
    5 CONTINUE
      DO 20 L=1,NE
        IF(LMAT(L).NE.0) THEN
          CALL LNODES(L,NCN)
          DO 10 K=1,NCN
            N=NODE(K)
            NPID(N)=NPID(N)+1
   10     CONTINUE
        ENDIF
   20 CONTINUE
C
C-----DEVELOP LIST OF ELEMENT BOUNDARY SIDES
      NBS=0
      DO 40 L=1,NE
        IF(LMAT(L).EQ.0) GOTO 40
        NCN=6
        IF(NOP(L,7).GT.0) NCN=8
        DO 30 K=1,NCN,2
          N2=NOP(L,K+1)
          IF(NPID(N2).NE.1) GOTO 30
          N1=NOP(L,K)
          N3=K+2
          IF(N3.GT.NCN) N3=1
          N3=NOP(L,N3)
          NBS=NBS+1
          IF(NBS.GT.MAXS) THEN
            IER=IER+1
            WRITE(IO2,2000) MAXS
            GOTO 999
          ENDIF
          IES(NBS,1)=N1
          IES(NBS,2)=N2
          IES(NBS,3)=N3
          NPID(N2)=-NPID(N2)
   30   CONTINUE
   40 CONTINUE
C
C---- PLOT BOUNDARY SIDES IN SEQUENTIAL ORDER
      NSBS=0
      LS=1
      GOTO 70
C---- SEARCH BOUNDARY SIDE LIST FOR ADJACENT SIDE
   45 DO 50 J=2,NBS
        IF(IES(J,1).EQ.NN) THEN
          LS=J
          GOTO 70
        ENDIF
   50 CONTINUE
C---- FIND NEXT UNPLOTTED SIDE
      DO 60 J=2,NBS
        IF(IES(J,1).GT.1) THEN
          LS=J
          GOTO 70
        ENDIF
   60 CONTINUE
C---- THERE IS AN ERROR IF YOU ARE HERE
      WRITE(IO2,2010)
      GOTO 999
C---- DETERMINE NODE POINT COORDINATES
   70 N1=IES(LS,1)
      N2=IES(LS,2)
      N3=IES(LS,3)
      X1=CORD(N1,1)
      Y1=CORD(N1,2)
      X2=CORD(N2,1)
      Y2=CORD(N2,2)
      X3=CORD(N3,1)
      Y3=CORD(N3,2)
C---- CONVERT TO PLOT COORDINATES
      CALL TRFMXY(X1,Y1,XSCALE,YSCALE,XL,YL,SINA,COSA)
      CALL TRFMXY(X2,Y2,XSCALE,YSCALE,XL,YL,SINA,COSA)
      CALL TRFMXY(X3,Y3,XSCALE,YSCALE,XL,YL,SINA,COSA)
C---- PLOT ELEMENT SIDE
      X1=X1+XLP
      X2=X2+XLP
      X3=X3+XLP
      CALL FIT(X1,Y1,X2,Y2,X3,Y3,XLP,YLP,XUP,YUP)
      NSBS=NSBS+1
      NN=IES(LS,3)
      IES(LS,1)=-IES(LS,1)
      IF(NSBS.LT.NBS) GOTO 45
C---- SET NPID ARRAY POSITIVE
      DO 100 N=1,NP
        NPID(N)=IABS(NPID(N))
  100 CONTINUE
  999 RETURN
C
C---- FORMAT STATEMENTS
 2000 FORMAT(/1X,'***ERROR #??? - MAXIMUM NUMBER OF ELEMENT SIDES ',
     # 'EXCEEDED (',I5,').  INCREASE MAXS.')
 2010 FORMAT(/1X,'***ERROR #??? - CHECK ELEMENT SIDE LIST')
      END
C
C
C
      SUBROUTINE CONPLT
C
C---- CONPLT ----------------------------------------------------------S
C
C  PURPOSE:
C    CONTROLS PLOTTING OF GROUND-SURFACE ELEVATION CONTOUR LINES.
C
C  SUBPROGRAM(S) CALLED:
C    LNODES, BNDPLT, CNTORT, CNTORQ, ACVINC
C
C----------------------------------------------------------------------F
C
      INCLUDE 'DINMOD.INC'
      DIMENSION XLOC(8),YLOC(8),ZLOC(8),NXID(8)
      DATA ZIP/1.0E-04/
C
C---- OUTPUT FORMATS
2000  FORMAT(1H+,79(' ')/1H+,'Plotting (contours)...')
C
      IF(SCREEN) WRITE(*,2000)
C
C---- ASSIGN CONSTANTS AND CHECK FOR DEFAULTS
      CVMAX=1.0E+35
      CVMIN=-CVMAX
      IF(HTC.LT.ZIP) HTC=0.105
      IF(CVINC.LT.ZIP) CALL ACVINC
C
C---- COMPUTE NUMBER OF DECIMAL PALCES IN CONTOUR VALUE LABEL
      TEMP=CVINC
      NDECV=0
   10 TEMP=ABS(ANINT(TEMP)-TEMP)
      IF(TEMP.GT.ZIP) THEN
        NDECV=NDECV+1
        TEMP=10.*TEMP
        GOTO 10
      ENDIF
      IF(NDECV.EQ.0) NDECV=-1
C
C---- PLOT TITLE (LEAVE 1/2 INCH BORDER ALONG Y-AXIS FOR PLOT TITLE)
      CALL SYMBOL(0.3,0.0,HTT,PTITLE,0,90.0,LENCHR(PTITLE))
C
C---- PLOT NETWORK BOUNDARY
      CALL BNDPLT
C
C---- LOOP AROUND ELEMENTS
      DO 100 L=1,NE
        IF(LMAT(L).EQ.0) GOTO 100
        CALL LNODES(L,NCN)
        IF(NCN.GT.8) NCN=8
C------ ASSIGN CONTOUR VALUES
        DO 50 K=1,NCN
          N=NODE(K)
          XLOC(K)=CORD(N,1)
          YLOC(K)=CORD(N,2)
          ZLOC(K)=GRND(N)
          NXID(K)=NPID(N)
   50   CONTINUE
C------ PLOT CONTOUR LINES
        IF(NCN.EQ.6) THEN
          CALL CNTORT(XLOC,YLOC,ZLOC,NXID,NDECV)
        ELSE
          CALL CNTORQ(XLOC,YLOC,ZLOC,NXID,NDECV)
        ENDIF
  100 CONTINUE
      RETURN
      END
C
C
C
      SUBROUTINE CNTORT(XN,YN,CVAL,NXID,NDEC)
C
C---- CNTORT ----------------------------------------------------------S
C
C  PURPOSE:
C    PLOTS CONTOUR LINES WITHIN TRIANGULAR ELEMENTS.
C
C  INPUT ARGUMENT(S):
C    XN,YN - COORDINATE ARRAYS OF ELEMENT NODE POINTS.
C    CVAL - ARRAY OF CONTOUR VALUES AT NODE POINTS.
C    NXID - NODE POINT ID ARRAY. SET TO 1 FOR MIDSIDE NODES LOCATED ON
C           THE NETWORK BOUNDARY.
C    NDEC - NUMBER OF DECIMAL PLACES TO BE PLOTTED.
C
C  SUBPROGRAM(S) CALLED:
C    TRFMXY, FIT, CVPLOT
C
C----------------------------------------------------------------------F
C
      INCLUDE 'DINMOD.INC'
      DIMENSION BETA(4),ZETA(4),XN(8),YN(8),CVAL(8),NXID(8),LSC(3)
      REAL*4 L1,L2,L3
      DATA ZIP/1.0E-08/
C
C-----ASSIGN CORNER NODE CONTOUR VALUES
      CV1=CVAL(1)
      CV2=CVAL(3)
      CV3=CVAL(5)
C
C-----CHECK FOR POSSIBLE CONTOUR LINE WITHIN ELEMENT
      CVLO=AMIN1(CV1,CV2,CV3)
      IF(CVLO.GT.CVMAX) GOTO 999
      CVHI=AMAX1(CV1,CV2,CV3)
      IF(CVHI.LT.CVMIN) GOTO 999
C
C-----BEGIN SEARCH FOR CONTOUR POINTS.  SET INITIAL CONTOUR VALUE.
      CV=CVINC*AINT(CVLO/CVINC)-CVINC
C
C-----INCREMENT CONTOUR VALUE
10    CV=CV+CVINC
      LSC(1)=0
      LSC(2)=0
      LSC(3)=0
C
C-----IS CONTOUR VALUE WITHIN ALLOWABLE RANGE?
      IF(CV.LT.CVLO) GOTO 10
      IF(CV.GT.CVHI) GOTO 999
C
C-----SET INITIAL POINT COUNTER FOR CURRENT CONTOUR VALUE
      IP=0
C
C-----CHECK FOR CONTOUR POINT ALONG FIRST SIDE
      IF(CV.LT.AMIN1(CV1,CV2) .OR. CV.GT.AMAX1(CV1,CV2)) GOTO 20
      IF(ABS(CV1-CV2).GT.ZIP) THEN
        IP=IP+1
        BETA(IP)=(CV-CV2)/(CV1-CV2)
        ZETA(IP)=1.0-BETA(IP)
        IF(NXID(2).EQ.1) LSC(IP)=1
      ENDIF
C
C-----CHECK FOR CONTOUR POINT ALONG SECOND SIDE
20    IF(CV.LT.AMIN1(CV2,CV3) .OR. CV.GT.AMAX1(CV2,CV3)) GOTO 30
      IF(ABS(CV2-CV3).GT.ZIP) THEN
        IP=IP+1
        BETA(IP)=0.0
        ZETA(IP)=(CV-CV3)/(CV2-CV3)
        IF(NXID(4).EQ.1) LSC(IP)=1
      ENDIF
C
C-----CHECK FOR CONTOUR POINT ALONG THIRD SIDE
30    IF(CV.LT.AMIN1(CV3,CV1) .OR. CV.GT.AMAX1(CV3,CV1)) GOTO 40
      IF(ABS(CV3-CV1).GT.ZIP) THEN
        IP=IP+1
        BETA(IP)=(CV-CV3)/(CV1-CV3)
        ZETA(IP)=0.0
        IF(NXID(6).EQ.1) LSC(IP)=1
      ENDIF
C
C-----HAVE TWO CONTOUR POINTS BEEN FOUND?  IF NOT, TRY NEXT VALUE.
40    IF(IP.LT.2) GOTO 10
C
C-----CHECK FOR IDENTICAL INTERSECTION POINTS
      BDIF=ABS(BETA(1)-BETA(2))
      ZDIF=ABS(ZETA(1)-ZETA(2))
      IF( BDIF.LT.ZIP .AND. ZDIF.LT.ZIP ) GOTO 10
C
C-----COMPUTE CONTOUR LINE END- AND MID-POINT COORDINATES
      L1=BETA(1)
      L2=ZETA(1)
      L3=1.0-L1-L2
      W1=(2.0*L1-1.0)*L1
      W2=(2.0*L2-1.0)*L2
      W3=(2.0*L3-1.0)*L3
      W4=4.0*L1*L2
      W5=4.0*L2*L3
      W6=4.0*L3*L1
      XA=W1*XN(1)+W2*XN(3)+W3*XN(5)+W4*XN(2)+W5*XN(4)+W6*XN(6)
      YA=W1*YN(1)+W2*YN(3)+W3*YN(5)+W4*YN(2)+W5*YN(4)+W6*YN(6)
      L1=0.5*(BETA(1)+BETA(2))
      L2=0.5*(ZETA(1)+ZETA(2))
      L3=1.0-L1-L2
      W1=(2.0*L1-1.0)*L1
      W2=(2.0*L2-1.0)*L2
      W3=(2.0*L3-1.0)*L3
      W4=4.0*L1*L2
      W5=4.0*L2*L3
      W6=4.0*L3*L1
      XB=W1*XN(1)+W2*XN(3)+W3*XN(5)+W4*XN(2)+W5*XN(4)+W6*XN(6)
      YB=W1*YN(1)+W2*YN(3)+W3*YN(5)+W4*YN(2)+W5*YN(4)+W6*YN(6)
      L1=BETA(2)
      L2=ZETA(2)
      L3=1.0-L1-L2
      W1=(2.0*L1-1.0)*L1
      W2=(2.0*L2-1.0)*L2
      W3=(2.0*L3-1.0)*L3
      W4=4.0*L1*L2
      W5=4.0*L2*L3
      W6=4.0*L3*L1
      XC=W1*XN(1)+W2*XN(3)+W3*XN(5)+W4*XN(2)+W5*XN(4)+W6*XN(6)
      YC=W1*YN(1)+W2*YN(3)+W3*YN(5)+W4*YN(2)+W5*YN(4)+W6*YN(6)
C
C-----TRANSFORM TO PLOT COORDINATES
      CALL TRFMXY(XA,YA,XSCALE,YSCALE,XL,YL,SINA,COSA)
      CALL TRFMXY(XB,YB,XSCALE,YSCALE,XL,YL,SINA,COSA)
      CALL TRFMXY(XC,YC,XSCALE,YSCALE,XL,YL,SINA,COSA)
C
C-----PLOT CONTOUR LINE
      XA=XA+XLP
      XB=XB+XLP
      XC=XC+XLP
      CALL FIT(XA,YA,XB,YB,XC,YC,XLP,YLP,XUP,YUP)
C
C-----PLOT CONTOUR VALUE AT BOUNDARY INTERSECTIONS
      CALL CVPLOT(XA,YA,XB,YB,XC,YC,LSC,CV,NDEC,HTC,XLP,YLP,XUP,YUP)
      GOTO 10
999   RETURN
      END
C
C
C
      SUBROUTINE CNTORQ(XQ,YQ,CQ,NQID,NDEC)
C
C---- CNTORQ ----------------------------------------------------------S
C
C  PURPOSE:
C    PLOTS CONTOUR LINES WITHIN QUADRILATERL ELEMENTS.  QUADRILATERAL
C    ELEMENTS ARE DIVIDED INTO FOUR TRIANGULAR ELEMENTS IN ORDER TO
C    DRAW CONTOUR LINES.  FOR EACH OF THE NEWLY DEFINED TRIANGUALR
C    ELEMENTS, SUBROUTINE CNTORT IS CALLED TO PLOT THE CONTOURS.
C
C  INPUT ARGUMENT(S):
C    XQ,YQ - COORDINATE ARRAYS OF ELEMENT NODE POINTS.
C    CQ - ARRAY OF CONTOUR VALUES AT NODE POINTS.
C    NQID - NODE POINT ID ARRAY. SET TO 1 FOR MIDSIDE NODES LOCATED ON
C           THE NETWORK BOUNDARY.
C    NDEC - NUMBER OF DECIMAL PLACES TO BE PLOTTED.
C
C  SUBPROGRAM(S) CALLED:
C    CNTORT
C
C----------------------------------------------------------------------F
C
      DIMENSION XQ(8),YQ(8),CQ(8),XR(8),YR(8),CR(8),NQID(8),NRID(8)
C
C-----ASSIGN CENTER POINT VALUES
      XR(5)=0.5*(XQ(2)+XQ(4)+XQ(6)+XQ(8))-0.25*(XQ(1)+XQ(3)+XQ(5)+XQ(7))
      YR(5)=0.5*(YQ(2)+YQ(4)+YQ(6)+YQ(8))-0.25*(YQ(1)+YQ(3)+YQ(5)+YQ(7))
      CR(5)=0.5*(CQ(2)+CQ(4)+CQ(6)+CQ(8))-0.25*(CQ(1)+CQ(3)+CQ(5)+CQ(7))
      NRID(5)=0
C
C-----FIRST ELEMENT
      DO 10 K=1,3
        XR(K)=XQ(K)
        YR(K)=YQ(K)
        CR(K)=CQ(K)
        NRID(K)=NQID(K)
10    CONTINUE
      XR(4)=0.5*(XR(3)+XR(5))
      YR(4)=0.5*(YR(3)+YR(5))
      CR(4)=0.5*(CR(3)+CR(5))
      NRID(4)=0
      XR(6)=0.5*(XR(5)+XR(1))
      YR(6)=0.5*(YR(5)+YR(1))
      CR(6)=0.5*(CR(5)+CR(1))
      NRID(6)=0
      CALL CNTORT(XR,YR,CR,NRID,NDEC)
C
C-----SECOND ELEMENT
      DO 20 K=1,3
        KK=K+2
        XR(K)=XQ(KK)
        YR(K)=YQ(KK)
        CR(K)=CQ(KK)
        NRID(K)=NQID(KK)
20    CONTINUE
      XR(4)=0.5*(XR(3)+XR(5))
      YR(4)=0.5*(YR(3)+YR(5))
      CR(4)=0.5*(CR(3)+CR(5))
      NRID(4)=0
      XR(6)=0.5*(XR(5)+XR(1))
      YR(6)=0.5*(YR(5)+YR(1))
      CR(6)=0.5*(CR(5)+CR(1))
      NRID(6)=0
      CALL CNTORT(XR,YR,CR,NRID,NDEC)
C
C-----THIRD ELEMENT
      DO 30 K=1,3
        KK=K+4
        XR(K)=XQ(KK)
        YR(K)=YQ(KK)
        CR(K)=CQ(KK)
        NRID(K)=NQID(KK)
30    CONTINUE
      XR(4)=0.5*(XR(3)+XR(5))
      YR(4)=0.5*(YR(3)+YR(5))
      CR(4)=0.5*(CR(3)+CR(5))
      NRID(4)=0
      XR(6)=0.5*(XR(5)+XR(1))
      YR(6)=0.5*(YR(5)+YR(1))
      CR(6)=0.5*(CR(5)+CR(1))
      NRID(6)=0
      CALL CNTORT(XR,YR,CR,NRID,NDEC)
C
C-----FOURTH ELEMENT
      DO 40 K=1,3
        KK=K+6
        IF(K.EQ.3) KK=1
        XR(K)=XQ(KK)
        YR(K)=YQ(KK)
        CR(K)=CQ(KK)
        NRID(K)=NQID(KK)
40    CONTINUE
      XR(4)=0.5*(XR(3)+XR(5))
      YR(4)=0.5*(YR(3)+YR(5))
      CR(4)=0.5*(CR(3)+CR(5))
      NRID(4)=0
      XR(6)=0.5*(XR(5)+XR(1))
      YR(6)=0.5*(YR(5)+YR(1))
      CR(6)=0.5*(CR(5)+CR(1))
      NRID(6)=0
      CALL CNTORT(XR,YR,CR,NRID,NDEC)
      RETURN
      END
C
C
C
      SUBROUTINE CVPLOT(XA,YA,XB,YB,XC,YC,LSC,CV,NDEC,HTC,XLP,YLP,
     # XUP,YUP)
C
C---- CVPLOT ----------------------------------------------------------S
C
C  PURPOSE:
C    PLOTS CONTOUR VALUES AT INTERSECTIONS OF CONTOUR LINES WITH THE
C    BOUNDARY OF THE NETWORK.
C
C  INPUT ARGUMENT(S):
C    XA,YA,XB,YB,XC,YC - COORDINATES OF THE ENDPOINTS AND MIDSIDE POINT
C    OF A CONTOUR LINE.
C    LSC - ELEMENT SIDE CODE ARRAY.
C    CV - CONTOUR VALUE.
C    NDEC - NUMBER OF DECIMAL POINTS IN PLOOTED CONTOUR VALUE.
C    HTC - HEIGHT OF PLOTTED CONTOUR VALUE, IN INCHES.
C    XLP,YLP - COORDINATES OF LOWER-LEFT CORNER OF VIEWPORT.
C    XUP,YUP - COORDINATES OF UPPER-RIGHT CORNER OF VIEWPORT.
C
C  SUBPROGRAM(S) CALLED:
C    NUMBER
C
C----------------------------------------------------------------------F
C
      DIMENSION LSC(3)
      DATA RTOD/57.29578/
      IF( LSC(1).EQ.0 .AND. LSC(2).EQ.0 ) GOTO 999
C
C-----COMPUTE NUMBER OF DIGITS IN CONTOUR VALUE
      NLEFT=1
      J=INT(CV)
      IF(J.GT.0) THEN
        K=1
        DO 10 I=1,4
          K=K*10
          IF(J.GE.K) NLEFT=NLEFT+1
10      CONTINUE
      ENDIF
      NDIG=1+NLEFT+NDEC
C
C-----CHECK FIRST ENDPOINT
      KODE=PCODE(XA,YA,XLP,YLP,XUP,YUP)
      IF(LSC(1).EQ.1 .AND. KODE.EQ.0) THEN
        DXDS=-1.5*XA+2.0*XB-0.5*XC
        DYDS=-1.5*YA+2.0*YB-0.5*YC
        ANGLE=RTOD*ATAN2(DYDS,DXDS)
        FACT=HTC/SQRT(DXDS*DXDS+DYDS*DYDS)
        IF(DXDS.GT.0.) THEN
          DX=FACT*(-REAL(NDIG+1)*DXDS+0.5*DYDS)
          DY=FACT*(-REAL(NDIG+1)*DYDS-0.5*DXDS)
          ANGLE=RTOD*ATAN2(DYDS,DXDS)
        ELSE
          DX=FACT*(-DXDS-0.5*DYDS)
          DY=FACT*(-DYDS+0.5*DXDS)
          ANGLE=RTOD*ATAN2(-DYDS,-DXDS)
        ENDIF
        CALL NUMBER(XA+DX,YA+DY,HTC,CV,ANGLE,NDEC)
      ENDIF
C
C-----CHECK SECOND ENDPOINT
      KODE=PCODE(XB,YB,XLP,YLP,XUP,YUP)
      IF(LSC(2).EQ.1 .AND. KODE.EQ.0) THEN
        DXDS=0.5*XA-2.0*XB+1.5*XC
        DYDS=0.5*YA-2.0*YB+1.5*YC
        FACT=HTC/SQRT(DXDS*DXDS+DYDS*DYDS)
        IF(DXDS.GT.0.) THEN
          DX=FACT*(DXDS+0.5*DYDS)
          DY=FACT*(DYDS-0.5*DXDS)
          ANGLE=RTOD*ATAN2(DYDS,DXDS)
        ELSE
          DX=FACT*(REAL(NDIG+1)*DXDS-0.5*DYDS)
          DY=FACT*(REAL(NDIG+1)*DYDS+0.5*DXDS)
          ANGLE=RTOD*ATAN2(-DYDS,-DXDS)
        ENDIF
        CALL NUMBER(XC+DX,YC+DY,HTC,CV,ANGLE,NDEC)
      ENDIF
999   RETURN
      END
C
C
C
      FUNCTION PCODE(X,Y,XL,YL,XU,YU)
C
C---- PCODE -----------------------------------------------------------S
C
C  PURPOSE:
C    DETERMINES THE POINT LOCATION CODE AS SHOWN BELOW:
C
C                            |            |
C                    1001    |    1000    |    1010
C             YUP____________|____________|____________
C                            |            |
C                    0001    |    0000    |    0010
C             YLP____________|____________|____________
C                            |            |
C                    0101    |    0100    |    0110
C                            |            |
C                           XLP          XUP
C
C  INPUT ARGUMENT(S):
C    X - X-COORDINATE OF THE POINT IN QUESTION
C    Y - Y-COORDINATE OF THE POINT IN QUESTION
C    XL - LOWER X-COORDINATE OF THE VIEWPORT
C    YL - LOWER Y-COORDINATE OF THE VIEWPORT
C    XU - UPPER X-COORDINATE OF THE VIEWPORT
C    YU - UPPER Y-COORDINATE OF THE VIEWPORT
C
C----------------------------------------------------------------------F
C
      PCODE=0
      IF(X.LT.XL) THEN
        PCODE=PCODE+1
      ELSEIF(X.GT.XU) THEN
        PCODE=PCODE+10
      ENDIF
      IF(Y.LT.YL) THEN
        PCODE=PCODE+100
      ELSEIF(Y.GT.YU) THEN
        PCODE=PCODE+1000
      ENDIF
      RETURN
      END
C
C
C
      SUBROUTINE ACVINC
C
C---- ACVINC ----------------------------------------------------------S
C
C  PURPOSE:
C    ASSIGNS THE CONTOUR VALUE INTERVAL.  A CONTOUR VALUE INTERVAL THAT
C    PROVIDES ABOUT TEN (10) CONTOUR LINES IS ASSIGNED.
C
C----------------------------------------------------------------------F
C
      INCLUDE 'DINMOD.INC'
      DIMENSION SAVE(5)
      DATA SAVE/1.,2.,5.,10.,20./,NCVINC/10/
      VMIN=1.0E+35
      VMAX=-VMIN
C
C---- Determine maximum and minimum contour values
      DO 20 L=1,NE
        IF(LMAT(L).EQ.0) GO TO 20
        NCN=6
        IF(NOP(L,7).GT.0) NCN=8
        DO 10 K=1,NCN
          N=NOP(L,K)
          CV=GRND(N)
          IF(CV.GT.VMAX) THEN
            VMAX=CV
          ELSEIF(CV.LT.VMIN) THEN
            VMIN=CV
          ENDIF
10      CONTINUE
20    CONTINUE
C
C---- Assign contour interval
      CVINC=(VMAX-VMIN)/REAL(NCVINC)
      I=ALOG10(CVINC)
      P=10.**REAL(I)
      CVINC=CVINC/P-0.001
      DO 30 I=1,5
        IS=I
        IF(SAVE(I).GT.CVINC) GOTO 40
30    CONTINUE
40    CVINC=P*SAVE(IS)
      RETURN
      END
C
C
C
      SUBROUTINE INTANG (X1,Y1,X2,Y2,X3,Y3,A)
C
C---- INTANG ----------------------------------------------------------S
C
C  PURPOSE:
C    COMPUTES EXTERIOR ANGLES OF THE POLYGON DURING AUTOMATIC GRID
C    GENERATION.
C
C  INPUT ARGUMENT(S):
C    X1,Y1 - COORDINATES OF 1ST CORNER NODE
C    X2,Y2 - COORDINATES OF 2ND CORNER NODE
C    X3,Y3 - COORDINATES OF 3RD CORNER NODE
C
C  OUTPUT ARGUMENT(S):
C    A     - INTERIOR ANGLE IN RADIANS
C
C----------------------------------------------------------------------F
C
      DATA PI/3.14159265/
C
      A1=X2-X1
      B1=Y2-Y1
      A2=X3-X2
      B2=Y3-Y2
      V1CROSSV2=A1*B2-B1*A2
      V1DOTV2=A1*A2+B1*B2
      ABSV1=SQRT(A1*A1+B1*B1)
      ABSV2=SQRT(A2*A2+B2*B2)
      A=ABSV1*ABSV2
      IF(A.GT.0.) A=ACOS(V1DOTV2/A)
      IF(V1CROSSV2.LT.0.) THEN
        A=PI+A
      ELSE
        A=PI-A
      ENDIF
      RETURN
      END
C
C
C
      SUBROUTINE GEOCHK(IER)
C
C---- GEOCHK ----------------------------------------------------------S
C
C  PURPOSE:
C    CHECKS THE GEOMETRIC INPUT DATA FOR INTERNAL CONSISTENCY AND
C    COMPLETENESS.  A LIST OF ELEMENT SIDES IS FORMED FROM THE ELEMENT
C    CONNECTIVITY DATA.  EACH SIDE IS TESTED AGAINST SIDES ALREADY
C    IN THE LIST BEFORE IT IS ADDED.  IF A DISCREPANCY IS FOUND, THE
C    ERROR COUNT IS INCREMENTED BY ONE AND A MESSAGE IS PRINTED.
C
C  OUTPUT ARGUMENT(S):
C    IER - ERROR COUNT.
C
C  SUBPROGRAM(S) CALLED:
C    LNODES
C
C----------------------------------------------------------------------F
C
C---- Declarations (arguments)
      INTEGER   IER
C
C---- Declarations (local)
      INTEGER   I,J,K,L,N,NES,NCN,NCN1,IES1,IES2,IES3,ICODE
C
C---- Common blocks
      INCLUDE 'DINMOD.INC'
C
C---- Output formats
2000  FORMAT(1H+,79(' ')/1H+,'Computing (network geometry check)...')
2001  FORMAT(' ***ERROR #140 - SIDE ',I5,',',I5,',',I5,' AT ELEMENT',I5,
     # ' DISAGREES WITH'/17x,'SIDE ',I5,',',I5,',',I5,' AT ELEMENT',I5)
2005  FORMAT(/' LIST OF ELEMENT SIDES - SIDE(NODE1,NODE2,NODE3)'/
     #       /(5(1X,I5,'(',I5,',',I5,',',I5,')')))
2010  FORMAT(' ***',I5,' ERROR(S) ENCOUNTERED DURING GEOMETRIC ',
     # 'DATA CHECK'/)
2020  FORMAT(' ***ERROR #150 - CENTER NODE ',I5,' APPEARS IN ',
     # 'ELEMENTS ',I5,' AND ',I5)
2030  FORMAT(' ***ERROR #160 - ENTRY NUMBER',I2,' IN THE ',
     # 'CONNECTIVITY LIST FOR ELEMENT ',I5,' IS OUT OF RANGE')
2070  FORMAT(' ***ERROR #161 - NODE MIXUP.  NODE ',I5,' IN ELEMENTS ',
     # I5,' AND ',I5,'.')
C
      IF(SCREEN) WRITE(*,2000)
C
C---- Initialize values
      IER=0
      NES=0
C
C---- Assemble list of element sides and check for geometric consistency
      DO 80 L=1,NE
        IF(LMAT(L).EQ.0) GOTO 80
        CALL LNODES(L,NCN)
        IF(NODE(4).LT.1) GOTO 80
        NCN1=NCN-1
C
C------ Make sure all entries in connectivity list are OK
        DO 40 K=1,NCN
          N=NODE(K)
          IF(N.LT.1) THEN
            IER=IER+1
            WRITE(IO2,2030) K,L
          ELSEIF(N.GT.MAXP) THEN
            IER=IER+1
            WRITE(IO2,2030) K,L
          ENDIF
40      CONTINUE
        DO 70 K=1,NCN1,2
C
C-------- Extract potential element side
          N1=NODE(K)
          N2=NODE(K+1)
          N3=MOD(K+2,NCN)
          IF(NCN.EQ.9) N3=MOD(K+2,NCN1)
          N3=NODE(N3)
          IF(NES.EQ.0) GOTO 61
C
C-------- COMPARE WITH LIST OF ALREADY FORMED ELEMENT SIDES
          DO 60 J=1,NES
            IES1=IES(J,1)
            IES2=IES(J,2)
            IES3=IES(J,3)
C
C---------- First check to see if sides are the same
            IF(N1.EQ.IES3 .AND. N2.EQ.IES2 .AND. N3.EQ.IES1) GOTO 70
C
C---------- If not, compute the connection code
            ICODE=0
            IF(N1.EQ.IES1.OR.N1.EQ.IES2.OR.N1.EQ.IES3) ICODE=ICODE+1
            IF(N2.EQ.IES1.OR.N2.EQ.IES2.OR.N2.EQ.IES3) ICODE=ICODE+1
            IF(N3.EQ.IES1.OR.N3.EQ.IES2.OR.N3.EQ.IES3) ICODE=ICODE+1
            IF(ICODE.EQ.0) GOTO 60
C
C---------- Are sides connected only at one endpoint?
            IF(ICODE.EQ.1) THEN
              IF(N1.EQ.IES1 .OR. N1.EQ.IES3) GOTO 60
              IF(N3.EQ.IES1 .OR. N3.EQ.IES3) GOTO 60
            ENDIF
C
C---------- Error trap
            IER=IER+1
            WRITE(IO2,2001) N1,N2,N3,L,IES1,IES2,IES3,LSIDE(J)
60        CONTINUE
C
C-------- Side is new, add to list of element sides
61        NES=NES+1
          IES(NES,1)=N1
          IES(NES,2)=N2
          IES(NES,3)=N3
          LSIDE(NES)=L
70      CONTINUE
C
C------ Check on center node for 9-node quadrilaterals
        IF(NCN.GT.8) THEN
          N=NODE(9)
          LP1=L+1
          DO 78 LL=LP1,NE
            IF(LMAT(LL).EQ.0) GOTO 78
            CALL LNODES(LL,NCN)
            DO 76 K=1,NCN
              NN=NODE(K)
              IF(N.EQ.NN) THEN
                IER=IER+1
                WRITE(IO2,2020) N,L,LL
              ENDIF
76          CONTINUE
78        CONTINUE
        ENDIF
80    CONTINUE
C
C---- Check for node mixup
      DO 85 N=1,NP
        NPID(N)=0
85    CONTINUE
      DO 100 L=1,NE
        IF(LMAT(L).NE.0) THEN
          CALL LNODES(L,NCN)
          DO 90 K=1,NCN
            N=NODE(K)
            IF(NPID(N).EQ.0) THEN
              IF(K.EQ.9) THEN
                NPID(N)=3+10*L
              ELSEIF(MOD(K,2).EQ.1) THEN
                NPID(N)=1+10*L
              ELSE
                NPID(N)=2+10*L
              ENDIF
            ELSE
              IF(K.EQ.9) THEN
                IF(MOD(NPID(N),10).NE.3) THEN
                  IER=IER+1
                  WRITE(IO2,2070) N,L,NPID(N)/10
                ENDIF
              ELSEIF(MOD(K,2).EQ.1) THEN
                IF(MOD(NPID(N),10).NE.1) THEN
                  IER=IER+1
                  WRITE(IO2,2070) N,L,NPID(N)/10
                ENDIF
              ELSE
                IF(MOD(NPID(N),10).NE.2) THEN
                  IER=IER+1
                  WRITE(IO2,2070) N,L,NPID(N)/10
                ENDIF
              ENDIF
            ENDIF
90        CONTINUE
        ENDIF
100   CONTINUE
      IF(IER.GT.0) WRITE(IO2,2010) IER
      RETURN
      END
C
C
C
      SUBROUTINE GRDGEN(IER)
C
C---- GRDGEN ----------------------------------------------------------S
C
C  PURPOSE:
C    AUTOMATICALLY GENERATES TRIANGULAR ELEMENTS BY SUBDIVIDING THE
C    INTERIOR OF A POLYGONAL REGION DEFINED BY A SERIES OF CORNER
C    NODE POINTS.
C
C  OUTPUT ARGUMENT(S):
C    IER -  ERROR COUNT.
C
C  SUBPROGRAM(S) CALLED:
C    INTANG, SMOOTH
C
C----------------------------------------------------------------------F
C
      INCLUDE 'DINMOD.INC'
      DATA PI/3.14159265/,HPI/1.57079633/,ZIP/1.0E-06/
C
C---- Output formats
2000  FORMAT(1H+,79(' ')/
     # 1H+,'Computing (automatic network generation)...')
2010  FORMAT(' ***ERROR #180 - GENERATED ELEMENT NUMBER EXCEEDS ',
     # 'ELEMENT ARRAY DIMENSION.')
2020  FORMAT(' ***ERROR #181 - GENERATED NODE NUMBER EXCEEDS ',
     # 'NODAL ARRAY DIMENSION.')
2030  FORMAT(' ***ERROR #182 - POLYGON NO.',I5,' HAS NO INTERNAL ',
     # 'ANGLES < 180 DEGREES.')
2100  FORMAT(/50X,'*** AUTOMATIC GRID GENERATION ***'/)
2101  FORMAT(/24X,'*** AUTOMATIC GRID GENERATION ***'/)
2110  FORMAT(/' REGION NO. ',I3,' - BOUNDED BY THE FOLLOWING NODES:'/
     # (7X,20I6))
2111  FORMAT(/' REGION NO. ',I3,' - BOUNDED BY THE FOLLOWING NODES:'/
     # (5X,12I5))
C
C---- Screen acknowledgement
      IF(SCREEN) WRITE(*,2000)
      IF(WIDE) THEN
        WRITE(IO2,2100)
      ELSE
        WRITE(IO2,2101)
      ENDIF
C
C---- Initialize values
      IER=0
      KHI=0
      IGEN=0
      NEOLD=NE
      NPOLD=NP
C
C---- Fill initial polygon array
10    IGEN=IGEN+1
      NPTS=LNGEN(KHI+1)
      IF(NPTS.EQ.0) GOTO 999
      M=LNGEN(KHI+2)
      NITSM=LNGEN(KHI+3)
      KLO=KHI+4
      KHI=KHI+NPTS+3
      KK=0
      DO 20 K=KLO,KHI
        N1=LNGEN(K)
        IF(K.LT.KHI) THEN
          N3=LNGEN(K+1)
        ELSE
          N3=LNGEN(KLO)
        ENDIF
        CALL MIDNUM(N1,N3,N2)
        IF(N2.EQ.0) THEN
          NP=NP+1
          IF(NP.GT.MAXP) THEN
            IER=IER+1
            WRITE(IO2,2020)
            GOTO 999
          ENDIF
          N2=NP
        ENDIF
        KK=KK+1
        NPOLY(KK)=N1
        KK=KK+1
        NPOLY(KK)=N2
20    CONTINUE
      NPTS=2*NPTS
      ILO=1
      JLO=1
      IF(WIDE) THEN
        WRITE(IO2,2110) IGEN,(NPOLY(K),K=1,NPTS)
      ELSE
        WRITE(IO2,2111) IGEN,(NPOLY(K),K=1,NPTS)
      ENDIF

C
C---- Check for final element
30    IF(NPTS.GT.6) GOTO 50

C
C-----FORM FINAL ELEMENT FOR CURRENT POLYGON
      NE=NE+1
      IF(NE.GT.MAXE) THEN
        IER=IER+1
        WRITE(IO2,2010)
        GOTO 999
      ENDIF
      DO 40 K=1,6
        NOP(NE,K)=NPOLY(K)
40    CONTINUE
      LMAT(NE)=M
      GOTO 10
C
C---- Remove all internal angles in current polygon <= 90 degrees
50    IHI=NPTS-1
      DO 60 I=ILO,IHI,2
        IF(I.EQ.1) THEN
          N1=NPOLY(NPTS-1)
          N2=NPOLY(NPTS)
        ELSE
          N1=NPOLY(I-2)
          N2=NPOLY(I-1)
        ENDIF
        N3=NPOLY(I)
        N4=NPOLY(I+1)
        IF(I.EQ.IHI) THEN
          N5=NPOLY(1)
        ELSE
          N5=NPOLY(I+2)
        ENDIF
        CALL INTANG(CORD(N1,1),CORD(N1,2),CORD(N3,1),CORD(N3,2),
     #  CORD(N5,1),CORD(N5,2),A)
        IF(A.LT.HPI+ZIP) THEN
          IC=I
          GOTO 70
        ENDIF
60    CONTINUE
      IF(ILO.EQ.1) GOTO 110
      ILO=1
      GOTO 50
C
C---- Form new element and node points
70    NE=NE+1
      IF(NE.GT.MAXE) THEN
        IER=IER+1
        WRITE(IO2,2010)
        GOTO 999
      ENDIF
      NP=NP+1
      IF(NP.GT.MAXP) THEN
        IER=IER+1
        WRITE(IO2,2020)
        GOTO 999
      ENDIF
      NOP(NE,1)=N1
      NOP(NE,2)=N2
      NOP(NE,3)=N3
      NOP(NE,4)=N4
      NOP(NE,5)=N5
      NOP(NE,6)=NP
      LMAT(NE)=M
C
C---- Update polygon array
      NPTS=NPTS-2
      DO 80 J=IC,NPTS
        NPOLY(J)=NPOLY(J+2)
80    CONTINUE
      IF(IC.EQ.1) THEN
        NPOLY(NPTS)=NP
      ELSE
        NPOLY(IC-1)=NP
      ENDIF
      ILO=IC
      IF(IC.GT.NPTS) ILO=1
      GOTO 30
C
C---- Find an interior angle < 180 degrees
110   IHI=NPTS-1
      DO 120 I=JLO,IHI,2
        IF(I.EQ.1) THEN
          N1=NPOLY(NPTS-1)
          N2=NPOLY(NPTS)
        ELSE
          N1=NPOLY(I-2)
          N2=NPOLY(I-1)
        ENDIF
        N3=NPOLY(I)
        N4=NPOLY(I+1)
        IF(I.EQ.IHI) THEN
          N5=NPOLY(1)
        ELSE
          N5=NPOLY(I+2)
        ENDIF
        CALL INTANG(CORD(N1,1),CORD(N1,2),CORD(N3,1),CORD(N3,2),
     #  CORD(N5,1),CORD(N5,2),A)
        IF(A.LT.PI) GOTO 130
120   CONTINUE
      IF(JLO.EQ.1) THEN
        IER=IER+1
        WRITE(IO2,2030) IGEN
        GOTO 999
      ELSE
        JLO=1
        GOTO 110
      ENDIF
C
C---- Create a new node point
130   N6=NP+1
      N7=NP+2
      N8=NP+3
      N9=NP+4
      NP=N9
      IF(NP.GT.MAXP) THEN
        IER=IER+1
        WRITE(IO2,2020)
        GOTO 999
      ENDIF
      X=0.5*(CORD(N1,1)+CORD(N5,1))+OMEGA*(CORD(N1,2)-CORD(N5,2))
      Y=0.5*(CORD(N1,2)+CORD(N5,2))+OMEGA*(CORD(N5,1)-CORD(N1,1))
      CORD(N9,1)=X
      CORD(N9,2)=Y
C
C---- Form two new elements
      IF(NE+2.GT.MAXE) THEN
        IER=IER+1
        WRITE(IO2,2010)
        GOTO 999
      ENDIF
      NE=NE+1
      NOP(NE,1)=N1
      NOP(NE,2)=N2
      NOP(NE,3)=N3
      NOP(NE,4)=N7
      NOP(NE,5)=N9
      NOP(NE,6)=N6
      LMAT(NE)=M
      NE=NE+1
      NOP(NE,1)=N3
      NOP(NE,2)=N4
      NOP(NE,3)=N5
      NOP(NE,4)=N8
      NOP(NE,5)=N9
      NOP(NE,6)=N7
      LMAT(NE)=M
C
C---- Update polygon array
      IF(I.EQ.1) THEN
        NPOLY(NPTS)=N6
      ELSE
        NPOLY(I-1)=N6
      ENDIF
      NPOLY(I)=N9
      NPOLY(I+1)=N8
      ILO=I
      IF(I.EQ.IHI) ILO=1
      GOTO 30
  999 IF(NITSM.GT.0) CALL SMOOTH(NPOLD+1,NP,NEOLD+1,NE,NITSM)
      RETURN
      END
